// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'a_hint_of_bug.swagger.chopper.dart';
part 'a_hint_of_bug.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class AHintOfBug extends ChopperService {
  static AHintOfBug create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$AHintOfBug(client);
    }

    final newClient = ChopperClient(
        services: [_$AHintOfBug()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http:///api');
    return _$AHintOfBug(newClient);
  }

  ///
  ///@param payload
  ///@param X-Fields An optional fields mask
  Future<chopper.Response<AnimalResponse>> animalsPost({
    required AnimalData? payload,
    String? xFields,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AnimalData, () => AnimalData.fromJsonFactory);
    generatedMapping.putIfAbsent(
        AnimalResponse, () => AnimalResponse.fromJsonFactory);

    return _animalsPost(
        payload: payload, xFields: xFields, cacheControl: cacheControl);
  }

  ///
  ///@param payload
  ///@param X-Fields An optional fields mask
  @Post(path: '/animals/')
  Future<chopper.Response<AnimalResponse>> _animalsPost({
    @Body() required AnimalData? payload,
    @Header('X-Fields') String? xFields,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param updated_after
  ///@param X-Fields An optional fields mask
  Future<chopper.Response<List<AnimalResponse>>> animalsGet({
    String? updatedAfter,
    String? xFields,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AnimalResponse, () => AnimalResponse.fromJsonFactory);

    return _animalsGet(
        updatedAfter: updatedAfter,
        xFields: xFields,
        cacheControl: cacheControl);
  }

  ///
  ///@param updated_after
  ///@param X-Fields An optional fields mask
  @Get(path: '/animals/')
  Future<chopper.Response<List<AnimalResponse>>> _animalsGet({
    @Query('updated_after') String? updatedAfter,
    @Header('X-Fields') String? xFields,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param payload
  ///@param X-Fields An optional fields mask
  Future<chopper.Response<AnimalResponse>> animalsAnimalIdPut({
    required AnimalData? payload,
    String? xFields,
    required int? animalId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AnimalData, () => AnimalData.fromJsonFactory);
    generatedMapping.putIfAbsent(
        AnimalResponse, () => AnimalResponse.fromJsonFactory);

    return _animalsAnimalIdPut(
        payload: payload,
        xFields: xFields,
        animalId: animalId,
        cacheControl: cacheControl);
  }

  ///
  ///@param payload
  ///@param X-Fields An optional fields mask
  @Put(path: '/animals/{animal_id}')
  Future<chopper.Response<AnimalResponse>> _animalsAnimalIdPut({
    @Body() required AnimalData? payload,
    @Header('X-Fields') String? xFields,
    @Path('animal_id') required int? animalId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param X-Fields An optional fields mask
  Future<chopper.Response<AnimalResponse>> animalsAnimalIdGet({
    String? xFields,
    required int? animalId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AnimalResponse, () => AnimalResponse.fromJsonFactory);

    return _animalsAnimalIdGet(
        xFields: xFields, animalId: animalId, cacheControl: cacheControl);
  }

  ///
  ///@param X-Fields An optional fields mask
  @Get(path: '/animals/{animal_id}')
  Future<chopper.Response<AnimalResponse>> _animalsAnimalIdGet({
    @Header('X-Fields') String? xFields,
    @Path('animal_id') required int? animalId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param X-Fields An optional fields mask
  Future<chopper.Response<AnimalResponse>> animalsAnimalIdDelete({
    String? xFields,
    required int? animalId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AnimalResponse, () => AnimalResponse.fromJsonFactory);

    return _animalsAnimalIdDelete(
        xFields: xFields, animalId: animalId, cacheControl: cacheControl);
  }

  ///
  ///@param X-Fields An optional fields mask
  @Delete(path: '/animals/{animal_id}')
  Future<chopper.Response<AnimalResponse>> _animalsAnimalIdDelete({
    @Header('X-Fields') String? xFields,
    @Path('animal_id') required int? animalId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class AnimalData {
  AnimalData({
    required this.species,
    required this.age,
    required this.family,
    required this.name,
  });

  factory AnimalData.fromJson(Map<String, dynamic> json) =>
      _$AnimalDataFromJson(json);

  @JsonKey(name: 'species', includeIfNull: false, defaultValue: '')
  final String species;
  @JsonKey(name: 'age', includeIfNull: false)
  final int age;
  @JsonKey(name: 'family', includeIfNull: false, defaultValue: '')
  final String family;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$AnimalDataFromJson;
  static const toJsonFactory = _$AnimalDataToJson;
  Map<String, dynamic> toJson() => _$AnimalDataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AnimalData &&
            (identical(other.species, species) ||
                const DeepCollectionEquality()
                    .equals(other.species, species)) &&
            (identical(other.age, age) ||
                const DeepCollectionEquality().equals(other.age, age)) &&
            (identical(other.family, family) ||
                const DeepCollectionEquality().equals(other.family, family)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(species) ^
      const DeepCollectionEquality().hash(age) ^
      const DeepCollectionEquality().hash(family) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $AnimalDataExtension on AnimalData {
  AnimalData copyWith(
      {String? species, int? age, String? family, String? name}) {
    return AnimalData(
        species: species ?? this.species,
        age: age ?? this.age,
        family: family ?? this.family,
        name: name ?? this.name);
  }

  AnimalData copyWithWrapped(
      {Wrapped<String>? species,
      Wrapped<int>? age,
      Wrapped<String>? family,
      Wrapped<String>? name}) {
    return AnimalData(
        species: (species != null ? species.value : this.species),
        age: (age != null ? age.value : this.age),
        family: (family != null ? family.value : this.family),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class AnimalResponse {
  AnimalResponse({
    this.species,
    this.updatedAt,
    this.name,
    this.age,
    this.family,
    this.createdAt,
    this.id,
  });

  factory AnimalResponse.fromJson(Map<String, dynamic> json) =>
      _$AnimalResponseFromJson(json);

  @JsonKey(name: 'species', includeIfNull: false, defaultValue: '')
  final String? species;
  @JsonKey(name: 'updated_at', includeIfNull: false, defaultValue: '')
  final String? updatedAt;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'age', includeIfNull: false)
  final int? age;
  @JsonKey(name: 'family', includeIfNull: false, defaultValue: '')
  final String? family;
  @JsonKey(name: 'created_at', includeIfNull: false, defaultValue: '')
  final String? createdAt;
  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  static const fromJsonFactory = _$AnimalResponseFromJson;
  static const toJsonFactory = _$AnimalResponseToJson;
  Map<String, dynamic> toJson() => _$AnimalResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AnimalResponse &&
            (identical(other.species, species) ||
                const DeepCollectionEquality()
                    .equals(other.species, species)) &&
            (identical(other.updatedAt, updatedAt) ||
                const DeepCollectionEquality()
                    .equals(other.updatedAt, updatedAt)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.age, age) ||
                const DeepCollectionEquality().equals(other.age, age)) &&
            (identical(other.family, family) ||
                const DeepCollectionEquality().equals(other.family, family)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(species) ^
      const DeepCollectionEquality().hash(updatedAt) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(age) ^
      const DeepCollectionEquality().hash(family) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $AnimalResponseExtension on AnimalResponse {
  AnimalResponse copyWith(
      {String? species,
      String? updatedAt,
      String? name,
      int? age,
      String? family,
      String? createdAt,
      int? id}) {
    return AnimalResponse(
        species: species ?? this.species,
        updatedAt: updatedAt ?? this.updatedAt,
        name: name ?? this.name,
        age: age ?? this.age,
        family: family ?? this.family,
        createdAt: createdAt ?? this.createdAt,
        id: id ?? this.id);
  }

  AnimalResponse copyWithWrapped(
      {Wrapped<String?>? species,
      Wrapped<String?>? updatedAt,
      Wrapped<String?>? name,
      Wrapped<int?>? age,
      Wrapped<String?>? family,
      Wrapped<String?>? createdAt,
      Wrapped<int?>? id}) {
    return AnimalResponse(
        species: (species != null ? species.value : this.species),
        updatedAt: (updatedAt != null ? updatedAt.value : this.updatedAt),
        name: (name != null ? name.value : this.name),
        age: (age != null ? age.value : this.age),
        family: (family != null ? family.value : this.family),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        id: (id != null ? id.value : this.id));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
