// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'address_remote_data_source.swagger.chopper.dart';
part 'address_remote_data_source.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class AddressRemoteDataSource extends ChopperService {
  static AddressRemoteDataSource create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$AddressRemoteDataSource(client);
    }

    final newClient = ChopperClient(
        services: [_$AddressRemoteDataSource()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$AddressRemoteDataSource(newClient);
  }

  ///
  ///@param postalCode
  ///@param city
  ///@param street
  ///@param houseNumber
  ///@param houseNumberExtra
  Future<chopper.Response<AddressLookup>> v1AddressesLookupGet({
    required String? postalCode,
    String? city,
    String? street,
    int? houseNumber,
    String? houseNumberExtra,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AddressLookup, () => AddressLookup.fromJsonFactory);

    return _v1AddressesLookupGet(
        postalCode: postalCode,
        city: city,
        street: street,
        houseNumber: houseNumber,
        houseNumberExtra: houseNumberExtra,
        cacheControl: cacheControl);
  }

  ///
  ///@param postalCode
  ///@param city
  ///@param street
  ///@param houseNumber
  ///@param houseNumberExtra
  @Get(path: '/v1/addresses/lookup')
  Future<chopper.Response<AddressLookup>> _v1AddressesLookupGet({
    @Query('postalCode') required String? postalCode,
    @Query('city') String? city,
    @Query('street') String? street,
    @Query('houseNumber') int? houseNumber,
    @Query('houseNumberExtra') String? houseNumberExtra,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param x-application
  ///@param postalCode
  Future<chopper.Response<PostalCodeAvailablity>>
      v1AddressesPostalcodePostalCodeAvailabilityGet({
    String? xApplication,
    required String? postalCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PostalCodeAvailablity, () => PostalCodeAvailablity.fromJsonFactory);

    return _v1AddressesPostalcodePostalCodeAvailabilityGet(
        xApplication: xApplication,
        postalCode: postalCode,
        cacheControl: cacheControl);
  }

  ///
  ///@param x-application
  ///@param postalCode
  @Get(path: '/v1/addresses/postalcode/{postalCode}/availability')
  Future<chopper.Response<PostalCodeAvailablity>>
      _v1AddressesPostalcodePostalCodeAvailabilityGet({
    @Header('x-application') String? xApplication,
    @Path('postalCode') required String? postalCode,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class AddressLookup {
  AddressLookup({
    this.street,
    this.houseNumber,
    this.houseNumberExtra,
    required this.postalCode,
    this.city,
    required this.countryCode,
    this.cityOptions,
    this.streetOptions,
  });

  factory AddressLookup.fromJson(Map<String, dynamic> json) =>
      _$AddressLookupFromJson(json);

  @JsonKey(name: 'street', includeIfNull: false, defaultValue: '')
  final String? street;
  @JsonKey(name: 'houseNumber', includeIfNull: false)
  final int? houseNumber;
  @JsonKey(name: 'houseNumberExtra', includeIfNull: false, defaultValue: '')
  final String? houseNumberExtra;
  @JsonKey(name: 'postalCode', includeIfNull: false, defaultValue: '')
  final String postalCode;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String? city;
  @JsonKey(name: 'countryCode', includeIfNull: false, defaultValue: '')
  final String countryCode;
  @JsonKey(name: 'cityOptions', includeIfNull: false, defaultValue: <String>[])
  final List<String>? cityOptions;
  @JsonKey(
      name: 'streetOptions', includeIfNull: false, defaultValue: <String>[])
  final List<String>? streetOptions;
  static const fromJsonFactory = _$AddressLookupFromJson;
  static const toJsonFactory = _$AddressLookupToJson;
  Map<String, dynamic> toJson() => _$AddressLookupToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AddressLookup &&
            (identical(other.street, street) ||
                const DeepCollectionEquality().equals(other.street, street)) &&
            (identical(other.houseNumber, houseNumber) ||
                const DeepCollectionEquality()
                    .equals(other.houseNumber, houseNumber)) &&
            (identical(other.houseNumberExtra, houseNumberExtra) ||
                const DeepCollectionEquality()
                    .equals(other.houseNumberExtra, houseNumberExtra)) &&
            (identical(other.postalCode, postalCode) ||
                const DeepCollectionEquality()
                    .equals(other.postalCode, postalCode)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.countryCode, countryCode) ||
                const DeepCollectionEquality()
                    .equals(other.countryCode, countryCode)) &&
            (identical(other.cityOptions, cityOptions) ||
                const DeepCollectionEquality()
                    .equals(other.cityOptions, cityOptions)) &&
            (identical(other.streetOptions, streetOptions) ||
                const DeepCollectionEquality()
                    .equals(other.streetOptions, streetOptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(street) ^
      const DeepCollectionEquality().hash(houseNumber) ^
      const DeepCollectionEquality().hash(houseNumberExtra) ^
      const DeepCollectionEquality().hash(postalCode) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(countryCode) ^
      const DeepCollectionEquality().hash(cityOptions) ^
      const DeepCollectionEquality().hash(streetOptions) ^
      runtimeType.hashCode;
}

extension $AddressLookupExtension on AddressLookup {
  AddressLookup copyWith(
      {String? street,
      int? houseNumber,
      String? houseNumberExtra,
      String? postalCode,
      String? city,
      String? countryCode,
      List<String>? cityOptions,
      List<String>? streetOptions}) {
    return AddressLookup(
        street: street ?? this.street,
        houseNumber: houseNumber ?? this.houseNumber,
        houseNumberExtra: houseNumberExtra ?? this.houseNumberExtra,
        postalCode: postalCode ?? this.postalCode,
        city: city ?? this.city,
        countryCode: countryCode ?? this.countryCode,
        cityOptions: cityOptions ?? this.cityOptions,
        streetOptions: streetOptions ?? this.streetOptions);
  }

  AddressLookup copyWithWrapped(
      {Wrapped<String?>? street,
      Wrapped<int?>? houseNumber,
      Wrapped<String?>? houseNumberExtra,
      Wrapped<String>? postalCode,
      Wrapped<String?>? city,
      Wrapped<String>? countryCode,
      Wrapped<List<String>?>? cityOptions,
      Wrapped<List<String>?>? streetOptions}) {
    return AddressLookup(
        street: (street != null ? street.value : this.street),
        houseNumber:
            (houseNumber != null ? houseNumber.value : this.houseNumber),
        houseNumberExtra: (houseNumberExtra != null
            ? houseNumberExtra.value
            : this.houseNumberExtra),
        postalCode: (postalCode != null ? postalCode.value : this.postalCode),
        city: (city != null ? city.value : this.city),
        countryCode:
            (countryCode != null ? countryCode.value : this.countryCode),
        cityOptions:
            (cityOptions != null ? cityOptions.value : this.cityOptions),
        streetOptions:
            (streetOptions != null ? streetOptions.value : this.streetOptions));
  }
}

@JsonSerializable(explicitToJson: true)
class PostalCodeAvailablity {
  PostalCodeAvailablity({
    required this.available,
  });

  factory PostalCodeAvailablity.fromJson(Map<String, dynamic> json) =>
      _$PostalCodeAvailablityFromJson(json);

  @JsonKey(name: 'available', includeIfNull: false)
  final bool available;
  static const fromJsonFactory = _$PostalCodeAvailablityFromJson;
  static const toJsonFactory = _$PostalCodeAvailablityToJson;
  Map<String, dynamic> toJson() => _$PostalCodeAvailablityToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostalCodeAvailablity &&
            (identical(other.available, available) ||
                const DeepCollectionEquality()
                    .equals(other.available, available)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(available) ^ runtimeType.hashCode;
}

extension $PostalCodeAvailablityExtension on PostalCodeAvailablity {
  PostalCodeAvailablity copyWith({bool? available}) {
    return PostalCodeAvailablity(available: available ?? this.available);
  }

  PostalCodeAvailablity copyWithWrapped({Wrapped<bool>? available}) {
    return PostalCodeAvailablity(
        available: (available != null ? available.value : this.available));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
