// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'anton_swagger.enums.swagger.dart' as enums;
export 'anton_swagger.enums.swagger.dart';

part 'anton_swagger.swagger.chopper.dart';
part 'anton_swagger.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class AntonSwagger extends ChopperService {
  static AntonSwagger create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$AntonSwagger(client);
    }

    final newClient = ChopperClient(
        services: [_$AntonSwagger()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://localhost:8015/');
    return _$AntonSwagger(newClient);
  }

  ///get list of enrollments
  ///@param externalMemberId external member id
  Future<chopper.Response<List<Enrollment>>>
      loyaltyApiV1MemberExternalMemberIdEnrollmentsGet({
    required String? externalMemberId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Enrollment, () => Enrollment.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdEnrollmentsGet(
        externalMemberId: externalMemberId, cacheControl: cacheControl);
  }

  ///get list of enrollments
  ///@param externalMemberId external member id
  @Get(path: '/loyalty/api/v1/member/{externalMemberId}/enrollments')
  Future<chopper.Response<List<Enrollment>>>
      _loyaltyApiV1MemberExternalMemberIdEnrollmentsGet({
    @Path('externalMemberId') required String? externalMemberId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get list of offers
  ///@param externalMemberId external member id
  ///@param offerTypes set of offer types
  ///@param page zero-based page index
  ///@param size maximum number of records to return
  ///@param channel channel
  ///@param active active offers only indicator
  ///@param readyToClaim ready to claim offers only indicator
  Future<chopper.Response<List<Offer>>>
      loyaltyApiV1MemberExternalMemberIdOffersGet({
    required String? externalMemberId,
    enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes? offerTypes,
    int? page,
    int? size,
    required String? channel,
    bool? active,
    bool? readyToClaim,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Offer, () => Offer.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersGet(
        externalMemberId: externalMemberId,
        offerTypes: enums
            .$LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesMap[
                offerTypes]
            ?.toString(),
        page: page,
        size: size,
        channel: channel,
        active: active,
        readyToClaim: readyToClaim,
        cacheControl: cacheControl);
  }

  ///get list of offers
  ///@param externalMemberId external member id
  ///@param offerTypes set of offer types
  ///@param page zero-based page index
  ///@param size maximum number of records to return
  ///@param channel channel
  ///@param active active offers only indicator
  ///@param readyToClaim ready to claim offers only indicator
  @Get(path: '/loyalty/api/v1/member/{externalMemberId}/offers')
  Future<chopper.Response<List<Offer>>>
      _loyaltyApiV1MemberExternalMemberIdOffersGet({
    @Path('externalMemberId') required String? externalMemberId,
    @Query('offerTypes') String? offerTypes,
    @Query('page') int? page,
    @Query('size') int? size,
    @Query('channel') required String? channel,
    @Query('active') bool? active,
    @Query('readyToClaim') bool? readyToClaim,
    @Header('Cache-Control') String? cacheControl,
  });

  ///confirm offer claim
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param offerClaimId offer claim id
  Future<chopper.Response>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdClaimsOfferClaimIdConfirmPost({
    required String? externalMemberId,
    required int? offerId,
    required int? offerClaimId,
    String? cacheControl,
  }) {
    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdClaimsOfferClaimIdConfirmPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        offerClaimId: offerClaimId,
        cacheControl: cacheControl);
  }

  ///confirm offer claim
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param offerClaimId offer claim id
  @Post(
    path:
        '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/claims/{offerClaimId}/confirm',
    optionalBody: true,
  )
  Future<chopper.Response>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdClaimsOfferClaimIdConfirmPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Path('offerClaimId') required int? offerClaimId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get education offer completion
  ///@param externalMemberId external member id
  ///@param offerId offer id
  Future<chopper.Response<OfferConfirmation>>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdEducationGet({
    required String? externalMemberId,
    required int? offerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        OfferConfirmation, () => OfferConfirmation.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEducationGet(
        externalMemberId: externalMemberId,
        offerId: offerId,
        cacheControl: cacheControl);
  }

  ///get education offer completion
  ///@param externalMemberId external member id
  ///@param offerId offer id
  @Get(
      path:
          '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/education')
  Future<chopper.Response<OfferConfirmation>>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEducationGet({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///confirm education offer
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param education education
  Future<chopper.Response<OfferConfirmation>>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdEducationConfirmPost({
    required String? externalMemberId,
    required int? offerId,
    required Education? education,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Education, () => Education.fromJsonFactory);
    generatedMapping.putIfAbsent(
        OfferConfirmation, () => OfferConfirmation.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEducationConfirmPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        education: education,
        cacheControl: cacheControl);
  }

  ///confirm education offer
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param education education
  @Post(
      path:
          '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/education/confirm')
  Future<chopper.Response<OfferConfirmation>>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEducationConfirmPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Body() required Education? education,
    @Header('Cache-Control') String? cacheControl,
  });

  ///cancel offer enrollment
  ///@param externalMemberId external member id
  ///@param offerId offer id
  Future<chopper.Response>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdEnrollmentCancelPost({
    required String? externalMemberId,
    required int? offerId,
    String? cacheControl,
  }) {
    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEnrollmentCancelPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        cacheControl: cacheControl);
  }

  ///cancel offer enrollment
  ///@param externalMemberId external member id
  ///@param offerId offer id
  @Post(
    path:
        '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/enrollment/cancel',
    optionalBody: true,
  )
  Future<chopper.Response>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEnrollmentCancelPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///confirm offer enrollment
  ///@param externalMemberId external member id
  ///@param offerId offer id
  Future<chopper.Response>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdEnrollmentConfirmPost({
    required String? externalMemberId,
    required int? offerId,
    String? cacheControl,
  }) {
    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEnrollmentConfirmPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        cacheControl: cacheControl);
  }

  ///confirm offer enrollment
  ///@param externalMemberId external member id
  ///@param offerId offer id
  @Post(
    path:
        '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/enrollment/confirm',
    optionalBody: true,
  )
  Future<chopper.Response>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdEnrollmentConfirmPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get party offer completion
  ///@param externalMemberId external member id
  ///@param offerId offer id
  Future<chopper.Response<OfferConfirmation>>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdPartyGet({
    required String? externalMemberId,
    required int? offerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        OfferConfirmation, () => OfferConfirmation.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdPartyGet(
        externalMemberId: externalMemberId,
        offerId: offerId,
        cacheControl: cacheControl);
  }

  ///get party offer completion
  ///@param externalMemberId external member id
  ///@param offerId offer id
  @Get(path: '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/party')
  Future<chopper.Response<OfferConfirmation>>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdPartyGet({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///confirm offer party
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param party party
  Future<chopper.Response<OfferConfirmation>>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdPartyConfirmPost({
    required String? externalMemberId,
    required int? offerId,
    required Party? party,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Party, () => Party.fromJsonFactory);
    generatedMapping.putIfAbsent(
        OfferConfirmation, () => OfferConfirmation.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdPartyConfirmPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        party: party,
        cacheControl: cacheControl);
  }

  ///confirm offer party
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param party party
  @Post(
      path:
          '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/party/confirm')
  Future<chopper.Response<OfferConfirmation>>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdPartyConfirmPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Body() required Party? party,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get quiz offer confirmation
  ///@param externalMemberId external member id
  ///@param offerId offer id
  Future<chopper.Response<OfferConfirmation>>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdQuizGet({
    required String? externalMemberId,
    required int? offerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        OfferConfirmation, () => OfferConfirmation.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdQuizGet(
        externalMemberId: externalMemberId,
        offerId: offerId,
        cacheControl: cacheControl);
  }

  ///get quiz offer confirmation
  ///@param externalMemberId external member id
  ///@param offerId offer id
  @Get(path: '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/quiz')
  Future<chopper.Response<OfferConfirmation>>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdQuizGet({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///confirm offer quiz
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param quiz quiz
  Future<chopper.Response<OfferConfirmation>>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdQuizConfirmPost({
    required String? externalMemberId,
    required int? offerId,
    required Quiz? quiz,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Quiz, () => Quiz.fromJsonFactory);
    generatedMapping.putIfAbsent(
        OfferConfirmation, () => OfferConfirmation.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdQuizConfirmPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        quiz: quiz,
        cacheControl: cacheControl);
  }

  ///confirm offer quiz
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param quiz quiz
  @Post(
      path:
          '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/quiz/confirm')
  Future<chopper.Response<OfferConfirmation>>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdQuizConfirmPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Body() required Quiz? quiz,
    @Header('Cache-Control') String? cacheControl,
  });

  ///confirm referral
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param referMember referMember
  Future<chopper.Response>
      loyaltyApiV1MemberExternalMemberIdOffersOfferIdReferralConfirmPost({
    required String? externalMemberId,
    required int? offerId,
    required ReferMember? referMember,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReferMember, () => ReferMember.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdOffersOfferIdReferralConfirmPost(
        externalMemberId: externalMemberId,
        offerId: offerId,
        referMember: referMember,
        cacheControl: cacheControl);
  }

  ///confirm referral
  ///@param externalMemberId external member id
  ///@param offerId offer id
  ///@param referMember referMember
  @Post(
      path:
          '/loyalty/api/v1/member/{externalMemberId}/offers/{offerId}/referral/confirm')
  Future<chopper.Response>
      _loyaltyApiV1MemberExternalMemberIdOffersOfferIdReferralConfirmPost({
    @Path('externalMemberId') required String? externalMemberId,
    @Path('offerId') required int? offerId,
    @Body() required ReferMember? referMember,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get list of referrals
  ///@param externalMemberId external member id
  Future<chopper.Response<List<Enrollment>>>
      loyaltyApiV1MemberExternalMemberIdReferralsGet({
    required String? externalMemberId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Enrollment, () => Enrollment.fromJsonFactory);

    return _loyaltyApiV1MemberExternalMemberIdReferralsGet(
        externalMemberId: externalMemberId, cacheControl: cacheControl);
  }

  ///get list of referrals
  ///@param externalMemberId external member id
  @Get(path: '/loyalty/api/v1/member/{externalMemberId}/referrals')
  Future<chopper.Response<List<Enrollment>>>
      _loyaltyApiV1MemberExternalMemberIdReferralsGet({
    @Path('externalMemberId') required String? externalMemberId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Education {
  Education({
    this.confirmation,
  });

  factory Education.fromJson(Map<String, dynamic> json) =>
      _$EducationFromJson(json);

  @JsonKey(name: 'confirmation', includeIfNull: false, defaultValue: '')
  final String? confirmation;
  static const fromJsonFactory = _$EducationFromJson;
  static const toJsonFactory = _$EducationToJson;
  Map<String, dynamic> toJson() => _$EducationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Education &&
            (identical(other.confirmation, confirmation) ||
                const DeepCollectionEquality()
                    .equals(other.confirmation, confirmation)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(confirmation) ^ runtimeType.hashCode;
}

extension $EducationExtension on Education {
  Education copyWith({String? confirmation}) {
    return Education(confirmation: confirmation ?? this.confirmation);
  }

  Education copyWithWrapped({Wrapped<String?>? confirmation}) {
    return Education(
        confirmation:
            (confirmation != null ? confirmation.value : this.confirmation));
  }
}

@JsonSerializable(explicitToJson: true)
class Enrollment {
  Enrollment({
    this.enrolledAt,
    this.offerId,
  });

  factory Enrollment.fromJson(Map<String, dynamic> json) =>
      _$EnrollmentFromJson(json);

  @JsonKey(name: 'enrolledAt', includeIfNull: false)
  final DateTime? enrolledAt;
  @JsonKey(name: 'offerId', includeIfNull: false)
  final num? offerId;
  static const fromJsonFactory = _$EnrollmentFromJson;
  static const toJsonFactory = _$EnrollmentToJson;
  Map<String, dynamic> toJson() => _$EnrollmentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Enrollment &&
            (identical(other.enrolledAt, enrolledAt) ||
                const DeepCollectionEquality()
                    .equals(other.enrolledAt, enrolledAt)) &&
            (identical(other.offerId, offerId) ||
                const DeepCollectionEquality().equals(other.offerId, offerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(enrolledAt) ^
      const DeepCollectionEquality().hash(offerId) ^
      runtimeType.hashCode;
}

extension $EnrollmentExtension on Enrollment {
  Enrollment copyWith({DateTime? enrolledAt, num? offerId}) {
    return Enrollment(
        enrolledAt: enrolledAt ?? this.enrolledAt,
        offerId: offerId ?? this.offerId);
  }

  Enrollment copyWithWrapped(
      {Wrapped<DateTime?>? enrolledAt, Wrapped<num?>? offerId}) {
    return Enrollment(
        enrolledAt: (enrolledAt != null ? enrolledAt.value : this.enrolledAt),
        offerId: (offerId != null ? offerId.value : this.offerId));
  }
}

@JsonSerializable(explicitToJson: true)
class Offer {
  Offer({
    this.claimId,
    this.cmsId,
    this.endDate,
    this.enrolled,
    this.id,
    this.largeImageUrl,
    this.longDescription,
    this.mediumImageUrl,
    this.points,
    this.readyToClaim,
    this.shortDescription,
    this.smallImageUrl,
    this.startDate,
    this.title,
    this.toClaim,
    this.toEnroll,
    this.type,
  });

  factory Offer.fromJson(Map<String, dynamic> json) => _$OfferFromJson(json);

  @JsonKey(name: 'claimId', includeIfNull: false)
  final num? claimId;
  @JsonKey(name: 'cmsId', includeIfNull: false)
  final num? cmsId;
  @JsonKey(name: 'endDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? endDate;
  @JsonKey(name: 'enrolled', includeIfNull: false)
  final bool? enrolled;
  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'largeImageUrl', includeIfNull: false, defaultValue: '')
  final String? largeImageUrl;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'mediumImageUrl', includeIfNull: false, defaultValue: '')
  final String? mediumImageUrl;
  @JsonKey(name: 'points', includeIfNull: false)
  final int? points;
  @JsonKey(name: 'readyToClaim', includeIfNull: false)
  final bool? readyToClaim;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'smallImageUrl', includeIfNull: false, defaultValue: '')
  final String? smallImageUrl;
  @JsonKey(name: 'startDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? startDate;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'toClaim', includeIfNull: false)
  final bool? toClaim;
  @JsonKey(name: 'toEnroll', includeIfNull: false)
  final bool? toEnroll;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: offerTypeToJson,
    fromJson: offerTypeFromJson,
  )
  final enums.OfferType? type;
  static const fromJsonFactory = _$OfferFromJson;
  static const toJsonFactory = _$OfferToJson;
  Map<String, dynamic> toJson() => _$OfferToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Offer &&
            (identical(other.claimId, claimId) ||
                const DeepCollectionEquality()
                    .equals(other.claimId, claimId)) &&
            (identical(other.cmsId, cmsId) ||
                const DeepCollectionEquality().equals(other.cmsId, cmsId)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.enrolled, enrolled) ||
                const DeepCollectionEquality()
                    .equals(other.enrolled, enrolled)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.largeImageUrl, largeImageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.largeImageUrl, largeImageUrl)) &&
            (identical(other.longDescription, longDescription) ||
                const DeepCollectionEquality()
                    .equals(other.longDescription, longDescription)) &&
            (identical(other.mediumImageUrl, mediumImageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.mediumImageUrl, mediumImageUrl)) &&
            (identical(other.points, points) ||
                const DeepCollectionEquality().equals(other.points, points)) &&
            (identical(other.readyToClaim, readyToClaim) ||
                const DeepCollectionEquality()
                    .equals(other.readyToClaim, readyToClaim)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.smallImageUrl, smallImageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.smallImageUrl, smallImageUrl)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.toClaim, toClaim) ||
                const DeepCollectionEquality()
                    .equals(other.toClaim, toClaim)) &&
            (identical(other.toEnroll, toEnroll) ||
                const DeepCollectionEquality()
                    .equals(other.toEnroll, toEnroll)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(claimId) ^
      const DeepCollectionEquality().hash(cmsId) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(enrolled) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(largeImageUrl) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(mediumImageUrl) ^
      const DeepCollectionEquality().hash(points) ^
      const DeepCollectionEquality().hash(readyToClaim) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(smallImageUrl) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(toClaim) ^
      const DeepCollectionEquality().hash(toEnroll) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $OfferExtension on Offer {
  Offer copyWith(
      {num? claimId,
      num? cmsId,
      DateTime? endDate,
      bool? enrolled,
      num? id,
      String? largeImageUrl,
      String? longDescription,
      String? mediumImageUrl,
      int? points,
      bool? readyToClaim,
      String? shortDescription,
      String? smallImageUrl,
      DateTime? startDate,
      String? title,
      bool? toClaim,
      bool? toEnroll,
      enums.OfferType? type}) {
    return Offer(
        claimId: claimId ?? this.claimId,
        cmsId: cmsId ?? this.cmsId,
        endDate: endDate ?? this.endDate,
        enrolled: enrolled ?? this.enrolled,
        id: id ?? this.id,
        largeImageUrl: largeImageUrl ?? this.largeImageUrl,
        longDescription: longDescription ?? this.longDescription,
        mediumImageUrl: mediumImageUrl ?? this.mediumImageUrl,
        points: points ?? this.points,
        readyToClaim: readyToClaim ?? this.readyToClaim,
        shortDescription: shortDescription ?? this.shortDescription,
        smallImageUrl: smallImageUrl ?? this.smallImageUrl,
        startDate: startDate ?? this.startDate,
        title: title ?? this.title,
        toClaim: toClaim ?? this.toClaim,
        toEnroll: toEnroll ?? this.toEnroll,
        type: type ?? this.type);
  }

  Offer copyWithWrapped(
      {Wrapped<num?>? claimId,
      Wrapped<num?>? cmsId,
      Wrapped<DateTime?>? endDate,
      Wrapped<bool?>? enrolled,
      Wrapped<num?>? id,
      Wrapped<String?>? largeImageUrl,
      Wrapped<String?>? longDescription,
      Wrapped<String?>? mediumImageUrl,
      Wrapped<int?>? points,
      Wrapped<bool?>? readyToClaim,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? smallImageUrl,
      Wrapped<DateTime?>? startDate,
      Wrapped<String?>? title,
      Wrapped<bool?>? toClaim,
      Wrapped<bool?>? toEnroll,
      Wrapped<enums.OfferType?>? type}) {
    return Offer(
        claimId: (claimId != null ? claimId.value : this.claimId),
        cmsId: (cmsId != null ? cmsId.value : this.cmsId),
        endDate: (endDate != null ? endDate.value : this.endDate),
        enrolled: (enrolled != null ? enrolled.value : this.enrolled),
        id: (id != null ? id.value : this.id),
        largeImageUrl:
            (largeImageUrl != null ? largeImageUrl.value : this.largeImageUrl),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        mediumImageUrl: (mediumImageUrl != null
            ? mediumImageUrl.value
            : this.mediumImageUrl),
        points: (points != null ? points.value : this.points),
        readyToClaim:
            (readyToClaim != null ? readyToClaim.value : this.readyToClaim),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        smallImageUrl:
            (smallImageUrl != null ? smallImageUrl.value : this.smallImageUrl),
        startDate: (startDate != null ? startDate.value : this.startDate),
        title: (title != null ? title.value : this.title),
        toClaim: (toClaim != null ? toClaim.value : this.toClaim),
        toEnroll: (toEnroll != null ? toEnroll.value : this.toEnroll),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class OfferConfirmation {
  OfferConfirmation({
    this.completionStatus,
    this.confirmationId,
    this.offerId,
  });

  factory OfferConfirmation.fromJson(Map<String, dynamic> json) =>
      _$OfferConfirmationFromJson(json);

  @JsonKey(
    name: 'completionStatus',
    includeIfNull: false,
    toJson: offerConfirmationCompletionStatusToJson,
    fromJson: offerConfirmationCompletionStatusFromJson,
  )
  final enums.OfferConfirmationCompletionStatus? completionStatus;
  @JsonKey(name: 'confirmationId', includeIfNull: false)
  final num? confirmationId;
  @JsonKey(name: 'offerId', includeIfNull: false)
  final num? offerId;
  static const fromJsonFactory = _$OfferConfirmationFromJson;
  static const toJsonFactory = _$OfferConfirmationToJson;
  Map<String, dynamic> toJson() => _$OfferConfirmationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OfferConfirmation &&
            (identical(other.completionStatus, completionStatus) ||
                const DeepCollectionEquality()
                    .equals(other.completionStatus, completionStatus)) &&
            (identical(other.confirmationId, confirmationId) ||
                const DeepCollectionEquality()
                    .equals(other.confirmationId, confirmationId)) &&
            (identical(other.offerId, offerId) ||
                const DeepCollectionEquality().equals(other.offerId, offerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(completionStatus) ^
      const DeepCollectionEquality().hash(confirmationId) ^
      const DeepCollectionEquality().hash(offerId) ^
      runtimeType.hashCode;
}

extension $OfferConfirmationExtension on OfferConfirmation {
  OfferConfirmation copyWith(
      {enums.OfferConfirmationCompletionStatus? completionStatus,
      num? confirmationId,
      num? offerId}) {
    return OfferConfirmation(
        completionStatus: completionStatus ?? this.completionStatus,
        confirmationId: confirmationId ?? this.confirmationId,
        offerId: offerId ?? this.offerId);
  }

  OfferConfirmation copyWithWrapped(
      {Wrapped<enums.OfferConfirmationCompletionStatus?>? completionStatus,
      Wrapped<num?>? confirmationId,
      Wrapped<num?>? offerId}) {
    return OfferConfirmation(
        completionStatus: (completionStatus != null
            ? completionStatus.value
            : this.completionStatus),
        confirmationId: (confirmationId != null
            ? confirmationId.value
            : this.confirmationId),
        offerId: (offerId != null ? offerId.value : this.offerId));
  }
}

@JsonSerializable(explicitToJson: true)
class Party {
  Party({
    this.confirmation,
  });

  factory Party.fromJson(Map<String, dynamic> json) => _$PartyFromJson(json);

  @JsonKey(name: 'confirmation', includeIfNull: false, defaultValue: '')
  final String? confirmation;
  static const fromJsonFactory = _$PartyFromJson;
  static const toJsonFactory = _$PartyToJson;
  Map<String, dynamic> toJson() => _$PartyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Party &&
            (identical(other.confirmation, confirmation) ||
                const DeepCollectionEquality()
                    .equals(other.confirmation, confirmation)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(confirmation) ^ runtimeType.hashCode;
}

extension $PartyExtension on Party {
  Party copyWith({String? confirmation}) {
    return Party(confirmation: confirmation ?? this.confirmation);
  }

  Party copyWithWrapped({Wrapped<String?>? confirmation}) {
    return Party(
        confirmation:
            (confirmation != null ? confirmation.value : this.confirmation));
  }
}

@JsonSerializable(explicitToJson: true)
class Quiz {
  Quiz();

  factory Quiz.fromJson(Map<String, dynamic> json) => _$QuizFromJson(json);

  static const fromJsonFactory = _$QuizFromJson;
  static const toJsonFactory = _$QuizToJson;
  Map<String, dynamic> toJson() => _$QuizToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class ReferMember {
  ReferMember({
    this.email,
    this.firstName,
    this.lastName,
    this.message,
    this.phone,
  });

  factory ReferMember.fromJson(Map<String, dynamic> json) =>
      _$ReferMemberFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  static const fromJsonFactory = _$ReferMemberFromJson;
  static const toJsonFactory = _$ReferMemberToJson;
  Map<String, dynamic> toJson() => _$ReferMemberToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReferMember &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(phone) ^
      runtimeType.hashCode;
}

extension $ReferMemberExtension on ReferMember {
  ReferMember copyWith(
      {String? email,
      String? firstName,
      String? lastName,
      String? message,
      String? phone}) {
    return ReferMember(
        email: email ?? this.email,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        message: message ?? this.message,
        phone: phone ?? this.phone);
  }

  ReferMember copyWithWrapped(
      {Wrapped<String?>? email,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? message,
      Wrapped<String?>? phone}) {
    return ReferMember(
        email: (email != null ? email.value : this.email),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        message: (message != null ? message.value : this.message),
        phone: (phone != null ? phone.value : this.phone));
  }
}

@JsonSerializable(explicitToJson: true)
class Referral {
  Referral({
    this.offerId,
    this.referralCode,
  });

  factory Referral.fromJson(Map<String, dynamic> json) =>
      _$ReferralFromJson(json);

  @JsonKey(name: 'offerId', includeIfNull: false)
  final num? offerId;
  @JsonKey(name: 'referralCode', includeIfNull: false, defaultValue: '')
  final String? referralCode;
  static const fromJsonFactory = _$ReferralFromJson;
  static const toJsonFactory = _$ReferralToJson;
  Map<String, dynamic> toJson() => _$ReferralToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Referral &&
            (identical(other.offerId, offerId) ||
                const DeepCollectionEquality()
                    .equals(other.offerId, offerId)) &&
            (identical(other.referralCode, referralCode) ||
                const DeepCollectionEquality()
                    .equals(other.referralCode, referralCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(offerId) ^
      const DeepCollectionEquality().hash(referralCode) ^
      runtimeType.hashCode;
}

extension $ReferralExtension on Referral {
  Referral copyWith({num? offerId, String? referralCode}) {
    return Referral(
        offerId: offerId ?? this.offerId,
        referralCode: referralCode ?? this.referralCode);
  }

  Referral copyWithWrapped(
      {Wrapped<num?>? offerId, Wrapped<String?>? referralCode}) {
    return Referral(
        offerId: (offerId != null ? offerId.value : this.offerId),
        referralCode:
            (referralCode != null ? referralCode.value : this.referralCode));
  }
}

@JsonSerializable(explicitToJson: true)
class Status {
  Status({
    this.causedMessage,
    this.errorMessage,
  });

  factory Status.fromJson(Map<String, dynamic> json) => _$StatusFromJson(json);

  @JsonKey(name: 'causedMessage', includeIfNull: false, defaultValue: '')
  final String? causedMessage;
  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  static const fromJsonFactory = _$StatusFromJson;
  static const toJsonFactory = _$StatusToJson;
  Map<String, dynamic> toJson() => _$StatusToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Status &&
            (identical(other.causedMessage, causedMessage) ||
                const DeepCollectionEquality()
                    .equals(other.causedMessage, causedMessage)) &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(causedMessage) ^
      const DeepCollectionEquality().hash(errorMessage) ^
      runtimeType.hashCode;
}

extension $StatusExtension on Status {
  Status copyWith({String? causedMessage, String? errorMessage}) {
    return Status(
        causedMessage: causedMessage ?? this.causedMessage,
        errorMessage: errorMessage ?? this.errorMessage);
  }

  Status copyWithWrapped(
      {Wrapped<String?>? causedMessage, Wrapped<String?>? errorMessage}) {
    return Status(
        causedMessage:
            (causedMessage != null ? causedMessage.value : this.causedMessage),
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage));
  }
}

String? loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesToJson(
    enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes?
        loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes) {
  return enums.$LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesMap[
      loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes];
}

enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
    loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesFromJson(
  Object? loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes, [
  enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes? defaultValue,
]) {
  if (loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes is String) {
    return enums
        .$LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
          .swaggerGeneratedUnknown;
}

List<String> loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesListToJson(
    List<enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes>?
        loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes) {
  if (loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes == null) {
    return [];
  }

  return loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
      .map((e) =>
          enums.$LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesMap[e]!)
      .toList();
}

List<enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes>
    loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesListFromJson(
  List? loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes, [
  List<enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes>?
      defaultValue,
]) {
  if (loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes == null) {
    return defaultValue ?? [];
  }

  return loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
      .map((e) => loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesFromJson(
          e.toString()))
      .toList();
}

List<enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes>?
    loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesNullableListFromJson(
  List? loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes, [
  List<enums.LoyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes>?
      defaultValue,
]) {
  if (loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes == null) {
    return defaultValue;
  }

  return loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypes
      .map((e) => loyaltyApiV1MemberExternalMemberIdOffersGetOfferTypesFromJson(
          e.toString()))
      .toList();
}

String? offerTypeToJson(enums.OfferType? offerType) {
  return enums.$OfferTypeMap[offerType];
}

enums.OfferType offerTypeFromJson(
  Object? offerType, [
  enums.OfferType? defaultValue,
]) {
  if (offerType is String) {
    return enums.$OfferTypeMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == offerType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.OfferType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$OfferTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.OfferType.swaggerGeneratedUnknown;
}

List<String> offerTypeListToJson(List<enums.OfferType>? offerType) {
  if (offerType == null) {
    return [];
  }

  return offerType.map((e) => enums.$OfferTypeMap[e]!).toList();
}

List<enums.OfferType> offerTypeListFromJson(
  List? offerType, [
  List<enums.OfferType>? defaultValue,
]) {
  if (offerType == null) {
    return defaultValue ?? [];
  }

  return offerType.map((e) => offerTypeFromJson(e.toString())).toList();
}

List<enums.OfferType>? offerTypeNullableListFromJson(
  List? offerType, [
  List<enums.OfferType>? defaultValue,
]) {
  if (offerType == null) {
    return defaultValue;
  }

  return offerType.map((e) => offerTypeFromJson(e.toString())).toList();
}

String? offerConfirmationCompletionStatusToJson(
    enums.OfferConfirmationCompletionStatus?
        offerConfirmationCompletionStatus) {
  return enums
      .$OfferConfirmationCompletionStatusMap[offerConfirmationCompletionStatus];
}

enums.OfferConfirmationCompletionStatus
    offerConfirmationCompletionStatusFromJson(
  Object? offerConfirmationCompletionStatus, [
  enums.OfferConfirmationCompletionStatus? defaultValue,
]) {
  if (offerConfirmationCompletionStatus is String) {
    return enums.$OfferConfirmationCompletionStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                offerConfirmationCompletionStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.OfferConfirmationCompletionStatus.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$OfferConfirmationCompletionStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.OfferConfirmationCompletionStatus.swaggerGeneratedUnknown;
}

List<String> offerConfirmationCompletionStatusListToJson(
    List<enums.OfferConfirmationCompletionStatus>?
        offerConfirmationCompletionStatus) {
  if (offerConfirmationCompletionStatus == null) {
    return [];
  }

  return offerConfirmationCompletionStatus
      .map((e) => enums.$OfferConfirmationCompletionStatusMap[e]!)
      .toList();
}

List<enums.OfferConfirmationCompletionStatus>
    offerConfirmationCompletionStatusListFromJson(
  List? offerConfirmationCompletionStatus, [
  List<enums.OfferConfirmationCompletionStatus>? defaultValue,
]) {
  if (offerConfirmationCompletionStatus == null) {
    return defaultValue ?? [];
  }

  return offerConfirmationCompletionStatus
      .map((e) => offerConfirmationCompletionStatusFromJson(e.toString()))
      .toList();
}

List<enums.OfferConfirmationCompletionStatus>?
    offerConfirmationCompletionStatusNullableListFromJson(
  List? offerConfirmationCompletionStatus, [
  List<enums.OfferConfirmationCompletionStatus>? defaultValue,
]) {
  if (offerConfirmationCompletionStatus == null) {
    return defaultValue;
  }

  return offerConfirmationCompletionStatus
      .map((e) => offerConfirmationCompletionStatusFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
