// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'api_service.enums.swagger.dart' as enums;
export 'api_service.enums.swagger.dart';

part 'api_service.swagger.chopper.dart';
part 'api_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ApiService extends ChopperService {
  static ApiService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ApiService(client);
    }

    final newClient = ChopperClient(
        services: [_$ApiService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$ApiService(newClient);
  }

  ///gets account data
  Future<chopper.Response<AccountModel>> apiAccountGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AccountModel, () => AccountModel.fromJsonFactory);

    return _apiAccountGet(cacheControl: cacheControl);
  }

  ///gets account data
  @Get(path: '/api/Account')
  Future<chopper.Response<AccountModel>> _apiAccountGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets drs account data
  Future<chopper.Response<DrsAccountModel>> apiAccountDrsGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        DrsAccountModel, () => DrsAccountModel.fromJsonFactory);

    return _apiAccountDrsGet(cacheControl: cacheControl);
  }

  ///gets drs account data
  @Get(path: '/api/Account/drs')
  Future<chopper.Response<DrsAccountModel>> _apiAccountDrsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets amounts by categories
  Future<chopper.Response<List<AmountByCategories>>>
      apiAccountAmountsCategoriesGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AmountByCategories, () => AmountByCategories.fromJsonFactory);

    return _apiAccountAmountsCategoriesGet(cacheControl: cacheControl);
  }

  ///gets amounts by categories
  @Get(path: '/api/Account/amounts-categories')
  Future<chopper.Response<List<AmountByCategories>>>
      _apiAccountAmountsCategoriesGet(
          {@Header('Cache-Control') String? cacheControl});

  ///gets account info data
  Future<chopper.Response<AccountInfoModel>> apiAccountInfoGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AccountInfoModel, () => AccountInfoModel.fromJsonFactory);

    return _apiAccountInfoGet(cacheControl: cacheControl);
  }

  ///gets account info data
  @Get(path: '/api/Account/info')
  Future<chopper.Response<AccountInfoModel>> _apiAccountInfoGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets account statements
  ///@param sort
  ///@param fromDate
  ///@param toDate
  ///@param offset
  ///@param itemsPerPage
  Future<chopper.Response<List<TransactionModel>>> apiAccountStatementsGet({
    String? sort,
    String? fromDate,
    String? toDate,
    int? offset,
    int? itemsPerPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TransactionModel, () => TransactionModel.fromJsonFactory);

    return _apiAccountStatementsGet(
        sort: sort,
        fromDate: fromDate,
        toDate: toDate,
        offset: offset,
        itemsPerPage: itemsPerPage,
        cacheControl: cacheControl);
  }

  ///gets account statements
  ///@param sort
  ///@param fromDate
  ///@param toDate
  ///@param offset
  ///@param itemsPerPage
  @Get(path: '/api/Account/statements')
  Future<chopper.Response<List<TransactionModel>>> _apiAccountStatementsGet({
    @Query('sort') String? sort,
    @Query('fromDate') String? fromDate,
    @Query('toDate') String? toDate,
    @Query('offset') int? offset,
    @Query('itemsPerPage') int? itemsPerPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///gets drs account statements
  ///@param sort
  ///@param fromDate
  ///@param toDate
  ///@param offset
  ///@param itemsPerPage
  Future<chopper.Response<List<DrsTransactionsModel>>>
      apiAccountDrsStatementsGet({
    String? sort,
    String? fromDate,
    String? toDate,
    int? offset,
    int? itemsPerPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DrsTransactionsModel, () => DrsTransactionsModel.fromJsonFactory);

    return _apiAccountDrsStatementsGet(
        sort: sort,
        fromDate: fromDate,
        toDate: toDate,
        offset: offset,
        itemsPerPage: itemsPerPage,
        cacheControl: cacheControl);
  }

  ///gets drs account statements
  ///@param sort
  ///@param fromDate
  ///@param toDate
  ///@param offset
  ///@param itemsPerPage
  @Get(path: '/api/Account/drs/statements')
  Future<chopper.Response<List<DrsTransactionsModel>>>
      _apiAccountDrsStatementsGet({
    @Query('sort') String? sort,
    @Query('fromDate') String? fromDate,
    @Query('toDate') String? toDate,
    @Query('offset') int? offset,
    @Query('itemsPerPage') int? itemsPerPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///create linktoken
  ///@param platform
  Future<chopper.Response<String>> apiAccountPlaidLinktokenPost({
    String? platform,
    String? cacheControl,
    required CreateLinkToken? body,
  }) {
    return _apiAccountPlaidLinktokenPost(
        platform: platform, cacheControl: cacheControl, body: body);
  }

  ///create linktoken
  ///@param platform
  @Post(path: '/api/Account/plaid-linktoken')
  Future<chopper.Response<String>> _apiAccountPlaidLinktokenPost({
    @Query('platform') String? platform,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CreateLinkToken? body,
  });

  ///get card secret
  Future<chopper.Response<CardSecret>> apiAccountCardSecretGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(CardSecret, () => CardSecret.fromJsonFactory);

    return _apiAccountCardSecretGet(cacheControl: cacheControl);
  }

  ///get card secret
  @Get(path: '/api/Account/card-secret')
  Future<chopper.Response<CardSecret>> _apiAccountCardSecretGet(
      {@Header('Cache-Control') String? cacheControl});

  ///recalculate cashback for current month
  Future<chopper.Response<AccountModel>> apiAccountRecalculatePost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AccountModel, () => AccountModel.fromJsonFactory);

    return _apiAccountRecalculatePost(cacheControl: cacheControl);
  }

  ///recalculate cashback for current month
  @Post(
    path: '/api/Account/recalculate',
    optionalBody: true,
  )
  Future<chopper.Response<AccountModel>> _apiAccountRecalculatePost(
      {@Header('Cache-Control') String? cacheControl});

  ///close account
  Future<chopper.Response> apiAccountClosePost({
    String? cacheControl,
    required CloseAccount? body,
  }) {
    return _apiAccountClosePost(cacheControl: cacheControl, body: body);
  }

  ///close account
  @Post(path: '/api/Account/close')
  Future<chopper.Response> _apiAccountClosePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CloseAccount? body,
  });

  ///check if user can close account
  Future<chopper.Response<CanBeClosedAccountModel>> apiAccountCanBeClosedPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        CanBeClosedAccountModel, () => CanBeClosedAccountModel.fromJsonFactory);

    return _apiAccountCanBeClosedPost(cacheControl: cacheControl);
  }

  ///check if user can close account
  @Post(
    path: '/api/Account/can-be-closed',
    optionalBody: true,
  )
  Future<chopper.Response<CanBeClosedAccountModel>> _apiAccountCanBeClosedPost(
      {@Header('Cache-Control') String? cacheControl});

  ///get onfido jwt token
  Future<chopper.Response<OnfidoJwtModel>> apiAccountOnfidoJwtPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        OnfidoJwtModel, () => OnfidoJwtModel.fromJsonFactory);

    return _apiAccountOnfidoJwtPost(cacheControl: cacheControl);
  }

  ///get onfido jwt token
  @Post(
    path: '/api/Account/onfido-jwt',
    optionalBody: true,
  )
  Future<chopper.Response<OnfidoJwtModel>> _apiAccountOnfidoJwtPost(
      {@Header('Cache-Control') String? cacheControl});

  ///start final KYC check
  Future<chopper.Response> apiAccountStartFinalKycCheckPost(
      {String? cacheControl}) {
    return _apiAccountStartFinalKycCheckPost(cacheControl: cacheControl);
  }

  ///start final KYC check
  @Post(
    path: '/api/Account/start-finalKycCheck',
    optionalBody: true,
  )
  Future<chopper.Response> _apiAccountStartFinalKycCheckPost(
      {@Header('Cache-Control') String? cacheControl});

  ///get transactions details
  Future<chopper.Response<ImpactProfileModel>> apiAccountImpactProfileGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ImpactProfileModel, () => ImpactProfileModel.fromJsonFactory);

    return _apiAccountImpactProfileGet(cacheControl: cacheControl);
  }

  ///get transactions details
  @Get(path: '/api/Account/impactProfile')
  Future<chopper.Response<ImpactProfileModel>> _apiAccountImpactProfileGet(
      {@Header('Cache-Control') String? cacheControl});

  ///
  Future<chopper.Response> appleAppSiteAssociationGet({String? cacheControl}) {
    return _appleAppSiteAssociationGet(cacheControl: cacheControl);
  }

  ///
  @Get(path: '/apple-app-site-association')
  Future<chopper.Response> _appleAppSiteAssociationGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets app settings
  ///@param version
  Future<chopper.Response<AppSettingsModel>> apiAppSettingsGet({
    String? version,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AppSettingsModel, () => AppSettingsModel.fromJsonFactory);

    return _apiAppSettingsGet(version: version, cacheControl: cacheControl);
  }

  ///gets app settings
  ///@param version
  @Get(path: '/api/AppSettings')
  Future<chopper.Response<AppSettingsModel>> _apiAppSettingsGet({
    @Query('version') String? version,
    @Header('Cache-Control') String? cacheControl,
  });

  ///gets card data
  Future<chopper.Response<CardModel>> apiCardFullGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(CardModel, () => CardModel.fromJsonFactory);

    return _apiCardFullGet(cacheControl: cacheControl);
  }

  ///gets card data
  @Get(path: '/api/Card/full')
  Future<chopper.Response<CardModel>> _apiCardFullGet(
      {@Header('Cache-Control') String? cacheControl});

  ///freeze/unfreeze card for user
  Future<chopper.Response<CardModel>> apiCardPut({
    String? cacheControl,
    required UpdateCard? body,
  }) {
    generatedMapping.putIfAbsent(CardModel, () => CardModel.fromJsonFactory);

    return _apiCardPut(cacheControl: cacheControl, body: body);
  }

  ///freeze/unfreeze card for user
  @Put(path: '/api/Card')
  Future<chopper.Response<CardModel>> _apiCardPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UpdateCard? body,
  });

  ///create a request for physical card
  Future<chopper.Response> apiCardPhysicalPost({String? cacheControl}) {
    return _apiCardPhysicalPost(cacheControl: cacheControl);
  }

  ///create a request for physical card
  @Post(
    path: '/api/Card/physical',
    optionalBody: true,
  )
  Future<chopper.Response> _apiCardPhysicalPost(
      {@Header('Cache-Control') String? cacheControl});

  ///activate physical card
  Future<chopper.Response<CardModel>> apiCardPhysicalPut({
    String? cacheControl,
    required ActivatePhysicalCard? body,
  }) {
    generatedMapping.putIfAbsent(CardModel, () => CardModel.fromJsonFactory);

    return _apiCardPhysicalPut(cacheControl: cacheControl, body: body);
  }

  ///activate physical card
  @Put(path: '/api/Card/physical')
  Future<chopper.Response<CardModel>> _apiCardPhysicalPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ActivatePhysicalCard? body,
  });

  ///get physical card pin
  Future<chopper.Response<PinModel>> apiCardPhysicalPinGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(PinModel, () => PinModel.fromJsonFactory);

    return _apiCardPhysicalPinGet(cacheControl: cacheControl);
  }

  ///get physical card pin
  @Get(path: '/api/Card/physical/pin')
  Future<chopper.Response<PinModel>> _apiCardPhysicalPinGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets all categories
  ///@param sort
  ///@param offset
  ///@param itemsPerPage
  Future<chopper.Response<List<CategoryModel>>> apiCategoriesGet({
    String? sort,
    int? offset,
    int? itemsPerPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CategoryModel, () => CategoryModel.fromJsonFactory);

    return _apiCategoriesGet(
        sort: sort,
        offset: offset,
        itemsPerPage: itemsPerPage,
        cacheControl: cacheControl);
  }

  ///gets all categories
  ///@param sort
  ///@param offset
  ///@param itemsPerPage
  @Get(path: '/api/Categories')
  Future<chopper.Response<List<CategoryModel>>> _apiCategoriesGet({
    @Query('sort') String? sort,
    @Query('offset') int? offset,
    @Query('itemsPerPage') int? itemsPerPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get logs name
  Future<chopper.Response<List<String>>> apiDataLogsNameGet(
      {String? cacheControl}) {
    return _apiDataLogsNameGet(cacheControl: cacheControl);
  }

  ///get logs name
  @Get(path: '/api/Data/logs-name')
  Future<chopper.Response<List<String>>> _apiDataLogsNameGet(
      {@Header('Cache-Control') String? cacheControl});

  ///download log file
  ///@param name
  Future<chopper.Response> apiDataDownloadLogGet({
    String? name,
    String? cacheControl,
  }) {
    return _apiDataDownloadLogGet(name: name, cacheControl: cacheControl);
  }

  ///download log file
  ///@param name
  @Get(path: '/api/Data/download-log')
  Future<chopper.Response> _apiDataDownloadLogGet({
    @Query('name') String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///read log
  ///@param name
  Future<chopper.Response<String>> apiDataReadLogGet({
    String? name,
    String? cacheControl,
  }) {
    return _apiDataReadLogGet(name: name, cacheControl: cacheControl);
  }

  ///read log
  ///@param name
  @Get(path: '/api/Data/read-log')
  Future<chopper.Response<String>> _apiDataReadLogGet({
    @Query('name') String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete test users
  Future<chopper.Response> apiDataTestUsersDelete({String? cacheControl}) {
    return _apiDataTestUsersDelete(cacheControl: cacheControl);
  }

  ///delete test users
  @Delete(path: '/api/Data/test-users')
  Future<chopper.Response> _apiDataTestUsersDelete(
      {@Header('Cache-Control') String? cacheControl});

  ///gets incentives
  ///@param search
  ///@param sort
  ///@param start
  ///@param limit
  ///@param onlyActive
  ///@param startTime
  ///@param endTime
  Future<chopper.Response<List<IncentiveClientModel>>> apiIncentiveGet({
    String? search,
    String? sort,
    int? start,
    int? limit,
    bool? onlyActive,
    String? startTime,
    String? endTime,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        IncentiveClientModel, () => IncentiveClientModel.fromJsonFactory);

    return _apiIncentiveGet(
        search: search,
        sort: sort,
        start: start,
        limit: limit,
        onlyActive: onlyActive,
        startTime: startTime,
        endTime: endTime,
        cacheControl: cacheControl);
  }

  ///gets incentives
  ///@param search
  ///@param sort
  ///@param start
  ///@param limit
  ///@param onlyActive
  ///@param startTime
  ///@param endTime
  @Get(path: '/api/Incentive')
  Future<chopper.Response<List<IncentiveClientModel>>> _apiIncentiveGet({
    @Query('search') String? search,
    @Query('sort') String? sort,
    @Query('start') int? start,
    @Query('limit') int? limit,
    @Query('onlyActive') bool? onlyActive,
    @Query('startTime') String? startTime,
    @Query('endTime') String? endTime,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get current user
  Future<chopper.Response<AppUserModelBase>> apiProfileUserGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AppUserModelBase, () => AppUserModelBase.fromJsonFactory);

    return _apiProfileUserGet(cacheControl: cacheControl);
  }

  ///get current user
  @Get(path: '/api/Profile/user')
  Future<chopper.Response<AppUserModelBase>> _apiProfileUserGet(
      {@Header('Cache-Control') String? cacheControl});

  ///get current profile
  Future<chopper.Response<AppProfileModel>> apiProfileGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AppProfileModel, () => AppProfileModel.fromJsonFactory);

    return _apiProfileGet(cacheControl: cacheControl);
  }

  ///get current profile
  @Get(path: '/api/Profile')
  Future<chopper.Response<AppProfileModel>> _apiProfileGet(
      {@Header('Cache-Control') String? cacheControl});

  ///edit profile
  Future<chopper.Response<AppProfileModel>> apiProfilePut({
    String? cacheControl,
    required EditAppUser? body,
  }) {
    generatedMapping.putIfAbsent(
        AppProfileModel, () => AppProfileModel.fromJsonFactory);

    return _apiProfilePut(cacheControl: cacheControl, body: body);
  }

  ///edit profile
  @Put(path: '/api/Profile')
  Future<chopper.Response<AppProfileModel>> _apiProfilePut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required EditAppUser? body,
  });

  ///register a new user
  Future<chopper.Response<AppUserModel>> apiProfilePost({
    String? cacheControl,
    required RegisterAppUser? body,
  }) {
    generatedMapping.putIfAbsent(
        AppUserModel, () => AppUserModel.fromJsonFactory);

    return _apiProfilePost(cacheControl: cacheControl, body: body);
  }

  ///register a new user
  @Post(path: '/api/Profile')
  Future<chopper.Response<AppUserModel>> _apiProfilePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RegisterAppUser? body,
  });

  ///update password
  Future<chopper.Response<AppUserModelBase>> apiProfilePasswordPut({
    String? cacheControl,
    required EditPassword? body,
  }) {
    generatedMapping.putIfAbsent(
        AppUserModelBase, () => AppUserModelBase.fromJsonFactory);

    return _apiProfilePasswordPut(cacheControl: cacheControl, body: body);
  }

  ///update password
  @Put(path: '/api/Profile/password')
  Future<chopper.Response<AppUserModelBase>> _apiProfilePasswordPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required EditPassword? body,
  });

  ///reset password
  Future<chopper.Response<AppUserModel>> apiProfilePasswordPost({
    String? cacheControl,
    required ResetPassword? body,
  }) {
    generatedMapping.putIfAbsent(
        AppUserModel, () => AppUserModel.fromJsonFactory);

    return _apiProfilePasswordPost(cacheControl: cacheControl, body: body);
  }

  ///reset password
  @Post(path: '/api/Profile/password')
  Future<chopper.Response<AppUserModel>> _apiProfilePasswordPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ResetPassword? body,
  });

  ///authenticate user
  Future<chopper.Response<AppUserModel>> apiProfileAuthenticatePost({
    String? cacheControl,
    required AuthenticateModel? body,
  }) {
    generatedMapping.putIfAbsent(
        AppUserModel, () => AppUserModel.fromJsonFactory);

    return _apiProfileAuthenticatePost(cacheControl: cacheControl, body: body);
  }

  ///authenticate user
  @Post(path: '/api/Profile/authenticate')
  Future<chopper.Response<AppUserModel>> _apiProfileAuthenticatePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required AuthenticateModel? body,
  });

  ///refresh user token
  Future<chopper.Response<AppUserModel>> apiProfileRefreshTokenPost({
    String? cacheControl,
    required RefreshToken? body,
  }) {
    generatedMapping.putIfAbsent(
        AppUserModel, () => AppUserModel.fromJsonFactory);

    return _apiProfileRefreshTokenPost(cacheControl: cacheControl, body: body);
  }

  ///refresh user token
  @Post(path: '/api/Profile/refresh-token')
  Future<chopper.Response<AppUserModel>> _apiProfileRefreshTokenPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RefreshToken? body,
  });

  ///sign out user
  Future<chopper.Response> apiProfileSignoutPost({String? cacheControl}) {
    return _apiProfileSignoutPost(cacheControl: cacheControl);
  }

  ///sign out user
  @Post(
    path: '/api/Profile/signout',
    optionalBody: true,
  )
  Future<chopper.Response> _apiProfileSignoutPost(
      {@Header('Cache-Control') String? cacheControl});

  ///create confirm token
  Future<chopper.Response<TokenModel>> apiProfileConfirmTokenPost({
    String? cacheControl,
    required ConfirmToken? body,
  }) {
    generatedMapping.putIfAbsent(TokenModel, () => TokenModel.fromJsonFactory);

    return _apiProfileConfirmTokenPost(cacheControl: cacheControl, body: body);
  }

  ///create confirm token
  @Post(path: '/api/Profile/confirm-token')
  Future<chopper.Response<TokenModel>> _apiProfileConfirmTokenPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ConfirmToken? body,
  });

  ///forgot password
  Future<chopper.Response> apiProfilePasswordTokenPost({
    String? cacheControl,
    required ForgotPassword? body,
  }) {
    return _apiProfilePasswordTokenPost(cacheControl: cacheControl, body: body);
  }

  ///forgot password
  @Post(path: '/api/Profile/password-token')
  Future<chopper.Response> _apiProfilePasswordTokenPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ForgotPassword? body,
  });

  ///validate reset password token
  Future<chopper.Response> apiProfileValidatePasswordTokenPost({
    String? cacheControl,
    required ValidatePasswordToken? body,
  }) {
    return _apiProfileValidatePasswordTokenPost(
        cacheControl: cacheControl, body: body);
  }

  ///validate reset password token
  @Post(path: '/api/Profile/validate-password-token')
  Future<chopper.Response> _apiProfileValidatePasswordTokenPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ValidatePasswordToken? body,
  });

  ///retry a registration
  Future<chopper.Response<AppProfileModelResponseModel>> apiProfileRetryPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(AppProfileModelResponseModel,
        () => AppProfileModelResponseModel.fromJsonFactory);

    return _apiProfileRetryPost(cacheControl: cacheControl);
  }

  ///retry a registration
  @Post(
    path: '/api/Profile/retry',
    optionalBody: true,
  )
  Future<chopper.Response<AppProfileModelResponseModel>> _apiProfileRetryPost(
      {@Header('Cache-Control') String? cacheControl});

  ///retry a registration
  Future<chopper.Response<AppProfileModel>> apiProfileRetryRegisterPost({
    String? cacheControl,
    required RegisterAppUserBase? body,
  }) {
    generatedMapping.putIfAbsent(
        AppProfileModel, () => AppProfileModel.fromJsonFactory);

    return _apiProfileRetryRegisterPost(cacheControl: cacheControl, body: body);
  }

  ///retry a registration
  @Post(path: '/api/Profile/retry-register')
  Future<chopper.Response<AppProfileModel>> _apiProfileRetryRegisterPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RegisterAppUserBase? body,
  });

  ///create or update channel for push notification
  Future<chopper.Response> apiPushChannelsPost({
    String? cacheControl,
    required CreatePushChannel? body,
  }) {
    return _apiPushChannelsPost(cacheControl: cacheControl, body: body);
  }

  ///create or update channel for push notification
  @Post(path: '/api/PushChannels')
  Future<chopper.Response> _apiPushChannelsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CreatePushChannel? body,
  });

  ///check barcode
  ///@param barcode
  Future<chopper.Response> apiRecycleBarcodeGet({
    String? barcode,
    String? cacheControl,
  }) {
    return _apiRecycleBarcodeGet(barcode: barcode, cacheControl: cacheControl);
  }

  ///check barcode
  ///@param barcode
  @Get(path: '/api/Recycle/barcode')
  Future<chopper.Response> _apiRecycleBarcodeGet({
    @Query('barcode') String? barcode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///complete exchanging bottles for money
  Future<chopper.Response<ReceivingMoneyModel>> apiRecycleBarcodePost({
    String? cacheControl,
    required BarcodeComplete? body,
  }) {
    generatedMapping.putIfAbsent(
        ReceivingMoneyModel, () => ReceivingMoneyModel.fromJsonFactory);

    return _apiRecycleBarcodePost(cacheControl: cacheControl, body: body);
  }

  ///complete exchanging bottles for money
  @Post(path: '/api/Recycle/barcode')
  Future<chopper.Response<ReceivingMoneyModel>> _apiRecycleBarcodePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required BarcodeComplete? body,
  });

  ///gets locations and retailer
  Future<chopper.Response<DrsLocationModel>> apiRecycleLocationsGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        DrsLocationModel, () => DrsLocationModel.fromJsonFactory);

    return _apiRecycleLocationsGet(cacheControl: cacheControl);
  }

  ///gets locations and retailer
  @Get(path: '/api/Recycle/locations')
  Future<chopper.Response<DrsLocationModel>> _apiRecycleLocationsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets redirect page
  Future<chopper.Response<String>> redirectAppGet({String? cacheControl}) {
    return _redirectAppGet(cacheControl: cacheControl);
  }

  ///gets redirect page
  @Get(path: '/redirect/app')
  Future<chopper.Response<String>> _redirectAppGet(
      {@Header('Cache-Control') String? cacheControl});

  ///gets all retailers
  ///@param sort
  ///@param isWeb
  ///@param isMobile
  ///@param offset
  ///@param itemsPerPage
  Future<chopper.Response<List<RetailerModel>>> apiRetailersGet({
    String? sort,
    bool? isWeb,
    bool? isMobile,
    int? offset,
    int? itemsPerPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RetailerModel, () => RetailerModel.fromJsonFactory);

    return _apiRetailersGet(
        sort: sort,
        isWeb: isWeb,
        isMobile: isMobile,
        offset: offset,
        itemsPerPage: itemsPerPage,
        cacheControl: cacheControl);
  }

  ///gets all retailers
  ///@param sort
  ///@param isWeb
  ///@param isMobile
  ///@param offset
  ///@param itemsPerPage
  @Get(path: '/api/Retailers')
  Future<chopper.Response<List<RetailerModel>>> _apiRetailersGet({
    @Query('sort') String? sort,
    @Query('isWeb') bool? isWeb,
    @Query('isMobile') bool? isMobile,
    @Query('offset') int? offset,
    @Query('itemsPerPage') int? itemsPerPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///provides retailer
  ///@param key
  Future<chopper.Response<RetailerModel>> apiRetailersKeyGet({
    required String? key,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RetailerModel, () => RetailerModel.fromJsonFactory);

    return _apiRetailersKeyGet(key: key, cacheControl: cacheControl);
  }

  ///provides retailer
  ///@param key
  @Get(path: '/api/Retailers/{key}')
  Future<chopper.Response<RetailerModel>> _apiRetailersKeyGet({
    @Path('key') required String? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///gets available web templates
  ///@param sort
  ///@param offset
  ///@param itemsPerPage
  Future<chopper.Response<List<WebTemplateModel>>> apiWebTemplateAvailableGet({
    String? sort,
    int? offset,
    int? itemsPerPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WebTemplateModel, () => WebTemplateModel.fromJsonFactory);

    return _apiWebTemplateAvailableGet(
        sort: sort,
        offset: offset,
        itemsPerPage: itemsPerPage,
        cacheControl: cacheControl);
  }

  ///gets available web templates
  ///@param sort
  ///@param offset
  ///@param itemsPerPage
  @Get(path: '/api/WebTemplate/available')
  Future<chopper.Response<List<WebTemplateModel>>> _apiWebTemplateAvailableGet({
    @Query('sort') String? sort,
    @Query('offset') int? offset,
    @Query('itemsPerPage') int? itemsPerPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///gets web template
  ///@param key
  Future<chopper.Response<WebTemplateModel>> apiWebTemplateKeyGet({
    required String? key,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WebTemplateModel, () => WebTemplateModel.fromJsonFactory);

    return _apiWebTemplateKeyGet(key: key, cacheControl: cacheControl);
  }

  ///gets web template
  ///@param key
  @Get(path: '/api/WebTemplate/{key}')
  Future<chopper.Response<WebTemplateModel>> _apiWebTemplateKeyGet({
    @Path('key') required String? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  Future<chopper.Response> wellKnownAppleAppSiteAssociationGet(
      {String? cacheControl}) {
    return _wellKnownAppleAppSiteAssociationGet(cacheControl: cacheControl);
  }

  ///
  @Get(path: '/.well-known/apple-app-site-association')
  Future<chopper.Response> _wellKnownAppleAppSiteAssociationGet(
      {@Header('Cache-Control') String? cacheControl});

  ///
  Future<chopper.Response> wellKnownAssetlinksJsonGet({String? cacheControl}) {
    return _wellKnownAssetlinksJsonGet(cacheControl: cacheControl);
  }

  ///
  @Get(path: '/.well-known/assetlinks.json')
  Future<chopper.Response> _wellKnownAssetlinksJsonGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class AccountInfoModel {
  AccountInfoModel({
    this.holderName,
    this.sortCode,
    this.number,
    this.bic,
    this.iban,
    this.isClosed,
    this.balance,
  });

  factory AccountInfoModel.fromJson(Map<String, dynamic> json) =>
      _$AccountInfoModelFromJson(json);

  @JsonKey(name: 'holderName', includeIfNull: false, defaultValue: '')
  final String? holderName;
  @JsonKey(name: 'sortCode', includeIfNull: false, defaultValue: '')
  final String? sortCode;
  @JsonKey(name: 'number', includeIfNull: false, defaultValue: '')
  final String? number;
  @JsonKey(name: 'bic', includeIfNull: false, defaultValue: '')
  final String? bic;
  @JsonKey(name: 'iban', includeIfNull: false, defaultValue: '')
  final String? iban;
  @JsonKey(name: 'isClosed', includeIfNull: false)
  final bool? isClosed;
  @JsonKey(name: 'balance', includeIfNull: false)
  final double? balance;
  static const fromJsonFactory = _$AccountInfoModelFromJson;
  static const toJsonFactory = _$AccountInfoModelToJson;
  Map<String, dynamic> toJson() => _$AccountInfoModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AccountInfoModel &&
            (identical(other.holderName, holderName) ||
                const DeepCollectionEquality()
                    .equals(other.holderName, holderName)) &&
            (identical(other.sortCode, sortCode) ||
                const DeepCollectionEquality()
                    .equals(other.sortCode, sortCode)) &&
            (identical(other.number, number) ||
                const DeepCollectionEquality().equals(other.number, number)) &&
            (identical(other.bic, bic) ||
                const DeepCollectionEquality().equals(other.bic, bic)) &&
            (identical(other.iban, iban) ||
                const DeepCollectionEquality().equals(other.iban, iban)) &&
            (identical(other.isClosed, isClosed) ||
                const DeepCollectionEquality()
                    .equals(other.isClosed, isClosed)) &&
            (identical(other.balance, balance) ||
                const DeepCollectionEquality().equals(other.balance, balance)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(holderName) ^
      const DeepCollectionEquality().hash(sortCode) ^
      const DeepCollectionEquality().hash(number) ^
      const DeepCollectionEquality().hash(bic) ^
      const DeepCollectionEquality().hash(iban) ^
      const DeepCollectionEquality().hash(isClosed) ^
      const DeepCollectionEquality().hash(balance) ^
      runtimeType.hashCode;
}

extension $AccountInfoModelExtension on AccountInfoModel {
  AccountInfoModel copyWith(
      {String? holderName,
      String? sortCode,
      String? number,
      String? bic,
      String? iban,
      bool? isClosed,
      double? balance}) {
    return AccountInfoModel(
        holderName: holderName ?? this.holderName,
        sortCode: sortCode ?? this.sortCode,
        number: number ?? this.number,
        bic: bic ?? this.bic,
        iban: iban ?? this.iban,
        isClosed: isClosed ?? this.isClosed,
        balance: balance ?? this.balance);
  }

  AccountInfoModel copyWithWrapped(
      {Wrapped<String?>? holderName,
      Wrapped<String?>? sortCode,
      Wrapped<String?>? number,
      Wrapped<String?>? bic,
      Wrapped<String?>? iban,
      Wrapped<bool?>? isClosed,
      Wrapped<double?>? balance}) {
    return AccountInfoModel(
        holderName: (holderName != null ? holderName.value : this.holderName),
        sortCode: (sortCode != null ? sortCode.value : this.sortCode),
        number: (number != null ? number.value : this.number),
        bic: (bic != null ? bic.value : this.bic),
        iban: (iban != null ? iban.value : this.iban),
        isClosed: (isClosed != null ? isClosed.value : this.isClosed),
        balance: (balance != null ? balance.value : this.balance));
  }
}

@JsonSerializable(explicitToJson: true)
class AccountModel {
  AccountModel({
    this.date,
    this.balance,
    this.monthSpend,
    this.monthCashback,
    this.cashbackRate,
    this.cashbackHasNextLevel,
    this.cashbackNextLevelDiff,
    this.cashbackNextLevel,
    this.calculationDate,
    this.isActive,
    this.paidStatus,
    this.transactionsCount,
    this.allSpendingAmount,
    this.previousMonthCashback,
    this.previousPaidStatus,
  });

  factory AccountModel.fromJson(Map<String, dynamic> json) =>
      _$AccountModelFromJson(json);

  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'balance', includeIfNull: false)
  final double? balance;
  @JsonKey(name: 'monthSpend', includeIfNull: false)
  final double? monthSpend;
  @JsonKey(name: 'monthCashback', includeIfNull: false)
  final double? monthCashback;
  @JsonKey(name: 'cashbackRate', includeIfNull: false)
  final double? cashbackRate;
  @JsonKey(name: 'cashbackHasNextLevel', includeIfNull: false)
  final bool? cashbackHasNextLevel;
  @JsonKey(name: 'cashbackNextLevelDiff', includeIfNull: false)
  final double? cashbackNextLevelDiff;
  @JsonKey(name: 'cashbackNextLevel', includeIfNull: false)
  final double? cashbackNextLevel;
  @JsonKey(name: 'calculationDate', includeIfNull: false)
  final DateTime? calculationDate;
  @JsonKey(name: 'isActive', includeIfNull: false)
  final bool? isActive;
  @JsonKey(name: 'paidStatus', includeIfNull: false, defaultValue: '')
  final String? paidStatus;
  @JsonKey(name: 'transactionsCount', includeIfNull: false)
  final int? transactionsCount;
  @JsonKey(name: 'allSpendingAmount', includeIfNull: false)
  final double? allSpendingAmount;
  @JsonKey(name: 'previousMonthCashback', includeIfNull: false)
  final double? previousMonthCashback;
  @JsonKey(name: 'previousPaidStatus', includeIfNull: false, defaultValue: '')
  final String? previousPaidStatus;
  static const fromJsonFactory = _$AccountModelFromJson;
  static const toJsonFactory = _$AccountModelToJson;
  Map<String, dynamic> toJson() => _$AccountModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AccountModel &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.balance, balance) ||
                const DeepCollectionEquality()
                    .equals(other.balance, balance)) &&
            (identical(other.monthSpend, monthSpend) ||
                const DeepCollectionEquality()
                    .equals(other.monthSpend, monthSpend)) &&
            (identical(other.monthCashback, monthCashback) ||
                const DeepCollectionEquality()
                    .equals(other.monthCashback, monthCashback)) &&
            (identical(other.cashbackRate, cashbackRate) ||
                const DeepCollectionEquality()
                    .equals(other.cashbackRate, cashbackRate)) &&
            (identical(other.cashbackHasNextLevel, cashbackHasNextLevel) ||
                const DeepCollectionEquality().equals(
                    other.cashbackHasNextLevel, cashbackHasNextLevel)) &&
            (identical(other.cashbackNextLevelDiff, cashbackNextLevelDiff) ||
                const DeepCollectionEquality().equals(
                    other.cashbackNextLevelDiff, cashbackNextLevelDiff)) &&
            (identical(other.cashbackNextLevel, cashbackNextLevel) ||
                const DeepCollectionEquality()
                    .equals(other.cashbackNextLevel, cashbackNextLevel)) &&
            (identical(other.calculationDate, calculationDate) ||
                const DeepCollectionEquality()
                    .equals(other.calculationDate, calculationDate)) &&
            (identical(other.isActive, isActive) ||
                const DeepCollectionEquality()
                    .equals(other.isActive, isActive)) &&
            (identical(other.paidStatus, paidStatus) ||
                const DeepCollectionEquality()
                    .equals(other.paidStatus, paidStatus)) &&
            (identical(other.transactionsCount, transactionsCount) ||
                const DeepCollectionEquality()
                    .equals(other.transactionsCount, transactionsCount)) &&
            (identical(other.allSpendingAmount, allSpendingAmount) ||
                const DeepCollectionEquality()
                    .equals(other.allSpendingAmount, allSpendingAmount)) &&
            (identical(other.previousMonthCashback, previousMonthCashback) ||
                const DeepCollectionEquality().equals(
                    other.previousMonthCashback, previousMonthCashback)) &&
            (identical(other.previousPaidStatus, previousPaidStatus) ||
                const DeepCollectionEquality()
                    .equals(other.previousPaidStatus, previousPaidStatus)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(balance) ^
      const DeepCollectionEquality().hash(monthSpend) ^
      const DeepCollectionEquality().hash(monthCashback) ^
      const DeepCollectionEquality().hash(cashbackRate) ^
      const DeepCollectionEquality().hash(cashbackHasNextLevel) ^
      const DeepCollectionEquality().hash(cashbackNextLevelDiff) ^
      const DeepCollectionEquality().hash(cashbackNextLevel) ^
      const DeepCollectionEquality().hash(calculationDate) ^
      const DeepCollectionEquality().hash(isActive) ^
      const DeepCollectionEquality().hash(paidStatus) ^
      const DeepCollectionEquality().hash(transactionsCount) ^
      const DeepCollectionEquality().hash(allSpendingAmount) ^
      const DeepCollectionEquality().hash(previousMonthCashback) ^
      const DeepCollectionEquality().hash(previousPaidStatus) ^
      runtimeType.hashCode;
}

extension $AccountModelExtension on AccountModel {
  AccountModel copyWith(
      {DateTime? date,
      double? balance,
      double? monthSpend,
      double? monthCashback,
      double? cashbackRate,
      bool? cashbackHasNextLevel,
      double? cashbackNextLevelDiff,
      double? cashbackNextLevel,
      DateTime? calculationDate,
      bool? isActive,
      String? paidStatus,
      int? transactionsCount,
      double? allSpendingAmount,
      double? previousMonthCashback,
      String? previousPaidStatus}) {
    return AccountModel(
        date: date ?? this.date,
        balance: balance ?? this.balance,
        monthSpend: monthSpend ?? this.monthSpend,
        monthCashback: monthCashback ?? this.monthCashback,
        cashbackRate: cashbackRate ?? this.cashbackRate,
        cashbackHasNextLevel: cashbackHasNextLevel ?? this.cashbackHasNextLevel,
        cashbackNextLevelDiff:
            cashbackNextLevelDiff ?? this.cashbackNextLevelDiff,
        cashbackNextLevel: cashbackNextLevel ?? this.cashbackNextLevel,
        calculationDate: calculationDate ?? this.calculationDate,
        isActive: isActive ?? this.isActive,
        paidStatus: paidStatus ?? this.paidStatus,
        transactionsCount: transactionsCount ?? this.transactionsCount,
        allSpendingAmount: allSpendingAmount ?? this.allSpendingAmount,
        previousMonthCashback:
            previousMonthCashback ?? this.previousMonthCashback,
        previousPaidStatus: previousPaidStatus ?? this.previousPaidStatus);
  }

  AccountModel copyWithWrapped(
      {Wrapped<DateTime?>? date,
      Wrapped<double?>? balance,
      Wrapped<double?>? monthSpend,
      Wrapped<double?>? monthCashback,
      Wrapped<double?>? cashbackRate,
      Wrapped<bool?>? cashbackHasNextLevel,
      Wrapped<double?>? cashbackNextLevelDiff,
      Wrapped<double?>? cashbackNextLevel,
      Wrapped<DateTime?>? calculationDate,
      Wrapped<bool?>? isActive,
      Wrapped<String?>? paidStatus,
      Wrapped<int?>? transactionsCount,
      Wrapped<double?>? allSpendingAmount,
      Wrapped<double?>? previousMonthCashback,
      Wrapped<String?>? previousPaidStatus}) {
    return AccountModel(
        date: (date != null ? date.value : this.date),
        balance: (balance != null ? balance.value : this.balance),
        monthSpend: (monthSpend != null ? monthSpend.value : this.monthSpend),
        monthCashback:
            (monthCashback != null ? monthCashback.value : this.monthCashback),
        cashbackRate:
            (cashbackRate != null ? cashbackRate.value : this.cashbackRate),
        cashbackHasNextLevel: (cashbackHasNextLevel != null
            ? cashbackHasNextLevel.value
            : this.cashbackHasNextLevel),
        cashbackNextLevelDiff: (cashbackNextLevelDiff != null
            ? cashbackNextLevelDiff.value
            : this.cashbackNextLevelDiff),
        cashbackNextLevel: (cashbackNextLevel != null
            ? cashbackNextLevel.value
            : this.cashbackNextLevel),
        calculationDate: (calculationDate != null
            ? calculationDate.value
            : this.calculationDate),
        isActive: (isActive != null ? isActive.value : this.isActive),
        paidStatus: (paidStatus != null ? paidStatus.value : this.paidStatus),
        transactionsCount: (transactionsCount != null
            ? transactionsCount.value
            : this.transactionsCount),
        allSpendingAmount: (allSpendingAmount != null
            ? allSpendingAmount.value
            : this.allSpendingAmount),
        previousMonthCashback: (previousMonthCashback != null
            ? previousMonthCashback.value
            : this.previousMonthCashback),
        previousPaidStatus: (previousPaidStatus != null
            ? previousPaidStatus.value
            : this.previousPaidStatus));
  }
}

@JsonSerializable(explicitToJson: true)
class ActivatePhysicalCard {
  ActivatePhysicalCard({
    this.lastDigits,
  });

  factory ActivatePhysicalCard.fromJson(Map<String, dynamic> json) =>
      _$ActivatePhysicalCardFromJson(json);

  @JsonKey(name: 'lastDigits', includeIfNull: false, defaultValue: '')
  final String? lastDigits;
  static const fromJsonFactory = _$ActivatePhysicalCardFromJson;
  static const toJsonFactory = _$ActivatePhysicalCardToJson;
  Map<String, dynamic> toJson() => _$ActivatePhysicalCardToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ActivatePhysicalCard &&
            (identical(other.lastDigits, lastDigits) ||
                const DeepCollectionEquality()
                    .equals(other.lastDigits, lastDigits)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastDigits) ^ runtimeType.hashCode;
}

extension $ActivatePhysicalCardExtension on ActivatePhysicalCard {
  ActivatePhysicalCard copyWith({String? lastDigits}) {
    return ActivatePhysicalCard(lastDigits: lastDigits ?? this.lastDigits);
  }

  ActivatePhysicalCard copyWithWrapped({Wrapped<String?>? lastDigits}) {
    return ActivatePhysicalCard(
        lastDigits: (lastDigits != null ? lastDigits.value : this.lastDigits));
  }
}

@JsonSerializable(explicitToJson: true)
class AmountByCategories {
  AmountByCategories({
    this.id,
    this.title,
    this.amount,
    this.type,
  });

  factory AmountByCategories.fromJson(Map<String, dynamic> json) =>
      _$AmountByCategoriesFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'amount', includeIfNull: false)
  final double? amount;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  static const fromJsonFactory = _$AmountByCategoriesFromJson;
  static const toJsonFactory = _$AmountByCategoriesToJson;
  Map<String, dynamic> toJson() => _$AmountByCategoriesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AmountByCategories &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $AmountByCategoriesExtension on AmountByCategories {
  AmountByCategories copyWith(
      {String? id, String? title, double? amount, String? type}) {
    return AmountByCategories(
        id: id ?? this.id,
        title: title ?? this.title,
        amount: amount ?? this.amount,
        type: type ?? this.type);
  }

  AmountByCategories copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<double?>? amount,
      Wrapped<String?>? type}) {
    return AmountByCategories(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        amount: (amount != null ? amount.value : this.amount),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class AppProfileModel {
  AppProfileModel({
    this.id,
    this.firstName,
    this.lastName,
    this.userName,
    this.email,
    this.status,
    this.company,
    this.updatedTime,
    this.birthDate,
    this.phoneNumber,
    this.finalKycCheckStatus,
    this.onfidoStatus,
    this.howDidYouHear,
    this.addressCity,
    this.addressIsoCountry,
    this.addressNumber,
    this.addressPostalCode,
    this.addressRegion,
    this.addressStreet,
    this.physicalCardStatus,
  });

  factory AppProfileModel.fromJson(Map<String, dynamic> json) =>
      _$AppProfileModelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'userName', includeIfNull: false, defaultValue: '')
  final String? userName;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: userStatusToJson,
    fromJson: userStatusFromJson,
  )
  final enums.UserStatus? status;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'updatedTime', includeIfNull: false)
  final DateTime? updatedTime;
  @JsonKey(name: 'birthDate', includeIfNull: false)
  final DateTime? birthDate;
  @JsonKey(name: 'phoneNumber', includeIfNull: false, defaultValue: '')
  final String? phoneNumber;
  @JsonKey(
    name: 'finalKycCheckStatus',
    includeIfNull: false,
    toJson: kycCheckStatusToJson,
    fromJson: kycCheckStatusFromJson,
  )
  final enums.KycCheckStatus? finalKycCheckStatus;
  @JsonKey(
    name: 'onfidoStatus',
    includeIfNull: false,
    toJson: userStatusToJson,
    fromJson: userStatusFromJson,
  )
  final enums.UserStatus? onfidoStatus;
  @JsonKey(name: 'howDidYouHear', includeIfNull: false, defaultValue: '')
  final String? howDidYouHear;
  @JsonKey(name: 'address_city', includeIfNull: false, defaultValue: '')
  final String? addressCity;
  @JsonKey(name: 'address_iso_country', includeIfNull: false, defaultValue: '')
  final String? addressIsoCountry;
  @JsonKey(name: 'address_number', includeIfNull: false, defaultValue: '')
  final String? addressNumber;
  @JsonKey(name: 'address_postal_code', includeIfNull: false, defaultValue: '')
  final String? addressPostalCode;
  @JsonKey(name: 'address_region', includeIfNull: false, defaultValue: '')
  final String? addressRegion;
  @JsonKey(name: 'address_street', includeIfNull: false, defaultValue: '')
  final String? addressStreet;
  @JsonKey(
    name: 'physicalCardStatus',
    includeIfNull: false,
    toJson: cardStatusToJson,
    fromJson: cardStatusFromJson,
  )
  final enums.CardStatus? physicalCardStatus;
  static const fromJsonFactory = _$AppProfileModelFromJson;
  static const toJsonFactory = _$AppProfileModelToJson;
  Map<String, dynamic> toJson() => _$AppProfileModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AppProfileModel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.userName, userName) ||
                const DeepCollectionEquality()
                    .equals(other.userName, userName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.updatedTime, updatedTime) ||
                const DeepCollectionEquality()
                    .equals(other.updatedTime, updatedTime)) &&
            (identical(other.birthDate, birthDate) ||
                const DeepCollectionEquality()
                    .equals(other.birthDate, birthDate)) &&
            (identical(other.phoneNumber, phoneNumber) ||
                const DeepCollectionEquality()
                    .equals(other.phoneNumber, phoneNumber)) &&
            (identical(other.finalKycCheckStatus, finalKycCheckStatus) ||
                const DeepCollectionEquality()
                    .equals(other.finalKycCheckStatus, finalKycCheckStatus)) &&
            (identical(other.onfidoStatus, onfidoStatus) ||
                const DeepCollectionEquality()
                    .equals(other.onfidoStatus, onfidoStatus)) &&
            (identical(other.howDidYouHear, howDidYouHear) ||
                const DeepCollectionEquality()
                    .equals(other.howDidYouHear, howDidYouHear)) &&
            (identical(other.addressCity, addressCity) ||
                const DeepCollectionEquality()
                    .equals(other.addressCity, addressCity)) &&
            (identical(other.addressIsoCountry, addressIsoCountry) ||
                const DeepCollectionEquality()
                    .equals(other.addressIsoCountry, addressIsoCountry)) &&
            (identical(other.addressNumber, addressNumber) ||
                const DeepCollectionEquality()
                    .equals(other.addressNumber, addressNumber)) &&
            (identical(other.addressPostalCode, addressPostalCode) ||
                const DeepCollectionEquality()
                    .equals(other.addressPostalCode, addressPostalCode)) &&
            (identical(other.addressRegion, addressRegion) ||
                const DeepCollectionEquality()
                    .equals(other.addressRegion, addressRegion)) &&
            (identical(other.addressStreet, addressStreet) ||
                const DeepCollectionEquality()
                    .equals(other.addressStreet, addressStreet)) &&
            (identical(other.physicalCardStatus, physicalCardStatus) ||
                const DeepCollectionEquality()
                    .equals(other.physicalCardStatus, physicalCardStatus)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(userName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(updatedTime) ^
      const DeepCollectionEquality().hash(birthDate) ^
      const DeepCollectionEquality().hash(phoneNumber) ^
      const DeepCollectionEquality().hash(finalKycCheckStatus) ^
      const DeepCollectionEquality().hash(onfidoStatus) ^
      const DeepCollectionEquality().hash(howDidYouHear) ^
      const DeepCollectionEquality().hash(addressCity) ^
      const DeepCollectionEquality().hash(addressIsoCountry) ^
      const DeepCollectionEquality().hash(addressNumber) ^
      const DeepCollectionEquality().hash(addressPostalCode) ^
      const DeepCollectionEquality().hash(addressRegion) ^
      const DeepCollectionEquality().hash(addressStreet) ^
      const DeepCollectionEquality().hash(physicalCardStatus) ^
      runtimeType.hashCode;
}

extension $AppProfileModelExtension on AppProfileModel {
  AppProfileModel copyWith(
      {String? id,
      String? firstName,
      String? lastName,
      String? userName,
      String? email,
      enums.UserStatus? status,
      String? company,
      DateTime? updatedTime,
      DateTime? birthDate,
      String? phoneNumber,
      enums.KycCheckStatus? finalKycCheckStatus,
      enums.UserStatus? onfidoStatus,
      String? howDidYouHear,
      String? addressCity,
      String? addressIsoCountry,
      String? addressNumber,
      String? addressPostalCode,
      String? addressRegion,
      String? addressStreet,
      enums.CardStatus? physicalCardStatus}) {
    return AppProfileModel(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        userName: userName ?? this.userName,
        email: email ?? this.email,
        status: status ?? this.status,
        company: company ?? this.company,
        updatedTime: updatedTime ?? this.updatedTime,
        birthDate: birthDate ?? this.birthDate,
        phoneNumber: phoneNumber ?? this.phoneNumber,
        finalKycCheckStatus: finalKycCheckStatus ?? this.finalKycCheckStatus,
        onfidoStatus: onfidoStatus ?? this.onfidoStatus,
        howDidYouHear: howDidYouHear ?? this.howDidYouHear,
        addressCity: addressCity ?? this.addressCity,
        addressIsoCountry: addressIsoCountry ?? this.addressIsoCountry,
        addressNumber: addressNumber ?? this.addressNumber,
        addressPostalCode: addressPostalCode ?? this.addressPostalCode,
        addressRegion: addressRegion ?? this.addressRegion,
        addressStreet: addressStreet ?? this.addressStreet,
        physicalCardStatus: physicalCardStatus ?? this.physicalCardStatus);
  }

  AppProfileModel copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? userName,
      Wrapped<String?>? email,
      Wrapped<enums.UserStatus?>? status,
      Wrapped<String?>? company,
      Wrapped<DateTime?>? updatedTime,
      Wrapped<DateTime?>? birthDate,
      Wrapped<String?>? phoneNumber,
      Wrapped<enums.KycCheckStatus?>? finalKycCheckStatus,
      Wrapped<enums.UserStatus?>? onfidoStatus,
      Wrapped<String?>? howDidYouHear,
      Wrapped<String?>? addressCity,
      Wrapped<String?>? addressIsoCountry,
      Wrapped<String?>? addressNumber,
      Wrapped<String?>? addressPostalCode,
      Wrapped<String?>? addressRegion,
      Wrapped<String?>? addressStreet,
      Wrapped<enums.CardStatus?>? physicalCardStatus}) {
    return AppProfileModel(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        userName: (userName != null ? userName.value : this.userName),
        email: (email != null ? email.value : this.email),
        status: (status != null ? status.value : this.status),
        company: (company != null ? company.value : this.company),
        updatedTime:
            (updatedTime != null ? updatedTime.value : this.updatedTime),
        birthDate: (birthDate != null ? birthDate.value : this.birthDate),
        phoneNumber:
            (phoneNumber != null ? phoneNumber.value : this.phoneNumber),
        finalKycCheckStatus: (finalKycCheckStatus != null
            ? finalKycCheckStatus.value
            : this.finalKycCheckStatus),
        onfidoStatus:
            (onfidoStatus != null ? onfidoStatus.value : this.onfidoStatus),
        howDidYouHear:
            (howDidYouHear != null ? howDidYouHear.value : this.howDidYouHear),
        addressCity:
            (addressCity != null ? addressCity.value : this.addressCity),
        addressIsoCountry: (addressIsoCountry != null
            ? addressIsoCountry.value
            : this.addressIsoCountry),
        addressNumber:
            (addressNumber != null ? addressNumber.value : this.addressNumber),
        addressPostalCode: (addressPostalCode != null
            ? addressPostalCode.value
            : this.addressPostalCode),
        addressRegion:
            (addressRegion != null ? addressRegion.value : this.addressRegion),
        addressStreet:
            (addressStreet != null ? addressStreet.value : this.addressStreet),
        physicalCardStatus: (physicalCardStatus != null
            ? physicalCardStatus.value
            : this.physicalCardStatus));
  }
}

@JsonSerializable(explicitToJson: true)
class AppProfileModelResponseModel {
  AppProfileModelResponseModel({
    this.isSuccess,
    this.errorCode,
    this.errorMessage,
    this.result,
  });

  factory AppProfileModelResponseModel.fromJson(Map<String, dynamic> json) =>
      _$AppProfileModelResponseModelFromJson(json);

  @JsonKey(name: 'isSuccess', includeIfNull: false)
  final bool? isSuccess;
  @JsonKey(name: 'errorCode', includeIfNull: false, defaultValue: '')
  final String? errorCode;
  @JsonKey(name: 'errorMessage', includeIfNull: false, defaultValue: '')
  final String? errorMessage;
  @JsonKey(name: 'result', includeIfNull: false)
  final AppProfileModel? result;
  static const fromJsonFactory = _$AppProfileModelResponseModelFromJson;
  static const toJsonFactory = _$AppProfileModelResponseModelToJson;
  Map<String, dynamic> toJson() => _$AppProfileModelResponseModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AppProfileModelResponseModel &&
            (identical(other.isSuccess, isSuccess) ||
                const DeepCollectionEquality()
                    .equals(other.isSuccess, isSuccess)) &&
            (identical(other.errorCode, errorCode) ||
                const DeepCollectionEquality()
                    .equals(other.errorCode, errorCode)) &&
            (identical(other.errorMessage, errorMessage) ||
                const DeepCollectionEquality()
                    .equals(other.errorMessage, errorMessage)) &&
            (identical(other.result, result) ||
                const DeepCollectionEquality().equals(other.result, result)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isSuccess) ^
      const DeepCollectionEquality().hash(errorCode) ^
      const DeepCollectionEquality().hash(errorMessage) ^
      const DeepCollectionEquality().hash(result) ^
      runtimeType.hashCode;
}

extension $AppProfileModelResponseModelExtension
    on AppProfileModelResponseModel {
  AppProfileModelResponseModel copyWith(
      {bool? isSuccess,
      String? errorCode,
      String? errorMessage,
      AppProfileModel? result}) {
    return AppProfileModelResponseModel(
        isSuccess: isSuccess ?? this.isSuccess,
        errorCode: errorCode ?? this.errorCode,
        errorMessage: errorMessage ?? this.errorMessage,
        result: result ?? this.result);
  }

  AppProfileModelResponseModel copyWithWrapped(
      {Wrapped<bool?>? isSuccess,
      Wrapped<String?>? errorCode,
      Wrapped<String?>? errorMessage,
      Wrapped<AppProfileModel?>? result}) {
    return AppProfileModelResponseModel(
        isSuccess: (isSuccess != null ? isSuccess.value : this.isSuccess),
        errorCode: (errorCode != null ? errorCode.value : this.errorCode),
        errorMessage:
            (errorMessage != null ? errorMessage.value : this.errorMessage),
        result: (result != null ? result.value : this.result));
  }
}

@JsonSerializable(explicitToJson: true)
class AppSettingsModel {
  AppSettingsModel({
    this.miniOsVersion,
    this.minAndroidVersion,
    this.privacyPoliceLink,
    this.termsConditionsLink,
    this.helpLink,
    this.howDidYouHears,
  });

  factory AppSettingsModel.fromJson(Map<String, dynamic> json) =>
      _$AppSettingsModelFromJson(json);

  @JsonKey(name: 'miniOsVersion', includeIfNull: false, defaultValue: '')
  final String? miniOsVersion;
  @JsonKey(name: 'minAndroidVersion', includeIfNull: false, defaultValue: '')
  final String? minAndroidVersion;
  @JsonKey(name: 'privacyPoliceLink', includeIfNull: false, defaultValue: '')
  final String? privacyPoliceLink;
  @JsonKey(name: 'termsConditionsLink', includeIfNull: false, defaultValue: '')
  final String? termsConditionsLink;
  @JsonKey(name: 'helpLink', includeIfNull: false, defaultValue: '')
  final String? helpLink;
  @JsonKey(
      name: 'howDidYouHears', includeIfNull: false, defaultValue: <String>[])
  final List<String>? howDidYouHears;
  static const fromJsonFactory = _$AppSettingsModelFromJson;
  static const toJsonFactory = _$AppSettingsModelToJson;
  Map<String, dynamic> toJson() => _$AppSettingsModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AppSettingsModel &&
            (identical(other.miniOsVersion, miniOsVersion) ||
                const DeepCollectionEquality()
                    .equals(other.miniOsVersion, miniOsVersion)) &&
            (identical(other.minAndroidVersion, minAndroidVersion) ||
                const DeepCollectionEquality()
                    .equals(other.minAndroidVersion, minAndroidVersion)) &&
            (identical(other.privacyPoliceLink, privacyPoliceLink) ||
                const DeepCollectionEquality()
                    .equals(other.privacyPoliceLink, privacyPoliceLink)) &&
            (identical(other.termsConditionsLink, termsConditionsLink) ||
                const DeepCollectionEquality()
                    .equals(other.termsConditionsLink, termsConditionsLink)) &&
            (identical(other.helpLink, helpLink) ||
                const DeepCollectionEquality()
                    .equals(other.helpLink, helpLink)) &&
            (identical(other.howDidYouHears, howDidYouHears) ||
                const DeepCollectionEquality()
                    .equals(other.howDidYouHears, howDidYouHears)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(miniOsVersion) ^
      const DeepCollectionEquality().hash(minAndroidVersion) ^
      const DeepCollectionEquality().hash(privacyPoliceLink) ^
      const DeepCollectionEquality().hash(termsConditionsLink) ^
      const DeepCollectionEquality().hash(helpLink) ^
      const DeepCollectionEquality().hash(howDidYouHears) ^
      runtimeType.hashCode;
}

extension $AppSettingsModelExtension on AppSettingsModel {
  AppSettingsModel copyWith(
      {String? miniOsVersion,
      String? minAndroidVersion,
      String? privacyPoliceLink,
      String? termsConditionsLink,
      String? helpLink,
      List<String>? howDidYouHears}) {
    return AppSettingsModel(
        miniOsVersion: miniOsVersion ?? this.miniOsVersion,
        minAndroidVersion: minAndroidVersion ?? this.minAndroidVersion,
        privacyPoliceLink: privacyPoliceLink ?? this.privacyPoliceLink,
        termsConditionsLink: termsConditionsLink ?? this.termsConditionsLink,
        helpLink: helpLink ?? this.helpLink,
        howDidYouHears: howDidYouHears ?? this.howDidYouHears);
  }

  AppSettingsModel copyWithWrapped(
      {Wrapped<String?>? miniOsVersion,
      Wrapped<String?>? minAndroidVersion,
      Wrapped<String?>? privacyPoliceLink,
      Wrapped<String?>? termsConditionsLink,
      Wrapped<String?>? helpLink,
      Wrapped<List<String>?>? howDidYouHears}) {
    return AppSettingsModel(
        miniOsVersion:
            (miniOsVersion != null ? miniOsVersion.value : this.miniOsVersion),
        minAndroidVersion: (minAndroidVersion != null
            ? minAndroidVersion.value
            : this.minAndroidVersion),
        privacyPoliceLink: (privacyPoliceLink != null
            ? privacyPoliceLink.value
            : this.privacyPoliceLink),
        termsConditionsLink: (termsConditionsLink != null
            ? termsConditionsLink.value
            : this.termsConditionsLink),
        helpLink: (helpLink != null ? helpLink.value : this.helpLink),
        howDidYouHears: (howDidYouHears != null
            ? howDidYouHears.value
            : this.howDidYouHears));
  }
}

@JsonSerializable(explicitToJson: true)
class AppUserModel {
  AppUserModel({
    this.id,
    this.firstName,
    this.lastName,
    this.userName,
    this.email,
    this.status,
    this.company,
    this.updatedTime,
    this.token,
    this.refreshToken,
  });

  factory AppUserModel.fromJson(Map<String, dynamic> json) =>
      _$AppUserModelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'userName', includeIfNull: false, defaultValue: '')
  final String? userName;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: userStatusToJson,
    fromJson: userStatusFromJson,
  )
  final enums.UserStatus? status;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'updatedTime', includeIfNull: false)
  final DateTime? updatedTime;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  static const fromJsonFactory = _$AppUserModelFromJson;
  static const toJsonFactory = _$AppUserModelToJson;
  Map<String, dynamic> toJson() => _$AppUserModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AppUserModel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.userName, userName) ||
                const DeepCollectionEquality()
                    .equals(other.userName, userName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.updatedTime, updatedTime) ||
                const DeepCollectionEquality()
                    .equals(other.updatedTime, updatedTime)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(userName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(updatedTime) ^
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      runtimeType.hashCode;
}

extension $AppUserModelExtension on AppUserModel {
  AppUserModel copyWith(
      {String? id,
      String? firstName,
      String? lastName,
      String? userName,
      String? email,
      enums.UserStatus? status,
      String? company,
      DateTime? updatedTime,
      String? token,
      String? refreshToken}) {
    return AppUserModel(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        userName: userName ?? this.userName,
        email: email ?? this.email,
        status: status ?? this.status,
        company: company ?? this.company,
        updatedTime: updatedTime ?? this.updatedTime,
        token: token ?? this.token,
        refreshToken: refreshToken ?? this.refreshToken);
  }

  AppUserModel copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? userName,
      Wrapped<String?>? email,
      Wrapped<enums.UserStatus?>? status,
      Wrapped<String?>? company,
      Wrapped<DateTime?>? updatedTime,
      Wrapped<String?>? token,
      Wrapped<String?>? refreshToken}) {
    return AppUserModel(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        userName: (userName != null ? userName.value : this.userName),
        email: (email != null ? email.value : this.email),
        status: (status != null ? status.value : this.status),
        company: (company != null ? company.value : this.company),
        updatedTime:
            (updatedTime != null ? updatedTime.value : this.updatedTime),
        token: (token != null ? token.value : this.token),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class AppUserModelBase {
  AppUserModelBase({
    this.id,
    this.firstName,
    this.lastName,
    this.userName,
    this.email,
    this.status,
    this.company,
    this.updatedTime,
  });

  factory AppUserModelBase.fromJson(Map<String, dynamic> json) =>
      _$AppUserModelBaseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'userName', includeIfNull: false, defaultValue: '')
  final String? userName;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: userStatusToJson,
    fromJson: userStatusFromJson,
  )
  final enums.UserStatus? status;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'updatedTime', includeIfNull: false)
  final DateTime? updatedTime;
  static const fromJsonFactory = _$AppUserModelBaseFromJson;
  static const toJsonFactory = _$AppUserModelBaseToJson;
  Map<String, dynamic> toJson() => _$AppUserModelBaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AppUserModelBase &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.userName, userName) ||
                const DeepCollectionEquality()
                    .equals(other.userName, userName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.updatedTime, updatedTime) ||
                const DeepCollectionEquality()
                    .equals(other.updatedTime, updatedTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(userName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(updatedTime) ^
      runtimeType.hashCode;
}

extension $AppUserModelBaseExtension on AppUserModelBase {
  AppUserModelBase copyWith(
      {String? id,
      String? firstName,
      String? lastName,
      String? userName,
      String? email,
      enums.UserStatus? status,
      String? company,
      DateTime? updatedTime}) {
    return AppUserModelBase(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        userName: userName ?? this.userName,
        email: email ?? this.email,
        status: status ?? this.status,
        company: company ?? this.company,
        updatedTime: updatedTime ?? this.updatedTime);
  }

  AppUserModelBase copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? userName,
      Wrapped<String?>? email,
      Wrapped<enums.UserStatus?>? status,
      Wrapped<String?>? company,
      Wrapped<DateTime?>? updatedTime}) {
    return AppUserModelBase(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        userName: (userName != null ? userName.value : this.userName),
        email: (email != null ? email.value : this.email),
        status: (status != null ? status.value : this.status),
        company: (company != null ? company.value : this.company),
        updatedTime:
            (updatedTime != null ? updatedTime.value : this.updatedTime));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthenticateModel {
  AuthenticateModel({
    required this.username,
    required this.password,
  });

  factory AuthenticateModel.fromJson(Map<String, dynamic> json) =>
      _$AuthenticateModelFromJson(json);

  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  static const fromJsonFactory = _$AuthenticateModelFromJson;
  static const toJsonFactory = _$AuthenticateModelToJson;
  Map<String, dynamic> toJson() => _$AuthenticateModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthenticateModel &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $AuthenticateModelExtension on AuthenticateModel {
  AuthenticateModel copyWith({String? username, String? password}) {
    return AuthenticateModel(
        username: username ?? this.username,
        password: password ?? this.password);
  }

  AuthenticateModel copyWithWrapped(
      {Wrapped<String>? username, Wrapped<String>? password}) {
    return AuthenticateModel(
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class BarcodeComplete {
  BarcodeComplete({
    required this.barcode,
    required this.locationId,
    this.countBottles,
    this.qrCode,
  });

  factory BarcodeComplete.fromJson(Map<String, dynamic> json) =>
      _$BarcodeCompleteFromJson(json);

  @JsonKey(name: 'barcode', includeIfNull: false, defaultValue: '')
  final String barcode;
  @JsonKey(name: 'locationId', includeIfNull: false, defaultValue: '')
  final String locationId;
  @JsonKey(name: 'countBottles', includeIfNull: false)
  final int? countBottles;
  @JsonKey(name: 'qrCode', includeIfNull: false, defaultValue: '')
  final String? qrCode;
  static const fromJsonFactory = _$BarcodeCompleteFromJson;
  static const toJsonFactory = _$BarcodeCompleteToJson;
  Map<String, dynamic> toJson() => _$BarcodeCompleteToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BarcodeComplete &&
            (identical(other.barcode, barcode) ||
                const DeepCollectionEquality()
                    .equals(other.barcode, barcode)) &&
            (identical(other.locationId, locationId) ||
                const DeepCollectionEquality()
                    .equals(other.locationId, locationId)) &&
            (identical(other.countBottles, countBottles) ||
                const DeepCollectionEquality()
                    .equals(other.countBottles, countBottles)) &&
            (identical(other.qrCode, qrCode) ||
                const DeepCollectionEquality().equals(other.qrCode, qrCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(barcode) ^
      const DeepCollectionEquality().hash(locationId) ^
      const DeepCollectionEquality().hash(countBottles) ^
      const DeepCollectionEquality().hash(qrCode) ^
      runtimeType.hashCode;
}

extension $BarcodeCompleteExtension on BarcodeComplete {
  BarcodeComplete copyWith(
      {String? barcode,
      String? locationId,
      int? countBottles,
      String? qrCode}) {
    return BarcodeComplete(
        barcode: barcode ?? this.barcode,
        locationId: locationId ?? this.locationId,
        countBottles: countBottles ?? this.countBottles,
        qrCode: qrCode ?? this.qrCode);
  }

  BarcodeComplete copyWithWrapped(
      {Wrapped<String>? barcode,
      Wrapped<String>? locationId,
      Wrapped<int?>? countBottles,
      Wrapped<String?>? qrCode}) {
    return BarcodeComplete(
        barcode: (barcode != null ? barcode.value : this.barcode),
        locationId: (locationId != null ? locationId.value : this.locationId),
        countBottles:
            (countBottles != null ? countBottles.value : this.countBottles),
        qrCode: (qrCode != null ? qrCode.value : this.qrCode));
  }
}

@JsonSerializable(explicitToJson: true)
class CanBeClosedAccountModel {
  CanBeClosedAccountModel({
    this.canClose,
  });

  factory CanBeClosedAccountModel.fromJson(Map<String, dynamic> json) =>
      _$CanBeClosedAccountModelFromJson(json);

  @JsonKey(name: 'canClose', includeIfNull: false)
  final bool? canClose;
  static const fromJsonFactory = _$CanBeClosedAccountModelFromJson;
  static const toJsonFactory = _$CanBeClosedAccountModelToJson;
  Map<String, dynamic> toJson() => _$CanBeClosedAccountModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CanBeClosedAccountModel &&
            (identical(other.canClose, canClose) ||
                const DeepCollectionEquality()
                    .equals(other.canClose, canClose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(canClose) ^ runtimeType.hashCode;
}

extension $CanBeClosedAccountModelExtension on CanBeClosedAccountModel {
  CanBeClosedAccountModel copyWith({bool? canClose}) {
    return CanBeClosedAccountModel(canClose: canClose ?? this.canClose);
  }

  CanBeClosedAccountModel copyWithWrapped({Wrapped<bool?>? canClose}) {
    return CanBeClosedAccountModel(
        canClose: (canClose != null ? canClose.value : this.canClose));
  }
}

@JsonSerializable(explicitToJson: true)
class CardModel {
  CardModel({
    this.lastDigits,
    this.status,
    this.isFrozen,
    this.validPeriod,
    this.holderName,
    this.token,
    this.physicalCardRequest,
    this.isPhysicalCard,
    this.physicalCardStatus,
  });

  factory CardModel.fromJson(Map<String, dynamic> json) =>
      _$CardModelFromJson(json);

  @JsonKey(name: 'lastDigits', includeIfNull: false, defaultValue: '')
  final String? lastDigits;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'isFrozen', includeIfNull: false)
  final bool? isFrozen;
  @JsonKey(name: 'validPeriod', includeIfNull: false, defaultValue: '')
  final String? validPeriod;
  @JsonKey(name: 'holderName', includeIfNull: false, defaultValue: '')
  final String? holderName;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  @JsonKey(name: 'physicalCardRequest', includeIfNull: false)
  final bool? physicalCardRequest;
  @JsonKey(name: 'isPhysicalCard', includeIfNull: false)
  final bool? isPhysicalCard;
  @JsonKey(
    name: 'physicalCardStatus',
    includeIfNull: false,
    toJson: cardStatusToJson,
    fromJson: cardStatusFromJson,
  )
  final enums.CardStatus? physicalCardStatus;
  static const fromJsonFactory = _$CardModelFromJson;
  static const toJsonFactory = _$CardModelToJson;
  Map<String, dynamic> toJson() => _$CardModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CardModel &&
            (identical(other.lastDigits, lastDigits) ||
                const DeepCollectionEquality()
                    .equals(other.lastDigits, lastDigits)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.isFrozen, isFrozen) ||
                const DeepCollectionEquality()
                    .equals(other.isFrozen, isFrozen)) &&
            (identical(other.validPeriod, validPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.validPeriod, validPeriod)) &&
            (identical(other.holderName, holderName) ||
                const DeepCollectionEquality()
                    .equals(other.holderName, holderName)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.physicalCardRequest, physicalCardRequest) ||
                const DeepCollectionEquality()
                    .equals(other.physicalCardRequest, physicalCardRequest)) &&
            (identical(other.isPhysicalCard, isPhysicalCard) ||
                const DeepCollectionEquality()
                    .equals(other.isPhysicalCard, isPhysicalCard)) &&
            (identical(other.physicalCardStatus, physicalCardStatus) ||
                const DeepCollectionEquality()
                    .equals(other.physicalCardStatus, physicalCardStatus)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastDigits) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(isFrozen) ^
      const DeepCollectionEquality().hash(validPeriod) ^
      const DeepCollectionEquality().hash(holderName) ^
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(physicalCardRequest) ^
      const DeepCollectionEquality().hash(isPhysicalCard) ^
      const DeepCollectionEquality().hash(physicalCardStatus) ^
      runtimeType.hashCode;
}

extension $CardModelExtension on CardModel {
  CardModel copyWith(
      {String? lastDigits,
      String? status,
      bool? isFrozen,
      String? validPeriod,
      String? holderName,
      String? token,
      bool? physicalCardRequest,
      bool? isPhysicalCard,
      enums.CardStatus? physicalCardStatus}) {
    return CardModel(
        lastDigits: lastDigits ?? this.lastDigits,
        status: status ?? this.status,
        isFrozen: isFrozen ?? this.isFrozen,
        validPeriod: validPeriod ?? this.validPeriod,
        holderName: holderName ?? this.holderName,
        token: token ?? this.token,
        physicalCardRequest: physicalCardRequest ?? this.physicalCardRequest,
        isPhysicalCard: isPhysicalCard ?? this.isPhysicalCard,
        physicalCardStatus: physicalCardStatus ?? this.physicalCardStatus);
  }

  CardModel copyWithWrapped(
      {Wrapped<String?>? lastDigits,
      Wrapped<String?>? status,
      Wrapped<bool?>? isFrozen,
      Wrapped<String?>? validPeriod,
      Wrapped<String?>? holderName,
      Wrapped<String?>? token,
      Wrapped<bool?>? physicalCardRequest,
      Wrapped<bool?>? isPhysicalCard,
      Wrapped<enums.CardStatus?>? physicalCardStatus}) {
    return CardModel(
        lastDigits: (lastDigits != null ? lastDigits.value : this.lastDigits),
        status: (status != null ? status.value : this.status),
        isFrozen: (isFrozen != null ? isFrozen.value : this.isFrozen),
        validPeriod:
            (validPeriod != null ? validPeriod.value : this.validPeriod),
        holderName: (holderName != null ? holderName.value : this.holderName),
        token: (token != null ? token.value : this.token),
        physicalCardRequest: (physicalCardRequest != null
            ? physicalCardRequest.value
            : this.physicalCardRequest),
        isPhysicalCard: (isPhysicalCard != null
            ? isPhysicalCard.value
            : this.isPhysicalCard),
        physicalCardStatus: (physicalCardStatus != null
            ? physicalCardStatus.value
            : this.physicalCardStatus));
  }
}

@JsonSerializable(explicitToJson: true)
class CardSecret {
  CardSecret({
    this.token,
    this.secret,
  });

  factory CardSecret.fromJson(Map<String, dynamic> json) =>
      _$CardSecretFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  @JsonKey(name: 'secret', includeIfNull: false, defaultValue: '')
  final String? secret;
  static const fromJsonFactory = _$CardSecretFromJson;
  static const toJsonFactory = _$CardSecretToJson;
  Map<String, dynamic> toJson() => _$CardSecretToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CardSecret &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.secret, secret) ||
                const DeepCollectionEquality().equals(other.secret, secret)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(secret) ^
      runtimeType.hashCode;
}

extension $CardSecretExtension on CardSecret {
  CardSecret copyWith({String? token, String? secret}) {
    return CardSecret(
        token: token ?? this.token, secret: secret ?? this.secret);
  }

  CardSecret copyWithWrapped(
      {Wrapped<String?>? token, Wrapped<String?>? secret}) {
    return CardSecret(
        token: (token != null ? token.value : this.token),
        secret: (secret != null ? secret.value : this.secret));
  }
}

@JsonSerializable(explicitToJson: true)
class CategoryModel {
  CategoryModel({
    this.id,
    this.title,
    this.iconSvg,
  });

  factory CategoryModel.fromJson(Map<String, dynamic> json) =>
      _$CategoryModelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'iconSvg', includeIfNull: false, defaultValue: '')
  final String? iconSvg;
  static const fromJsonFactory = _$CategoryModelFromJson;
  static const toJsonFactory = _$CategoryModelToJson;
  Map<String, dynamic> toJson() => _$CategoryModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CategoryModel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.iconSvg, iconSvg) ||
                const DeepCollectionEquality().equals(other.iconSvg, iconSvg)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(iconSvg) ^
      runtimeType.hashCode;
}

extension $CategoryModelExtension on CategoryModel {
  CategoryModel copyWith({String? id, String? title, String? iconSvg}) {
    return CategoryModel(
        id: id ?? this.id,
        title: title ?? this.title,
        iconSvg: iconSvg ?? this.iconSvg);
  }

  CategoryModel copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? iconSvg}) {
    return CategoryModel(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        iconSvg: (iconSvg != null ? iconSvg.value : this.iconSvg));
  }
}

@JsonSerializable(explicitToJson: true)
class CloseAccount {
  CloseAccount({
    this.holderName,
    this.accountNumber,
    this.sortCode,
  });

  factory CloseAccount.fromJson(Map<String, dynamic> json) =>
      _$CloseAccountFromJson(json);

  @JsonKey(name: 'holderName', includeIfNull: false, defaultValue: '')
  final String? holderName;
  @JsonKey(name: 'accountNumber', includeIfNull: false, defaultValue: '')
  final String? accountNumber;
  @JsonKey(name: 'sortCode', includeIfNull: false, defaultValue: '')
  final String? sortCode;
  static const fromJsonFactory = _$CloseAccountFromJson;
  static const toJsonFactory = _$CloseAccountToJson;
  Map<String, dynamic> toJson() => _$CloseAccountToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CloseAccount &&
            (identical(other.holderName, holderName) ||
                const DeepCollectionEquality()
                    .equals(other.holderName, holderName)) &&
            (identical(other.accountNumber, accountNumber) ||
                const DeepCollectionEquality()
                    .equals(other.accountNumber, accountNumber)) &&
            (identical(other.sortCode, sortCode) ||
                const DeepCollectionEquality()
                    .equals(other.sortCode, sortCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(holderName) ^
      const DeepCollectionEquality().hash(accountNumber) ^
      const DeepCollectionEquality().hash(sortCode) ^
      runtimeType.hashCode;
}

extension $CloseAccountExtension on CloseAccount {
  CloseAccount copyWith(
      {String? holderName, String? accountNumber, String? sortCode}) {
    return CloseAccount(
        holderName: holderName ?? this.holderName,
        accountNumber: accountNumber ?? this.accountNumber,
        sortCode: sortCode ?? this.sortCode);
  }

  CloseAccount copyWithWrapped(
      {Wrapped<String?>? holderName,
      Wrapped<String?>? accountNumber,
      Wrapped<String?>? sortCode}) {
    return CloseAccount(
        holderName: (holderName != null ? holderName.value : this.holderName),
        accountNumber:
            (accountNumber != null ? accountNumber.value : this.accountNumber),
        sortCode: (sortCode != null ? sortCode.value : this.sortCode));
  }
}

@JsonSerializable(explicitToJson: true)
class ConfirmToken {
  ConfirmToken({
    required this.email,
  });

  factory ConfirmToken.fromJson(Map<String, dynamic> json) =>
      _$ConfirmTokenFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  static const fromJsonFactory = _$ConfirmTokenFromJson;
  static const toJsonFactory = _$ConfirmTokenToJson;
  Map<String, dynamic> toJson() => _$ConfirmTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ConfirmToken &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^ runtimeType.hashCode;
}

extension $ConfirmTokenExtension on ConfirmToken {
  ConfirmToken copyWith({String? email}) {
    return ConfirmToken(email: email ?? this.email);
  }

  ConfirmToken copyWithWrapped({Wrapped<String>? email}) {
    return ConfirmToken(email: (email != null ? email.value : this.email));
  }
}

@JsonSerializable(explicitToJson: true)
class CreateLinkToken {
  CreateLinkToken({
    required this.amount,
    this.type,
    this.startDate,
  });

  factory CreateLinkToken.fromJson(Map<String, dynamic> json) =>
      _$CreateLinkTokenFromJson(json);

  @JsonKey(name: 'amount', includeIfNull: false)
  final double amount;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: linkTokenTypeToJson,
    fromJson: linkTokenTypeFromJson,
  )
  final enums.LinkTokenType? type;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  static const fromJsonFactory = _$CreateLinkTokenFromJson;
  static const toJsonFactory = _$CreateLinkTokenToJson;
  Map<String, dynamic> toJson() => _$CreateLinkTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CreateLinkToken &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(startDate) ^
      runtimeType.hashCode;
}

extension $CreateLinkTokenExtension on CreateLinkToken {
  CreateLinkToken copyWith(
      {double? amount, enums.LinkTokenType? type, DateTime? startDate}) {
    return CreateLinkToken(
        amount: amount ?? this.amount,
        type: type ?? this.type,
        startDate: startDate ?? this.startDate);
  }

  CreateLinkToken copyWithWrapped(
      {Wrapped<double>? amount,
      Wrapped<enums.LinkTokenType?>? type,
      Wrapped<DateTime?>? startDate}) {
    return CreateLinkToken(
        amount: (amount != null ? amount.value : this.amount),
        type: (type != null ? type.value : this.type),
        startDate: (startDate != null ? startDate.value : this.startDate));
  }
}

@JsonSerializable(explicitToJson: true)
class CreatePushChannel {
  CreatePushChannel({
    required this.platform,
    required this.channel,
  });

  factory CreatePushChannel.fromJson(Map<String, dynamic> json) =>
      _$CreatePushChannelFromJson(json);

  @JsonKey(name: 'platform', includeIfNull: false, defaultValue: '')
  final String platform;
  @JsonKey(name: 'channel', includeIfNull: false, defaultValue: '')
  final String channel;
  static const fromJsonFactory = _$CreatePushChannelFromJson;
  static const toJsonFactory = _$CreatePushChannelToJson;
  Map<String, dynamic> toJson() => _$CreatePushChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CreatePushChannel &&
            (identical(other.platform, platform) ||
                const DeepCollectionEquality()
                    .equals(other.platform, platform)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality().equals(other.channel, channel)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(platform) ^
      const DeepCollectionEquality().hash(channel) ^
      runtimeType.hashCode;
}

extension $CreatePushChannelExtension on CreatePushChannel {
  CreatePushChannel copyWith({String? platform, String? channel}) {
    return CreatePushChannel(
        platform: platform ?? this.platform, channel: channel ?? this.channel);
  }

  CreatePushChannel copyWithWrapped(
      {Wrapped<String>? platform, Wrapped<String>? channel}) {
    return CreatePushChannel(
        platform: (platform != null ? platform.value : this.platform),
        channel: (channel != null ? channel.value : this.channel));
  }
}

@JsonSerializable(explicitToJson: true)
class DrsAccountModel {
  DrsAccountModel({
    this.balance,
    this.bottles,
    this.refund,
  });

  factory DrsAccountModel.fromJson(Map<String, dynamic> json) =>
      _$DrsAccountModelFromJson(json);

  @JsonKey(name: 'balance', includeIfNull: false)
  final double? balance;
  @JsonKey(name: 'bottles', includeIfNull: false)
  final int? bottles;
  @JsonKey(name: 'refund', includeIfNull: false)
  final double? refund;
  static const fromJsonFactory = _$DrsAccountModelFromJson;
  static const toJsonFactory = _$DrsAccountModelToJson;
  Map<String, dynamic> toJson() => _$DrsAccountModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DrsAccountModel &&
            (identical(other.balance, balance) ||
                const DeepCollectionEquality()
                    .equals(other.balance, balance)) &&
            (identical(other.bottles, bottles) ||
                const DeepCollectionEquality()
                    .equals(other.bottles, bottles)) &&
            (identical(other.refund, refund) ||
                const DeepCollectionEquality().equals(other.refund, refund)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(balance) ^
      const DeepCollectionEquality().hash(bottles) ^
      const DeepCollectionEquality().hash(refund) ^
      runtimeType.hashCode;
}

extension $DrsAccountModelExtension on DrsAccountModel {
  DrsAccountModel copyWith({double? balance, int? bottles, double? refund}) {
    return DrsAccountModel(
        balance: balance ?? this.balance,
        bottles: bottles ?? this.bottles,
        refund: refund ?? this.refund);
  }

  DrsAccountModel copyWithWrapped(
      {Wrapped<double?>? balance,
      Wrapped<int?>? bottles,
      Wrapped<double?>? refund}) {
    return DrsAccountModel(
        balance: (balance != null ? balance.value : this.balance),
        bottles: (bottles != null ? bottles.value : this.bottles),
        refund: (refund != null ? refund.value : this.refund));
  }
}

@JsonSerializable(explicitToJson: true)
class DrsLocationModel {
  DrsLocationModel({
    this.bins,
    this.retailers,
  });

  factory DrsLocationModel.fromJson(Map<String, dynamic> json) =>
      _$DrsLocationModelFromJson(json);

  @JsonKey(name: 'bins', includeIfNull: false, defaultValue: <LocationItem>[])
  final List<LocationItem>? bins;
  @JsonKey(
      name: 'retailers', includeIfNull: false, defaultValue: <LocationItem>[])
  final List<LocationItem>? retailers;
  static const fromJsonFactory = _$DrsLocationModelFromJson;
  static const toJsonFactory = _$DrsLocationModelToJson;
  Map<String, dynamic> toJson() => _$DrsLocationModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DrsLocationModel &&
            (identical(other.bins, bins) ||
                const DeepCollectionEquality().equals(other.bins, bins)) &&
            (identical(other.retailers, retailers) ||
                const DeepCollectionEquality()
                    .equals(other.retailers, retailers)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(bins) ^
      const DeepCollectionEquality().hash(retailers) ^
      runtimeType.hashCode;
}

extension $DrsLocationModelExtension on DrsLocationModel {
  DrsLocationModel copyWith(
      {List<LocationItem>? bins, List<LocationItem>? retailers}) {
    return DrsLocationModel(
        bins: bins ?? this.bins, retailers: retailers ?? this.retailers);
  }

  DrsLocationModel copyWithWrapped(
      {Wrapped<List<LocationItem>?>? bins,
      Wrapped<List<LocationItem>?>? retailers}) {
    return DrsLocationModel(
        bins: (bins != null ? bins.value : this.bins),
        retailers: (retailers != null ? retailers.value : this.retailers));
  }
}

@JsonSerializable(explicitToJson: true)
class DrsTransactionsModel {
  DrsTransactionsModel({
    this.date,
    this.refund,
    this.numberOfDeposits,
  });

  factory DrsTransactionsModel.fromJson(Map<String, dynamic> json) =>
      _$DrsTransactionsModelFromJson(json);

  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'refund', includeIfNull: false)
  final double? refund;
  @JsonKey(name: 'numberOfDeposits', includeIfNull: false)
  final int? numberOfDeposits;
  static const fromJsonFactory = _$DrsTransactionsModelFromJson;
  static const toJsonFactory = _$DrsTransactionsModelToJson;
  Map<String, dynamic> toJson() => _$DrsTransactionsModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DrsTransactionsModel &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.refund, refund) ||
                const DeepCollectionEquality().equals(other.refund, refund)) &&
            (identical(other.numberOfDeposits, numberOfDeposits) ||
                const DeepCollectionEquality()
                    .equals(other.numberOfDeposits, numberOfDeposits)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(refund) ^
      const DeepCollectionEquality().hash(numberOfDeposits) ^
      runtimeType.hashCode;
}

extension $DrsTransactionsModelExtension on DrsTransactionsModel {
  DrsTransactionsModel copyWith(
      {DateTime? date, double? refund, int? numberOfDeposits}) {
    return DrsTransactionsModel(
        date: date ?? this.date,
        refund: refund ?? this.refund,
        numberOfDeposits: numberOfDeposits ?? this.numberOfDeposits);
  }

  DrsTransactionsModel copyWithWrapped(
      {Wrapped<DateTime?>? date,
      Wrapped<double?>? refund,
      Wrapped<int?>? numberOfDeposits}) {
    return DrsTransactionsModel(
        date: (date != null ? date.value : this.date),
        refund: (refund != null ? refund.value : this.refund),
        numberOfDeposits: (numberOfDeposits != null
            ? numberOfDeposits.value
            : this.numberOfDeposits));
  }
}

@JsonSerializable(explicitToJson: true)
class EditAppUser {
  EditAppUser({
    required this.firstName,
    required this.lastName,
    required this.city,
    required this.addressNumber,
    required this.region,
    required this.postalCode,
    this.street,
    required this.phoneNumber,
    this.howDidYouHear,
    this.company,
  });

  factory EditAppUser.fromJson(Map<String, dynamic> json) =>
      _$EditAppUserFromJson(json);

  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String lastName;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String city;
  @JsonKey(name: 'addressNumber', includeIfNull: false, defaultValue: '')
  final String addressNumber;
  @JsonKey(name: 'region', includeIfNull: false, defaultValue: '')
  final String region;
  @JsonKey(name: 'postalCode', includeIfNull: false, defaultValue: '')
  final String postalCode;
  @JsonKey(name: 'street', includeIfNull: false, defaultValue: '')
  final String? street;
  @JsonKey(name: 'phoneNumber', includeIfNull: false, defaultValue: '')
  final String phoneNumber;
  @JsonKey(name: 'howDidYouHear', includeIfNull: false, defaultValue: '')
  final String? howDidYouHear;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  static const fromJsonFactory = _$EditAppUserFromJson;
  static const toJsonFactory = _$EditAppUserToJson;
  Map<String, dynamic> toJson() => _$EditAppUserToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EditAppUser &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.addressNumber, addressNumber) ||
                const DeepCollectionEquality()
                    .equals(other.addressNumber, addressNumber)) &&
            (identical(other.region, region) ||
                const DeepCollectionEquality().equals(other.region, region)) &&
            (identical(other.postalCode, postalCode) ||
                const DeepCollectionEquality()
                    .equals(other.postalCode, postalCode)) &&
            (identical(other.street, street) ||
                const DeepCollectionEquality().equals(other.street, street)) &&
            (identical(other.phoneNumber, phoneNumber) ||
                const DeepCollectionEquality()
                    .equals(other.phoneNumber, phoneNumber)) &&
            (identical(other.howDidYouHear, howDidYouHear) ||
                const DeepCollectionEquality()
                    .equals(other.howDidYouHear, howDidYouHear)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality().equals(other.company, company)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(addressNumber) ^
      const DeepCollectionEquality().hash(region) ^
      const DeepCollectionEquality().hash(postalCode) ^
      const DeepCollectionEquality().hash(street) ^
      const DeepCollectionEquality().hash(phoneNumber) ^
      const DeepCollectionEquality().hash(howDidYouHear) ^
      const DeepCollectionEquality().hash(company) ^
      runtimeType.hashCode;
}

extension $EditAppUserExtension on EditAppUser {
  EditAppUser copyWith(
      {String? firstName,
      String? lastName,
      String? city,
      String? addressNumber,
      String? region,
      String? postalCode,
      String? street,
      String? phoneNumber,
      String? howDidYouHear,
      String? company}) {
    return EditAppUser(
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        city: city ?? this.city,
        addressNumber: addressNumber ?? this.addressNumber,
        region: region ?? this.region,
        postalCode: postalCode ?? this.postalCode,
        street: street ?? this.street,
        phoneNumber: phoneNumber ?? this.phoneNumber,
        howDidYouHear: howDidYouHear ?? this.howDidYouHear,
        company: company ?? this.company);
  }

  EditAppUser copyWithWrapped(
      {Wrapped<String>? firstName,
      Wrapped<String>? lastName,
      Wrapped<String>? city,
      Wrapped<String>? addressNumber,
      Wrapped<String>? region,
      Wrapped<String>? postalCode,
      Wrapped<String?>? street,
      Wrapped<String>? phoneNumber,
      Wrapped<String?>? howDidYouHear,
      Wrapped<String?>? company}) {
    return EditAppUser(
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        city: (city != null ? city.value : this.city),
        addressNumber:
            (addressNumber != null ? addressNumber.value : this.addressNumber),
        region: (region != null ? region.value : this.region),
        postalCode: (postalCode != null ? postalCode.value : this.postalCode),
        street: (street != null ? street.value : this.street),
        phoneNumber:
            (phoneNumber != null ? phoneNumber.value : this.phoneNumber),
        howDidYouHear:
            (howDidYouHear != null ? howDidYouHear.value : this.howDidYouHear),
        company: (company != null ? company.value : this.company));
  }
}

@JsonSerializable(explicitToJson: true)
class EditPassword {
  EditPassword({
    required this.oldPassword,
    required this.newPassword,
    required this.confirmPassword,
  });

  factory EditPassword.fromJson(Map<String, dynamic> json) =>
      _$EditPasswordFromJson(json);

  @JsonKey(name: 'oldPassword', includeIfNull: false, defaultValue: '')
  final String oldPassword;
  @JsonKey(name: 'newPassword', includeIfNull: false, defaultValue: '')
  final String newPassword;
  @JsonKey(name: 'confirmPassword', includeIfNull: false, defaultValue: '')
  final String confirmPassword;
  static const fromJsonFactory = _$EditPasswordFromJson;
  static const toJsonFactory = _$EditPasswordToJson;
  Map<String, dynamic> toJson() => _$EditPasswordToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EditPassword &&
            (identical(other.oldPassword, oldPassword) ||
                const DeepCollectionEquality()
                    .equals(other.oldPassword, oldPassword)) &&
            (identical(other.newPassword, newPassword) ||
                const DeepCollectionEquality()
                    .equals(other.newPassword, newPassword)) &&
            (identical(other.confirmPassword, confirmPassword) ||
                const DeepCollectionEquality()
                    .equals(other.confirmPassword, confirmPassword)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(oldPassword) ^
      const DeepCollectionEquality().hash(newPassword) ^
      const DeepCollectionEquality().hash(confirmPassword) ^
      runtimeType.hashCode;
}

extension $EditPasswordExtension on EditPassword {
  EditPassword copyWith(
      {String? oldPassword, String? newPassword, String? confirmPassword}) {
    return EditPassword(
        oldPassword: oldPassword ?? this.oldPassword,
        newPassword: newPassword ?? this.newPassword,
        confirmPassword: confirmPassword ?? this.confirmPassword);
  }

  EditPassword copyWithWrapped(
      {Wrapped<String>? oldPassword,
      Wrapped<String>? newPassword,
      Wrapped<String>? confirmPassword}) {
    return EditPassword(
        oldPassword:
            (oldPassword != null ? oldPassword.value : this.oldPassword),
        newPassword:
            (newPassword != null ? newPassword.value : this.newPassword),
        confirmPassword: (confirmPassword != null
            ? confirmPassword.value
            : this.confirmPassword));
  }
}

@JsonSerializable(explicitToJson: true)
class ForgotPassword {
  ForgotPassword({
    required this.email,
  });

  factory ForgotPassword.fromJson(Map<String, dynamic> json) =>
      _$ForgotPasswordFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  static const fromJsonFactory = _$ForgotPasswordFromJson;
  static const toJsonFactory = _$ForgotPasswordToJson;
  Map<String, dynamic> toJson() => _$ForgotPasswordToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ForgotPassword &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^ runtimeType.hashCode;
}

extension $ForgotPasswordExtension on ForgotPassword {
  ForgotPassword copyWith({String? email}) {
    return ForgotPassword(email: email ?? this.email);
  }

  ForgotPassword copyWithWrapped({Wrapped<String>? email}) {
    return ForgotPassword(email: (email != null ? email.value : this.email));
  }
}

@JsonSerializable(explicitToJson: true)
class ImpactProfileModel {
  ImpactProfileModel({
    this.treesPlanted,
    this.oxygenReleased,
    this.coAbsorbed,
    this.cardTransaction,
    this.transactionsPerWeek,
  });

  factory ImpactProfileModel.fromJson(Map<String, dynamic> json) =>
      _$ImpactProfileModelFromJson(json);

  @JsonKey(name: 'treesPlanted', includeIfNull: false)
  final double? treesPlanted;
  @JsonKey(name: 'oxygenReleased', includeIfNull: false)
  final double? oxygenReleased;
  @JsonKey(name: 'coAbsorbed', includeIfNull: false)
  final double? coAbsorbed;
  @JsonKey(name: 'cardTransaction', includeIfNull: false)
  final double? cardTransaction;
  @JsonKey(name: 'transactionsPerWeek', includeIfNull: false)
  final double? transactionsPerWeek;
  static const fromJsonFactory = _$ImpactProfileModelFromJson;
  static const toJsonFactory = _$ImpactProfileModelToJson;
  Map<String, dynamic> toJson() => _$ImpactProfileModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ImpactProfileModel &&
            (identical(other.treesPlanted, treesPlanted) ||
                const DeepCollectionEquality()
                    .equals(other.treesPlanted, treesPlanted)) &&
            (identical(other.oxygenReleased, oxygenReleased) ||
                const DeepCollectionEquality()
                    .equals(other.oxygenReleased, oxygenReleased)) &&
            (identical(other.coAbsorbed, coAbsorbed) ||
                const DeepCollectionEquality()
                    .equals(other.coAbsorbed, coAbsorbed)) &&
            (identical(other.cardTransaction, cardTransaction) ||
                const DeepCollectionEquality()
                    .equals(other.cardTransaction, cardTransaction)) &&
            (identical(other.transactionsPerWeek, transactionsPerWeek) ||
                const DeepCollectionEquality()
                    .equals(other.transactionsPerWeek, transactionsPerWeek)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(treesPlanted) ^
      const DeepCollectionEquality().hash(oxygenReleased) ^
      const DeepCollectionEquality().hash(coAbsorbed) ^
      const DeepCollectionEquality().hash(cardTransaction) ^
      const DeepCollectionEquality().hash(transactionsPerWeek) ^
      runtimeType.hashCode;
}

extension $ImpactProfileModelExtension on ImpactProfileModel {
  ImpactProfileModel copyWith(
      {double? treesPlanted,
      double? oxygenReleased,
      double? coAbsorbed,
      double? cardTransaction,
      double? transactionsPerWeek}) {
    return ImpactProfileModel(
        treesPlanted: treesPlanted ?? this.treesPlanted,
        oxygenReleased: oxygenReleased ?? this.oxygenReleased,
        coAbsorbed: coAbsorbed ?? this.coAbsorbed,
        cardTransaction: cardTransaction ?? this.cardTransaction,
        transactionsPerWeek: transactionsPerWeek ?? this.transactionsPerWeek);
  }

  ImpactProfileModel copyWithWrapped(
      {Wrapped<double?>? treesPlanted,
      Wrapped<double?>? oxygenReleased,
      Wrapped<double?>? coAbsorbed,
      Wrapped<double?>? cardTransaction,
      Wrapped<double?>? transactionsPerWeek}) {
    return ImpactProfileModel(
        treesPlanted:
            (treesPlanted != null ? treesPlanted.value : this.treesPlanted),
        oxygenReleased: (oxygenReleased != null
            ? oxygenReleased.value
            : this.oxygenReleased),
        coAbsorbed: (coAbsorbed != null ? coAbsorbed.value : this.coAbsorbed),
        cardTransaction: (cardTransaction != null
            ? cardTransaction.value
            : this.cardTransaction),
        transactionsPerWeek: (transactionsPerWeek != null
            ? transactionsPerWeek.value
            : this.transactionsPerWeek));
  }
}

@JsonSerializable(explicitToJson: true)
class IncentiveClientModel {
  IncentiveClientModel({
    this.id,
    this.title,
    this.startDate,
    this.endDate,
    this.specialPromoImageUrl,
    this.specialPromoImageUrlForWebApp,
    this.retailer,
  });

  factory IncentiveClientModel.fromJson(Map<String, dynamic> json) =>
      _$IncentiveClientModelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  @JsonKey(name: 'specialPromoImageUrl', includeIfNull: false, defaultValue: '')
  final String? specialPromoImageUrl;
  @JsonKey(
      name: 'specialPromoImageUrlForWebApp',
      includeIfNull: false,
      defaultValue: '')
  final String? specialPromoImageUrlForWebApp;
  @JsonKey(name: 'retailer', includeIfNull: false)
  final RetailerModel? retailer;
  static const fromJsonFactory = _$IncentiveClientModelFromJson;
  static const toJsonFactory = _$IncentiveClientModelToJson;
  Map<String, dynamic> toJson() => _$IncentiveClientModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IncentiveClientModel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.specialPromoImageUrl, specialPromoImageUrl) ||
                const DeepCollectionEquality().equals(
                    other.specialPromoImageUrl, specialPromoImageUrl)) &&
            (identical(other.specialPromoImageUrlForWebApp,
                    specialPromoImageUrlForWebApp) ||
                const DeepCollectionEquality().equals(
                    other.specialPromoImageUrlForWebApp,
                    specialPromoImageUrlForWebApp)) &&
            (identical(other.retailer, retailer) ||
                const DeepCollectionEquality()
                    .equals(other.retailer, retailer)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(specialPromoImageUrl) ^
      const DeepCollectionEquality().hash(specialPromoImageUrlForWebApp) ^
      const DeepCollectionEquality().hash(retailer) ^
      runtimeType.hashCode;
}

extension $IncentiveClientModelExtension on IncentiveClientModel {
  IncentiveClientModel copyWith(
      {String? id,
      String? title,
      DateTime? startDate,
      DateTime? endDate,
      String? specialPromoImageUrl,
      String? specialPromoImageUrlForWebApp,
      RetailerModel? retailer}) {
    return IncentiveClientModel(
        id: id ?? this.id,
        title: title ?? this.title,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        specialPromoImageUrl: specialPromoImageUrl ?? this.specialPromoImageUrl,
        specialPromoImageUrlForWebApp:
            specialPromoImageUrlForWebApp ?? this.specialPromoImageUrlForWebApp,
        retailer: retailer ?? this.retailer);
  }

  IncentiveClientModel copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate,
      Wrapped<String?>? specialPromoImageUrl,
      Wrapped<String?>? specialPromoImageUrlForWebApp,
      Wrapped<RetailerModel?>? retailer}) {
    return IncentiveClientModel(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        specialPromoImageUrl: (specialPromoImageUrl != null
            ? specialPromoImageUrl.value
            : this.specialPromoImageUrl),
        specialPromoImageUrlForWebApp: (specialPromoImageUrlForWebApp != null
            ? specialPromoImageUrlForWebApp.value
            : this.specialPromoImageUrlForWebApp),
        retailer: (retailer != null ? retailer.value : this.retailer));
  }
}

@JsonSerializable(explicitToJson: true)
class LocationItem {
  LocationItem({
    this.id,
    this.name,
    this.description,
  });

  factory LocationItem.fromJson(Map<String, dynamic> json) =>
      _$LocationItemFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$LocationItemFromJson;
  static const toJsonFactory = _$LocationItemToJson;
  Map<String, dynamic> toJson() => _$LocationItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocationItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $LocationItemExtension on LocationItem {
  LocationItem copyWith({String? id, String? name, String? description}) {
    return LocationItem(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description);
  }

  LocationItem copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description}) {
    return LocationItem(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class OnfidoJwtModel {
  OnfidoJwtModel({
    this.token,
  });

  factory OnfidoJwtModel.fromJson(Map<String, dynamic> json) =>
      _$OnfidoJwtModelFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$OnfidoJwtModelFromJson;
  static const toJsonFactory = _$OnfidoJwtModelToJson;
  Map<String, dynamic> toJson() => _$OnfidoJwtModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OnfidoJwtModel &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^ runtimeType.hashCode;
}

extension $OnfidoJwtModelExtension on OnfidoJwtModel {
  OnfidoJwtModel copyWith({String? token}) {
    return OnfidoJwtModel(token: token ?? this.token);
  }

  OnfidoJwtModel copyWithWrapped({Wrapped<String?>? token}) {
    return OnfidoJwtModel(token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class PinModel {
  PinModel({
    this.pin,
  });

  factory PinModel.fromJson(Map<String, dynamic> json) =>
      _$PinModelFromJson(json);

  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  static const fromJsonFactory = _$PinModelFromJson;
  static const toJsonFactory = _$PinModelToJson;
  Map<String, dynamic> toJson() => _$PinModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinModel &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pin) ^ runtimeType.hashCode;
}

extension $PinModelExtension on PinModel {
  PinModel copyWith({String? pin}) {
    return PinModel(pin: pin ?? this.pin);
  }

  PinModel copyWithWrapped({Wrapped<String?>? pin}) {
    return PinModel(pin: (pin != null ? pin.value : this.pin));
  }
}

@JsonSerializable(explicitToJson: true)
class ProblemDetails {
  ProblemDetails({
    this.type,
    this.title,
    this.status,
    this.detail,
    this.instance,
  });

  factory ProblemDetails.fromJson(Map<String, dynamic> json) =>
      _$ProblemDetailsFromJson(json);

  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'status', includeIfNull: false)
  final int? status;
  @JsonKey(name: 'detail', includeIfNull: false, defaultValue: '')
  final String? detail;
  @JsonKey(name: 'instance', includeIfNull: false, defaultValue: '')
  final String? instance;
  static const fromJsonFactory = _$ProblemDetailsFromJson;
  static const toJsonFactory = _$ProblemDetailsToJson;
  Map<String, dynamic> toJson() => _$ProblemDetailsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProblemDetails &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.detail, detail) ||
                const DeepCollectionEquality().equals(other.detail, detail)) &&
            (identical(other.instance, instance) ||
                const DeepCollectionEquality()
                    .equals(other.instance, instance)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(detail) ^
      const DeepCollectionEquality().hash(instance) ^
      runtimeType.hashCode;
}

extension $ProblemDetailsExtension on ProblemDetails {
  ProblemDetails copyWith(
      {String? type,
      String? title,
      int? status,
      String? detail,
      String? instance}) {
    return ProblemDetails(
        type: type ?? this.type,
        title: title ?? this.title,
        status: status ?? this.status,
        detail: detail ?? this.detail,
        instance: instance ?? this.instance);
  }

  ProblemDetails copyWithWrapped(
      {Wrapped<String?>? type,
      Wrapped<String?>? title,
      Wrapped<int?>? status,
      Wrapped<String?>? detail,
      Wrapped<String?>? instance}) {
    return ProblemDetails(
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title),
        status: (status != null ? status.value : this.status),
        detail: (detail != null ? detail.value : this.detail),
        instance: (instance != null ? instance.value : this.instance));
  }
}

@JsonSerializable(explicitToJson: true)
class ReceivingMoneyModel {
  ReceivingMoneyModel({
    this.amount,
  });

  factory ReceivingMoneyModel.fromJson(Map<String, dynamic> json) =>
      _$ReceivingMoneyModelFromJson(json);

  @JsonKey(name: 'amount', includeIfNull: false)
  final double? amount;
  static const fromJsonFactory = _$ReceivingMoneyModelFromJson;
  static const toJsonFactory = _$ReceivingMoneyModelToJson;
  Map<String, dynamic> toJson() => _$ReceivingMoneyModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReceivingMoneyModel &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(amount) ^ runtimeType.hashCode;
}

extension $ReceivingMoneyModelExtension on ReceivingMoneyModel {
  ReceivingMoneyModel copyWith({double? amount}) {
    return ReceivingMoneyModel(amount: amount ?? this.amount);
  }

  ReceivingMoneyModel copyWithWrapped({Wrapped<double?>? amount}) {
    return ReceivingMoneyModel(
        amount: (amount != null ? amount.value : this.amount));
  }
}

@JsonSerializable(explicitToJson: true)
class RefreshToken {
  RefreshToken({
    required this.token,
  });

  factory RefreshToken.fromJson(Map<String, dynamic> json) =>
      _$RefreshTokenFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String token;
  static const fromJsonFactory = _$RefreshTokenFromJson;
  static const toJsonFactory = _$RefreshTokenToJson;
  Map<String, dynamic> toJson() => _$RefreshTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RefreshToken &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^ runtimeType.hashCode;
}

extension $RefreshTokenExtension on RefreshToken {
  RefreshToken copyWith({String? token}) {
    return RefreshToken(token: token ?? this.token);
  }

  RefreshToken copyWithWrapped({Wrapped<String>? token}) {
    return RefreshToken(token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class RegisterAppUser {
  RegisterAppUser({
    required this.firstName,
    required this.lastName,
    required this.city,
    required this.addressNumber,
    required this.region,
    required this.postalCode,
    this.street,
    required this.phoneNumber,
    this.howDidYouHear,
    this.company,
    required this.birthDate,
    required this.email,
    required this.token,
    required this.code,
    required this.password,
    required this.confirmPassword,
    this.userName,
  });

  factory RegisterAppUser.fromJson(Map<String, dynamic> json) =>
      _$RegisterAppUserFromJson(json);

  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String lastName;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String city;
  @JsonKey(name: 'addressNumber', includeIfNull: false, defaultValue: '')
  final String addressNumber;
  @JsonKey(name: 'region', includeIfNull: false, defaultValue: '')
  final String region;
  @JsonKey(name: 'postalCode', includeIfNull: false, defaultValue: '')
  final String postalCode;
  @JsonKey(name: 'street', includeIfNull: false, defaultValue: '')
  final String? street;
  @JsonKey(name: 'phoneNumber', includeIfNull: false, defaultValue: '')
  final String phoneNumber;
  @JsonKey(name: 'howDidYouHear', includeIfNull: false, defaultValue: '')
  final String? howDidYouHear;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'birthDate', includeIfNull: false)
  final DateTime birthDate;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String token;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String code;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  @JsonKey(name: 'confirmPassword', includeIfNull: false, defaultValue: '')
  final String confirmPassword;
  @JsonKey(name: 'userName', includeIfNull: false, defaultValue: '')
  final String? userName;
  static const fromJsonFactory = _$RegisterAppUserFromJson;
  static const toJsonFactory = _$RegisterAppUserToJson;
  Map<String, dynamic> toJson() => _$RegisterAppUserToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RegisterAppUser &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.addressNumber, addressNumber) ||
                const DeepCollectionEquality()
                    .equals(other.addressNumber, addressNumber)) &&
            (identical(other.region, region) ||
                const DeepCollectionEquality().equals(other.region, region)) &&
            (identical(other.postalCode, postalCode) ||
                const DeepCollectionEquality()
                    .equals(other.postalCode, postalCode)) &&
            (identical(other.street, street) ||
                const DeepCollectionEquality().equals(other.street, street)) &&
            (identical(other.phoneNumber, phoneNumber) ||
                const DeepCollectionEquality()
                    .equals(other.phoneNumber, phoneNumber)) &&
            (identical(other.howDidYouHear, howDidYouHear) ||
                const DeepCollectionEquality()
                    .equals(other.howDidYouHear, howDidYouHear)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.birthDate, birthDate) ||
                const DeepCollectionEquality()
                    .equals(other.birthDate, birthDate)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.confirmPassword, confirmPassword) ||
                const DeepCollectionEquality()
                    .equals(other.confirmPassword, confirmPassword)) &&
            (identical(other.userName, userName) ||
                const DeepCollectionEquality()
                    .equals(other.userName, userName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(addressNumber) ^
      const DeepCollectionEquality().hash(region) ^
      const DeepCollectionEquality().hash(postalCode) ^
      const DeepCollectionEquality().hash(street) ^
      const DeepCollectionEquality().hash(phoneNumber) ^
      const DeepCollectionEquality().hash(howDidYouHear) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(birthDate) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(confirmPassword) ^
      const DeepCollectionEquality().hash(userName) ^
      runtimeType.hashCode;
}

extension $RegisterAppUserExtension on RegisterAppUser {
  RegisterAppUser copyWith(
      {String? firstName,
      String? lastName,
      String? city,
      String? addressNumber,
      String? region,
      String? postalCode,
      String? street,
      String? phoneNumber,
      String? howDidYouHear,
      String? company,
      DateTime? birthDate,
      String? email,
      String? token,
      String? code,
      String? password,
      String? confirmPassword,
      String? userName}) {
    return RegisterAppUser(
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        city: city ?? this.city,
        addressNumber: addressNumber ?? this.addressNumber,
        region: region ?? this.region,
        postalCode: postalCode ?? this.postalCode,
        street: street ?? this.street,
        phoneNumber: phoneNumber ?? this.phoneNumber,
        howDidYouHear: howDidYouHear ?? this.howDidYouHear,
        company: company ?? this.company,
        birthDate: birthDate ?? this.birthDate,
        email: email ?? this.email,
        token: token ?? this.token,
        code: code ?? this.code,
        password: password ?? this.password,
        confirmPassword: confirmPassword ?? this.confirmPassword,
        userName: userName ?? this.userName);
  }

  RegisterAppUser copyWithWrapped(
      {Wrapped<String>? firstName,
      Wrapped<String>? lastName,
      Wrapped<String>? city,
      Wrapped<String>? addressNumber,
      Wrapped<String>? region,
      Wrapped<String>? postalCode,
      Wrapped<String?>? street,
      Wrapped<String>? phoneNumber,
      Wrapped<String?>? howDidYouHear,
      Wrapped<String?>? company,
      Wrapped<DateTime>? birthDate,
      Wrapped<String>? email,
      Wrapped<String>? token,
      Wrapped<String>? code,
      Wrapped<String>? password,
      Wrapped<String>? confirmPassword,
      Wrapped<String?>? userName}) {
    return RegisterAppUser(
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        city: (city != null ? city.value : this.city),
        addressNumber:
            (addressNumber != null ? addressNumber.value : this.addressNumber),
        region: (region != null ? region.value : this.region),
        postalCode: (postalCode != null ? postalCode.value : this.postalCode),
        street: (street != null ? street.value : this.street),
        phoneNumber:
            (phoneNumber != null ? phoneNumber.value : this.phoneNumber),
        howDidYouHear:
            (howDidYouHear != null ? howDidYouHear.value : this.howDidYouHear),
        company: (company != null ? company.value : this.company),
        birthDate: (birthDate != null ? birthDate.value : this.birthDate),
        email: (email != null ? email.value : this.email),
        token: (token != null ? token.value : this.token),
        code: (code != null ? code.value : this.code),
        password: (password != null ? password.value : this.password),
        confirmPassword: (confirmPassword != null
            ? confirmPassword.value
            : this.confirmPassword),
        userName: (userName != null ? userName.value : this.userName));
  }
}

@JsonSerializable(explicitToJson: true)
class RegisterAppUserBase {
  RegisterAppUserBase({
    required this.firstName,
    required this.lastName,
    required this.city,
    required this.addressNumber,
    required this.region,
    required this.postalCode,
    this.street,
    required this.phoneNumber,
    this.howDidYouHear,
    this.company,
    required this.birthDate,
  });

  factory RegisterAppUserBase.fromJson(Map<String, dynamic> json) =>
      _$RegisterAppUserBaseFromJson(json);

  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String lastName;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String city;
  @JsonKey(name: 'addressNumber', includeIfNull: false, defaultValue: '')
  final String addressNumber;
  @JsonKey(name: 'region', includeIfNull: false, defaultValue: '')
  final String region;
  @JsonKey(name: 'postalCode', includeIfNull: false, defaultValue: '')
  final String postalCode;
  @JsonKey(name: 'street', includeIfNull: false, defaultValue: '')
  final String? street;
  @JsonKey(name: 'phoneNumber', includeIfNull: false, defaultValue: '')
  final String phoneNumber;
  @JsonKey(name: 'howDidYouHear', includeIfNull: false, defaultValue: '')
  final String? howDidYouHear;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'birthDate', includeIfNull: false)
  final DateTime birthDate;
  static const fromJsonFactory = _$RegisterAppUserBaseFromJson;
  static const toJsonFactory = _$RegisterAppUserBaseToJson;
  Map<String, dynamic> toJson() => _$RegisterAppUserBaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RegisterAppUserBase &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.addressNumber, addressNumber) ||
                const DeepCollectionEquality()
                    .equals(other.addressNumber, addressNumber)) &&
            (identical(other.region, region) ||
                const DeepCollectionEquality().equals(other.region, region)) &&
            (identical(other.postalCode, postalCode) ||
                const DeepCollectionEquality()
                    .equals(other.postalCode, postalCode)) &&
            (identical(other.street, street) ||
                const DeepCollectionEquality().equals(other.street, street)) &&
            (identical(other.phoneNumber, phoneNumber) ||
                const DeepCollectionEquality()
                    .equals(other.phoneNumber, phoneNumber)) &&
            (identical(other.howDidYouHear, howDidYouHear) ||
                const DeepCollectionEquality()
                    .equals(other.howDidYouHear, howDidYouHear)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.birthDate, birthDate) ||
                const DeepCollectionEquality()
                    .equals(other.birthDate, birthDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(addressNumber) ^
      const DeepCollectionEquality().hash(region) ^
      const DeepCollectionEquality().hash(postalCode) ^
      const DeepCollectionEquality().hash(street) ^
      const DeepCollectionEquality().hash(phoneNumber) ^
      const DeepCollectionEquality().hash(howDidYouHear) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(birthDate) ^
      runtimeType.hashCode;
}

extension $RegisterAppUserBaseExtension on RegisterAppUserBase {
  RegisterAppUserBase copyWith(
      {String? firstName,
      String? lastName,
      String? city,
      String? addressNumber,
      String? region,
      String? postalCode,
      String? street,
      String? phoneNumber,
      String? howDidYouHear,
      String? company,
      DateTime? birthDate}) {
    return RegisterAppUserBase(
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        city: city ?? this.city,
        addressNumber: addressNumber ?? this.addressNumber,
        region: region ?? this.region,
        postalCode: postalCode ?? this.postalCode,
        street: street ?? this.street,
        phoneNumber: phoneNumber ?? this.phoneNumber,
        howDidYouHear: howDidYouHear ?? this.howDidYouHear,
        company: company ?? this.company,
        birthDate: birthDate ?? this.birthDate);
  }

  RegisterAppUserBase copyWithWrapped(
      {Wrapped<String>? firstName,
      Wrapped<String>? lastName,
      Wrapped<String>? city,
      Wrapped<String>? addressNumber,
      Wrapped<String>? region,
      Wrapped<String>? postalCode,
      Wrapped<String?>? street,
      Wrapped<String>? phoneNumber,
      Wrapped<String?>? howDidYouHear,
      Wrapped<String?>? company,
      Wrapped<DateTime>? birthDate}) {
    return RegisterAppUserBase(
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        city: (city != null ? city.value : this.city),
        addressNumber:
            (addressNumber != null ? addressNumber.value : this.addressNumber),
        region: (region != null ? region.value : this.region),
        postalCode: (postalCode != null ? postalCode.value : this.postalCode),
        street: (street != null ? street.value : this.street),
        phoneNumber:
            (phoneNumber != null ? phoneNumber.value : this.phoneNumber),
        howDidYouHear:
            (howDidYouHear != null ? howDidYouHear.value : this.howDidYouHear),
        company: (company != null ? company.value : this.company),
        birthDate: (birthDate != null ? birthDate.value : this.birthDate));
  }
}

@JsonSerializable(explicitToJson: true)
class ResetPassword {
  ResetPassword({
    required this.email,
    required this.password,
    this.confirmPassword,
    required this.code,
  });

  factory ResetPassword.fromJson(Map<String, dynamic> json) =>
      _$ResetPasswordFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  @JsonKey(name: 'confirmPassword', includeIfNull: false, defaultValue: '')
  final String? confirmPassword;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String code;
  static const fromJsonFactory = _$ResetPasswordFromJson;
  static const toJsonFactory = _$ResetPasswordToJson;
  Map<String, dynamic> toJson() => _$ResetPasswordToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ResetPassword &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.confirmPassword, confirmPassword) ||
                const DeepCollectionEquality()
                    .equals(other.confirmPassword, confirmPassword)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(confirmPassword) ^
      const DeepCollectionEquality().hash(code) ^
      runtimeType.hashCode;
}

extension $ResetPasswordExtension on ResetPassword {
  ResetPassword copyWith(
      {String? email,
      String? password,
      String? confirmPassword,
      String? code}) {
    return ResetPassword(
        email: email ?? this.email,
        password: password ?? this.password,
        confirmPassword: confirmPassword ?? this.confirmPassword,
        code: code ?? this.code);
  }

  ResetPassword copyWithWrapped(
      {Wrapped<String>? email,
      Wrapped<String>? password,
      Wrapped<String?>? confirmPassword,
      Wrapped<String>? code}) {
    return ResetPassword(
        email: (email != null ? email.value : this.email),
        password: (password != null ? password.value : this.password),
        confirmPassword: (confirmPassword != null
            ? confirmPassword.value
            : this.confirmPassword),
        code: (code != null ? code.value : this.code));
  }
}

@JsonSerializable(explicitToJson: true)
class RetailerModel {
  RetailerModel({
    this.title,
    this.shortDescription,
    this.imageUrl,
    this.id,
    this.isPreview,
    this.categoryId,
    this.merchantIds,
    this.webTemplateId,
    this.shopLink,
    this.fullDescription,
    this.promoTitle,
    this.promoImageUrl,
    this.mobileAvailable,
    this.webAvailable,
    this.isSustainable,
    this.whyIsSustainable,
    this.additionalCategories,
  });

  factory RetailerModel.fromJson(Map<String, dynamic> json) =>
      _$RetailerModelFromJson(json);

  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'isPreview', includeIfNull: false)
  final bool? isPreview;
  @JsonKey(name: 'categoryId', includeIfNull: false, defaultValue: '')
  final String? categoryId;
  @JsonKey(name: 'merchantIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? merchantIds;
  @JsonKey(name: 'webTemplateId', includeIfNull: false, defaultValue: '')
  final String? webTemplateId;
  @JsonKey(name: 'shopLink', includeIfNull: false, defaultValue: '')
  final String? shopLink;
  @JsonKey(name: 'fullDescription', includeIfNull: false, defaultValue: '')
  final String? fullDescription;
  @JsonKey(name: 'promoTitle', includeIfNull: false, defaultValue: '')
  final String? promoTitle;
  @JsonKey(name: 'promoImageUrl', includeIfNull: false, defaultValue: '')
  final String? promoImageUrl;
  @JsonKey(name: 'mobileAvailable', includeIfNull: false)
  final bool? mobileAvailable;
  @JsonKey(name: 'webAvailable', includeIfNull: false)
  final bool? webAvailable;
  @JsonKey(name: 'isSustainable', includeIfNull: false)
  final bool? isSustainable;
  @JsonKey(name: 'whyIsSustainable', includeIfNull: false, defaultValue: '')
  final String? whyIsSustainable;
  @JsonKey(
      name: 'additionalCategories',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? additionalCategories;
  static const fromJsonFactory = _$RetailerModelFromJson;
  static const toJsonFactory = _$RetailerModelToJson;
  Map<String, dynamic> toJson() => _$RetailerModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RetailerModel &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.isPreview, isPreview) ||
                const DeepCollectionEquality()
                    .equals(other.isPreview, isPreview)) &&
            (identical(other.categoryId, categoryId) ||
                const DeepCollectionEquality()
                    .equals(other.categoryId, categoryId)) &&
            (identical(other.merchantIds, merchantIds) ||
                const DeepCollectionEquality()
                    .equals(other.merchantIds, merchantIds)) &&
            (identical(other.webTemplateId, webTemplateId) ||
                const DeepCollectionEquality()
                    .equals(other.webTemplateId, webTemplateId)) &&
            (identical(other.shopLink, shopLink) ||
                const DeepCollectionEquality()
                    .equals(other.shopLink, shopLink)) &&
            (identical(other.fullDescription, fullDescription) ||
                const DeepCollectionEquality()
                    .equals(other.fullDescription, fullDescription)) &&
            (identical(other.promoTitle, promoTitle) ||
                const DeepCollectionEquality()
                    .equals(other.promoTitle, promoTitle)) &&
            (identical(other.promoImageUrl, promoImageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.promoImageUrl, promoImageUrl)) &&
            (identical(other.mobileAvailable, mobileAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.mobileAvailable, mobileAvailable)) &&
            (identical(other.webAvailable, webAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.webAvailable, webAvailable)) &&
            (identical(other.isSustainable, isSustainable) ||
                const DeepCollectionEquality()
                    .equals(other.isSustainable, isSustainable)) &&
            (identical(other.whyIsSustainable, whyIsSustainable) ||
                const DeepCollectionEquality()
                    .equals(other.whyIsSustainable, whyIsSustainable)) &&
            (identical(other.additionalCategories, additionalCategories) ||
                const DeepCollectionEquality()
                    .equals(other.additionalCategories, additionalCategories)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(isPreview) ^
      const DeepCollectionEquality().hash(categoryId) ^
      const DeepCollectionEquality().hash(merchantIds) ^
      const DeepCollectionEquality().hash(webTemplateId) ^
      const DeepCollectionEquality().hash(shopLink) ^
      const DeepCollectionEquality().hash(fullDescription) ^
      const DeepCollectionEquality().hash(promoTitle) ^
      const DeepCollectionEquality().hash(promoImageUrl) ^
      const DeepCollectionEquality().hash(mobileAvailable) ^
      const DeepCollectionEquality().hash(webAvailable) ^
      const DeepCollectionEquality().hash(isSustainable) ^
      const DeepCollectionEquality().hash(whyIsSustainable) ^
      const DeepCollectionEquality().hash(additionalCategories) ^
      runtimeType.hashCode;
}

extension $RetailerModelExtension on RetailerModel {
  RetailerModel copyWith(
      {String? title,
      String? shortDescription,
      String? imageUrl,
      String? id,
      bool? isPreview,
      String? categoryId,
      List<String>? merchantIds,
      String? webTemplateId,
      String? shopLink,
      String? fullDescription,
      String? promoTitle,
      String? promoImageUrl,
      bool? mobileAvailable,
      bool? webAvailable,
      bool? isSustainable,
      String? whyIsSustainable,
      List<String>? additionalCategories}) {
    return RetailerModel(
        title: title ?? this.title,
        shortDescription: shortDescription ?? this.shortDescription,
        imageUrl: imageUrl ?? this.imageUrl,
        id: id ?? this.id,
        isPreview: isPreview ?? this.isPreview,
        categoryId: categoryId ?? this.categoryId,
        merchantIds: merchantIds ?? this.merchantIds,
        webTemplateId: webTemplateId ?? this.webTemplateId,
        shopLink: shopLink ?? this.shopLink,
        fullDescription: fullDescription ?? this.fullDescription,
        promoTitle: promoTitle ?? this.promoTitle,
        promoImageUrl: promoImageUrl ?? this.promoImageUrl,
        mobileAvailable: mobileAvailable ?? this.mobileAvailable,
        webAvailable: webAvailable ?? this.webAvailable,
        isSustainable: isSustainable ?? this.isSustainable,
        whyIsSustainable: whyIsSustainable ?? this.whyIsSustainable,
        additionalCategories:
            additionalCategories ?? this.additionalCategories);
  }

  RetailerModel copyWithWrapped(
      {Wrapped<String?>? title,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? imageUrl,
      Wrapped<String?>? id,
      Wrapped<bool?>? isPreview,
      Wrapped<String?>? categoryId,
      Wrapped<List<String>?>? merchantIds,
      Wrapped<String?>? webTemplateId,
      Wrapped<String?>? shopLink,
      Wrapped<String?>? fullDescription,
      Wrapped<String?>? promoTitle,
      Wrapped<String?>? promoImageUrl,
      Wrapped<bool?>? mobileAvailable,
      Wrapped<bool?>? webAvailable,
      Wrapped<bool?>? isSustainable,
      Wrapped<String?>? whyIsSustainable,
      Wrapped<List<String>?>? additionalCategories}) {
    return RetailerModel(
        title: (title != null ? title.value : this.title),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        id: (id != null ? id.value : this.id),
        isPreview: (isPreview != null ? isPreview.value : this.isPreview),
        categoryId: (categoryId != null ? categoryId.value : this.categoryId),
        merchantIds:
            (merchantIds != null ? merchantIds.value : this.merchantIds),
        webTemplateId:
            (webTemplateId != null ? webTemplateId.value : this.webTemplateId),
        shopLink: (shopLink != null ? shopLink.value : this.shopLink),
        fullDescription: (fullDescription != null
            ? fullDescription.value
            : this.fullDescription),
        promoTitle: (promoTitle != null ? promoTitle.value : this.promoTitle),
        promoImageUrl:
            (promoImageUrl != null ? promoImageUrl.value : this.promoImageUrl),
        mobileAvailable: (mobileAvailable != null
            ? mobileAvailable.value
            : this.mobileAvailable),
        webAvailable:
            (webAvailable != null ? webAvailable.value : this.webAvailable),
        isSustainable:
            (isSustainable != null ? isSustainable.value : this.isSustainable),
        whyIsSustainable: (whyIsSustainable != null
            ? whyIsSustainable.value
            : this.whyIsSustainable),
        additionalCategories: (additionalCategories != null
            ? additionalCategories.value
            : this.additionalCategories));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenModel {
  TokenModel({
    this.token,
  });

  factory TokenModel.fromJson(Map<String, dynamic> json) =>
      _$TokenModelFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenModelFromJson;
  static const toJsonFactory = _$TokenModelToJson;
  Map<String, dynamic> toJson() => _$TokenModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenModel &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^ runtimeType.hashCode;
}

extension $TokenModelExtension on TokenModel {
  TokenModel copyWith({String? token}) {
    return TokenModel(token: token ?? this.token);
  }

  TokenModel copyWithWrapped({Wrapped<String?>? token}) {
    return TokenModel(token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TransactionModel {
  TransactionModel({
    this.retailer,
    this.regularRetailer,
    this.amount,
    this.cashback,
    this.date,
    this.regularCashback,
    this.bonusCashback,
    this.status,
    this.subTitle,
    this.senderName,
    this.isTransfer,
  });

  factory TransactionModel.fromJson(Map<String, dynamic> json) =>
      _$TransactionModelFromJson(json);

  @JsonKey(name: 'retailer', includeIfNull: false, defaultValue: '')
  final String? retailer;
  @JsonKey(name: 'regularRetailer', includeIfNull: false, defaultValue: '')
  final String? regularRetailer;
  @JsonKey(name: 'amount', includeIfNull: false)
  final double? amount;
  @JsonKey(name: 'cashback', includeIfNull: false)
  final double? cashback;
  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'regularCashback', includeIfNull: false)
  final double? regularCashback;
  @JsonKey(name: 'bonusCashback', includeIfNull: false)
  final double? bonusCashback;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'subTitle', includeIfNull: false, defaultValue: '')
  final String? subTitle;
  @JsonKey(name: 'senderName', includeIfNull: false, defaultValue: '')
  final String? senderName;
  @JsonKey(name: 'isTransfer', includeIfNull: false)
  final bool? isTransfer;
  static const fromJsonFactory = _$TransactionModelFromJson;
  static const toJsonFactory = _$TransactionModelToJson;
  Map<String, dynamic> toJson() => _$TransactionModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TransactionModel &&
            (identical(other.retailer, retailer) ||
                const DeepCollectionEquality()
                    .equals(other.retailer, retailer)) &&
            (identical(other.regularRetailer, regularRetailer) ||
                const DeepCollectionEquality()
                    .equals(other.regularRetailer, regularRetailer)) &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.cashback, cashback) ||
                const DeepCollectionEquality()
                    .equals(other.cashback, cashback)) &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.regularCashback, regularCashback) ||
                const DeepCollectionEquality()
                    .equals(other.regularCashback, regularCashback)) &&
            (identical(other.bonusCashback, bonusCashback) ||
                const DeepCollectionEquality()
                    .equals(other.bonusCashback, bonusCashback)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.subTitle, subTitle) ||
                const DeepCollectionEquality()
                    .equals(other.subTitle, subTitle)) &&
            (identical(other.senderName, senderName) ||
                const DeepCollectionEquality()
                    .equals(other.senderName, senderName)) &&
            (identical(other.isTransfer, isTransfer) ||
                const DeepCollectionEquality()
                    .equals(other.isTransfer, isTransfer)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(retailer) ^
      const DeepCollectionEquality().hash(regularRetailer) ^
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(cashback) ^
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(regularCashback) ^
      const DeepCollectionEquality().hash(bonusCashback) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(subTitle) ^
      const DeepCollectionEquality().hash(senderName) ^
      const DeepCollectionEquality().hash(isTransfer) ^
      runtimeType.hashCode;
}

extension $TransactionModelExtension on TransactionModel {
  TransactionModel copyWith(
      {String? retailer,
      String? regularRetailer,
      double? amount,
      double? cashback,
      DateTime? date,
      double? regularCashback,
      double? bonusCashback,
      String? status,
      String? subTitle,
      String? senderName,
      bool? isTransfer}) {
    return TransactionModel(
        retailer: retailer ?? this.retailer,
        regularRetailer: regularRetailer ?? this.regularRetailer,
        amount: amount ?? this.amount,
        cashback: cashback ?? this.cashback,
        date: date ?? this.date,
        regularCashback: regularCashback ?? this.regularCashback,
        bonusCashback: bonusCashback ?? this.bonusCashback,
        status: status ?? this.status,
        subTitle: subTitle ?? this.subTitle,
        senderName: senderName ?? this.senderName,
        isTransfer: isTransfer ?? this.isTransfer);
  }

  TransactionModel copyWithWrapped(
      {Wrapped<String?>? retailer,
      Wrapped<String?>? regularRetailer,
      Wrapped<double?>? amount,
      Wrapped<double?>? cashback,
      Wrapped<DateTime?>? date,
      Wrapped<double?>? regularCashback,
      Wrapped<double?>? bonusCashback,
      Wrapped<String?>? status,
      Wrapped<String?>? subTitle,
      Wrapped<String?>? senderName,
      Wrapped<bool?>? isTransfer}) {
    return TransactionModel(
        retailer: (retailer != null ? retailer.value : this.retailer),
        regularRetailer: (regularRetailer != null
            ? regularRetailer.value
            : this.regularRetailer),
        amount: (amount != null ? amount.value : this.amount),
        cashback: (cashback != null ? cashback.value : this.cashback),
        date: (date != null ? date.value : this.date),
        regularCashback: (regularCashback != null
            ? regularCashback.value
            : this.regularCashback),
        bonusCashback:
            (bonusCashback != null ? bonusCashback.value : this.bonusCashback),
        status: (status != null ? status.value : this.status),
        subTitle: (subTitle != null ? subTitle.value : this.subTitle),
        senderName: (senderName != null ? senderName.value : this.senderName),
        isTransfer: (isTransfer != null ? isTransfer.value : this.isTransfer));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateCard {
  UpdateCard({
    required this.isFrozen,
  });

  factory UpdateCard.fromJson(Map<String, dynamic> json) =>
      _$UpdateCardFromJson(json);

  @JsonKey(name: 'isFrozen', includeIfNull: false)
  final bool isFrozen;
  static const fromJsonFactory = _$UpdateCardFromJson;
  static const toJsonFactory = _$UpdateCardToJson;
  Map<String, dynamic> toJson() => _$UpdateCardToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateCard &&
            (identical(other.isFrozen, isFrozen) ||
                const DeepCollectionEquality()
                    .equals(other.isFrozen, isFrozen)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isFrozen) ^ runtimeType.hashCode;
}

extension $UpdateCardExtension on UpdateCard {
  UpdateCard copyWith({bool? isFrozen}) {
    return UpdateCard(isFrozen: isFrozen ?? this.isFrozen);
  }

  UpdateCard copyWithWrapped({Wrapped<bool>? isFrozen}) {
    return UpdateCard(
        isFrozen: (isFrozen != null ? isFrozen.value : this.isFrozen));
  }
}

@JsonSerializable(explicitToJson: true)
class ValidatePasswordToken {
  ValidatePasswordToken({
    required this.email,
    required this.code,
  });

  factory ValidatePasswordToken.fromJson(Map<String, dynamic> json) =>
      _$ValidatePasswordTokenFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String code;
  static const fromJsonFactory = _$ValidatePasswordTokenFromJson;
  static const toJsonFactory = _$ValidatePasswordTokenToJson;
  Map<String, dynamic> toJson() => _$ValidatePasswordTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidatePasswordToken &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(code) ^
      runtimeType.hashCode;
}

extension $ValidatePasswordTokenExtension on ValidatePasswordToken {
  ValidatePasswordToken copyWith({String? email, String? code}) {
    return ValidatePasswordToken(
        email: email ?? this.email, code: code ?? this.code);
  }

  ValidatePasswordToken copyWithWrapped(
      {Wrapped<String>? email, Wrapped<String>? code}) {
    return ValidatePasswordToken(
        email: (email != null ? email.value : this.email),
        code: (code != null ? code.value : this.code));
  }
}

@JsonSerializable(explicitToJson: true)
class WebTemplateModel {
  WebTemplateModel({
    this.id,
    this.template,
    this.name,
  });

  factory WebTemplateModel.fromJson(Map<String, dynamic> json) =>
      _$WebTemplateModelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'template', includeIfNull: false, defaultValue: '')
  final String? template;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$WebTemplateModelFromJson;
  static const toJsonFactory = _$WebTemplateModelToJson;
  Map<String, dynamic> toJson() => _$WebTemplateModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebTemplateModel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.template, template) ||
                const DeepCollectionEquality()
                    .equals(other.template, template)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(template) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $WebTemplateModelExtension on WebTemplateModel {
  WebTemplateModel copyWith({String? id, String? template, String? name}) {
    return WebTemplateModel(
        id: id ?? this.id,
        template: template ?? this.template,
        name: name ?? this.name);
  }

  WebTemplateModel copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? template,
      Wrapped<String?>? name}) {
    return WebTemplateModel(
        id: (id != null ? id.value : this.id),
        template: (template != null ? template.value : this.template),
        name: (name != null ? name.value : this.name));
  }
}

String? cardStatusToJson(enums.CardStatus? cardStatus) {
  return enums.$CardStatusMap[cardStatus];
}

enums.CardStatus cardStatusFromJson(
  Object? cardStatus, [
  enums.CardStatus? defaultValue,
]) {
  if (cardStatus is String) {
    return enums.$CardStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cardStatus.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.CardStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CardStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CardStatus.swaggerGeneratedUnknown;
}

List<String> cardStatusListToJson(List<enums.CardStatus>? cardStatus) {
  if (cardStatus == null) {
    return [];
  }

  return cardStatus.map((e) => enums.$CardStatusMap[e]!).toList();
}

List<enums.CardStatus> cardStatusListFromJson(
  List? cardStatus, [
  List<enums.CardStatus>? defaultValue,
]) {
  if (cardStatus == null) {
    return defaultValue ?? [];
  }

  return cardStatus.map((e) => cardStatusFromJson(e.toString())).toList();
}

List<enums.CardStatus>? cardStatusNullableListFromJson(
  List? cardStatus, [
  List<enums.CardStatus>? defaultValue,
]) {
  if (cardStatus == null) {
    return defaultValue;
  }

  return cardStatus.map((e) => cardStatusFromJson(e.toString())).toList();
}

String? kycCheckStatusToJson(enums.KycCheckStatus? kycCheckStatus) {
  return enums.$KycCheckStatusMap[kycCheckStatus];
}

enums.KycCheckStatus kycCheckStatusFromJson(
  Object? kycCheckStatus, [
  enums.KycCheckStatus? defaultValue,
]) {
  if (kycCheckStatus is String) {
    return enums.$KycCheckStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == kycCheckStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.KycCheckStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$KycCheckStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.KycCheckStatus.swaggerGeneratedUnknown;
}

List<String> kycCheckStatusListToJson(
    List<enums.KycCheckStatus>? kycCheckStatus) {
  if (kycCheckStatus == null) {
    return [];
  }

  return kycCheckStatus.map((e) => enums.$KycCheckStatusMap[e]!).toList();
}

List<enums.KycCheckStatus> kycCheckStatusListFromJson(
  List? kycCheckStatus, [
  List<enums.KycCheckStatus>? defaultValue,
]) {
  if (kycCheckStatus == null) {
    return defaultValue ?? [];
  }

  return kycCheckStatus
      .map((e) => kycCheckStatusFromJson(e.toString()))
      .toList();
}

List<enums.KycCheckStatus>? kycCheckStatusNullableListFromJson(
  List? kycCheckStatus, [
  List<enums.KycCheckStatus>? defaultValue,
]) {
  if (kycCheckStatus == null) {
    return defaultValue;
  }

  return kycCheckStatus
      .map((e) => kycCheckStatusFromJson(e.toString()))
      .toList();
}

String? linkTokenTypeToJson(enums.LinkTokenType? linkTokenType) {
  return enums.$LinkTokenTypeMap[linkTokenType];
}

enums.LinkTokenType linkTokenTypeFromJson(
  Object? linkTokenType, [
  enums.LinkTokenType? defaultValue,
]) {
  if (linkTokenType is String) {
    return enums.$LinkTokenTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == linkTokenType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.LinkTokenType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LinkTokenTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LinkTokenType.swaggerGeneratedUnknown;
}

List<String> linkTokenTypeListToJson(List<enums.LinkTokenType>? linkTokenType) {
  if (linkTokenType == null) {
    return [];
  }

  return linkTokenType.map((e) => enums.$LinkTokenTypeMap[e]!).toList();
}

List<enums.LinkTokenType> linkTokenTypeListFromJson(
  List? linkTokenType, [
  List<enums.LinkTokenType>? defaultValue,
]) {
  if (linkTokenType == null) {
    return defaultValue ?? [];
  }

  return linkTokenType.map((e) => linkTokenTypeFromJson(e.toString())).toList();
}

List<enums.LinkTokenType>? linkTokenTypeNullableListFromJson(
  List? linkTokenType, [
  List<enums.LinkTokenType>? defaultValue,
]) {
  if (linkTokenType == null) {
    return defaultValue;
  }

  return linkTokenType.map((e) => linkTokenTypeFromJson(e.toString())).toList();
}

String? userStatusToJson(enums.UserStatus? userStatus) {
  return enums.$UserStatusMap[userStatus];
}

enums.UserStatus userStatusFromJson(
  Object? userStatus, [
  enums.UserStatus? defaultValue,
]) {
  if (userStatus is String) {
    return enums.$UserStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == userStatus.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.UserStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserStatus.swaggerGeneratedUnknown;
}

List<String> userStatusListToJson(List<enums.UserStatus>? userStatus) {
  if (userStatus == null) {
    return [];
  }

  return userStatus.map((e) => enums.$UserStatusMap[e]!).toList();
}

List<enums.UserStatus> userStatusListFromJson(
  List? userStatus, [
  List<enums.UserStatus>? defaultValue,
]) {
  if (userStatus == null) {
    return defaultValue ?? [];
  }

  return userStatus.map((e) => userStatusFromJson(e.toString())).toList();
}

List<enums.UserStatus>? userStatusNullableListFromJson(
  List? userStatus, [
  List<enums.UserStatus>? defaultValue,
]) {
  if (userStatus == null) {
    return defaultValue;
  }

  return userStatus.map((e) => userStatusFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
