// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'auth_service.swagger.chopper.dart';
part 'auth_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class AuthService extends ChopperService {
  static AuthService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$AuthService(client);
    }

    final newClient = ChopperClient(
        services: [_$AuthService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$AuthService(newClient);
  }

  ///Sign in and get session
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param extClientId
  ///@param userAgent
  ///@param trueClientIp
  ///@param deviceId the id of the device to be use in the silent authentication. The name of this header is set by configuration
  ///@param token if the device is supported, then token=true will include a refreshToken and refreshTokenExpiry in the response body. (true or false, false is the default value)
  Future<chopper.Response<WebSession>>
      countryCodeLanguageCodeDeviceCodeSessionPost({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? extClientId,
    String? userAgent,
    String? trueClientIp,
    String? deviceId,
    bool? token,
    String? cacheControl,
    required Credentials? body,
  }) {
    generatedMapping.putIfAbsent(WebSession, () => WebSession.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeSessionPost(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        extClientId: extClientId,
        userAgent: userAgent,
        trueClientIp: trueClientIp,
        deviceId: deviceId,
        token: token,
        cacheControl: cacheControl,
        body: body);
  }

  ///Sign in and get session
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param extClientId
  ///@param userAgent
  ///@param trueClientIp
  ///@param deviceId the id of the device to be use in the silent authentication. The name of this header is set by configuration
  ///@param token if the device is supported, then token=true will include a refreshToken and refreshTokenExpiry in the response body. (true or false, false is the default value)
  @Post(path: '/{countryCode}/{languageCode}/{deviceCode}/session')
  Future<chopper.Response<WebSession>>
      _countryCodeLanguageCodeDeviceCodeSessionPost({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('extClientId') String? extClientId,
    @Header('userAgent') String? userAgent,
    @Header('trueClientIp') String? trueClientIp,
    @Header('deviceId') String? deviceId,
    @Query('token') bool? token,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Credentials? body,
  });

  ///Returns the session for the supplied token.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  ///@param X-Client-Id
  ///@param X-Dr-Test
  ///@param uriInfo
  Future<chopper.Response<WebSession>>
      countryCodeLanguageCodeDeviceCodeSessionGet({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? xOESPToken,
    String? xOESPUsername,
    String? xClientId,
    String? xDrTest,
    List<String>? uriInfo,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(WebSession, () => WebSession.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeSessionGet(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        xOESPToken: xOESPToken,
        xOESPUsername: xOESPUsername,
        xClientId: xClientId,
        xDrTest: xDrTest,
        uriInfo: uriInfo,
        cacheControl: cacheControl);
  }

  ///Returns the session for the supplied token.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  ///@param X-Client-Id
  ///@param X-Dr-Test
  ///@param uriInfo
  @Get(path: '/{countryCode}/{languageCode}/{deviceCode}/session')
  Future<chopper.Response<WebSession>>
      _countryCodeLanguageCodeDeviceCodeSessionGet({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('X-OESP-Token') String? xOESPToken,
    @Header('X-OESP-Username') String? xOESPUsername,
    @Header('X-Client-Id') String? xClientId,
    @Header('X-Dr-Test') String? xDrTest,
    @Query('uriInfo') List<String>? uriInfo,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update an existing session
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  ///@param X-Client-Id
  ///@param X-Dr-Test
  ///@param uriInfo
  Future<chopper.Response<WebSession>>
      countryCodeLanguageCodeDeviceCodeSessionPut({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? xOESPToken,
    String? xOESPUsername,
    String? xClientId,
    String? xDrTest,
    List<String>? uriInfo,
    String? cacheControl,
    required WebSession? body,
  }) {
    generatedMapping.putIfAbsent(WebSession, () => WebSession.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeSessionPut(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        xOESPToken: xOESPToken,
        xOESPUsername: xOESPUsername,
        xClientId: xClientId,
        xDrTest: xDrTest,
        uriInfo: uriInfo,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update an existing session
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  ///@param X-Client-Id
  ///@param X-Dr-Test
  ///@param uriInfo
  @Put(path: '/{countryCode}/{languageCode}/{deviceCode}/session')
  Future<chopper.Response<WebSession>>
      _countryCodeLanguageCodeDeviceCodeSessionPut({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('X-OESP-Token') String? xOESPToken,
    @Header('X-OESP-Username') String? xOESPUsername,
    @Header('X-Client-Id') String? xClientId,
    @Header('X-Dr-Test') String? xDrTest,
    @Query('uriInfo') List<String>? uriInfo,
    @Header('Cache-Control') String? cacheControl,
    @Body() required WebSession? body,
  });

  ///Signs out for the supplied token.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  ///@param X-Client-Id
  ///@param uriInfo
  Future<chopper.Response> countryCodeLanguageCodeDeviceCodeSessionDelete({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? xOESPToken,
    String? xOESPUsername,
    String? xClientId,
    List<String>? uriInfo,
    String? cacheControl,
  }) {
    return _countryCodeLanguageCodeDeviceCodeSessionDelete(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        xOESPToken: xOESPToken,
        xOESPUsername: xOESPUsername,
        xClientId: xClientId,
        uriInfo: uriInfo,
        cacheControl: cacheControl);
  }

  ///Signs out for the supplied token.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  ///@param X-Client-Id
  ///@param uriInfo
  @Delete(path: '/{countryCode}/{languageCode}/{deviceCode}/session')
  Future<chopper.Response> _countryCodeLanguageCodeDeviceCodeSessionDelete({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('X-OESP-Token') String? xOESPToken,
    @Header('X-OESP-Username') String? xOESPUsername,
    @Header('X-Client-Id') String? xClientId,
    @Query('uriInfo') List<String>? uriInfo,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates the session with personalization Service values
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param extClientId
  ///@param userAgent
  ///@param trueClientIp
  ///@param deviceId the id of the device to be use in the silent authentication. The name of this header is set by configuration
  ///@param token if the device is supported, then token=true will include a refreshToken and refreshTokenExpiry in the response body. (true or false, false is the default value)
  Future<chopper.Response<WebSession>>
      countryCodeLanguageCodeDeviceCodeSessionUpdatePost({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? extClientId,
    String? userAgent,
    String? trueClientIp,
    String? deviceId,
    bool? token,
    String? cacheControl,
    required Credentials? body,
  }) {
    generatedMapping.putIfAbsent(WebSession, () => WebSession.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeSessionUpdatePost(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        extClientId: extClientId,
        userAgent: userAgent,
        trueClientIp: trueClientIp,
        deviceId: deviceId,
        token: token,
        cacheControl: cacheControl,
        body: body);
  }

  ///Updates the session with personalization Service values
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param extClientId
  ///@param userAgent
  ///@param trueClientIp
  ///@param deviceId the id of the device to be use in the silent authentication. The name of this header is set by configuration
  ///@param token if the device is supported, then token=true will include a refreshToken and refreshTokenExpiry in the response body. (true or false, false is the default value)
  @Post(path: '/{countryCode}/{languageCode}/{deviceCode}/session/update')
  Future<chopper.Response<WebSession>>
      _countryCodeLanguageCodeDeviceCodeSessionUpdatePost({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('extClientId') String? extClientId,
    @Header('userAgent') String? userAgent,
    @Header('trueClientIp') String? trueClientIp,
    @Header('deviceId') String? deviceId,
    @Query('token') bool? token,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Credentials? body,
  });

  ///Return SSO Authorization details when SSO is active for the country.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  Future<chopper.Response<AuthorizationDetails>>
      countryCodeLanguageCodeDeviceCodeAuthorizationGet({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationDetails, () => AuthorizationDetails.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeAuthorizationGet(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        cacheControl: cacheControl);
  }

  ///Return SSO Authorization details when SSO is active for the country.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  @Get(path: '/{countryCode}/{languageCode}/{deviceCode}/authorization')
  Future<chopper.Response<AuthorizationDetails>>
      _countryCodeLanguageCodeDeviceCodeAuthorizationGet({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Return SSO Authorization details when SSO is active for the country.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  Future<chopper.Response<AuthorizationResponse>>
      countryCodeLanguageCodeDeviceCodeAuthorizationPost({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? cacheControl,
    required Credentials? body,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeAuthorizationPost(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        cacheControl: cacheControl,
        body: body);
  }

  ///Return SSO Authorization details when SSO is active for the country.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  @Post(path: '/{countryCode}/{languageCode}/{deviceCode}/authorization')
  Future<chopper.Response<AuthorizationResponse>>
      _countryCodeLanguageCodeDeviceCodeAuthorizationPost({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Credentials? body,
  });

  ///Return a SSO response for a Set Top Box (STB) login.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  Future<chopper.Response<AuthorizationResponse>>
      countryCodeLanguageCodeDeviceCodeAuthorizationSilentstbPost({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? xOESPToken,
    String? xOESPUsername,
    String? cacheControl,
    required StbAuthenticationRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeAuthorizationSilentstbPost(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        xOESPToken: xOESPToken,
        xOESPUsername: xOESPUsername,
        cacheControl: cacheControl,
        body: body);
  }

  ///Return a SSO response for a Set Top Box (STB) login.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param X-OESP-Token
  ///@param X-OESP-Username
  @Post(
      path:
          '/{countryCode}/{languageCode}/{deviceCode}/authorization/silentstb')
  Future<chopper.Response<AuthorizationResponse>>
      _countryCodeLanguageCodeDeviceCodeAuthorizationSilentstbPost({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('X-OESP-Token') String? xOESPToken,
    @Header('X-OESP-Username') String? xOESPUsername,
    @Header('Cache-Control') String? cacheControl,
    @Body() required StbAuthenticationRequest? body,
  });

  ///Request an authorization token to allow a device (such as a Chromecast) to play a stream.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  Future<chopper.Response<DeviceAuthorizationResponse>>
      countryCodeLanguageCodeDeviceCodeAuthorizationDevicePost({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    String? cacheControl,
    required DeviceAuthorizationRequest? body,
  }) {
    generatedMapping.putIfAbsent(DeviceAuthorizationResponse,
        () => DeviceAuthorizationResponse.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeAuthorizationDevicePost(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        cacheControl: cacheControl,
        body: body);
  }

  ///Request an authorization token to allow a device (such as a Chromecast) to play a stream.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  @Post(path: '/{countryCode}/{languageCode}/{deviceCode}/authorization/device')
  Future<chopper.Response<DeviceAuthorizationResponse>>
      _countryCodeLanguageCodeDeviceCodeAuthorizationDevicePost({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeviceAuthorizationRequest? body,
  });

  ///Returns the session with the refresh token for the supplied token.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param deviceId the device id for authorization token
  ///@param authenticationToken the authentication token
  Future<chopper.Response<AuthorizationResponse>>
      countryCodeLanguageCodeDeviceCodeAuthorizationDeviceRefreshtokenDeviceIdAuthenticationTokenGet({
    required String? countryCode,
    required String? languageCode,
    required String? deviceCode,
    required String? deviceId,
    required String? authenticationToken,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AuthorizationResponse, () => AuthorizationResponse.fromJsonFactory);

    return _countryCodeLanguageCodeDeviceCodeAuthorizationDeviceRefreshtokenDeviceIdAuthenticationTokenGet(
        countryCode: countryCode,
        languageCode: languageCode,
        deviceCode: deviceCode,
        deviceId: deviceId,
        authenticationToken: authenticationToken,
        cacheControl: cacheControl);
  }

  ///Returns the session with the refresh token for the supplied token.
  ///@param countryCode the country code
  ///@param languageCode the language code
  ///@param deviceCode the device code
  ///@param deviceId the device id for authorization token
  ///@param authenticationToken the authentication token
  @Get(
      path:
          '/{countryCode}/{languageCode}/{deviceCode}/authorization/device/refreshtoken/{deviceId}/{authenticationToken}')
  Future<chopper.Response<AuthorizationResponse>>
      _countryCodeLanguageCodeDeviceCodeAuthorizationDeviceRefreshtokenDeviceIdAuthenticationTokenGet({
    @Path('countryCode') required String? countryCode,
    @Path('languageCode') required String? languageCode,
    @Path('deviceCode') required String? deviceCode,
    @Path('deviceId') required String? deviceId,
    @Path('authenticationToken') required String? authenticationToken,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Credentials {
  Credentials({
    this.username,
    this.password,
    this.refreshToken,
    this.authorizationGrant,
  });

  factory Credentials.fromJson(Map<String, dynamic> json) =>
      _$CredentialsFromJson(json);

  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  @JsonKey(name: 'authorizationGrant', includeIfNull: false)
  final SsoCredentials? authorizationGrant;
  static const fromJsonFactory = _$CredentialsFromJson;
  static const toJsonFactory = _$CredentialsToJson;
  Map<String, dynamic> toJson() => _$CredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Credentials &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)) &&
            (identical(other.authorizationGrant, authorizationGrant) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationGrant, authorizationGrant)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      const DeepCollectionEquality().hash(authorizationGrant) ^
      runtimeType.hashCode;
}

extension $CredentialsExtension on Credentials {
  Credentials copyWith(
      {String? username,
      String? password,
      String? refreshToken,
      SsoCredentials? authorizationGrant}) {
    return Credentials(
        username: username ?? this.username,
        password: password ?? this.password,
        refreshToken: refreshToken ?? this.refreshToken,
        authorizationGrant: authorizationGrant ?? this.authorizationGrant);
  }

  Credentials copyWithWrapped(
      {Wrapped<String?>? username,
      Wrapped<String?>? password,
      Wrapped<String?>? refreshToken,
      Wrapped<SsoCredentials?>? authorizationGrant}) {
    return Credentials(
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken),
        authorizationGrant: (authorizationGrant != null
            ? authorizationGrant.value
            : this.authorizationGrant));
  }
}

@JsonSerializable(explicitToJson: true)
class SsoCredentials {
  SsoCredentials({
    this.authorizationCode,
    this.state,
    this.validityToken,
  });

  factory SsoCredentials.fromJson(Map<String, dynamic> json) =>
      _$SsoCredentialsFromJson(json);

  @JsonKey(name: 'authorizationCode', includeIfNull: false, defaultValue: '')
  final String? authorizationCode;
  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$SsoCredentialsFromJson;
  static const toJsonFactory = _$SsoCredentialsToJson;
  Map<String, dynamic> toJson() => _$SsoCredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SsoCredentials &&
            (identical(other.authorizationCode, authorizationCode) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationCode, authorizationCode)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorizationCode) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $SsoCredentialsExtension on SsoCredentials {
  SsoCredentials copyWith(
      {String? authorizationCode, String? state, String? validityToken}) {
    return SsoCredentials(
        authorizationCode: authorizationCode ?? this.authorizationCode,
        state: state ?? this.state,
        validityToken: validityToken ?? this.validityToken);
  }

  SsoCredentials copyWithWrapped(
      {Wrapped<String?>? authorizationCode,
      Wrapped<String?>? state,
      Wrapped<String?>? validityToken}) {
    return SsoCredentials(
        authorizationCode: (authorizationCode != null
            ? authorizationCode.value
            : this.authorizationCode),
        state: (state != null ? state.value : this.state),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession {
  WebSession({
    this.oespToken,
    this.accessToken,
    this.username,
    this.locationId,
    this.timeToIdleSeconds,
    this.householdId,
    this.customer,
    this.canStream3G,
    this.adultPinVerified,
    this.parentalPinVerified,
    this.profilePinVerified,
    this.profileCredentialVerified,
    this.hasAdultCredential,
    this.profileSettings,
    this.entitlements,
    this.rbEntitlements,
    this.trackingId,
    this.refreshToken,
    this.homeScreenHint,
    this.refreshTokenExpiry,
  });

  factory WebSession.fromJson(Map<String, dynamic> json) =>
      _$WebSessionFromJson(json);

  @JsonKey(name: 'oespToken', includeIfNull: false, defaultValue: '')
  final String? oespToken;
  @JsonKey(name: 'accessToken', includeIfNull: false, defaultValue: '')
  final String? accessToken;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'locationId', includeIfNull: false, defaultValue: '')
  final String? locationId;
  @JsonKey(name: 'timeToIdleSeconds', includeIfNull: false)
  final int? timeToIdleSeconds;
  @JsonKey(name: 'householdId', includeIfNull: false, defaultValue: '')
  final String? householdId;
  @JsonKey(name: 'customer', includeIfNull: false)
  final WebSession$Customer? customer;
  @JsonKey(name: 'canStream3G', includeIfNull: false)
  final bool? canStream3G;
  @JsonKey(name: 'adultPinVerified', includeIfNull: false)
  final bool? adultPinVerified;
  @JsonKey(name: 'parentalPinVerified', includeIfNull: false)
  final bool? parentalPinVerified;
  @JsonKey(name: 'profilePinVerified', includeIfNull: false)
  final bool? profilePinVerified;
  @JsonKey(name: 'profileCredentialVerified', includeIfNull: false)
  final bool? profileCredentialVerified;
  @JsonKey(name: 'hasAdultCredential', includeIfNull: false)
  final bool? hasAdultCredential;
  @JsonKey(name: 'profileSettings', includeIfNull: false)
  final WebSession$ProfileSettings? profileSettings;
  @JsonKey(name: 'entitlements', includeIfNull: false, defaultValue: <String>[])
  final List<String>? entitlements;
  @JsonKey(
      name: 'rbEntitlements', includeIfNull: false, defaultValue: <String>[])
  final List<String>? rbEntitlements;
  @JsonKey(name: 'trackingId', includeIfNull: false, defaultValue: '')
  final String? trackingId;
  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  @JsonKey(name: 'homeScreenHint', includeIfNull: false, defaultValue: '')
  final String? homeScreenHint;
  @JsonKey(name: 'refreshTokenExpiry', includeIfNull: false)
  final int? refreshTokenExpiry;
  static const fromJsonFactory = _$WebSessionFromJson;
  static const toJsonFactory = _$WebSessionToJson;
  Map<String, dynamic> toJson() => _$WebSessionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession &&
            (identical(other.oespToken, oespToken) ||
                const DeepCollectionEquality()
                    .equals(other.oespToken, oespToken)) &&
            (identical(other.accessToken, accessToken) ||
                const DeepCollectionEquality()
                    .equals(other.accessToken, accessToken)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.locationId, locationId) ||
                const DeepCollectionEquality()
                    .equals(other.locationId, locationId)) &&
            (identical(other.timeToIdleSeconds, timeToIdleSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.timeToIdleSeconds, timeToIdleSeconds)) &&
            (identical(other.householdId, householdId) ||
                const DeepCollectionEquality()
                    .equals(other.householdId, householdId)) &&
            (identical(other.customer, customer) ||
                const DeepCollectionEquality()
                    .equals(other.customer, customer)) &&
            (identical(other.canStream3G, canStream3G) ||
                const DeepCollectionEquality()
                    .equals(other.canStream3G, canStream3G)) &&
            (identical(other.adultPinVerified, adultPinVerified) ||
                const DeepCollectionEquality()
                    .equals(other.adultPinVerified, adultPinVerified)) &&
            (identical(other.parentalPinVerified, parentalPinVerified) ||
                const DeepCollectionEquality()
                    .equals(other.parentalPinVerified, parentalPinVerified)) &&
            (identical(other.profilePinVerified, profilePinVerified) ||
                const DeepCollectionEquality()
                    .equals(other.profilePinVerified, profilePinVerified)) &&
            (identical(other.profileCredentialVerified, profileCredentialVerified) ||
                const DeepCollectionEquality().equals(
                    other.profileCredentialVerified,
                    profileCredentialVerified)) &&
            (identical(other.hasAdultCredential, hasAdultCredential) ||
                const DeepCollectionEquality()
                    .equals(other.hasAdultCredential, hasAdultCredential)) &&
            (identical(other.profileSettings, profileSettings) ||
                const DeepCollectionEquality()
                    .equals(other.profileSettings, profileSettings)) &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)) &&
            (identical(other.rbEntitlements, rbEntitlements) ||
                const DeepCollectionEquality()
                    .equals(other.rbEntitlements, rbEntitlements)) &&
            (identical(other.trackingId, trackingId) ||
                const DeepCollectionEquality()
                    .equals(other.trackingId, trackingId)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)) &&
            (identical(other.homeScreenHint, homeScreenHint) ||
                const DeepCollectionEquality()
                    .equals(other.homeScreenHint, homeScreenHint)) &&
            (identical(other.refreshTokenExpiry, refreshTokenExpiry) ||
                const DeepCollectionEquality().equals(other.refreshTokenExpiry, refreshTokenExpiry)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(oespToken) ^
      const DeepCollectionEquality().hash(accessToken) ^
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(locationId) ^
      const DeepCollectionEquality().hash(timeToIdleSeconds) ^
      const DeepCollectionEquality().hash(householdId) ^
      const DeepCollectionEquality().hash(customer) ^
      const DeepCollectionEquality().hash(canStream3G) ^
      const DeepCollectionEquality().hash(adultPinVerified) ^
      const DeepCollectionEquality().hash(parentalPinVerified) ^
      const DeepCollectionEquality().hash(profilePinVerified) ^
      const DeepCollectionEquality().hash(profileCredentialVerified) ^
      const DeepCollectionEquality().hash(hasAdultCredential) ^
      const DeepCollectionEquality().hash(profileSettings) ^
      const DeepCollectionEquality().hash(entitlements) ^
      const DeepCollectionEquality().hash(rbEntitlements) ^
      const DeepCollectionEquality().hash(trackingId) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      const DeepCollectionEquality().hash(homeScreenHint) ^
      const DeepCollectionEquality().hash(refreshTokenExpiry) ^
      runtimeType.hashCode;
}

extension $WebSessionExtension on WebSession {
  WebSession copyWith(
      {String? oespToken,
      String? accessToken,
      String? username,
      String? locationId,
      int? timeToIdleSeconds,
      String? householdId,
      WebSession$Customer? customer,
      bool? canStream3G,
      bool? adultPinVerified,
      bool? parentalPinVerified,
      bool? profilePinVerified,
      bool? profileCredentialVerified,
      bool? hasAdultCredential,
      WebSession$ProfileSettings? profileSettings,
      List<String>? entitlements,
      List<String>? rbEntitlements,
      String? trackingId,
      String? refreshToken,
      String? homeScreenHint,
      int? refreshTokenExpiry}) {
    return WebSession(
        oespToken: oespToken ?? this.oespToken,
        accessToken: accessToken ?? this.accessToken,
        username: username ?? this.username,
        locationId: locationId ?? this.locationId,
        timeToIdleSeconds: timeToIdleSeconds ?? this.timeToIdleSeconds,
        householdId: householdId ?? this.householdId,
        customer: customer ?? this.customer,
        canStream3G: canStream3G ?? this.canStream3G,
        adultPinVerified: adultPinVerified ?? this.adultPinVerified,
        parentalPinVerified: parentalPinVerified ?? this.parentalPinVerified,
        profilePinVerified: profilePinVerified ?? this.profilePinVerified,
        profileCredentialVerified:
            profileCredentialVerified ?? this.profileCredentialVerified,
        hasAdultCredential: hasAdultCredential ?? this.hasAdultCredential,
        profileSettings: profileSettings ?? this.profileSettings,
        entitlements: entitlements ?? this.entitlements,
        rbEntitlements: rbEntitlements ?? this.rbEntitlements,
        trackingId: trackingId ?? this.trackingId,
        refreshToken: refreshToken ?? this.refreshToken,
        homeScreenHint: homeScreenHint ?? this.homeScreenHint,
        refreshTokenExpiry: refreshTokenExpiry ?? this.refreshTokenExpiry);
  }

  WebSession copyWithWrapped(
      {Wrapped<String?>? oespToken,
      Wrapped<String?>? accessToken,
      Wrapped<String?>? username,
      Wrapped<String?>? locationId,
      Wrapped<int?>? timeToIdleSeconds,
      Wrapped<String?>? householdId,
      Wrapped<WebSession$Customer?>? customer,
      Wrapped<bool?>? canStream3G,
      Wrapped<bool?>? adultPinVerified,
      Wrapped<bool?>? parentalPinVerified,
      Wrapped<bool?>? profilePinVerified,
      Wrapped<bool?>? profileCredentialVerified,
      Wrapped<bool?>? hasAdultCredential,
      Wrapped<WebSession$ProfileSettings?>? profileSettings,
      Wrapped<List<String>?>? entitlements,
      Wrapped<List<String>?>? rbEntitlements,
      Wrapped<String?>? trackingId,
      Wrapped<String?>? refreshToken,
      Wrapped<String?>? homeScreenHint,
      Wrapped<int?>? refreshTokenExpiry}) {
    return WebSession(
        oespToken: (oespToken != null ? oespToken.value : this.oespToken),
        accessToken:
            (accessToken != null ? accessToken.value : this.accessToken),
        username: (username != null ? username.value : this.username),
        locationId: (locationId != null ? locationId.value : this.locationId),
        timeToIdleSeconds: (timeToIdleSeconds != null
            ? timeToIdleSeconds.value
            : this.timeToIdleSeconds),
        householdId:
            (householdId != null ? householdId.value : this.householdId),
        customer: (customer != null ? customer.value : this.customer),
        canStream3G:
            (canStream3G != null ? canStream3G.value : this.canStream3G),
        adultPinVerified: (adultPinVerified != null
            ? adultPinVerified.value
            : this.adultPinVerified),
        parentalPinVerified: (parentalPinVerified != null
            ? parentalPinVerified.value
            : this.parentalPinVerified),
        profilePinVerified: (profilePinVerified != null
            ? profilePinVerified.value
            : this.profilePinVerified),
        profileCredentialVerified: (profileCredentialVerified != null
            ? profileCredentialVerified.value
            : this.profileCredentialVerified),
        hasAdultCredential: (hasAdultCredential != null
            ? hasAdultCredential.value
            : this.hasAdultCredential),
        profileSettings: (profileSettings != null
            ? profileSettings.value
            : this.profileSettings),
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements),
        rbEntitlements: (rbEntitlements != null
            ? rbEntitlements.value
            : this.rbEntitlements),
        trackingId: (trackingId != null ? trackingId.value : this.trackingId),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken),
        homeScreenHint: (homeScreenHint != null
            ? homeScreenHint.value
            : this.homeScreenHint),
        refreshTokenExpiry: (refreshTokenExpiry != null
            ? refreshTokenExpiry.value
            : this.refreshTokenExpiry));
  }
}

typedef LoginError = List<LoginError$Item>;

@JsonSerializable(explicitToJson: true)
class LoginError$Item {
  LoginError$Item({
    this.type,
    this.code,
    this.reason,
  });

  factory LoginError$Item.fromJson(Map<String, dynamic> json) =>
      _$LoginError$ItemFromJson(json);

  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String? code;
  @JsonKey(name: 'reason', includeIfNull: false, defaultValue: '')
  final String? reason;
  static const fromJsonFactory = _$LoginError$ItemFromJson;
  static const toJsonFactory = _$LoginError$ItemToJson;
  Map<String, dynamic> toJson() => _$LoginError$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LoginError$Item &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.reason, reason) ||
                const DeepCollectionEquality().equals(other.reason, reason)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(reason) ^
      runtimeType.hashCode;
}

extension $LoginError$ItemExtension on LoginError$Item {
  LoginError$Item copyWith({String? type, String? code, String? reason}) {
    return LoginError$Item(
        type: type ?? this.type,
        code: code ?? this.code,
        reason: reason ?? this.reason);
  }

  LoginError$Item copyWithWrapped(
      {Wrapped<String?>? type,
      Wrapped<String?>? code,
      Wrapped<String?>? reason}) {
    return LoginError$Item(
        type: (type != null ? type.value : this.type),
        code: (code != null ? code.value : this.code),
        reason: (reason != null ? reason.value : this.reason));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationDetails {
  AuthorizationDetails({
    this.resetParentalPin,
    this.session,
    this.redirectUri,
    this.authorizationUri,
    this.state,
    this.deleteSessionUri,
    this.validityToken,
  });

  factory AuthorizationDetails.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationDetailsFromJson(json);

  @JsonKey(name: 'resetParentalPin', includeIfNull: false)
  final AuthorizationDetails$ResetParentalPin? resetParentalPin;
  @JsonKey(name: 'session', includeIfNull: false)
  final AuthorizationDetails$Session? session;
  @JsonKey(name: 'redirectUri', includeIfNull: false, defaultValue: '')
  final String? redirectUri;
  @JsonKey(name: 'authorizationUri', includeIfNull: false, defaultValue: '')
  final String? authorizationUri;
  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'deleteSessionUri', includeIfNull: false, defaultValue: '')
  final String? deleteSessionUri;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$AuthorizationDetailsFromJson;
  static const toJsonFactory = _$AuthorizationDetailsToJson;
  Map<String, dynamic> toJson() => _$AuthorizationDetailsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationDetails &&
            (identical(other.resetParentalPin, resetParentalPin) ||
                const DeepCollectionEquality()
                    .equals(other.resetParentalPin, resetParentalPin)) &&
            (identical(other.session, session) ||
                const DeepCollectionEquality()
                    .equals(other.session, session)) &&
            (identical(other.redirectUri, redirectUri) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUri, redirectUri)) &&
            (identical(other.authorizationUri, authorizationUri) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationUri, authorizationUri)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.deleteSessionUri, deleteSessionUri) ||
                const DeepCollectionEquality()
                    .equals(other.deleteSessionUri, deleteSessionUri)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(resetParentalPin) ^
      const DeepCollectionEquality().hash(session) ^
      const DeepCollectionEquality().hash(redirectUri) ^
      const DeepCollectionEquality().hash(authorizationUri) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(deleteSessionUri) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $AuthorizationDetailsExtension on AuthorizationDetails {
  AuthorizationDetails copyWith(
      {AuthorizationDetails$ResetParentalPin? resetParentalPin,
      AuthorizationDetails$Session? session,
      String? redirectUri,
      String? authorizationUri,
      String? state,
      String? deleteSessionUri,
      String? validityToken}) {
    return AuthorizationDetails(
        resetParentalPin: resetParentalPin ?? this.resetParentalPin,
        session: session ?? this.session,
        redirectUri: redirectUri ?? this.redirectUri,
        authorizationUri: authorizationUri ?? this.authorizationUri,
        state: state ?? this.state,
        deleteSessionUri: deleteSessionUri ?? this.deleteSessionUri,
        validityToken: validityToken ?? this.validityToken);
  }

  AuthorizationDetails copyWithWrapped(
      {Wrapped<AuthorizationDetails$ResetParentalPin?>? resetParentalPin,
      Wrapped<AuthorizationDetails$Session?>? session,
      Wrapped<String?>? redirectUri,
      Wrapped<String?>? authorizationUri,
      Wrapped<String?>? state,
      Wrapped<String?>? deleteSessionUri,
      Wrapped<String?>? validityToken}) {
    return AuthorizationDetails(
        resetParentalPin: (resetParentalPin != null
            ? resetParentalPin.value
            : this.resetParentalPin),
        session: (session != null ? session.value : this.session),
        redirectUri:
            (redirectUri != null ? redirectUri.value : this.redirectUri),
        authorizationUri: (authorizationUri != null
            ? authorizationUri.value
            : this.authorizationUri),
        state: (state != null ? state.value : this.state),
        deleteSessionUri: (deleteSessionUri != null
            ? deleteSessionUri.value
            : this.deleteSessionUri),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationResponse {
  AuthorizationResponse({
    this.username,
    this.refreshToken,
  });

  factory AuthorizationResponse.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationResponseFromJson(json);

  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'refreshToken', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  static const fromJsonFactory = _$AuthorizationResponseFromJson;
  static const toJsonFactory = _$AuthorizationResponseToJson;
  Map<String, dynamic> toJson() => _$AuthorizationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationResponse &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      runtimeType.hashCode;
}

extension $AuthorizationResponseExtension on AuthorizationResponse {
  AuthorizationResponse copyWith({String? username, String? refreshToken}) {
    return AuthorizationResponse(
        username: username ?? this.username,
        refreshToken: refreshToken ?? this.refreshToken);
  }

  AuthorizationResponse copyWithWrapped(
      {Wrapped<String?>? username, Wrapped<String?>? refreshToken}) {
    return AuthorizationResponse(
        username: (username != null ? username.value : this.username),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class StbAuthenticationRequest {
  StbAuthenticationRequest({
    this.authenticationToken,
  });

  factory StbAuthenticationRequest.fromJson(Map<String, dynamic> json) =>
      _$StbAuthenticationRequestFromJson(json);

  @JsonKey(name: 'authenticationToken', includeIfNull: false, defaultValue: '')
  final String? authenticationToken;
  static const fromJsonFactory = _$StbAuthenticationRequestFromJson;
  static const toJsonFactory = _$StbAuthenticationRequestToJson;
  Map<String, dynamic> toJson() => _$StbAuthenticationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StbAuthenticationRequest &&
            (identical(other.authenticationToken, authenticationToken) ||
                const DeepCollectionEquality()
                    .equals(other.authenticationToken, authenticationToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authenticationToken) ^
      runtimeType.hashCode;
}

extension $StbAuthenticationRequestExtension on StbAuthenticationRequest {
  StbAuthenticationRequest copyWith({String? authenticationToken}) {
    return StbAuthenticationRequest(
        authenticationToken: authenticationToken ?? this.authenticationToken);
  }

  StbAuthenticationRequest copyWithWrapped(
      {Wrapped<String?>? authenticationToken}) {
    return StbAuthenticationRequest(
        authenticationToken: (authenticationToken != null
            ? authenticationToken.value
            : this.authenticationToken));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceAuthorizationRequest {
  DeviceAuthorizationRequest({
    this.deviceId,
  });

  factory DeviceAuthorizationRequest.fromJson(Map<String, dynamic> json) =>
      _$DeviceAuthorizationRequestFromJson(json);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  static const fromJsonFactory = _$DeviceAuthorizationRequestFromJson;
  static const toJsonFactory = _$DeviceAuthorizationRequestToJson;
  Map<String, dynamic> toJson() => _$DeviceAuthorizationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceAuthorizationRequest &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^ runtimeType.hashCode;
}

extension $DeviceAuthorizationRequestExtension on DeviceAuthorizationRequest {
  DeviceAuthorizationRequest copyWith({String? deviceId}) {
    return DeviceAuthorizationRequest(deviceId: deviceId ?? this.deviceId);
  }

  DeviceAuthorizationRequest copyWithWrapped({Wrapped<String?>? deviceId}) {
    return DeviceAuthorizationRequest(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceAuthorizationResponse {
  DeviceAuthorizationResponse({
    this.authenticationToken,
  });

  factory DeviceAuthorizationResponse.fromJson(Map<String, dynamic> json) =>
      _$DeviceAuthorizationResponseFromJson(json);

  @JsonKey(name: 'authenticationToken', includeIfNull: false, defaultValue: '')
  final String? authenticationToken;
  static const fromJsonFactory = _$DeviceAuthorizationResponseFromJson;
  static const toJsonFactory = _$DeviceAuthorizationResponseToJson;
  Map<String, dynamic> toJson() => _$DeviceAuthorizationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceAuthorizationResponse &&
            (identical(other.authenticationToken, authenticationToken) ||
                const DeepCollectionEquality()
                    .equals(other.authenticationToken, authenticationToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authenticationToken) ^
      runtimeType.hashCode;
}

extension $DeviceAuthorizationResponseExtension on DeviceAuthorizationResponse {
  DeviceAuthorizationResponse copyWith({String? authenticationToken}) {
    return DeviceAuthorizationResponse(
        authenticationToken: authenticationToken ?? this.authenticationToken);
  }

  DeviceAuthorizationResponse copyWithWrapped(
      {Wrapped<String?>? authenticationToken}) {
    return DeviceAuthorizationResponse(
        authenticationToken: (authenticationToken != null
            ? authenticationToken.value
            : this.authenticationToken));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$Customer {
  WebSession$Customer({
    this.givenName,
    this.familyName,
    this.countryCode,
    this.gender,
    this.segmentAsNdh,
    this.status,
    this.smartCardId,
    this.physicalDeviceId,
    this.stbType,
    this.networkDvrAvailable,
    this.localDvrAvailable,
    this.householdId,
    this.sharedProfileId,
    this.replayTvEntitled,
    this.replayTvAvailable,
    this.replayTvMinimumBroadcastTime,
    this.replayTvOptedIn,
    this.offlineViewingEntitled,
    this.profileIds,
    this.oboProvisioned,
    this.customerId,
    this.purchaseEntitlementsToken,
  });

  factory WebSession$Customer.fromJson(Map<String, dynamic> json) =>
      _$WebSession$CustomerFromJson(json);

  @JsonKey(name: 'givenName', includeIfNull: false, defaultValue: '')
  final String? givenName;
  @JsonKey(name: 'familyName', includeIfNull: false, defaultValue: '')
  final String? familyName;
  @JsonKey(name: 'countryCode', includeIfNull: false, defaultValue: '')
  final String? countryCode;
  @JsonKey(name: 'gender', includeIfNull: false, defaultValue: '')
  final String? gender;
  @JsonKey(name: 'segmentAsNdh', includeIfNull: false)
  final bool? segmentAsNdh;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: <String>[])
  final List<String>? status;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'physicalDeviceId', includeIfNull: false, defaultValue: '')
  final String? physicalDeviceId;
  @JsonKey(name: 'stbType', includeIfNull: false, defaultValue: '')
  final String? stbType;
  @JsonKey(name: 'networkDvrAvailable', includeIfNull: false)
  final bool? networkDvrAvailable;
  @JsonKey(name: 'localDvrAvailable', includeIfNull: false)
  final bool? localDvrAvailable;
  @JsonKey(name: 'householdId', includeIfNull: false, defaultValue: '')
  final String? householdId;
  @JsonKey(name: 'sharedProfileId', includeIfNull: false, defaultValue: '')
  final String? sharedProfileId;
  @JsonKey(name: 'replayTvEntitled', includeIfNull: false)
  final bool? replayTvEntitled;
  @JsonKey(name: 'replayTvAvailable', includeIfNull: false)
  final bool? replayTvAvailable;
  @JsonKey(name: 'replayTvMinimumBroadcastTime', includeIfNull: false)
  final int? replayTvMinimumBroadcastTime;
  @JsonKey(name: 'replayTvOptedIn', includeIfNull: false)
  final bool? replayTvOptedIn;
  @JsonKey(name: 'offlineViewingEntitled', includeIfNull: false)
  final bool? offlineViewingEntitled;
  @JsonKey(name: 'profileIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? profileIds;
  @JsonKey(name: 'oboProvisioned', includeIfNull: false)
  final bool? oboProvisioned;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'purchaseEntitlementsToken', includeIfNull: false, defaultValue: '')
  final String? purchaseEntitlementsToken;
  static const fromJsonFactory = _$WebSession$CustomerFromJson;
  static const toJsonFactory = _$WebSession$CustomerToJson;
  Map<String, dynamic> toJson() => _$WebSession$CustomerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$Customer &&
            (identical(other.givenName, givenName) ||
                const DeepCollectionEquality()
                    .equals(other.givenName, givenName)) &&
            (identical(other.familyName, familyName) ||
                const DeepCollectionEquality()
                    .equals(other.familyName, familyName)) &&
            (identical(other.countryCode, countryCode) ||
                const DeepCollectionEquality()
                    .equals(other.countryCode, countryCode)) &&
            (identical(other.gender, gender) ||
                const DeepCollectionEquality().equals(other.gender, gender)) &&
            (identical(other.segmentAsNdh, segmentAsNdh) ||
                const DeepCollectionEquality()
                    .equals(other.segmentAsNdh, segmentAsNdh)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.physicalDeviceId, physicalDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.physicalDeviceId, physicalDeviceId)) &&
            (identical(other.stbType, stbType) ||
                const DeepCollectionEquality()
                    .equals(other.stbType, stbType)) &&
            (identical(other.networkDvrAvailable, networkDvrAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.networkDvrAvailable, networkDvrAvailable)) &&
            (identical(other.localDvrAvailable, localDvrAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.localDvrAvailable, localDvrAvailable)) &&
            (identical(other.householdId, householdId) ||
                const DeepCollectionEquality()
                    .equals(other.householdId, householdId)) &&
            (identical(other.sharedProfileId, sharedProfileId) ||
                const DeepCollectionEquality()
                    .equals(other.sharedProfileId, sharedProfileId)) &&
            (identical(other.replayTvEntitled, replayTvEntitled) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvEntitled, replayTvEntitled)) &&
            (identical(other.replayTvAvailable, replayTvAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvAvailable, replayTvAvailable)) &&
            (identical(other.replayTvMinimumBroadcastTime, replayTvMinimumBroadcastTime) ||
                const DeepCollectionEquality().equals(
                    other.replayTvMinimumBroadcastTime,
                    replayTvMinimumBroadcastTime)) &&
            (identical(other.replayTvOptedIn, replayTvOptedIn) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvOptedIn, replayTvOptedIn)) &&
            (identical(other.offlineViewingEntitled, offlineViewingEntitled) ||
                const DeepCollectionEquality().equals(
                    other.offlineViewingEntitled, offlineViewingEntitled)) &&
            (identical(other.profileIds, profileIds) ||
                const DeepCollectionEquality()
                    .equals(other.profileIds, profileIds)) &&
            (identical(other.oboProvisioned, oboProvisioned) ||
                const DeepCollectionEquality()
                    .equals(other.oboProvisioned, oboProvisioned)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.purchaseEntitlementsToken, purchaseEntitlementsToken) || const DeepCollectionEquality().equals(other.purchaseEntitlementsToken, purchaseEntitlementsToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(givenName) ^
      const DeepCollectionEquality().hash(familyName) ^
      const DeepCollectionEquality().hash(countryCode) ^
      const DeepCollectionEquality().hash(gender) ^
      const DeepCollectionEquality().hash(segmentAsNdh) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(physicalDeviceId) ^
      const DeepCollectionEquality().hash(stbType) ^
      const DeepCollectionEquality().hash(networkDvrAvailable) ^
      const DeepCollectionEquality().hash(localDvrAvailable) ^
      const DeepCollectionEquality().hash(householdId) ^
      const DeepCollectionEquality().hash(sharedProfileId) ^
      const DeepCollectionEquality().hash(replayTvEntitled) ^
      const DeepCollectionEquality().hash(replayTvAvailable) ^
      const DeepCollectionEquality().hash(replayTvMinimumBroadcastTime) ^
      const DeepCollectionEquality().hash(replayTvOptedIn) ^
      const DeepCollectionEquality().hash(offlineViewingEntitled) ^
      const DeepCollectionEquality().hash(profileIds) ^
      const DeepCollectionEquality().hash(oboProvisioned) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(purchaseEntitlementsToken) ^
      runtimeType.hashCode;
}

extension $WebSession$CustomerExtension on WebSession$Customer {
  WebSession$Customer copyWith(
      {String? givenName,
      String? familyName,
      String? countryCode,
      String? gender,
      bool? segmentAsNdh,
      List<String>? status,
      String? smartCardId,
      String? physicalDeviceId,
      String? stbType,
      bool? networkDvrAvailable,
      bool? localDvrAvailable,
      String? householdId,
      String? sharedProfileId,
      bool? replayTvEntitled,
      bool? replayTvAvailable,
      int? replayTvMinimumBroadcastTime,
      bool? replayTvOptedIn,
      bool? offlineViewingEntitled,
      List<String>? profileIds,
      bool? oboProvisioned,
      String? customerId,
      String? purchaseEntitlementsToken}) {
    return WebSession$Customer(
        givenName: givenName ?? this.givenName,
        familyName: familyName ?? this.familyName,
        countryCode: countryCode ?? this.countryCode,
        gender: gender ?? this.gender,
        segmentAsNdh: segmentAsNdh ?? this.segmentAsNdh,
        status: status ?? this.status,
        smartCardId: smartCardId ?? this.smartCardId,
        physicalDeviceId: physicalDeviceId ?? this.physicalDeviceId,
        stbType: stbType ?? this.stbType,
        networkDvrAvailable: networkDvrAvailable ?? this.networkDvrAvailable,
        localDvrAvailable: localDvrAvailable ?? this.localDvrAvailable,
        householdId: householdId ?? this.householdId,
        sharedProfileId: sharedProfileId ?? this.sharedProfileId,
        replayTvEntitled: replayTvEntitled ?? this.replayTvEntitled,
        replayTvAvailable: replayTvAvailable ?? this.replayTvAvailable,
        replayTvMinimumBroadcastTime:
            replayTvMinimumBroadcastTime ?? this.replayTvMinimumBroadcastTime,
        replayTvOptedIn: replayTvOptedIn ?? this.replayTvOptedIn,
        offlineViewingEntitled:
            offlineViewingEntitled ?? this.offlineViewingEntitled,
        profileIds: profileIds ?? this.profileIds,
        oboProvisioned: oboProvisioned ?? this.oboProvisioned,
        customerId: customerId ?? this.customerId,
        purchaseEntitlementsToken:
            purchaseEntitlementsToken ?? this.purchaseEntitlementsToken);
  }

  WebSession$Customer copyWithWrapped(
      {Wrapped<String?>? givenName,
      Wrapped<String?>? familyName,
      Wrapped<String?>? countryCode,
      Wrapped<String?>? gender,
      Wrapped<bool?>? segmentAsNdh,
      Wrapped<List<String>?>? status,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? physicalDeviceId,
      Wrapped<String?>? stbType,
      Wrapped<bool?>? networkDvrAvailable,
      Wrapped<bool?>? localDvrAvailable,
      Wrapped<String?>? householdId,
      Wrapped<String?>? sharedProfileId,
      Wrapped<bool?>? replayTvEntitled,
      Wrapped<bool?>? replayTvAvailable,
      Wrapped<int?>? replayTvMinimumBroadcastTime,
      Wrapped<bool?>? replayTvOptedIn,
      Wrapped<bool?>? offlineViewingEntitled,
      Wrapped<List<String>?>? profileIds,
      Wrapped<bool?>? oboProvisioned,
      Wrapped<String?>? customerId,
      Wrapped<String?>? purchaseEntitlementsToken}) {
    return WebSession$Customer(
        givenName: (givenName != null ? givenName.value : this.givenName),
        familyName: (familyName != null ? familyName.value : this.familyName),
        countryCode:
            (countryCode != null ? countryCode.value : this.countryCode),
        gender: (gender != null ? gender.value : this.gender),
        segmentAsNdh:
            (segmentAsNdh != null ? segmentAsNdh.value : this.segmentAsNdh),
        status: (status != null ? status.value : this.status),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        physicalDeviceId: (physicalDeviceId != null
            ? physicalDeviceId.value
            : this.physicalDeviceId),
        stbType: (stbType != null ? stbType.value : this.stbType),
        networkDvrAvailable: (networkDvrAvailable != null
            ? networkDvrAvailable.value
            : this.networkDvrAvailable),
        localDvrAvailable: (localDvrAvailable != null
            ? localDvrAvailable.value
            : this.localDvrAvailable),
        householdId:
            (householdId != null ? householdId.value : this.householdId),
        sharedProfileId: (sharedProfileId != null
            ? sharedProfileId.value
            : this.sharedProfileId),
        replayTvEntitled: (replayTvEntitled != null
            ? replayTvEntitled.value
            : this.replayTvEntitled),
        replayTvAvailable: (replayTvAvailable != null
            ? replayTvAvailable.value
            : this.replayTvAvailable),
        replayTvMinimumBroadcastTime: (replayTvMinimumBroadcastTime != null
            ? replayTvMinimumBroadcastTime.value
            : this.replayTvMinimumBroadcastTime),
        replayTvOptedIn: (replayTvOptedIn != null
            ? replayTvOptedIn.value
            : this.replayTvOptedIn),
        offlineViewingEntitled: (offlineViewingEntitled != null
            ? offlineViewingEntitled.value
            : this.offlineViewingEntitled),
        profileIds: (profileIds != null ? profileIds.value : this.profileIds),
        oboProvisioned: (oboProvisioned != null
            ? oboProvisioned.value
            : this.oboProvisioned),
        customerId: (customerId != null ? customerId.value : this.customerId),
        purchaseEntitlementsToken: (purchaseEntitlementsToken != null
            ? purchaseEntitlementsToken.value
            : this.purchaseEntitlementsToken));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings {
  WebSession$ProfileSettings({
    this.pinSettings,
    this.parentalSettings,
    this.purchaseSettings,
    this.termsSettings,
    this.optInSettings,
  });

  factory WebSession$ProfileSettings.fromJson(Map<String, dynamic> json) =>
      _$WebSession$ProfileSettingsFromJson(json);

  @JsonKey(name: 'pinSettings', includeIfNull: false)
  final WebSession$ProfileSettings$PinSettings? pinSettings;
  @JsonKey(name: 'parentalSettings', includeIfNull: false)
  final WebSession$ProfileSettings$ParentalSettings? parentalSettings;
  @JsonKey(name: 'purchaseSettings', includeIfNull: false)
  final WebSession$ProfileSettings$PurchaseSettings? purchaseSettings;
  @JsonKey(name: 'termsSettings', includeIfNull: false)
  final WebSession$ProfileSettings$TermsSettings? termsSettings;
  @JsonKey(name: 'optInSettings', includeIfNull: false)
  final WebSession$ProfileSettings$OptInSettings? optInSettings;
  static const fromJsonFactory = _$WebSession$ProfileSettingsFromJson;
  static const toJsonFactory = _$WebSession$ProfileSettingsToJson;
  Map<String, dynamic> toJson() => _$WebSession$ProfileSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings &&
            (identical(other.pinSettings, pinSettings) ||
                const DeepCollectionEquality()
                    .equals(other.pinSettings, pinSettings)) &&
            (identical(other.parentalSettings, parentalSettings) ||
                const DeepCollectionEquality()
                    .equals(other.parentalSettings, parentalSettings)) &&
            (identical(other.purchaseSettings, purchaseSettings) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseSettings, purchaseSettings)) &&
            (identical(other.termsSettings, termsSettings) ||
                const DeepCollectionEquality()
                    .equals(other.termsSettings, termsSettings)) &&
            (identical(other.optInSettings, optInSettings) ||
                const DeepCollectionEquality()
                    .equals(other.optInSettings, optInSettings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pinSettings) ^
      const DeepCollectionEquality().hash(parentalSettings) ^
      const DeepCollectionEquality().hash(purchaseSettings) ^
      const DeepCollectionEquality().hash(termsSettings) ^
      const DeepCollectionEquality().hash(optInSettings) ^
      runtimeType.hashCode;
}

extension $WebSession$ProfileSettingsExtension on WebSession$ProfileSettings {
  WebSession$ProfileSettings copyWith(
      {WebSession$ProfileSettings$PinSettings? pinSettings,
      WebSession$ProfileSettings$ParentalSettings? parentalSettings,
      WebSession$ProfileSettings$PurchaseSettings? purchaseSettings,
      WebSession$ProfileSettings$TermsSettings? termsSettings,
      WebSession$ProfileSettings$OptInSettings? optInSettings}) {
    return WebSession$ProfileSettings(
        pinSettings: pinSettings ?? this.pinSettings,
        parentalSettings: parentalSettings ?? this.parentalSettings,
        purchaseSettings: purchaseSettings ?? this.purchaseSettings,
        termsSettings: termsSettings ?? this.termsSettings,
        optInSettings: optInSettings ?? this.optInSettings);
  }

  WebSession$ProfileSettings copyWithWrapped(
      {Wrapped<WebSession$ProfileSettings$PinSettings?>? pinSettings,
      Wrapped<WebSession$ProfileSettings$ParentalSettings?>? parentalSettings,
      Wrapped<WebSession$ProfileSettings$PurchaseSettings?>? purchaseSettings,
      Wrapped<WebSession$ProfileSettings$TermsSettings?>? termsSettings,
      Wrapped<WebSession$ProfileSettings$OptInSettings?>? optInSettings}) {
    return WebSession$ProfileSettings(
        pinSettings:
            (pinSettings != null ? pinSettings.value : this.pinSettings),
        parentalSettings: (parentalSettings != null
            ? parentalSettings.value
            : this.parentalSettings),
        purchaseSettings: (purchaseSettings != null
            ? purchaseSettings.value
            : this.purchaseSettings),
        termsSettings:
            (termsSettings != null ? termsSettings.value : this.termsSettings),
        optInSettings:
            (optInSettings != null ? optInSettings.value : this.optInSettings));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationDetails$ResetParentalPin {
  AuthorizationDetails$ResetParentalPin({
    this.authorizationUri,
    this.redirectUri,
    this.state,
    this.validityToken,
  });

  factory AuthorizationDetails$ResetParentalPin.fromJson(
          Map<String, dynamic> json) =>
      _$AuthorizationDetails$ResetParentalPinFromJson(json);

  @JsonKey(name: 'authorizationUri', includeIfNull: false, defaultValue: '')
  final String? authorizationUri;
  @JsonKey(name: 'redirectUri', includeIfNull: false, defaultValue: '')
  final String? redirectUri;
  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory =
      _$AuthorizationDetails$ResetParentalPinFromJson;
  static const toJsonFactory = _$AuthorizationDetails$ResetParentalPinToJson;
  Map<String, dynamic> toJson() =>
      _$AuthorizationDetails$ResetParentalPinToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationDetails$ResetParentalPin &&
            (identical(other.authorizationUri, authorizationUri) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationUri, authorizationUri)) &&
            (identical(other.redirectUri, redirectUri) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUri, redirectUri)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorizationUri) ^
      const DeepCollectionEquality().hash(redirectUri) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $AuthorizationDetails$ResetParentalPinExtension
    on AuthorizationDetails$ResetParentalPin {
  AuthorizationDetails$ResetParentalPin copyWith(
      {String? authorizationUri,
      String? redirectUri,
      String? state,
      String? validityToken}) {
    return AuthorizationDetails$ResetParentalPin(
        authorizationUri: authorizationUri ?? this.authorizationUri,
        redirectUri: redirectUri ?? this.redirectUri,
        state: state ?? this.state,
        validityToken: validityToken ?? this.validityToken);
  }

  AuthorizationDetails$ResetParentalPin copyWithWrapped(
      {Wrapped<String?>? authorizationUri,
      Wrapped<String?>? redirectUri,
      Wrapped<String?>? state,
      Wrapped<String?>? validityToken}) {
    return AuthorizationDetails$ResetParentalPin(
        authorizationUri: (authorizationUri != null
            ? authorizationUri.value
            : this.authorizationUri),
        redirectUri:
            (redirectUri != null ? redirectUri.value : this.redirectUri),
        state: (state != null ? state.value : this.state),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationDetails$Session {
  AuthorizationDetails$Session({
    this.deleteSessionUri,
    this.redirectUri,
    this.state,
    this.authorizationUri,
    this.validityToken,
  });

  factory AuthorizationDetails$Session.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationDetails$SessionFromJson(json);

  @JsonKey(name: 'deleteSessionUri', includeIfNull: false, defaultValue: '')
  final String? deleteSessionUri;
  @JsonKey(name: 'redirectUri', includeIfNull: false, defaultValue: '')
  final String? redirectUri;
  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'authorizationUri', includeIfNull: false, defaultValue: '')
  final String? authorizationUri;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$AuthorizationDetails$SessionFromJson;
  static const toJsonFactory = _$AuthorizationDetails$SessionToJson;
  Map<String, dynamic> toJson() => _$AuthorizationDetails$SessionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationDetails$Session &&
            (identical(other.deleteSessionUri, deleteSessionUri) ||
                const DeepCollectionEquality()
                    .equals(other.deleteSessionUri, deleteSessionUri)) &&
            (identical(other.redirectUri, redirectUri) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUri, redirectUri)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.authorizationUri, authorizationUri) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationUri, authorizationUri)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deleteSessionUri) ^
      const DeepCollectionEquality().hash(redirectUri) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(authorizationUri) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $AuthorizationDetails$SessionExtension
    on AuthorizationDetails$Session {
  AuthorizationDetails$Session copyWith(
      {String? deleteSessionUri,
      String? redirectUri,
      String? state,
      String? authorizationUri,
      String? validityToken}) {
    return AuthorizationDetails$Session(
        deleteSessionUri: deleteSessionUri ?? this.deleteSessionUri,
        redirectUri: redirectUri ?? this.redirectUri,
        state: state ?? this.state,
        authorizationUri: authorizationUri ?? this.authorizationUri,
        validityToken: validityToken ?? this.validityToken);
  }

  AuthorizationDetails$Session copyWithWrapped(
      {Wrapped<String?>? deleteSessionUri,
      Wrapped<String?>? redirectUri,
      Wrapped<String?>? state,
      Wrapped<String?>? authorizationUri,
      Wrapped<String?>? validityToken}) {
    return AuthorizationDetails$Session(
        deleteSessionUri: (deleteSessionUri != null
            ? deleteSessionUri.value
            : this.deleteSessionUri),
        redirectUri:
            (redirectUri != null ? redirectUri.value : this.redirectUri),
        state: (state != null ? state.value : this.state),
        authorizationUri: (authorizationUri != null
            ? authorizationUri.value
            : this.authorizationUri),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$PinSettings {
  WebSession$ProfileSettings$PinSettings({
    this.isDefault,
  });

  factory WebSession$ProfileSettings$PinSettings.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$PinSettingsFromJson(json);

  @JsonKey(name: 'isDefault', includeIfNull: false)
  final bool? isDefault;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$PinSettingsFromJson;
  static const toJsonFactory = _$WebSession$ProfileSettings$PinSettingsToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$PinSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$PinSettings &&
            (identical(other.isDefault, isDefault) ||
                const DeepCollectionEquality()
                    .equals(other.isDefault, isDefault)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isDefault) ^ runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$PinSettingsExtension
    on WebSession$ProfileSettings$PinSettings {
  WebSession$ProfileSettings$PinSettings copyWith({bool? isDefault}) {
    return WebSession$ProfileSettings$PinSettings(
        isDefault: isDefault ?? this.isDefault);
  }

  WebSession$ProfileSettings$PinSettings copyWithWrapped(
      {Wrapped<bool?>? isDefault}) {
    return WebSession$ProfileSettings$PinSettings(
        isDefault: (isDefault != null ? isDefault.value : this.isDefault));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$ParentalSettings {
  WebSession$ProfileSettings$ParentalSettings({
    this.unrestrictedContentRatingCodes,
    this.isDefault,
  });

  factory WebSession$ProfileSettings$ParentalSettings.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$ParentalSettingsFromJson(json);

  @JsonKey(
      name: 'unrestrictedContentRatingCodes',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? unrestrictedContentRatingCodes;
  @JsonKey(name: 'isDefault', includeIfNull: false)
  final bool? isDefault;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$ParentalSettingsFromJson;
  static const toJsonFactory =
      _$WebSession$ProfileSettings$ParentalSettingsToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$ParentalSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$ParentalSettings &&
            (identical(other.unrestrictedContentRatingCodes,
                    unrestrictedContentRatingCodes) ||
                const DeepCollectionEquality().equals(
                    other.unrestrictedContentRatingCodes,
                    unrestrictedContentRatingCodes)) &&
            (identical(other.isDefault, isDefault) ||
                const DeepCollectionEquality()
                    .equals(other.isDefault, isDefault)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(unrestrictedContentRatingCodes) ^
      const DeepCollectionEquality().hash(isDefault) ^
      runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$ParentalSettingsExtension
    on WebSession$ProfileSettings$ParentalSettings {
  WebSession$ProfileSettings$ParentalSettings copyWith(
      {List<String>? unrestrictedContentRatingCodes, bool? isDefault}) {
    return WebSession$ProfileSettings$ParentalSettings(
        unrestrictedContentRatingCodes: unrestrictedContentRatingCodes ??
            this.unrestrictedContentRatingCodes,
        isDefault: isDefault ?? this.isDefault);
  }

  WebSession$ProfileSettings$ParentalSettings copyWithWrapped(
      {Wrapped<List<String>?>? unrestrictedContentRatingCodes,
      Wrapped<bool?>? isDefault}) {
    return WebSession$ProfileSettings$ParentalSettings(
        unrestrictedContentRatingCodes: (unrestrictedContentRatingCodes != null
            ? unrestrictedContentRatingCodes.value
            : this.unrestrictedContentRatingCodes),
        isDefault: (isDefault != null ? isDefault.value : this.isDefault));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$PurchaseSettings {
  WebSession$ProfileSettings$PurchaseSettings({
    this.restricted,
    this.isDefault,
  });

  factory WebSession$ProfileSettings$PurchaseSettings.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$PurchaseSettingsFromJson(json);

  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'isDefault', includeIfNull: false)
  final bool? isDefault;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$PurchaseSettingsFromJson;
  static const toJsonFactory =
      _$WebSession$ProfileSettings$PurchaseSettingsToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$PurchaseSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$PurchaseSettings &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.isDefault, isDefault) ||
                const DeepCollectionEquality()
                    .equals(other.isDefault, isDefault)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(isDefault) ^
      runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$PurchaseSettingsExtension
    on WebSession$ProfileSettings$PurchaseSettings {
  WebSession$ProfileSettings$PurchaseSettings copyWith(
      {bool? restricted, bool? isDefault}) {
    return WebSession$ProfileSettings$PurchaseSettings(
        restricted: restricted ?? this.restricted,
        isDefault: isDefault ?? this.isDefault);
  }

  WebSession$ProfileSettings$PurchaseSettings copyWithWrapped(
      {Wrapped<bool?>? restricted, Wrapped<bool?>? isDefault}) {
    return WebSession$ProfileSettings$PurchaseSettings(
        restricted: (restricted != null ? restricted.value : this.restricted),
        isDefault: (isDefault != null ? isDefault.value : this.isDefault));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$TermsSettings {
  WebSession$ProfileSettings$TermsSettings({
    this.version,
  });

  factory WebSession$ProfileSettings$TermsSettings.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$TermsSettingsFromJson(json);

  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String? version;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$TermsSettingsFromJson;
  static const toJsonFactory = _$WebSession$ProfileSettings$TermsSettingsToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$TermsSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$TermsSettings &&
            (identical(other.version, version) ||
                const DeepCollectionEquality().equals(other.version, version)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(version) ^ runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$TermsSettingsExtension
    on WebSession$ProfileSettings$TermsSettings {
  WebSession$ProfileSettings$TermsSettings copyWith({String? version}) {
    return WebSession$ProfileSettings$TermsSettings(
        version: version ?? this.version);
  }

  WebSession$ProfileSettings$TermsSettings copyWithWrapped(
      {Wrapped<String?>? version}) {
    return WebSession$ProfileSettings$TermsSettings(
        version: (version != null ? version.value : this.version));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$OptInSettings {
  WebSession$ProfileSettings$OptInSettings({
    this.sko,
    this.recommendations,
  });

  factory WebSession$ProfileSettings$OptInSettings.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$OptInSettingsFromJson(json);

  @JsonKey(name: 'sko', includeIfNull: false)
  final WebSession$ProfileSettings$OptInSettings$Sko? sko;
  @JsonKey(name: 'recommendations', includeIfNull: false)
  final WebSession$ProfileSettings$OptInSettings$Recommendations?
      recommendations;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$OptInSettingsFromJson;
  static const toJsonFactory = _$WebSession$ProfileSettings$OptInSettingsToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$OptInSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$OptInSettings &&
            (identical(other.sko, sko) ||
                const DeepCollectionEquality().equals(other.sko, sko)) &&
            (identical(other.recommendations, recommendations) ||
                const DeepCollectionEquality()
                    .equals(other.recommendations, recommendations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sko) ^
      const DeepCollectionEquality().hash(recommendations) ^
      runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$OptInSettingsExtension
    on WebSession$ProfileSettings$OptInSettings {
  WebSession$ProfileSettings$OptInSettings copyWith(
      {WebSession$ProfileSettings$OptInSettings$Sko? sko,
      WebSession$ProfileSettings$OptInSettings$Recommendations?
          recommendations}) {
    return WebSession$ProfileSettings$OptInSettings(
        sko: sko ?? this.sko,
        recommendations: recommendations ?? this.recommendations);
  }

  WebSession$ProfileSettings$OptInSettings copyWithWrapped(
      {Wrapped<WebSession$ProfileSettings$OptInSettings$Sko?>? sko,
      Wrapped<WebSession$ProfileSettings$OptInSettings$Recommendations?>?
          recommendations}) {
    return WebSession$ProfileSettings$OptInSettings(
        sko: (sko != null ? sko.value : this.sko),
        recommendations: (recommendations != null
            ? recommendations.value
            : this.recommendations));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$OptInSettings$Sko {
  WebSession$ProfileSettings$OptInSettings$Sko({
    this.status,
    this.lastUpdated,
    this.version,
  });

  factory WebSession$ProfileSettings$OptInSettings$Sko.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$OptInSettings$SkoFromJson(json);

  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'lastUpdated', includeIfNull: false)
  final num? lastUpdated;
  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String? version;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$OptInSettings$SkoFromJson;
  static const toJsonFactory =
      _$WebSession$ProfileSettings$OptInSettings$SkoToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$OptInSettings$SkoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$OptInSettings$Sko &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.lastUpdated, lastUpdated) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdated, lastUpdated)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality().equals(other.version, version)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(lastUpdated) ^
      const DeepCollectionEquality().hash(version) ^
      runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$OptInSettings$SkoExtension
    on WebSession$ProfileSettings$OptInSettings$Sko {
  WebSession$ProfileSettings$OptInSettings$Sko copyWith(
      {String? status, num? lastUpdated, String? version}) {
    return WebSession$ProfileSettings$OptInSettings$Sko(
        status: status ?? this.status,
        lastUpdated: lastUpdated ?? this.lastUpdated,
        version: version ?? this.version);
  }

  WebSession$ProfileSettings$OptInSettings$Sko copyWithWrapped(
      {Wrapped<String?>? status,
      Wrapped<num?>? lastUpdated,
      Wrapped<String?>? version}) {
    return WebSession$ProfileSettings$OptInSettings$Sko(
        status: (status != null ? status.value : this.status),
        lastUpdated:
            (lastUpdated != null ? lastUpdated.value : this.lastUpdated),
        version: (version != null ? version.value : this.version));
  }
}

@JsonSerializable(explicitToJson: true)
class WebSession$ProfileSettings$OptInSettings$Recommendations {
  WebSession$ProfileSettings$OptInSettings$Recommendations({
    this.status,
    this.lastUpdated,
  });

  factory WebSession$ProfileSettings$OptInSettings$Recommendations.fromJson(
          Map<String, dynamic> json) =>
      _$WebSession$ProfileSettings$OptInSettings$RecommendationsFromJson(json);

  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'lastUpdated', includeIfNull: false)
  final num? lastUpdated;
  static const fromJsonFactory =
      _$WebSession$ProfileSettings$OptInSettings$RecommendationsFromJson;
  static const toJsonFactory =
      _$WebSession$ProfileSettings$OptInSettings$RecommendationsToJson;
  Map<String, dynamic> toJson() =>
      _$WebSession$ProfileSettings$OptInSettings$RecommendationsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WebSession$ProfileSettings$OptInSettings$Recommendations &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.lastUpdated, lastUpdated) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdated, lastUpdated)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(lastUpdated) ^
      runtimeType.hashCode;
}

extension $WebSession$ProfileSettings$OptInSettings$RecommendationsExtension
    on WebSession$ProfileSettings$OptInSettings$Recommendations {
  WebSession$ProfileSettings$OptInSettings$Recommendations copyWith(
      {String? status, num? lastUpdated}) {
    return WebSession$ProfileSettings$OptInSettings$Recommendations(
        status: status ?? this.status,
        lastUpdated: lastUpdated ?? this.lastUpdated);
  }

  WebSession$ProfileSettings$OptInSettings$Recommendations copyWithWrapped(
      {Wrapped<String?>? status, Wrapped<num?>? lastUpdated}) {
    return WebSession$ProfileSettings$OptInSettings$Recommendations(
        status: (status != null ? status.value : this.status),
        lastUpdated:
            (lastUpdated != null ? lastUpdated.value : this.lastUpdated));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
