// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'authentication_application_service.enums.swagger.dart' as enums;
export 'authentication_application_service.enums.swagger.dart';

part 'authentication_application_service.swagger.chopper.dart';
part 'authentication_application_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class AuthenticationApplicationService extends ChopperService {
  static AuthenticationApplicationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$AuthenticationApplicationService(client);
    }

    final newClient = ChopperClient(
        services: [_$AuthenticationApplicationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://localhost:10014/auth');
    return _$AuthenticationApplicationService(newClient);
  }

  ///Verifies the given PIN code
  ///@param pinCode PIN code to be verified
  Future<chopper.Response<PinVerificationResult>> verifyPinPost({
    required PinCode? pinCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PinCode, () => PinCode.fromJsonFactory);
    generatedMapping.putIfAbsent(
        PinVerificationResult, () => PinVerificationResult.fromJsonFactory);

    return _verifyPinPost(pinCode: pinCode, cacheControl: cacheControl);
  }

  ///Verifies the given PIN code
  ///@param pinCode PIN code to be verified
  @Post(path: '/verifyPin')
  Future<chopper.Response<PinVerificationResult>> _verifyPinPost({
    @Body() required PinCode? pinCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the amount of last consecutive failed PIN attempts
  ///@param pinType Type of the PIN to get information about (PinType)
  Future<chopper.Response<PinAttemptsResult>> getFailedAttemptsPut({
    required PinTypeParam? pinType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PinTypeParam, () => PinTypeParam.fromJsonFactory);
    generatedMapping.putIfAbsent(
        PinAttemptsResult, () => PinAttemptsResult.fromJsonFactory);

    return _getFailedAttemptsPut(pinType: pinType, cacheControl: cacheControl);
  }

  ///Returns the amount of last consecutive failed PIN attempts
  ///@param pinType Type of the PIN to get information about (PinType)
  @Put(path: '/getFailedAttempts')
  Future<chopper.Response<PinAttemptsResult>> _getFailedAttemptsPut({
    @Body() required PinTypeParam? pinType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the amount of remaining PIN attempts
  ///@param pinType Type of the PIN to get information about (PinType)
  Future<chopper.Response<PinAttemptsResult>> getRemainingAttemptsPut({
    required PinTypeParam? pinType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PinTypeParam, () => PinTypeParam.fromJsonFactory);
    generatedMapping.putIfAbsent(
        PinAttemptsResult, () => PinAttemptsResult.fromJsonFactory);

    return _getRemainingAttemptsPut(
        pinType: pinType, cacheControl: cacheControl);
  }

  ///Returns the amount of remaining PIN attempts
  ///@param pinType Type of the PIN to get information about (PinType)
  @Put(path: '/getRemainingAttempts')
  Future<chopper.Response<PinAttemptsResult>> _getRemainingAttemptsPut({
    @Body() required PinTypeParam? pinType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the date-time when the suspension period is over for the given type of PIN is expired
  ///@param pinType Type of the PIN to get information about (PinType)
  Future<chopper.Response<int>> getSuspensionExpirationPut({
    required PinTypeParam? pinType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PinTypeParam, () => PinTypeParam.fromJsonFactory);

    return _getSuspensionExpirationPut(
        pinType: pinType, cacheControl: cacheControl);
  }

  ///Returns the date-time when the suspension period is over for the given type of PIN is expired
  ///@param pinType Type of the PIN to get information about (PinType)
  @Put(path: '/getSuspensionExpiration')
  Future<chopper.Response<int>> _getSuspensionExpirationPut({
    @Body() required PinTypeParam? pinType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Changes the old PIN code to a new one
  ///@param pinChange The old and new PIN codes
  Future<chopper.Response> changePinPost({
    required PinChange? pinChange,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PinChange, () => PinChange.fromJsonFactory);

    return _changePinPost(pinChange: pinChange, cacheControl: cacheControl);
  }

  ///Changes the old PIN code to a new one
  ///@param pinChange The old and new PIN codes
  @Post(path: '/changePin')
  Future<chopper.Response> _changePinPost({
    @Body() required PinChange? pinChange,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Changes the current profile
  ///@param profileId The profile ID to be set
  Future<chopper.Response> setCurrentProfilePost({
    required String? profileId,
    String? cacheControl,
  }) {
    return _setCurrentProfilePost(
        profileId: profileId, cacheControl: cacheControl);
  }

  ///Changes the current profile
  ///@param profileId The profile ID to be set
  @Post(path: '/setCurrentProfile')
  Future<chopper.Response> _setCurrentProfilePost({
    @Body() required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the current active profile
  Future<chopper.Response<Profile>> getCurrentProfilePut(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(Profile, () => Profile.fromJsonFactory);

    return _getCurrentProfilePut(cacheControl: cacheControl);
  }

  ///Returns the current active profile
  @Put(
    path: '/getCurrentProfile',
    optionalBody: true,
  )
  Future<chopper.Response<Profile>> _getCurrentProfilePut(
      {@Header('Cache-Control') String? cacheControl});

  ///Returns the list of available profiles
  Future<chopper.Response<List<Profile>>> getProfilesListPut(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(Profile, () => Profile.fromJsonFactory);

    return _getProfilesListPut(cacheControl: cacheControl);
  }

  ///Returns the list of available profiles
  @Put(
    path: '/getProfilesList',
    optionalBody: true,
  )
  Future<chopper.Response<List<Profile>>> _getProfilesListPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Add a new Profile
  ///@param profile
  Future<chopper.Response<ProfileId>> addProfilePost({
    required AddProfileParams? profile,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AddProfileParams, () => AddProfileParams.fromJsonFactory);
    generatedMapping.putIfAbsent(ProfileId, () => ProfileId.fromJsonFactory);

    return _addProfilePost(profile: profile, cacheControl: cacheControl);
  }

  ///Add a new Profile
  ///@param profile
  @Post(path: '/addProfile')
  Future<chopper.Response<ProfileId>> _addProfilePost({
    @Body() required AddProfileParams? profile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update Profile
  ///@param profile
  Future<chopper.Response> updateProfilePost({
    required UpdateProfileParams? profile,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UpdateProfileParams, () => UpdateProfileParams.fromJsonFactory);

    return _updateProfilePost(profile: profile, cacheControl: cacheControl);
  }

  ///Update Profile
  ///@param profile
  @Post(path: '/updateProfile')
  Future<chopper.Response> _updateProfilePost({
    @Body() required UpdateProfileParams? profile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Remove the Profile by the given ID
  ///@param profileId The ID of profile to be removed
  Future<chopper.Response> removeProfilePost({
    required String? profileId,
    String? cacheControl,
  }) {
    return _removeProfilePost(profileId: profileId, cacheControl: cacheControl);
  }

  ///Remove the Profile by the given ID
  ///@param profileId The ID of profile to be removed
  @Post(path: '/removeProfile')
  Future<chopper.Response> _removeProfilePost({
    @Body() required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns supported colors mapping for profiles
  Future<chopper.Response<Colors>> getProfileColorsPut({String? cacheControl}) {
    generatedMapping.putIfAbsent(Colors, () => Colors.fromJsonFactory);

    return _getProfileColorsPut(cacheControl: cacheControl);
  }

  ///Returns supported colors mapping for profiles
  @Put(
    path: '/getProfileColors',
    optionalBody: true,
  )
  Future<chopper.Response<Colors>> _getProfileColorsPut(
      {@Header('Cache-Control') String? cacheControl});

  ///Profile update event
  Future<chopper.Response<ProfileUpdateEvent>> profileUpdateGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ProfileUpdateEvent, () => ProfileUpdateEvent.fromJsonFactory);

    return _profileUpdateGet(cacheControl: cacheControl);
  }

  ///Profile update event
  @Get(path: '/profileUpdate')
  Future<chopper.Response<ProfileUpdateEvent>> _profileUpdateGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Profile switch event
  Future<chopper.Response<ProfileUpdateEvent>> profileSwitchGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ProfileUpdateEvent, () => ProfileUpdateEvent.fromJsonFactory);

    return _profileSwitchGet(cacheControl: cacheControl);
  }

  ///Profile switch event
  @Get(path: '/profileSwitch')
  Future<chopper.Response<ProfileUpdateEvent>> _profileSwitchGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Current profile ensured event
  Future<chopper.Response> currentProfileEnsuredGet({String? cacheControl}) {
    return _currentProfileEnsuredGet(cacheControl: cacheControl);
  }

  ///Current profile ensured event
  @Get(path: '/currentProfileEnsured')
  Future<chopper.Response> _currentProfileEnsuredGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class Colors {
  Colors();

  factory Colors.fromJson(Map<String, dynamic> json) => _$ColorsFromJson(json);

  static const fromJsonFactory = _$ColorsFromJson;
  static const toJsonFactory = _$ColorsToJson;
  Map<String, dynamic> toJson() => _$ColorsToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class PinCode {
  PinCode({
    required this.pin,
    required this.pinType,
  });

  factory PinCode.fromJson(Map<String, dynamic> json) =>
      _$PinCodeFromJson(json);

  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String pin;
  @JsonKey(
    name: 'pinType',
    includeIfNull: false,
    toJson: pinTypeToJson,
    fromJson: pinTypeFromJson,
  )
  final enums.PinType pinType;
  static const fromJsonFactory = _$PinCodeFromJson;
  static const toJsonFactory = _$PinCodeToJson;
  Map<String, dynamic> toJson() => _$PinCodeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinCode &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.pinType, pinType) ||
                const DeepCollectionEquality().equals(other.pinType, pinType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(pinType) ^
      runtimeType.hashCode;
}

extension $PinCodeExtension on PinCode {
  PinCode copyWith({String? pin, enums.PinType? pinType}) {
    return PinCode(pin: pin ?? this.pin, pinType: pinType ?? this.pinType);
  }

  PinCode copyWithWrapped(
      {Wrapped<String>? pin, Wrapped<enums.PinType>? pinType}) {
    return PinCode(
        pin: (pin != null ? pin.value : this.pin),
        pinType: (pinType != null ? pinType.value : this.pinType));
  }
}

@JsonSerializable(explicitToJson: true)
class PinChange {
  PinChange({
    this.oldPin,
    required this.newPin,
    required this.pinType,
  });

  factory PinChange.fromJson(Map<String, dynamic> json) =>
      _$PinChangeFromJson(json);

  @JsonKey(name: 'oldPin', includeIfNull: false, defaultValue: '')
  final String? oldPin;
  @JsonKey(name: 'newPin', includeIfNull: false, defaultValue: '')
  final String newPin;
  @JsonKey(
    name: 'pinType',
    includeIfNull: false,
    toJson: pinTypeToJson,
    fromJson: pinTypeFromJson,
  )
  final enums.PinType pinType;
  static const fromJsonFactory = _$PinChangeFromJson;
  static const toJsonFactory = _$PinChangeToJson;
  Map<String, dynamic> toJson() => _$PinChangeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinChange &&
            (identical(other.oldPin, oldPin) ||
                const DeepCollectionEquality().equals(other.oldPin, oldPin)) &&
            (identical(other.newPin, newPin) ||
                const DeepCollectionEquality().equals(other.newPin, newPin)) &&
            (identical(other.pinType, pinType) ||
                const DeepCollectionEquality().equals(other.pinType, pinType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(oldPin) ^
      const DeepCollectionEquality().hash(newPin) ^
      const DeepCollectionEquality().hash(pinType) ^
      runtimeType.hashCode;
}

extension $PinChangeExtension on PinChange {
  PinChange copyWith({String? oldPin, String? newPin, enums.PinType? pinType}) {
    return PinChange(
        oldPin: oldPin ?? this.oldPin,
        newPin: newPin ?? this.newPin,
        pinType: pinType ?? this.pinType);
  }

  PinChange copyWithWrapped(
      {Wrapped<String?>? oldPin,
      Wrapped<String>? newPin,
      Wrapped<enums.PinType>? pinType}) {
    return PinChange(
        oldPin: (oldPin != null ? oldPin.value : this.oldPin),
        newPin: (newPin != null ? newPin.value : this.newPin),
        pinType: (pinType != null ? pinType.value : this.pinType));
  }
}

@JsonSerializable(explicitToJson: true)
class PinTypeParam {
  PinTypeParam({
    required this.pinType,
  });

  factory PinTypeParam.fromJson(Map<String, dynamic> json) =>
      _$PinTypeParamFromJson(json);

  @JsonKey(
    name: 'pinType',
    includeIfNull: false,
    toJson: pinTypeToJson,
    fromJson: pinTypeFromJson,
  )
  final enums.PinType pinType;
  static const fromJsonFactory = _$PinTypeParamFromJson;
  static const toJsonFactory = _$PinTypeParamToJson;
  Map<String, dynamic> toJson() => _$PinTypeParamToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinTypeParam &&
            (identical(other.pinType, pinType) ||
                const DeepCollectionEquality().equals(other.pinType, pinType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pinType) ^ runtimeType.hashCode;
}

extension $PinTypeParamExtension on PinTypeParam {
  PinTypeParam copyWith({enums.PinType? pinType}) {
    return PinTypeParam(pinType: pinType ?? this.pinType);
  }

  PinTypeParam copyWithWrapped({Wrapped<enums.PinType>? pinType}) {
    return PinTypeParam(
        pinType: (pinType != null ? pinType.value : this.pinType));
  }
}

@JsonSerializable(explicitToJson: true)
class PinVerificationResult {
  PinVerificationResult({
    required this.result,
    this.suspensionExpiration,
  });

  factory PinVerificationResult.fromJson(Map<String, dynamic> json) =>
      _$PinVerificationResultFromJson(json);

  @JsonKey(
    name: 'result',
    includeIfNull: false,
    toJson: verificationResultToJson,
    fromJson: verificationResultFromJson,
  )
  final enums.VerificationResult result;
  @JsonKey(name: 'suspensionExpiration', includeIfNull: false)
  final int? suspensionExpiration;
  static const fromJsonFactory = _$PinVerificationResultFromJson;
  static const toJsonFactory = _$PinVerificationResultToJson;
  Map<String, dynamic> toJson() => _$PinVerificationResultToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinVerificationResult &&
            (identical(other.result, result) ||
                const DeepCollectionEquality().equals(other.result, result)) &&
            (identical(other.suspensionExpiration, suspensionExpiration) ||
                const DeepCollectionEquality()
                    .equals(other.suspensionExpiration, suspensionExpiration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(result) ^
      const DeepCollectionEquality().hash(suspensionExpiration) ^
      runtimeType.hashCode;
}

extension $PinVerificationResultExtension on PinVerificationResult {
  PinVerificationResult copyWith(
      {enums.VerificationResult? result, int? suspensionExpiration}) {
    return PinVerificationResult(
        result: result ?? this.result,
        suspensionExpiration:
            suspensionExpiration ?? this.suspensionExpiration);
  }

  PinVerificationResult copyWithWrapped(
      {Wrapped<enums.VerificationResult>? result,
      Wrapped<int?>? suspensionExpiration}) {
    return PinVerificationResult(
        result: (result != null ? result.value : this.result),
        suspensionExpiration: (suspensionExpiration != null
            ? suspensionExpiration.value
            : this.suspensionExpiration));
  }
}

@JsonSerializable(explicitToJson: true)
class PinAttemptsResult {
  PinAttemptsResult({
    required this.count,
  });

  factory PinAttemptsResult.fromJson(Map<String, dynamic> json) =>
      _$PinAttemptsResultFromJson(json);

  @JsonKey(name: 'count', includeIfNull: false)
  final int count;
  static const fromJsonFactory = _$PinAttemptsResultFromJson;
  static const toJsonFactory = _$PinAttemptsResultToJson;
  Map<String, dynamic> toJson() => _$PinAttemptsResultToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PinAttemptsResult &&
            (identical(other.count, count) ||
                const DeepCollectionEquality().equals(other.count, count)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(count) ^ runtimeType.hashCode;
}

extension $PinAttemptsResultExtension on PinAttemptsResult {
  PinAttemptsResult copyWith({int? count}) {
    return PinAttemptsResult(count: count ?? this.count);
  }

  PinAttemptsResult copyWithWrapped({Wrapped<int>? count}) {
    return PinAttemptsResult(count: (count != null ? count.value : this.count));
  }
}

@JsonSerializable(explicitToJson: true)
class AddProfileParams {
  AddProfileParams({
    required this.name,
    required this.color,
    required this.favoriteChannels,
  });

  factory AddProfileParams.fromJson(Map<String, dynamic> json) =>
      _$AddProfileParamsFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String> favoriteChannels;
  static const fromJsonFactory = _$AddProfileParamsFromJson;
  static const toJsonFactory = _$AddProfileParamsToJson;
  Map<String, dynamic> toJson() => _$AddProfileParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AddProfileParams &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      runtimeType.hashCode;
}

extension $AddProfileParamsExtension on AddProfileParams {
  AddProfileParams copyWith(
      {String? name, String? color, List<String>? favoriteChannels}) {
    return AddProfileParams(
        name: name ?? this.name,
        color: color ?? this.color,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels);
  }

  AddProfileParams copyWithWrapped(
      {Wrapped<String>? name,
      Wrapped<String>? color,
      Wrapped<List<String>>? favoriteChannels}) {
    return AddProfileParams(
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateProfileParams {
  UpdateProfileParams({
    required this.id,
    this.name,
    this.color,
  });

  factory UpdateProfileParams.fromJson(Map<String, dynamic> json) =>
      _$UpdateProfileParamsFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  static const fromJsonFactory = _$UpdateProfileParamsFromJson;
  static const toJsonFactory = _$UpdateProfileParamsToJson;
  Map<String, dynamic> toJson() => _$UpdateProfileParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateProfileParams &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      runtimeType.hashCode;
}

extension $UpdateProfileParamsExtension on UpdateProfileParams {
  UpdateProfileParams copyWith({String? id, String? name, String? color}) {
    return UpdateProfileParams(
        id: id ?? this.id, name: name ?? this.name, color: color ?? this.color);
  }

  UpdateProfileParams copyWithWrapped(
      {Wrapped<String>? id, Wrapped<String?>? name, Wrapped<String?>? color}) {
    return UpdateProfileParams(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileUpdateEvent {
  ProfileUpdateEvent({
    this.oldProfile,
    this.newProfile,
  });

  factory ProfileUpdateEvent.fromJson(Map<String, dynamic> json) =>
      _$ProfileUpdateEventFromJson(json);

  @JsonKey(name: 'oldProfile', includeIfNull: false)
  final Profile? oldProfile;
  @JsonKey(name: 'newProfile', includeIfNull: false)
  final Profile? newProfile;
  static const fromJsonFactory = _$ProfileUpdateEventFromJson;
  static const toJsonFactory = _$ProfileUpdateEventToJson;
  Map<String, dynamic> toJson() => _$ProfileUpdateEventToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileUpdateEvent &&
            (identical(other.oldProfile, oldProfile) ||
                const DeepCollectionEquality()
                    .equals(other.oldProfile, oldProfile)) &&
            (identical(other.newProfile, newProfile) ||
                const DeepCollectionEquality()
                    .equals(other.newProfile, newProfile)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(oldProfile) ^
      const DeepCollectionEquality().hash(newProfile) ^
      runtimeType.hashCode;
}

extension $ProfileUpdateEventExtension on ProfileUpdateEvent {
  ProfileUpdateEvent copyWith({Profile? oldProfile, Profile? newProfile}) {
    return ProfileUpdateEvent(
        oldProfile: oldProfile ?? this.oldProfile,
        newProfile: newProfile ?? this.newProfile);
  }

  ProfileUpdateEvent copyWithWrapped(
      {Wrapped<Profile?>? oldProfile, Wrapped<Profile?>? newProfile}) {
    return ProfileUpdateEvent(
        oldProfile: (oldProfile != null ? oldProfile.value : this.oldProfile),
        newProfile: (newProfile != null ? newProfile.value : this.newProfile));
  }
}

@JsonSerializable(explicitToJson: true)
class Profile {
  Profile({
    required this.id,
    required this.name,
    required this.isShared,
    required this.color,
  });

  factory Profile.fromJson(Map<String, dynamic> json) =>
      _$ProfileFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'isShared', includeIfNull: false)
  final bool isShared;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  static const fromJsonFactory = _$ProfileFromJson;
  static const toJsonFactory = _$ProfileToJson;
  Map<String, dynamic> toJson() => _$ProfileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Profile &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.isShared, isShared) ||
                const DeepCollectionEquality()
                    .equals(other.isShared, isShared)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(isShared) ^
      const DeepCollectionEquality().hash(color) ^
      runtimeType.hashCode;
}

extension $ProfileExtension on Profile {
  Profile copyWith({String? id, String? name, bool? isShared, String? color}) {
    return Profile(
        id: id ?? this.id,
        name: name ?? this.name,
        isShared: isShared ?? this.isShared,
        color: color ?? this.color);
  }

  Profile copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<bool>? isShared,
      Wrapped<String>? color}) {
    return Profile(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        isShared: (isShared != null ? isShared.value : this.isShared),
        color: (color != null ? color.value : this.color));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileId {
  ProfileId({
    required this.profileId,
  });

  factory ProfileId.fromJson(Map<String, dynamic> json) =>
      _$ProfileIdFromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  static const fromJsonFactory = _$ProfileIdFromJson;
  static const toJsonFactory = _$ProfileIdToJson;
  Map<String, dynamic> toJson() => _$ProfileIdToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileId &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^ runtimeType.hashCode;
}

extension $ProfileIdExtension on ProfileId {
  ProfileId copyWith({String? profileId}) {
    return ProfileId(profileId: profileId ?? this.profileId);
  }

  ProfileId copyWithWrapped({Wrapped<String>? profileId}) {
    return ProfileId(
        profileId: (profileId != null ? profileId.value : this.profileId));
  }
}

String? verificationResultToJson(enums.VerificationResult? verificationResult) {
  return enums.$VerificationResultMap[verificationResult];
}

enums.VerificationResult verificationResultFromJson(
  Object? verificationResult, [
  enums.VerificationResult? defaultValue,
]) {
  if (verificationResult is String) {
    return enums.$VerificationResultMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == verificationResult.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VerificationResult.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VerificationResultMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VerificationResult.swaggerGeneratedUnknown;
}

List<String> verificationResultListToJson(
    List<enums.VerificationResult>? verificationResult) {
  if (verificationResult == null) {
    return [];
  }

  return verificationResult
      .map((e) => enums.$VerificationResultMap[e]!)
      .toList();
}

List<enums.VerificationResult> verificationResultListFromJson(
  List? verificationResult, [
  List<enums.VerificationResult>? defaultValue,
]) {
  if (verificationResult == null) {
    return defaultValue ?? [];
  }

  return verificationResult
      .map((e) => verificationResultFromJson(e.toString()))
      .toList();
}

List<enums.VerificationResult>? verificationResultNullableListFromJson(
  List? verificationResult, [
  List<enums.VerificationResult>? defaultValue,
]) {
  if (verificationResult == null) {
    return defaultValue;
  }

  return verificationResult
      .map((e) => verificationResultFromJson(e.toString()))
      .toList();
}

String? authErrorToJson(enums.AuthError? authError) {
  return enums.$AuthErrorMap[authError];
}

enums.AuthError authErrorFromJson(
  Object? authError, [
  enums.AuthError? defaultValue,
]) {
  if (authError is String) {
    return enums.$AuthErrorMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == authError.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.AuthError.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$AuthErrorMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.AuthError.swaggerGeneratedUnknown;
}

List<String> authErrorListToJson(List<enums.AuthError>? authError) {
  if (authError == null) {
    return [];
  }

  return authError.map((e) => enums.$AuthErrorMap[e]!).toList();
}

List<enums.AuthError> authErrorListFromJson(
  List? authError, [
  List<enums.AuthError>? defaultValue,
]) {
  if (authError == null) {
    return defaultValue ?? [];
  }

  return authError.map((e) => authErrorFromJson(e.toString())).toList();
}

List<enums.AuthError>? authErrorNullableListFromJson(
  List? authError, [
  List<enums.AuthError>? defaultValue,
]) {
  if (authError == null) {
    return defaultValue;
  }

  return authError.map((e) => authErrorFromJson(e.toString())).toList();
}

String? pinTypeToJson(enums.PinType? pinType) {
  return enums.$PinTypeMap[pinType];
}

enums.PinType pinTypeFromJson(
  Object? pinType, [
  enums.PinType? defaultValue,
]) {
  if (pinType is String) {
    return enums.$PinTypeMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == pinType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PinType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PinTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.PinType.swaggerGeneratedUnknown;
}

List<String> pinTypeListToJson(List<enums.PinType>? pinType) {
  if (pinType == null) {
    return [];
  }

  return pinType.map((e) => enums.$PinTypeMap[e]!).toList();
}

List<enums.PinType> pinTypeListFromJson(
  List? pinType, [
  List<enums.PinType>? defaultValue,
]) {
  if (pinType == null) {
    return defaultValue ?? [];
  }

  return pinType.map((e) => pinTypeFromJson(e.toString())).toList();
}

List<enums.PinType>? pinTypeNullableListFromJson(
  List? pinType, [
  List<enums.PinType>? defaultValue,
]) {
  if (pinType == null) {
    return defaultValue;
  }

  return pinType.map((e) => pinTypeFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
