// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'bonus_remote_data_source.swagger.chopper.dart';
part 'bonus_remote_data_source.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class BonusRemoteDataSource extends ChopperService {
  static BonusRemoteDataSource create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$BonusRemoteDataSource(client);
    }

    final newClient = ChopperClient(
        services: [_$BonusRemoteDataSource()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$BonusRemoteDataSource(newClient);
  }

  ///Get spotlight bonus section from promotion-processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV1SpotlightGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV1SpotlightGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get spotlight bonus section from promotion-processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v1/spotlight')
  Future<chopper.Response<BonusSection>> _bonuspageV1SpotlightGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get bonus metadata.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  Future<chopper.Response<BonusMetadata>> bonuspageV1MetadataGet({
    String? appieCurrentOrderId,
    String? xApplication,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusMetadata, () => BonusMetadata.fromJsonFactory);

    return _bonuspageV1MetadataGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        cacheControl: cacheControl);
  }

  ///Get bonus metadata.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  @Get(path: '/bonuspage/v1/metadata')
  Future<chopper.Response<BonusMetadata>> _bonuspageV1MetadataGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get bonus section.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param sectionId
  Future<chopper.Response<BonusSection>> bonuspageV1SectionGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required int? sectionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV1SectionGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        sectionId: sectionId,
        cacheControl: cacheControl);
  }

  ///Get bonus section.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param sectionId
  @Get(path: '/bonuspage/v1/section')
  Future<chopper.Response<BonusSection>> _bonuspageV1SectionGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('sectionId') required int? sectionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get personal bonus from promotion processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV1PersonalGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV1PersonalGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get personal bonus from promotion processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v1/personal')
  Future<chopper.Response<BonusSection>> _bonuspageV1PersonalGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get pbo bonus.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV1PboGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV1PboGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get pbo bonus.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v1/pbo')
  Future<chopper.Response<BonusSection>> _bonuspageV1PboGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get bonus segment products.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param segmentId
  ///@param id
  ///@param includeActivatableDiscount
  ///@param date
  Future<chopper.Response<BonusGroup>> bonuspageV1SegmentGet({
    String? appieCurrentOrderId,
    String? xApplication,
    String? segmentId,
    String? id,
    bool? includeActivatableDiscount,
    required String? date,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(BonusGroup, () => BonusGroup.fromJsonFactory);

    return _bonuspageV1SegmentGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        segmentId: segmentId,
        id: id,
        includeActivatableDiscount: includeActivatableDiscount,
        date: date,
        cacheControl: cacheControl);
  }

  ///Get bonus segment products.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param segmentId
  ///@param id
  ///@param includeActivatableDiscount
  ///@param date
  @Get(path: '/bonuspage/v1/segment')
  Future<chopper.Response<BonusGroup>> _bonuspageV1SegmentGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('segmentId') String? segmentId,
    @Query('id') String? id,
    @Query('includeActivatableDiscount') bool? includeActivatableDiscount,
    @Query('date') required String? date,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get bonus folder from slug
  ///@param x-application
  ///@param folder
  Future<chopper.Response<BonusFolderLink>> bonuspageV1BonusFolderGet({
    String? xApplication,
    required String? folder,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusFolderLink, () => BonusFolderLink.fromJsonFactory);

    return _bonuspageV1BonusFolderGet(
        xApplication: xApplication, folder: folder, cacheControl: cacheControl);
  }

  ///Get bonus folder from slug
  ///@param x-application
  ///@param folder
  @Get(path: '/bonuspage/v1/bonus-folder')
  Future<chopper.Response<BonusFolderLink>> _bonuspageV1BonusFolderGet({
    @Header('x-application') String? xApplication,
    @Query('folder') required String? folder,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get choose and activate bonus from promotion processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV1ChooseAndActivateGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV1ChooseAndActivateGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get choose and activate bonus from promotion processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v1/choose-and-activate')
  Future<chopper.Response<BonusSection>> _bonuspageV1ChooseAndActivateGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get delivery bundle bonus from promotion processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV1DeliveryBundleGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV1DeliveryBundleGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get delivery bundle bonus from promotion processor.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v1/delivery-bundle')
  Future<chopper.Response<BonusSection>> _bonuspageV1DeliveryBundleGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Activate the Choose&Activate bonus offer
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param offerId
  ///@param segmentId
  ///@param startDate
  Future<chopper.Response<ProductOrBonusGroup>>
      bonuspageV1ActivateOfferIdPatch({
    String? appieCurrentOrderId,
    String? xApplication,
    required num? offerId,
    required String? segmentId,
    required String? startDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProductOrBonusGroup, () => ProductOrBonusGroup.fromJsonFactory);

    return _bonuspageV1ActivateOfferIdPatch(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        offerId: offerId,
        segmentId: segmentId,
        startDate: startDate,
        cacheControl: cacheControl);
  }

  ///Activate the Choose&Activate bonus offer
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param offerId
  ///@param segmentId
  ///@param startDate
  @Patch(
    path: '/bonuspage/v1/activate/{offerId}',
    optionalBody: true,
  )
  Future<chopper.Response<ProductOrBonusGroup>>
      _bonuspageV1ActivateOfferIdPatch({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Path('offerId') required num? offerId,
    @Query('segmentId') required String? segmentId,
    @Query('startDate') required String? startDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get spotlight bonus section.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV0SpotlightGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV0SpotlightGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get spotlight bonus section.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v0/spotlight')
  Future<chopper.Response<BonusSection>> _bonuspageV0SpotlightGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get personal bonus from product-service.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV0PersonalGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV0PersonalGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get personal bonus from product-service.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v0/personal')
  Future<chopper.Response<BonusSection>> _bonuspageV0PersonalGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get pbo bonus.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  Future<chopper.Response<BonusSection>> bonuspageV0PboGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required String? bonusStartDate,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _bonuspageV0PboGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        bonusStartDate: bonusStartDate,
        cacheControl: cacheControl);
  }

  ///Get pbo bonus.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param bonusStartDate
  @Get(path: '/bonuspage/v0/pbo')
  Future<chopper.Response<BonusSection>> _bonuspageV0PboGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('bonusStartDate') required String? bonusStartDate,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get bonus segment products.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param segmentId
  ///@param date
  Future<chopper.Response<BonusGroup>> bonuspageV0SegmentGet({
    String? appieCurrentOrderId,
    String? xApplication,
    required num? segmentId,
    required String? date,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(BonusGroup, () => BonusGroup.fromJsonFactory);

    return _bonuspageV0SegmentGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        segmentId: segmentId,
        date: date,
        cacheControl: cacheControl);
  }

  ///Get bonus segment products.
  ///@param Appie-Current-Order-Id
  ///@param x-application
  ///@param segmentId
  ///@param date
  @Get(path: '/bonuspage/v0/segment')
  Future<chopper.Response<BonusGroup>> _bonuspageV0SegmentGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Query('segmentId') required num? segmentId,
    @Query('date') required String? date,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Personal bonus + previously bought or Spotlight promotions
  ///@param Appie-Current-Order-Id
  ///@param x-application
  Future<chopper.Response<BonusSection>> discoverV2BonusGet({
    String? appieCurrentOrderId,
    String? xApplication,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _discoverV2BonusGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        cacheControl: cacheControl);
  }

  ///Personal bonus + previously bought or Spotlight promotions
  ///@param Appie-Current-Order-Id
  ///@param x-application
  @Get(path: '/discover/v2/bonus')
  Future<chopper.Response<BonusSection>> _discoverV2BonusGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param Appie-Current-Order-Id
  ///@param x-application
  Future<chopper.Response<BonusSection>> discoverV1BonusGet({
    String? appieCurrentOrderId,
    String? xApplication,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BonusSection, () => BonusSection.fromJsonFactory);

    return _discoverV1BonusGet(
        appieCurrentOrderId: appieCurrentOrderId,
        xApplication: xApplication,
        cacheControl: cacheControl);
  }

  ///
  ///@param Appie-Current-Order-Id
  ///@param x-application
  @Get(path: '/discover/v1/bonus')
  Future<chopper.Response<BonusSection>> _discoverV1BonusGet({
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Header('x-application') String? xApplication,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class BonusGroup {
  BonusGroup({
    this.id,
    this.offerId,
    this.offerStartDate,
    this.segmentId,
    this.segmentDescription,
    this.bonusStartDate,
    this.bonusEndDate,
    this.bonusType,
    this.promotionType,
    this.segmentType,
    this.subtitle,
    this.discountDescription,
    this.images,
    this.category,
    required this.future,
    this.products,
    this.shopType,
    this.salesUnitSize,
    this.bonusPeriodDescription,
    this.exampleFromPrice,
    this.exampleForPrice,
    this.exampleText,
    this.isStapelBonus,
    this.extraDescriptions,
    this.activationStatus,
  });

  factory BonusGroup.fromJson(Map<String, dynamic> json) =>
      _$BonusGroupFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'offerId', includeIfNull: false)
  final num? offerId;
  @JsonKey(name: 'offerStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? offerStartDate;
  @JsonKey(name: 'segmentId', includeIfNull: false)
  final num? segmentId;
  @JsonKey(name: 'segmentDescription', includeIfNull: false, defaultValue: '')
  final String? segmentDescription;
  @JsonKey(name: 'bonusStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusStartDate;
  @JsonKey(name: 'bonusEndDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusEndDate;
  @JsonKey(name: 'bonusType', includeIfNull: false, defaultValue: '')
  final String? bonusType;
  @JsonKey(name: 'promotionType', includeIfNull: false, defaultValue: '')
  final String? promotionType;
  @JsonKey(name: 'segmentType', includeIfNull: false, defaultValue: '')
  final String? segmentType;
  @JsonKey(name: 'subtitle', includeIfNull: false, defaultValue: '')
  final String? subtitle;
  @JsonKey(name: 'discountDescription', includeIfNull: false, defaultValue: '')
  final String? discountDescription;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image>? images;
  @JsonKey(name: 'category', includeIfNull: false, defaultValue: '')
  final String? category;
  @JsonKey(name: 'future', includeIfNull: false)
  final bool future;
  @JsonKey(
      name: 'products',
      includeIfNull: false,
      defaultValue: <BonusProductCard>[])
  final List<BonusProductCard>? products;
  @JsonKey(name: 'shopType', includeIfNull: false, defaultValue: '')
  final String? shopType;
  @JsonKey(name: 'salesUnitSize', includeIfNull: false, defaultValue: '')
  final String? salesUnitSize;
  @JsonKey(
      name: 'bonusPeriodDescription', includeIfNull: false, defaultValue: '')
  final String? bonusPeriodDescription;
  @JsonKey(name: 'exampleFromPrice', includeIfNull: false)
  final double? exampleFromPrice;
  @JsonKey(name: 'exampleForPrice', includeIfNull: false)
  final double? exampleForPrice;
  @JsonKey(name: 'exampleText', includeIfNull: false, defaultValue: '')
  final String? exampleText;
  @JsonKey(name: 'isStapelBonus', includeIfNull: false)
  final bool? isStapelBonus;
  @JsonKey(
      name: 'extraDescriptions', includeIfNull: false, defaultValue: <String>[])
  final List<String>? extraDescriptions;
  @JsonKey(name: 'activationStatus', includeIfNull: false, defaultValue: '')
  final String? activationStatus;
  static const fromJsonFactory = _$BonusGroupFromJson;
  static const toJsonFactory = _$BonusGroupToJson;
  Map<String, dynamic> toJson() => _$BonusGroupToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BonusGroup &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.offerId, offerId) ||
                const DeepCollectionEquality()
                    .equals(other.offerId, offerId)) &&
            (identical(other.offerStartDate, offerStartDate) ||
                const DeepCollectionEquality()
                    .equals(other.offerStartDate, offerStartDate)) &&
            (identical(other.segmentId, segmentId) ||
                const DeepCollectionEquality()
                    .equals(other.segmentId, segmentId)) &&
            (identical(other.segmentDescription, segmentDescription) ||
                const DeepCollectionEquality()
                    .equals(other.segmentDescription, segmentDescription)) &&
            (identical(other.bonusStartDate, bonusStartDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusStartDate, bonusStartDate)) &&
            (identical(other.bonusEndDate, bonusEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusEndDate, bonusEndDate)) &&
            (identical(other.bonusType, bonusType) ||
                const DeepCollectionEquality()
                    .equals(other.bonusType, bonusType)) &&
            (identical(other.promotionType, promotionType) ||
                const DeepCollectionEquality()
                    .equals(other.promotionType, promotionType)) &&
            (identical(other.segmentType, segmentType) ||
                const DeepCollectionEquality()
                    .equals(other.segmentType, segmentType)) &&
            (identical(other.subtitle, subtitle) ||
                const DeepCollectionEquality()
                    .equals(other.subtitle, subtitle)) &&
            (identical(other.discountDescription, discountDescription) ||
                const DeepCollectionEquality()
                    .equals(other.discountDescription, discountDescription)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.category, category) ||
                const DeepCollectionEquality()
                    .equals(other.category, category)) &&
            (identical(other.future, future) ||
                const DeepCollectionEquality().equals(other.future, future)) &&
            (identical(other.products, products) ||
                const DeepCollectionEquality()
                    .equals(other.products, products)) &&
            (identical(other.shopType, shopType) ||
                const DeepCollectionEquality()
                    .equals(other.shopType, shopType)) &&
            (identical(other.salesUnitSize, salesUnitSize) ||
                const DeepCollectionEquality()
                    .equals(other.salesUnitSize, salesUnitSize)) &&
            (identical(other.bonusPeriodDescription, bonusPeriodDescription) ||
                const DeepCollectionEquality().equals(
                    other.bonusPeriodDescription, bonusPeriodDescription)) &&
            (identical(other.exampleFromPrice, exampleFromPrice) ||
                const DeepCollectionEquality()
                    .equals(other.exampleFromPrice, exampleFromPrice)) &&
            (identical(other.exampleForPrice, exampleForPrice) ||
                const DeepCollectionEquality()
                    .equals(other.exampleForPrice, exampleForPrice)) &&
            (identical(other.exampleText, exampleText) ||
                const DeepCollectionEquality()
                    .equals(other.exampleText, exampleText)) &&
            (identical(other.isStapelBonus, isStapelBonus) ||
                const DeepCollectionEquality()
                    .equals(other.isStapelBonus, isStapelBonus)) &&
            (identical(other.extraDescriptions, extraDescriptions) || const DeepCollectionEquality().equals(other.extraDescriptions, extraDescriptions)) &&
            (identical(other.activationStatus, activationStatus) || const DeepCollectionEquality().equals(other.activationStatus, activationStatus)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(offerId) ^
      const DeepCollectionEquality().hash(offerStartDate) ^
      const DeepCollectionEquality().hash(segmentId) ^
      const DeepCollectionEquality().hash(segmentDescription) ^
      const DeepCollectionEquality().hash(bonusStartDate) ^
      const DeepCollectionEquality().hash(bonusEndDate) ^
      const DeepCollectionEquality().hash(bonusType) ^
      const DeepCollectionEquality().hash(promotionType) ^
      const DeepCollectionEquality().hash(segmentType) ^
      const DeepCollectionEquality().hash(subtitle) ^
      const DeepCollectionEquality().hash(discountDescription) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(category) ^
      const DeepCollectionEquality().hash(future) ^
      const DeepCollectionEquality().hash(products) ^
      const DeepCollectionEquality().hash(shopType) ^
      const DeepCollectionEquality().hash(salesUnitSize) ^
      const DeepCollectionEquality().hash(bonusPeriodDescription) ^
      const DeepCollectionEquality().hash(exampleFromPrice) ^
      const DeepCollectionEquality().hash(exampleForPrice) ^
      const DeepCollectionEquality().hash(exampleText) ^
      const DeepCollectionEquality().hash(isStapelBonus) ^
      const DeepCollectionEquality().hash(extraDescriptions) ^
      const DeepCollectionEquality().hash(activationStatus) ^
      runtimeType.hashCode;
}

extension $BonusGroupExtension on BonusGroup {
  BonusGroup copyWith(
      {String? id,
      num? offerId,
      DateTime? offerStartDate,
      num? segmentId,
      String? segmentDescription,
      DateTime? bonusStartDate,
      DateTime? bonusEndDate,
      String? bonusType,
      String? promotionType,
      String? segmentType,
      String? subtitle,
      String? discountDescription,
      List<Image>? images,
      String? category,
      bool? future,
      List<BonusProductCard>? products,
      String? shopType,
      String? salesUnitSize,
      String? bonusPeriodDescription,
      double? exampleFromPrice,
      double? exampleForPrice,
      String? exampleText,
      bool? isStapelBonus,
      List<String>? extraDescriptions,
      String? activationStatus}) {
    return BonusGroup(
        id: id ?? this.id,
        offerId: offerId ?? this.offerId,
        offerStartDate: offerStartDate ?? this.offerStartDate,
        segmentId: segmentId ?? this.segmentId,
        segmentDescription: segmentDescription ?? this.segmentDescription,
        bonusStartDate: bonusStartDate ?? this.bonusStartDate,
        bonusEndDate: bonusEndDate ?? this.bonusEndDate,
        bonusType: bonusType ?? this.bonusType,
        promotionType: promotionType ?? this.promotionType,
        segmentType: segmentType ?? this.segmentType,
        subtitle: subtitle ?? this.subtitle,
        discountDescription: discountDescription ?? this.discountDescription,
        images: images ?? this.images,
        category: category ?? this.category,
        future: future ?? this.future,
        products: products ?? this.products,
        shopType: shopType ?? this.shopType,
        salesUnitSize: salesUnitSize ?? this.salesUnitSize,
        bonusPeriodDescription:
            bonusPeriodDescription ?? this.bonusPeriodDescription,
        exampleFromPrice: exampleFromPrice ?? this.exampleFromPrice,
        exampleForPrice: exampleForPrice ?? this.exampleForPrice,
        exampleText: exampleText ?? this.exampleText,
        isStapelBonus: isStapelBonus ?? this.isStapelBonus,
        extraDescriptions: extraDescriptions ?? this.extraDescriptions,
        activationStatus: activationStatus ?? this.activationStatus);
  }

  BonusGroup copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<num?>? offerId,
      Wrapped<DateTime?>? offerStartDate,
      Wrapped<num?>? segmentId,
      Wrapped<String?>? segmentDescription,
      Wrapped<DateTime?>? bonusStartDate,
      Wrapped<DateTime?>? bonusEndDate,
      Wrapped<String?>? bonusType,
      Wrapped<String?>? promotionType,
      Wrapped<String?>? segmentType,
      Wrapped<String?>? subtitle,
      Wrapped<String?>? discountDescription,
      Wrapped<List<Image>?>? images,
      Wrapped<String?>? category,
      Wrapped<bool>? future,
      Wrapped<List<BonusProductCard>?>? products,
      Wrapped<String?>? shopType,
      Wrapped<String?>? salesUnitSize,
      Wrapped<String?>? bonusPeriodDescription,
      Wrapped<double?>? exampleFromPrice,
      Wrapped<double?>? exampleForPrice,
      Wrapped<String?>? exampleText,
      Wrapped<bool?>? isStapelBonus,
      Wrapped<List<String>?>? extraDescriptions,
      Wrapped<String?>? activationStatus}) {
    return BonusGroup(
        id: (id != null ? id.value : this.id),
        offerId: (offerId != null ? offerId.value : this.offerId),
        offerStartDate: (offerStartDate != null
            ? offerStartDate.value
            : this.offerStartDate),
        segmentId: (segmentId != null ? segmentId.value : this.segmentId),
        segmentDescription: (segmentDescription != null
            ? segmentDescription.value
            : this.segmentDescription),
        bonusStartDate: (bonusStartDate != null
            ? bonusStartDate.value
            : this.bonusStartDate),
        bonusEndDate:
            (bonusEndDate != null ? bonusEndDate.value : this.bonusEndDate),
        bonusType: (bonusType != null ? bonusType.value : this.bonusType),
        promotionType:
            (promotionType != null ? promotionType.value : this.promotionType),
        segmentType:
            (segmentType != null ? segmentType.value : this.segmentType),
        subtitle: (subtitle != null ? subtitle.value : this.subtitle),
        discountDescription: (discountDescription != null
            ? discountDescription.value
            : this.discountDescription),
        images: (images != null ? images.value : this.images),
        category: (category != null ? category.value : this.category),
        future: (future != null ? future.value : this.future),
        products: (products != null ? products.value : this.products),
        shopType: (shopType != null ? shopType.value : this.shopType),
        salesUnitSize:
            (salesUnitSize != null ? salesUnitSize.value : this.salesUnitSize),
        bonusPeriodDescription: (bonusPeriodDescription != null
            ? bonusPeriodDescription.value
            : this.bonusPeriodDescription),
        exampleFromPrice: (exampleFromPrice != null
            ? exampleFromPrice.value
            : this.exampleFromPrice),
        exampleForPrice: (exampleForPrice != null
            ? exampleForPrice.value
            : this.exampleForPrice),
        exampleText:
            (exampleText != null ? exampleText.value : this.exampleText),
        isStapelBonus:
            (isStapelBonus != null ? isStapelBonus.value : this.isStapelBonus),
        extraDescriptions: (extraDescriptions != null
            ? extraDescriptions.value
            : this.extraDescriptions),
        activationStatus: (activationStatus != null
            ? activationStatus.value
            : this.activationStatus));
  }
}

@JsonSerializable(explicitToJson: true)
class BonusProductCard {
  BonusProductCard({
    required this.webshopId,
    required this.hqId,
    required this.title,
    this.specialDescription,
    this.salesUnitSize,
    required this.images,
    this.bonusStartDate,
    this.bonusEndDate,
    this.discountType,
    this.promotionType,
    this.segmentType,
    this.bonusMechanism,
    this.currentPrice,
    this.priceBeforeBonus,
    this.orderAvailabilityStatus,
    this.orderAvailabilityDescription,
    this.mainCategory,
    this.subCategory,
    this.subCategoryId,
    this.brand,
    this.shopType,
    this.bonusPeriodDescription,
    this.availableOnline,
    this.isPreviouslyBought,
    this.descriptionHighlights,
    required this.propertyIcons,
    this.nix18,
    this.isStapelBonus,
    this.extraDescriptions,
    this.isBonus,
    required this.isInfiniteBonus,
    this.isBonusPrice,
    this.offerId,
    this.offerStartDate,
    this.segmentId,
    this.activationStatus,
    required this.isOrderable,
    this.descriptionFull,
    this.unitPriceDescription,
    this.properties,
    required this.isSample,
    this.bonusSegmentId,
    this.bonusSegmentDescription,
  });

  factory BonusProductCard.fromJson(Map<String, dynamic> json) =>
      _$BonusProductCardFromJson(json);

  @JsonKey(name: 'webshopId', includeIfNull: false)
  final num webshopId;
  @JsonKey(name: 'hqId', includeIfNull: false)
  final num hqId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'specialDescription', includeIfNull: false, defaultValue: '')
  final String? specialDescription;
  @JsonKey(name: 'salesUnitSize', includeIfNull: false, defaultValue: '')
  final String? salesUnitSize;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image> images;
  @JsonKey(name: 'bonusStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusStartDate;
  @JsonKey(name: 'bonusEndDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusEndDate;
  @JsonKey(name: 'discountType', includeIfNull: false, defaultValue: '')
  final String? discountType;
  @JsonKey(name: 'promotionType', includeIfNull: false, defaultValue: '')
  final String? promotionType;
  @JsonKey(name: 'segmentType', includeIfNull: false, defaultValue: '')
  final String? segmentType;
  @JsonKey(name: 'bonusMechanism', includeIfNull: false, defaultValue: '')
  final String? bonusMechanism;
  @JsonKey(name: 'currentPrice', includeIfNull: false)
  final double? currentPrice;
  @JsonKey(name: 'priceBeforeBonus', includeIfNull: false)
  final double? priceBeforeBonus;
  @JsonKey(
      name: 'orderAvailabilityStatus', includeIfNull: false, defaultValue: '')
  final String? orderAvailabilityStatus;
  @JsonKey(
      name: 'orderAvailabilityDescription',
      includeIfNull: false,
      defaultValue: '')
  final String? orderAvailabilityDescription;
  @JsonKey(name: 'mainCategory', includeIfNull: false, defaultValue: '')
  final String? mainCategory;
  @JsonKey(name: 'subCategory', includeIfNull: false, defaultValue: '')
  final String? subCategory;
  @JsonKey(name: 'subCategoryId', includeIfNull: false)
  final num? subCategoryId;
  @JsonKey(name: 'brand', includeIfNull: false, defaultValue: '')
  final String? brand;
  @JsonKey(name: 'shopType', includeIfNull: false, defaultValue: '')
  final String? shopType;
  @JsonKey(
      name: 'bonusPeriodDescription', includeIfNull: false, defaultValue: '')
  final String? bonusPeriodDescription;
  @JsonKey(name: 'availableOnline', includeIfNull: false)
  final bool? availableOnline;
  @JsonKey(name: 'isPreviouslyBought', includeIfNull: false)
  final bool? isPreviouslyBought;
  @JsonKey(
      name: 'descriptionHighlights', includeIfNull: false, defaultValue: '')
  final String? descriptionHighlights;
  @JsonKey(
      name: 'propertyIcons', includeIfNull: false, defaultValue: <String>[])
  final List<String> propertyIcons;
  @JsonKey(name: 'nix18', includeIfNull: false)
  final bool? nix18;
  @JsonKey(name: 'isStapelBonus', includeIfNull: false)
  final bool? isStapelBonus;
  @JsonKey(
      name: 'extraDescriptions', includeIfNull: false, defaultValue: <String>[])
  final List<String>? extraDescriptions;
  @JsonKey(name: 'isBonus', includeIfNull: false)
  final bool? isBonus;
  @JsonKey(name: 'isInfiniteBonus', includeIfNull: false)
  final bool isInfiniteBonus;
  @JsonKey(name: 'isBonusPrice', includeIfNull: false)
  final bool? isBonusPrice;
  @JsonKey(name: 'offerId', includeIfNull: false)
  final num? offerId;
  @JsonKey(name: 'offerStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? offerStartDate;
  @JsonKey(name: 'segmentId', includeIfNull: false, defaultValue: '')
  final String? segmentId;
  @JsonKey(name: 'activationStatus', includeIfNull: false, defaultValue: '')
  final String? activationStatus;
  @JsonKey(name: 'isOrderable', includeIfNull: false)
  final bool isOrderable;
  @JsonKey(name: 'descriptionFull', includeIfNull: false, defaultValue: '')
  final String? descriptionFull;
  @JsonKey(name: 'unitPriceDescription', includeIfNull: false, defaultValue: '')
  final String? unitPriceDescription;
  @JsonKey(name: 'properties', includeIfNull: false)
  final Map<String, dynamic>? properties;
  @JsonKey(name: 'isSample', includeIfNull: false)
  final bool isSample;
  @JsonKey(name: 'bonusSegmentId', includeIfNull: false)
  final num? bonusSegmentId;
  @JsonKey(
      name: 'bonusSegmentDescription', includeIfNull: false, defaultValue: '')
  final String? bonusSegmentDescription;
  static const fromJsonFactory = _$BonusProductCardFromJson;
  static const toJsonFactory = _$BonusProductCardToJson;
  Map<String, dynamic> toJson() => _$BonusProductCardToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BonusProductCard &&
            (identical(other.webshopId, webshopId) ||
                const DeepCollectionEquality()
                    .equals(other.webshopId, webshopId)) &&
            (identical(other.hqId, hqId) ||
                const DeepCollectionEquality().equals(other.hqId, hqId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.specialDescription, specialDescription) ||
                const DeepCollectionEquality()
                    .equals(other.specialDescription, specialDescription)) &&
            (identical(other.salesUnitSize, salesUnitSize) ||
                const DeepCollectionEquality()
                    .equals(other.salesUnitSize, salesUnitSize)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.bonusStartDate, bonusStartDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusStartDate, bonusStartDate)) &&
            (identical(other.bonusEndDate, bonusEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusEndDate, bonusEndDate)) &&
            (identical(other.discountType, discountType) ||
                const DeepCollectionEquality()
                    .equals(other.discountType, discountType)) &&
            (identical(other.promotionType, promotionType) ||
                const DeepCollectionEquality()
                    .equals(other.promotionType, promotionType)) &&
            (identical(other.segmentType, segmentType) ||
                const DeepCollectionEquality()
                    .equals(other.segmentType, segmentType)) &&
            (identical(other.bonusMechanism, bonusMechanism) ||
                const DeepCollectionEquality()
                    .equals(other.bonusMechanism, bonusMechanism)) &&
            (identical(other.currentPrice, currentPrice) ||
                const DeepCollectionEquality()
                    .equals(other.currentPrice, currentPrice)) &&
            (identical(other.priceBeforeBonus, priceBeforeBonus) ||
                const DeepCollectionEquality()
                    .equals(other.priceBeforeBonus, priceBeforeBonus)) &&
            (identical(other.orderAvailabilityStatus, orderAvailabilityStatus) ||
                const DeepCollectionEquality().equals(
                    other.orderAvailabilityStatus, orderAvailabilityStatus)) &&
            (identical(other.orderAvailabilityDescription, orderAvailabilityDescription) ||
                const DeepCollectionEquality().equals(
                    other.orderAvailabilityDescription,
                    orderAvailabilityDescription)) &&
            (identical(other.mainCategory, mainCategory) ||
                const DeepCollectionEquality()
                    .equals(other.mainCategory, mainCategory)) &&
            (identical(other.subCategory, subCategory) ||
                const DeepCollectionEquality()
                    .equals(other.subCategory, subCategory)) &&
            (identical(other.subCategoryId, subCategoryId) ||
                const DeepCollectionEquality()
                    .equals(other.subCategoryId, subCategoryId)) &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)) &&
            (identical(other.shopType, shopType) ||
                const DeepCollectionEquality()
                    .equals(other.shopType, shopType)) &&
            (identical(other.bonusPeriodDescription, bonusPeriodDescription) || const DeepCollectionEquality().equals(other.bonusPeriodDescription, bonusPeriodDescription)) &&
            (identical(other.availableOnline, availableOnline) || const DeepCollectionEquality().equals(other.availableOnline, availableOnline)) &&
            (identical(other.isPreviouslyBought, isPreviouslyBought) || const DeepCollectionEquality().equals(other.isPreviouslyBought, isPreviouslyBought)) &&
            (identical(other.descriptionHighlights, descriptionHighlights) || const DeepCollectionEquality().equals(other.descriptionHighlights, descriptionHighlights)) &&
            (identical(other.propertyIcons, propertyIcons) || const DeepCollectionEquality().equals(other.propertyIcons, propertyIcons)) &&
            (identical(other.nix18, nix18) || const DeepCollectionEquality().equals(other.nix18, nix18)) &&
            (identical(other.isStapelBonus, isStapelBonus) || const DeepCollectionEquality().equals(other.isStapelBonus, isStapelBonus)) &&
            (identical(other.extraDescriptions, extraDescriptions) || const DeepCollectionEquality().equals(other.extraDescriptions, extraDescriptions)) &&
            (identical(other.isBonus, isBonus) || const DeepCollectionEquality().equals(other.isBonus, isBonus)) &&
            (identical(other.isInfiniteBonus, isInfiniteBonus) || const DeepCollectionEquality().equals(other.isInfiniteBonus, isInfiniteBonus)) &&
            (identical(other.isBonusPrice, isBonusPrice) || const DeepCollectionEquality().equals(other.isBonusPrice, isBonusPrice)) &&
            (identical(other.offerId, offerId) || const DeepCollectionEquality().equals(other.offerId, offerId)) &&
            (identical(other.offerStartDate, offerStartDate) || const DeepCollectionEquality().equals(other.offerStartDate, offerStartDate)) &&
            (identical(other.segmentId, segmentId) || const DeepCollectionEquality().equals(other.segmentId, segmentId)) &&
            (identical(other.activationStatus, activationStatus) || const DeepCollectionEquality().equals(other.activationStatus, activationStatus)) &&
            (identical(other.isOrderable, isOrderable) || const DeepCollectionEquality().equals(other.isOrderable, isOrderable)) &&
            (identical(other.descriptionFull, descriptionFull) || const DeepCollectionEquality().equals(other.descriptionFull, descriptionFull)) &&
            (identical(other.unitPriceDescription, unitPriceDescription) || const DeepCollectionEquality().equals(other.unitPriceDescription, unitPriceDescription)) &&
            (identical(other.properties, properties) || const DeepCollectionEquality().equals(other.properties, properties)) &&
            (identical(other.isSample, isSample) || const DeepCollectionEquality().equals(other.isSample, isSample)) &&
            (identical(other.bonusSegmentId, bonusSegmentId) || const DeepCollectionEquality().equals(other.bonusSegmentId, bonusSegmentId)) &&
            (identical(other.bonusSegmentDescription, bonusSegmentDescription) || const DeepCollectionEquality().equals(other.bonusSegmentDescription, bonusSegmentDescription)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(webshopId) ^
      const DeepCollectionEquality().hash(hqId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(specialDescription) ^
      const DeepCollectionEquality().hash(salesUnitSize) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(bonusStartDate) ^
      const DeepCollectionEquality().hash(bonusEndDate) ^
      const DeepCollectionEquality().hash(discountType) ^
      const DeepCollectionEquality().hash(promotionType) ^
      const DeepCollectionEquality().hash(segmentType) ^
      const DeepCollectionEquality().hash(bonusMechanism) ^
      const DeepCollectionEquality().hash(currentPrice) ^
      const DeepCollectionEquality().hash(priceBeforeBonus) ^
      const DeepCollectionEquality().hash(orderAvailabilityStatus) ^
      const DeepCollectionEquality().hash(orderAvailabilityDescription) ^
      const DeepCollectionEquality().hash(mainCategory) ^
      const DeepCollectionEquality().hash(subCategory) ^
      const DeepCollectionEquality().hash(subCategoryId) ^
      const DeepCollectionEquality().hash(brand) ^
      const DeepCollectionEquality().hash(shopType) ^
      const DeepCollectionEquality().hash(bonusPeriodDescription) ^
      const DeepCollectionEquality().hash(availableOnline) ^
      const DeepCollectionEquality().hash(isPreviouslyBought) ^
      const DeepCollectionEquality().hash(descriptionHighlights) ^
      const DeepCollectionEquality().hash(propertyIcons) ^
      const DeepCollectionEquality().hash(nix18) ^
      const DeepCollectionEquality().hash(isStapelBonus) ^
      const DeepCollectionEquality().hash(extraDescriptions) ^
      const DeepCollectionEquality().hash(isBonus) ^
      const DeepCollectionEquality().hash(isInfiniteBonus) ^
      const DeepCollectionEquality().hash(isBonusPrice) ^
      const DeepCollectionEquality().hash(offerId) ^
      const DeepCollectionEquality().hash(offerStartDate) ^
      const DeepCollectionEquality().hash(segmentId) ^
      const DeepCollectionEquality().hash(activationStatus) ^
      const DeepCollectionEquality().hash(isOrderable) ^
      const DeepCollectionEquality().hash(descriptionFull) ^
      const DeepCollectionEquality().hash(unitPriceDescription) ^
      const DeepCollectionEquality().hash(properties) ^
      const DeepCollectionEquality().hash(isSample) ^
      const DeepCollectionEquality().hash(bonusSegmentId) ^
      const DeepCollectionEquality().hash(bonusSegmentDescription) ^
      runtimeType.hashCode;
}

extension $BonusProductCardExtension on BonusProductCard {
  BonusProductCard copyWith(
      {num? webshopId,
      num? hqId,
      String? title,
      String? specialDescription,
      String? salesUnitSize,
      List<Image>? images,
      DateTime? bonusStartDate,
      DateTime? bonusEndDate,
      String? discountType,
      String? promotionType,
      String? segmentType,
      String? bonusMechanism,
      double? currentPrice,
      double? priceBeforeBonus,
      String? orderAvailabilityStatus,
      String? orderAvailabilityDescription,
      String? mainCategory,
      String? subCategory,
      num? subCategoryId,
      String? brand,
      String? shopType,
      String? bonusPeriodDescription,
      bool? availableOnline,
      bool? isPreviouslyBought,
      String? descriptionHighlights,
      List<String>? propertyIcons,
      bool? nix18,
      bool? isStapelBonus,
      List<String>? extraDescriptions,
      bool? isBonus,
      bool? isInfiniteBonus,
      bool? isBonusPrice,
      num? offerId,
      DateTime? offerStartDate,
      String? segmentId,
      String? activationStatus,
      bool? isOrderable,
      String? descriptionFull,
      String? unitPriceDescription,
      Map<String, dynamic>? properties,
      bool? isSample,
      num? bonusSegmentId,
      String? bonusSegmentDescription}) {
    return BonusProductCard(
        webshopId: webshopId ?? this.webshopId,
        hqId: hqId ?? this.hqId,
        title: title ?? this.title,
        specialDescription: specialDescription ?? this.specialDescription,
        salesUnitSize: salesUnitSize ?? this.salesUnitSize,
        images: images ?? this.images,
        bonusStartDate: bonusStartDate ?? this.bonusStartDate,
        bonusEndDate: bonusEndDate ?? this.bonusEndDate,
        discountType: discountType ?? this.discountType,
        promotionType: promotionType ?? this.promotionType,
        segmentType: segmentType ?? this.segmentType,
        bonusMechanism: bonusMechanism ?? this.bonusMechanism,
        currentPrice: currentPrice ?? this.currentPrice,
        priceBeforeBonus: priceBeforeBonus ?? this.priceBeforeBonus,
        orderAvailabilityStatus:
            orderAvailabilityStatus ?? this.orderAvailabilityStatus,
        orderAvailabilityDescription:
            orderAvailabilityDescription ?? this.orderAvailabilityDescription,
        mainCategory: mainCategory ?? this.mainCategory,
        subCategory: subCategory ?? this.subCategory,
        subCategoryId: subCategoryId ?? this.subCategoryId,
        brand: brand ?? this.brand,
        shopType: shopType ?? this.shopType,
        bonusPeriodDescription:
            bonusPeriodDescription ?? this.bonusPeriodDescription,
        availableOnline: availableOnline ?? this.availableOnline,
        isPreviouslyBought: isPreviouslyBought ?? this.isPreviouslyBought,
        descriptionHighlights:
            descriptionHighlights ?? this.descriptionHighlights,
        propertyIcons: propertyIcons ?? this.propertyIcons,
        nix18: nix18 ?? this.nix18,
        isStapelBonus: isStapelBonus ?? this.isStapelBonus,
        extraDescriptions: extraDescriptions ?? this.extraDescriptions,
        isBonus: isBonus ?? this.isBonus,
        isInfiniteBonus: isInfiniteBonus ?? this.isInfiniteBonus,
        isBonusPrice: isBonusPrice ?? this.isBonusPrice,
        offerId: offerId ?? this.offerId,
        offerStartDate: offerStartDate ?? this.offerStartDate,
        segmentId: segmentId ?? this.segmentId,
        activationStatus: activationStatus ?? this.activationStatus,
        isOrderable: isOrderable ?? this.isOrderable,
        descriptionFull: descriptionFull ?? this.descriptionFull,
        unitPriceDescription: unitPriceDescription ?? this.unitPriceDescription,
        properties: properties ?? this.properties,
        isSample: isSample ?? this.isSample,
        bonusSegmentId: bonusSegmentId ?? this.bonusSegmentId,
        bonusSegmentDescription:
            bonusSegmentDescription ?? this.bonusSegmentDescription);
  }

  BonusProductCard copyWithWrapped(
      {Wrapped<num>? webshopId,
      Wrapped<num>? hqId,
      Wrapped<String>? title,
      Wrapped<String?>? specialDescription,
      Wrapped<String?>? salesUnitSize,
      Wrapped<List<Image>>? images,
      Wrapped<DateTime?>? bonusStartDate,
      Wrapped<DateTime?>? bonusEndDate,
      Wrapped<String?>? discountType,
      Wrapped<String?>? promotionType,
      Wrapped<String?>? segmentType,
      Wrapped<String?>? bonusMechanism,
      Wrapped<double?>? currentPrice,
      Wrapped<double?>? priceBeforeBonus,
      Wrapped<String?>? orderAvailabilityStatus,
      Wrapped<String?>? orderAvailabilityDescription,
      Wrapped<String?>? mainCategory,
      Wrapped<String?>? subCategory,
      Wrapped<num?>? subCategoryId,
      Wrapped<String?>? brand,
      Wrapped<String?>? shopType,
      Wrapped<String?>? bonusPeriodDescription,
      Wrapped<bool?>? availableOnline,
      Wrapped<bool?>? isPreviouslyBought,
      Wrapped<String?>? descriptionHighlights,
      Wrapped<List<String>>? propertyIcons,
      Wrapped<bool?>? nix18,
      Wrapped<bool?>? isStapelBonus,
      Wrapped<List<String>?>? extraDescriptions,
      Wrapped<bool?>? isBonus,
      Wrapped<bool>? isInfiniteBonus,
      Wrapped<bool?>? isBonusPrice,
      Wrapped<num?>? offerId,
      Wrapped<DateTime?>? offerStartDate,
      Wrapped<String?>? segmentId,
      Wrapped<String?>? activationStatus,
      Wrapped<bool>? isOrderable,
      Wrapped<String?>? descriptionFull,
      Wrapped<String?>? unitPriceDescription,
      Wrapped<Map<String, dynamic>?>? properties,
      Wrapped<bool>? isSample,
      Wrapped<num?>? bonusSegmentId,
      Wrapped<String?>? bonusSegmentDescription}) {
    return BonusProductCard(
        webshopId: (webshopId != null ? webshopId.value : this.webshopId),
        hqId: (hqId != null ? hqId.value : this.hqId),
        title: (title != null ? title.value : this.title),
        specialDescription: (specialDescription != null
            ? specialDescription.value
            : this.specialDescription),
        salesUnitSize:
            (salesUnitSize != null ? salesUnitSize.value : this.salesUnitSize),
        images: (images != null ? images.value : this.images),
        bonusStartDate: (bonusStartDate != null
            ? bonusStartDate.value
            : this.bonusStartDate),
        bonusEndDate:
            (bonusEndDate != null ? bonusEndDate.value : this.bonusEndDate),
        discountType:
            (discountType != null ? discountType.value : this.discountType),
        promotionType:
            (promotionType != null ? promotionType.value : this.promotionType),
        segmentType:
            (segmentType != null ? segmentType.value : this.segmentType),
        bonusMechanism: (bonusMechanism != null
            ? bonusMechanism.value
            : this.bonusMechanism),
        currentPrice:
            (currentPrice != null ? currentPrice.value : this.currentPrice),
        priceBeforeBonus: (priceBeforeBonus != null
            ? priceBeforeBonus.value
            : this.priceBeforeBonus),
        orderAvailabilityStatus: (orderAvailabilityStatus != null
            ? orderAvailabilityStatus.value
            : this.orderAvailabilityStatus),
        orderAvailabilityDescription: (orderAvailabilityDescription != null
            ? orderAvailabilityDescription.value
            : this.orderAvailabilityDescription),
        mainCategory:
            (mainCategory != null ? mainCategory.value : this.mainCategory),
        subCategory:
            (subCategory != null ? subCategory.value : this.subCategory),
        subCategoryId:
            (subCategoryId != null ? subCategoryId.value : this.subCategoryId),
        brand: (brand != null ? brand.value : this.brand),
        shopType: (shopType != null ? shopType.value : this.shopType),
        bonusPeriodDescription: (bonusPeriodDescription != null
            ? bonusPeriodDescription.value
            : this.bonusPeriodDescription),
        availableOnline: (availableOnline != null
            ? availableOnline.value
            : this.availableOnline),
        isPreviouslyBought: (isPreviouslyBought != null
            ? isPreviouslyBought.value
            : this.isPreviouslyBought),
        descriptionHighlights: (descriptionHighlights != null
            ? descriptionHighlights.value
            : this.descriptionHighlights),
        propertyIcons:
            (propertyIcons != null ? propertyIcons.value : this.propertyIcons),
        nix18: (nix18 != null ? nix18.value : this.nix18),
        isStapelBonus:
            (isStapelBonus != null ? isStapelBonus.value : this.isStapelBonus),
        extraDescriptions: (extraDescriptions != null
            ? extraDescriptions.value
            : this.extraDescriptions),
        isBonus: (isBonus != null ? isBonus.value : this.isBonus),
        isInfiniteBonus: (isInfiniteBonus != null
            ? isInfiniteBonus.value
            : this.isInfiniteBonus),
        isBonusPrice:
            (isBonusPrice != null ? isBonusPrice.value : this.isBonusPrice),
        offerId: (offerId != null ? offerId.value : this.offerId),
        offerStartDate: (offerStartDate != null
            ? offerStartDate.value
            : this.offerStartDate),
        segmentId: (segmentId != null ? segmentId.value : this.segmentId),
        activationStatus: (activationStatus != null
            ? activationStatus.value
            : this.activationStatus),
        isOrderable:
            (isOrderable != null ? isOrderable.value : this.isOrderable),
        descriptionFull: (descriptionFull != null
            ? descriptionFull.value
            : this.descriptionFull),
        unitPriceDescription: (unitPriceDescription != null
            ? unitPriceDescription.value
            : this.unitPriceDescription),
        properties: (properties != null ? properties.value : this.properties),
        isSample: (isSample != null ? isSample.value : this.isSample),
        bonusSegmentId: (bonusSegmentId != null
            ? bonusSegmentId.value
            : this.bonusSegmentId),
        bonusSegmentDescription: (bonusSegmentDescription != null
            ? bonusSegmentDescription.value
            : this.bonusSegmentDescription));
  }
}

@JsonSerializable(explicitToJson: true)
class BonusSection {
  BonusSection({
    required this.sectionType,
    required this.sectionDescription,
    required this.bonusGroupOrProducts,
    this.bonusGroupOrProduct,
    this.sectionImage,
  });

  factory BonusSection.fromJson(Map<String, dynamic> json) =>
      _$BonusSectionFromJson(json);

  @JsonKey(name: 'sectionType', includeIfNull: false, defaultValue: '')
  final String sectionType;
  @JsonKey(name: 'sectionDescription', includeIfNull: false, defaultValue: '')
  final String sectionDescription;
  @JsonKey(
      name: 'bonusGroupOrProducts',
      includeIfNull: false,
      defaultValue: <ProductOrBonusGroup>[])
  final List<ProductOrBonusGroup> bonusGroupOrProducts;
  @JsonKey(
      name: 'bonusGroupOrProduct',
      includeIfNull: false,
      defaultValue: <ProductOrBonusGroup>[])
  final List<ProductOrBonusGroup>? bonusGroupOrProduct;
  @JsonKey(name: 'sectionImage', includeIfNull: false, defaultValue: <Image>[])
  final List<Image>? sectionImage;
  static const fromJsonFactory = _$BonusSectionFromJson;
  static const toJsonFactory = _$BonusSectionToJson;
  Map<String, dynamic> toJson() => _$BonusSectionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BonusSection &&
            (identical(other.sectionType, sectionType) ||
                const DeepCollectionEquality()
                    .equals(other.sectionType, sectionType)) &&
            (identical(other.sectionDescription, sectionDescription) ||
                const DeepCollectionEquality()
                    .equals(other.sectionDescription, sectionDescription)) &&
            (identical(other.bonusGroupOrProducts, bonusGroupOrProducts) ||
                const DeepCollectionEquality().equals(
                    other.bonusGroupOrProducts, bonusGroupOrProducts)) &&
            (identical(other.bonusGroupOrProduct, bonusGroupOrProduct) ||
                const DeepCollectionEquality()
                    .equals(other.bonusGroupOrProduct, bonusGroupOrProduct)) &&
            (identical(other.sectionImage, sectionImage) ||
                const DeepCollectionEquality()
                    .equals(other.sectionImage, sectionImage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sectionType) ^
      const DeepCollectionEquality().hash(sectionDescription) ^
      const DeepCollectionEquality().hash(bonusGroupOrProducts) ^
      const DeepCollectionEquality().hash(bonusGroupOrProduct) ^
      const DeepCollectionEquality().hash(sectionImage) ^
      runtimeType.hashCode;
}

extension $BonusSectionExtension on BonusSection {
  BonusSection copyWith(
      {String? sectionType,
      String? sectionDescription,
      List<ProductOrBonusGroup>? bonusGroupOrProducts,
      List<ProductOrBonusGroup>? bonusGroupOrProduct,
      List<Image>? sectionImage}) {
    return BonusSection(
        sectionType: sectionType ?? this.sectionType,
        sectionDescription: sectionDescription ?? this.sectionDescription,
        bonusGroupOrProducts: bonusGroupOrProducts ?? this.bonusGroupOrProducts,
        bonusGroupOrProduct: bonusGroupOrProduct ?? this.bonusGroupOrProduct,
        sectionImage: sectionImage ?? this.sectionImage);
  }

  BonusSection copyWithWrapped(
      {Wrapped<String>? sectionType,
      Wrapped<String>? sectionDescription,
      Wrapped<List<ProductOrBonusGroup>>? bonusGroupOrProducts,
      Wrapped<List<ProductOrBonusGroup>?>? bonusGroupOrProduct,
      Wrapped<List<Image>?>? sectionImage}) {
    return BonusSection(
        sectionType:
            (sectionType != null ? sectionType.value : this.sectionType),
        sectionDescription: (sectionDescription != null
            ? sectionDescription.value
            : this.sectionDescription),
        bonusGroupOrProducts: (bonusGroupOrProducts != null
            ? bonusGroupOrProducts.value
            : this.bonusGroupOrProducts),
        bonusGroupOrProduct: (bonusGroupOrProduct != null
            ? bonusGroupOrProduct.value
            : this.bonusGroupOrProduct),
        sectionImage:
            (sectionImage != null ? sectionImage.value : this.sectionImage));
  }
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    required this.width,
    required this.height,
    required this.url,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  @JsonKey(name: 'width', includeIfNull: false)
  final int width;
  @JsonKey(name: 'height', includeIfNull: false)
  final int height;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$ImageFromJson;
  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.width, width) ||
                const DeepCollectionEquality().equals(other.width, width)) &&
            (identical(other.height, height) ||
                const DeepCollectionEquality().equals(other.height, height)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(width) ^
      const DeepCollectionEquality().hash(height) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({int? width, int? height, String? url}) {
    return Image(
        width: width ?? this.width,
        height: height ?? this.height,
        url: url ?? this.url);
  }

  Image copyWithWrapped(
      {Wrapped<int>? width, Wrapped<int>? height, Wrapped<String>? url}) {
    return Image(
        width: (width != null ? width.value : this.width),
        height: (height != null ? height.value : this.height),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class ProductOrBonusGroup {
  ProductOrBonusGroup({
    this.bonusGroup,
    this.product,
  });

  factory ProductOrBonusGroup.fromJson(Map<String, dynamic> json) =>
      _$ProductOrBonusGroupFromJson(json);

  @JsonKey(name: 'bonusGroup', includeIfNull: false)
  final BonusGroup? bonusGroup;
  @JsonKey(name: 'product', includeIfNull: false)
  final BonusProductCard? product;
  static const fromJsonFactory = _$ProductOrBonusGroupFromJson;
  static const toJsonFactory = _$ProductOrBonusGroupToJson;
  Map<String, dynamic> toJson() => _$ProductOrBonusGroupToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductOrBonusGroup &&
            (identical(other.bonusGroup, bonusGroup) ||
                const DeepCollectionEquality()
                    .equals(other.bonusGroup, bonusGroup)) &&
            (identical(other.product, product) ||
                const DeepCollectionEquality().equals(other.product, product)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(bonusGroup) ^
      const DeepCollectionEquality().hash(product) ^
      runtimeType.hashCode;
}

extension $ProductOrBonusGroupExtension on ProductOrBonusGroup {
  ProductOrBonusGroup copyWith(
      {BonusGroup? bonusGroup, BonusProductCard? product}) {
    return ProductOrBonusGroup(
        bonusGroup: bonusGroup ?? this.bonusGroup,
        product: product ?? this.product);
  }

  ProductOrBonusGroup copyWithWrapped(
      {Wrapped<BonusGroup?>? bonusGroup, Wrapped<BonusProductCard?>? product}) {
    return ProductOrBonusGroup(
        bonusGroup: (bonusGroup != null ? bonusGroup.value : this.bonusGroup),
        product: (product != null ? product.value : this.product));
  }
}

@JsonSerializable(explicitToJson: true)
class BonusMetadata {
  BonusMetadata({
    required this.periods,
  });

  factory BonusMetadata.fromJson(Map<String, dynamic> json) =>
      _$BonusMetadataFromJson(json);

  @JsonKey(
      name: 'periods',
      includeIfNull: false,
      defaultValue: <BonusPeriodMetadata>[])
  final List<BonusPeriodMetadata> periods;
  static const fromJsonFactory = _$BonusMetadataFromJson;
  static const toJsonFactory = _$BonusMetadataToJson;
  Map<String, dynamic> toJson() => _$BonusMetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BonusMetadata &&
            (identical(other.periods, periods) ||
                const DeepCollectionEquality().equals(other.periods, periods)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(periods) ^ runtimeType.hashCode;
}

extension $BonusMetadataExtension on BonusMetadata {
  BonusMetadata copyWith({List<BonusPeriodMetadata>? periods}) {
    return BonusMetadata(periods: periods ?? this.periods);
  }

  BonusMetadata copyWithWrapped({Wrapped<List<BonusPeriodMetadata>>? periods}) {
    return BonusMetadata(
        periods: (periods != null ? periods.value : this.periods));
  }
}

@JsonSerializable(explicitToJson: true)
class BonusPeriodMetadata {
  BonusPeriodMetadata({
    required this.bonusStartDate,
    required this.bonusEndDate,
    this.bonusFolderUrl,
    required this.urlMetadataList,
    this.mmiBannerUrl,
  });

  factory BonusPeriodMetadata.fromJson(Map<String, dynamic> json) =>
      _$BonusPeriodMetadataFromJson(json);

  @JsonKey(name: 'bonusStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime bonusStartDate;
  @JsonKey(name: 'bonusEndDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime bonusEndDate;
  @JsonKey(name: 'bonusFolderUrl', includeIfNull: false, defaultValue: '')
  final String? bonusFolderUrl;
  @JsonKey(
      name: 'urlMetadataList',
      includeIfNull: false,
      defaultValue: <UrlMetadata>[])
  final List<UrlMetadata> urlMetadataList;
  @JsonKey(name: 'mmiBannerUrl', includeIfNull: false, defaultValue: '')
  final String? mmiBannerUrl;
  static const fromJsonFactory = _$BonusPeriodMetadataFromJson;
  static const toJsonFactory = _$BonusPeriodMetadataToJson;
  Map<String, dynamic> toJson() => _$BonusPeriodMetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BonusPeriodMetadata &&
            (identical(other.bonusStartDate, bonusStartDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusStartDate, bonusStartDate)) &&
            (identical(other.bonusEndDate, bonusEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusEndDate, bonusEndDate)) &&
            (identical(other.bonusFolderUrl, bonusFolderUrl) ||
                const DeepCollectionEquality()
                    .equals(other.bonusFolderUrl, bonusFolderUrl)) &&
            (identical(other.urlMetadataList, urlMetadataList) ||
                const DeepCollectionEquality()
                    .equals(other.urlMetadataList, urlMetadataList)) &&
            (identical(other.mmiBannerUrl, mmiBannerUrl) ||
                const DeepCollectionEquality()
                    .equals(other.mmiBannerUrl, mmiBannerUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(bonusStartDate) ^
      const DeepCollectionEquality().hash(bonusEndDate) ^
      const DeepCollectionEquality().hash(bonusFolderUrl) ^
      const DeepCollectionEquality().hash(urlMetadataList) ^
      const DeepCollectionEquality().hash(mmiBannerUrl) ^
      runtimeType.hashCode;
}

extension $BonusPeriodMetadataExtension on BonusPeriodMetadata {
  BonusPeriodMetadata copyWith(
      {DateTime? bonusStartDate,
      DateTime? bonusEndDate,
      String? bonusFolderUrl,
      List<UrlMetadata>? urlMetadataList,
      String? mmiBannerUrl}) {
    return BonusPeriodMetadata(
        bonusStartDate: bonusStartDate ?? this.bonusStartDate,
        bonusEndDate: bonusEndDate ?? this.bonusEndDate,
        bonusFolderUrl: bonusFolderUrl ?? this.bonusFolderUrl,
        urlMetadataList: urlMetadataList ?? this.urlMetadataList,
        mmiBannerUrl: mmiBannerUrl ?? this.mmiBannerUrl);
  }

  BonusPeriodMetadata copyWithWrapped(
      {Wrapped<DateTime>? bonusStartDate,
      Wrapped<DateTime>? bonusEndDate,
      Wrapped<String?>? bonusFolderUrl,
      Wrapped<List<UrlMetadata>>? urlMetadataList,
      Wrapped<String?>? mmiBannerUrl}) {
    return BonusPeriodMetadata(
        bonusStartDate: (bonusStartDate != null
            ? bonusStartDate.value
            : this.bonusStartDate),
        bonusEndDate:
            (bonusEndDate != null ? bonusEndDate.value : this.bonusEndDate),
        bonusFolderUrl: (bonusFolderUrl != null
            ? bonusFolderUrl.value
            : this.bonusFolderUrl),
        urlMetadataList: (urlMetadataList != null
            ? urlMetadataList.value
            : this.urlMetadataList),
        mmiBannerUrl:
            (mmiBannerUrl != null ? mmiBannerUrl.value : this.mmiBannerUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class UrlMetadata {
  UrlMetadata({
    required this.url,
    required this.count,
    required this.images,
    this.bonusType,
    required this.description,
  });

  factory UrlMetadata.fromJson(Map<String, dynamic> json) =>
      _$UrlMetadataFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'count', includeIfNull: false)
  final int count;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image> images;
  @JsonKey(name: 'bonusType', includeIfNull: false, defaultValue: '')
  final String? bonusType;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  static const fromJsonFactory = _$UrlMetadataFromJson;
  static const toJsonFactory = _$UrlMetadataToJson;
  Map<String, dynamic> toJson() => _$UrlMetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UrlMetadata &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.count, count) ||
                const DeepCollectionEquality().equals(other.count, count)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.bonusType, bonusType) ||
                const DeepCollectionEquality()
                    .equals(other.bonusType, bonusType)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(count) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(bonusType) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $UrlMetadataExtension on UrlMetadata {
  UrlMetadata copyWith(
      {String? url,
      int? count,
      List<Image>? images,
      String? bonusType,
      String? description}) {
    return UrlMetadata(
        url: url ?? this.url,
        count: count ?? this.count,
        images: images ?? this.images,
        bonusType: bonusType ?? this.bonusType,
        description: description ?? this.description);
  }

  UrlMetadata copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<int>? count,
      Wrapped<List<Image>>? images,
      Wrapped<String?>? bonusType,
      Wrapped<String>? description}) {
    return UrlMetadata(
        url: (url != null ? url.value : this.url),
        count: (count != null ? count.value : this.count),
        images: (images != null ? images.value : this.images),
        bonusType: (bonusType != null ? bonusType.value : this.bonusType),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class BonusFolderLink {
  BonusFolderLink({
    this.bonusStartDate,
    this.bonusEndDate,
    required this.folderUrl,
  });

  factory BonusFolderLink.fromJson(Map<String, dynamic> json) =>
      _$BonusFolderLinkFromJson(json);

  @JsonKey(name: 'bonusStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusStartDate;
  @JsonKey(name: 'bonusEndDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusEndDate;
  @JsonKey(name: 'folderUrl', includeIfNull: false, defaultValue: '')
  final String folderUrl;
  static const fromJsonFactory = _$BonusFolderLinkFromJson;
  static const toJsonFactory = _$BonusFolderLinkToJson;
  Map<String, dynamic> toJson() => _$BonusFolderLinkToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BonusFolderLink &&
            (identical(other.bonusStartDate, bonusStartDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusStartDate, bonusStartDate)) &&
            (identical(other.bonusEndDate, bonusEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusEndDate, bonusEndDate)) &&
            (identical(other.folderUrl, folderUrl) ||
                const DeepCollectionEquality()
                    .equals(other.folderUrl, folderUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(bonusStartDate) ^
      const DeepCollectionEquality().hash(bonusEndDate) ^
      const DeepCollectionEquality().hash(folderUrl) ^
      runtimeType.hashCode;
}

extension $BonusFolderLinkExtension on BonusFolderLink {
  BonusFolderLink copyWith(
      {DateTime? bonusStartDate, DateTime? bonusEndDate, String? folderUrl}) {
    return BonusFolderLink(
        bonusStartDate: bonusStartDate ?? this.bonusStartDate,
        bonusEndDate: bonusEndDate ?? this.bonusEndDate,
        folderUrl: folderUrl ?? this.folderUrl);
  }

  BonusFolderLink copyWithWrapped(
      {Wrapped<DateTime?>? bonusStartDate,
      Wrapped<DateTime?>? bonusEndDate,
      Wrapped<String>? folderUrl}) {
    return BonusFolderLink(
        bonusStartDate: (bonusStartDate != null
            ? bonusStartDate.value
            : this.bonusStartDate),
        bonusEndDate:
            (bonusEndDate != null ? bonusEndDate.value : this.bonusEndDate),
        folderUrl: (folderUrl != null ? folderUrl.value : this.folderUrl));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
