import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'cms_document_remote_data_source.swagger.chopper.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class CmsDocumentRemoteDataSource extends ChopperService {
  static CmsDocumentRemoteDataSource create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$CmsDocumentRemoteDataSource(client);
    }

    final newClient = ChopperClient(
        services: [_$CmsDocumentRemoteDataSource()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$CmsDocumentRemoteDataSource(newClient);
  }

  ///Get document from cms
  ///@param X-Application
  ///@param documentPath
  Future<chopper.Response<String>> cmsV2DocumentGet({
    String? xApplication,
    required String? documentPath,
    String? cacheControl,
  }) {
    return _cmsV2DocumentGet(
        xApplication: xApplication,
        documentPath: documentPath,
        cacheControl: cacheControl);
  }

  ///Get document from cms
  ///@param X-Application
  ///@param documentPath
  @Get(path: '/cms/v2/document')
  Future<chopper.Response<String>> _cmsV2DocumentGet({
    @Header('X-Application') String? xApplication,
    @Query('documentPath') required String? documentPath,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get document from cms
  ///@param X-Application
  ///@param sitetarget
  Future<chopper.Response<String>> cmsV1DocumentGet({
    String? xApplication,
    required String? sitetarget,
    String? cacheControl,
  }) {
    return _cmsV1DocumentGet(
        xApplication: xApplication,
        sitetarget: sitetarget,
        cacheControl: cacheControl);
  }

  ///Get document from cms
  ///@param X-Application
  ///@param sitetarget
  @Get(path: '/cms/v1/document')
  Future<chopper.Response<String>> _cmsV1DocumentGet({
    @Header('X-Application') String? xApplication,
    @Query('sitetarget') required String? sitetarget,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get document from Hippo CMS by documentName and catalogName(optional)
  ///@param x-application
  ///@param documentName
  ///@param X-Locale
  ///@param folder
  Future<chopper.Response<String>> cmsV3DocumentGet({
    String? xApplication,
    required String? documentName,
    String? xLocale,
    String? folder,
    String? cacheControl,
  }) {
    return _cmsV3DocumentGet(
        xApplication: xApplication,
        documentName: documentName,
        xLocale: xLocale,
        folder: folder,
        cacheControl: cacheControl);
  }

  ///Get document from Hippo CMS by documentName and catalogName(optional)
  ///@param x-application
  ///@param documentName
  ///@param X-Locale
  ///@param folder
  @Get(path: '/cms/v3/document')
  Future<chopper.Response<String>> _cmsV3DocumentGet({
    @Header('x-application') String? xApplication,
    @Query('documentName') required String? documentName,
    @Header('X-Locale') String? xLocale,
    @Query('folder') String? folder,
    @Header('Cache-Control') String? cacheControl,
  });
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
