// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'customer_service_remote_data_source.enums.swagger.dart' as enums;
export 'customer_service_remote_data_source.enums.swagger.dart';

part 'customer_service_remote_data_source.swagger.chopper.dart';
part 'customer_service_remote_data_source.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class CustomerServiceRemoteDataSource extends ChopperService {
  static CustomerServiceRemoteDataSource create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$CustomerServiceRemoteDataSource(client);
    }

    final newClient = ChopperClient(
        services: [_$CustomerServiceRemoteDataSource()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$CustomerServiceRemoteDataSource(newClient);
  }

  ///
  ///@param X-Application
  Future<chopper.Response<List<Section>>> v1CustomerCareSectionsGet({
    String? xApplication,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Section, () => Section.fromJsonFactory);

    return _v1CustomerCareSectionsGet(
        xApplication: xApplication, cacheControl: cacheControl);
  }

  ///
  ///@param X-Application
  @Get(path: '/v1/customer-care/sections')
  Future<chopper.Response<List<Section>>> _v1CustomerCareSectionsGet({
    @Header('X-Application') String? xApplication,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param X-Application
  Future<chopper.Response> v1CustomerCareChannelsGet({
    String? xApplication,
    String? cacheControl,
  }) {
    return _v1CustomerCareChannelsGet(
        xApplication: xApplication, cacheControl: cacheControl);
  }

  ///
  ///@param X-Application
  @Get(path: '/v1/customer-care/channels')
  Future<chopper.Response> _v1CustomerCareChannelsGet({
    @Header('X-Application') String? xApplication,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Section {
  Section({
    required this.title,
    required this.href,
    required this.type,
  });

  factory Section.fromJson(Map<String, dynamic> json) =>
      _$SectionFromJson(json);

  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'href', includeIfNull: false, defaultValue: '')
  final String href;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: sectionTypeToJson,
    fromJson: sectionTypeFromJson,
  )
  final enums.SectionType type;
  static const fromJsonFactory = _$SectionFromJson;
  static const toJsonFactory = _$SectionToJson;
  Map<String, dynamic> toJson() => _$SectionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Section &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.href, href) ||
                const DeepCollectionEquality().equals(other.href, href)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(href) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $SectionExtension on Section {
  Section copyWith({String? title, String? href, enums.SectionType? type}) {
    return Section(
        title: title ?? this.title,
        href: href ?? this.href,
        type: type ?? this.type);
  }

  Section copyWithWrapped(
      {Wrapped<String>? title,
      Wrapped<String>? href,
      Wrapped<enums.SectionType>? type}) {
    return Section(
        title: (title != null ? title.value : this.title),
        href: (href != null ? href.value : this.href),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class Availability {
  Availability({
    required this.status,
    required this.startDateTime,
    required this.endDateTime,
    required this.nextOpeningHours,
  });

  factory Availability.fromJson(Map<String, dynamic> json) =>
      _$AvailabilityFromJson(json);

  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: availabilityStatusToJson,
    fromJson: availabilityStatusFromJson,
  )
  final enums.AvailabilityStatus status;
  @JsonKey(name: 'startDateTime', includeIfNull: false)
  final DateTime startDateTime;
  @JsonKey(name: 'endDateTime', includeIfNull: false)
  final DateTime endDateTime;
  @JsonKey(name: 'nextOpeningHours', includeIfNull: false)
  final DateTimeRange nextOpeningHours;
  static const fromJsonFactory = _$AvailabilityFromJson;
  static const toJsonFactory = _$AvailabilityToJson;
  Map<String, dynamic> toJson() => _$AvailabilityToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Availability &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.startDateTime, startDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.startDateTime, startDateTime)) &&
            (identical(other.endDateTime, endDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.endDateTime, endDateTime)) &&
            (identical(other.nextOpeningHours, nextOpeningHours) ||
                const DeepCollectionEquality()
                    .equals(other.nextOpeningHours, nextOpeningHours)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(startDateTime) ^
      const DeepCollectionEquality().hash(endDateTime) ^
      const DeepCollectionEquality().hash(nextOpeningHours) ^
      runtimeType.hashCode;
}

extension $AvailabilityExtension on Availability {
  Availability copyWith(
      {enums.AvailabilityStatus? status,
      DateTime? startDateTime,
      DateTime? endDateTime,
      DateTimeRange? nextOpeningHours}) {
    return Availability(
        status: status ?? this.status,
        startDateTime: startDateTime ?? this.startDateTime,
        endDateTime: endDateTime ?? this.endDateTime,
        nextOpeningHours: nextOpeningHours ?? this.nextOpeningHours);
  }

  Availability copyWithWrapped(
      {Wrapped<enums.AvailabilityStatus>? status,
      Wrapped<DateTime>? startDateTime,
      Wrapped<DateTime>? endDateTime,
      Wrapped<DateTimeRange>? nextOpeningHours}) {
    return Availability(
        status: (status != null ? status.value : this.status),
        startDateTime:
            (startDateTime != null ? startDateTime.value : this.startDateTime),
        endDateTime:
            (endDateTime != null ? endDateTime.value : this.endDateTime),
        nextOpeningHours: (nextOpeningHours != null
            ? nextOpeningHours.value
            : this.nextOpeningHours));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel {
  Channel({
    required this.id,
    required this.type,
    required this.visibleOnPlatforms,
    this.waitingTimeMinutes,
    required this.availability,
  });

  factory Channel.fromJson(Map<String, dynamic> json) =>
      _$ChannelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: channelTypeToJson,
    fromJson: channelTypeFromJson,
  )
  final enums.ChannelType type;
  @JsonKey(
    name: 'visibleOnPlatforms',
    includeIfNull: false,
    toJson: channelVisibleOnPlatformsListToJson,
    fromJson: channelVisibleOnPlatformsListFromJson,
  )
  final List<enums.ChannelVisibleOnPlatforms> visibleOnPlatforms;
  @JsonKey(name: 'waitingTimeMinutes', includeIfNull: false)
  final int? waitingTimeMinutes;
  @JsonKey(name: 'availability', includeIfNull: false)
  final Availability availability;
  static const fromJsonFactory = _$ChannelFromJson;
  static const toJsonFactory = _$ChannelToJson;
  Map<String, dynamic> toJson() => _$ChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.visibleOnPlatforms, visibleOnPlatforms) ||
                const DeepCollectionEquality()
                    .equals(other.visibleOnPlatforms, visibleOnPlatforms)) &&
            (identical(other.waitingTimeMinutes, waitingTimeMinutes) ||
                const DeepCollectionEquality()
                    .equals(other.waitingTimeMinutes, waitingTimeMinutes)) &&
            (identical(other.availability, availability) ||
                const DeepCollectionEquality()
                    .equals(other.availability, availability)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(visibleOnPlatforms) ^
      const DeepCollectionEquality().hash(waitingTimeMinutes) ^
      const DeepCollectionEquality().hash(availability) ^
      runtimeType.hashCode;
}

extension $ChannelExtension on Channel {
  Channel copyWith(
      {String? id,
      enums.ChannelType? type,
      List<enums.ChannelVisibleOnPlatforms>? visibleOnPlatforms,
      int? waitingTimeMinutes,
      Availability? availability}) {
    return Channel(
        id: id ?? this.id,
        type: type ?? this.type,
        visibleOnPlatforms: visibleOnPlatforms ?? this.visibleOnPlatforms,
        waitingTimeMinutes: waitingTimeMinutes ?? this.waitingTimeMinutes,
        availability: availability ?? this.availability);
  }

  Channel copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.ChannelType>? type,
      Wrapped<List<enums.ChannelVisibleOnPlatforms>>? visibleOnPlatforms,
      Wrapped<int?>? waitingTimeMinutes,
      Wrapped<Availability>? availability}) {
    return Channel(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        visibleOnPlatforms: (visibleOnPlatforms != null
            ? visibleOnPlatforms.value
            : this.visibleOnPlatforms),
        waitingTimeMinutes: (waitingTimeMinutes != null
            ? waitingTimeMinutes.value
            : this.waitingTimeMinutes),
        availability:
            (availability != null ? availability.value : this.availability));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatChannel {
  ChatChannel({
    required this.id,
    required this.type,
    required this.visibleOnPlatforms,
    this.waitingTimeMinutes,
    required this.availability,
  });

  factory ChatChannel.fromJson(Map<String, dynamic> json) =>
      _$ChatChannelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: chatChannelTypeToJson,
    fromJson: chatChannelTypeFromJson,
  )
  final enums.ChatChannelType type;
  @JsonKey(
    name: 'visibleOnPlatforms',
    includeIfNull: false,
    toJson: chatChannelVisibleOnPlatformsListToJson,
    fromJson: chatChannelVisibleOnPlatformsListFromJson,
  )
  final List<enums.ChatChannelVisibleOnPlatforms> visibleOnPlatforms;
  @JsonKey(name: 'waitingTimeMinutes', includeIfNull: false)
  final int? waitingTimeMinutes;
  @JsonKey(name: 'availability', includeIfNull: false)
  final Availability availability;
  static const fromJsonFactory = _$ChatChannelFromJson;
  static const toJsonFactory = _$ChatChannelToJson;
  Map<String, dynamic> toJson() => _$ChatChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatChannel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.visibleOnPlatforms, visibleOnPlatforms) ||
                const DeepCollectionEquality()
                    .equals(other.visibleOnPlatforms, visibleOnPlatforms)) &&
            (identical(other.waitingTimeMinutes, waitingTimeMinutes) ||
                const DeepCollectionEquality()
                    .equals(other.waitingTimeMinutes, waitingTimeMinutes)) &&
            (identical(other.availability, availability) ||
                const DeepCollectionEquality()
                    .equals(other.availability, availability)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(visibleOnPlatforms) ^
      const DeepCollectionEquality().hash(waitingTimeMinutes) ^
      const DeepCollectionEquality().hash(availability) ^
      runtimeType.hashCode;
}

extension $ChatChannelExtension on ChatChannel {
  ChatChannel copyWith(
      {String? id,
      enums.ChatChannelType? type,
      List<enums.ChatChannelVisibleOnPlatforms>? visibleOnPlatforms,
      int? waitingTimeMinutes,
      Availability? availability}) {
    return ChatChannel(
        id: id ?? this.id,
        type: type ?? this.type,
        visibleOnPlatforms: visibleOnPlatforms ?? this.visibleOnPlatforms,
        waitingTimeMinutes: waitingTimeMinutes ?? this.waitingTimeMinutes,
        availability: availability ?? this.availability);
  }

  ChatChannel copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.ChatChannelType>? type,
      Wrapped<List<enums.ChatChannelVisibleOnPlatforms>>? visibleOnPlatforms,
      Wrapped<int?>? waitingTimeMinutes,
      Wrapped<Availability>? availability}) {
    return ChatChannel(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        visibleOnPlatforms: (visibleOnPlatforms != null
            ? visibleOnPlatforms.value
            : this.visibleOnPlatforms),
        waitingTimeMinutes: (waitingTimeMinutes != null
            ? waitingTimeMinutes.value
            : this.waitingTimeMinutes),
        availability:
            (availability != null ? availability.value : this.availability));
  }
}

@JsonSerializable(explicitToJson: true)
class DateTimeRange {
  DateTimeRange({
    required this.startDateTime,
    required this.endDateTime,
  });

  factory DateTimeRange.fromJson(Map<String, dynamic> json) =>
      _$DateTimeRangeFromJson(json);

  @JsonKey(name: 'startDateTime', includeIfNull: false)
  final DateTime startDateTime;
  @JsonKey(name: 'endDateTime', includeIfNull: false)
  final DateTime endDateTime;
  static const fromJsonFactory = _$DateTimeRangeFromJson;
  static const toJsonFactory = _$DateTimeRangeToJson;
  Map<String, dynamic> toJson() => _$DateTimeRangeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DateTimeRange &&
            (identical(other.startDateTime, startDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.startDateTime, startDateTime)) &&
            (identical(other.endDateTime, endDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.endDateTime, endDateTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startDateTime) ^
      const DeepCollectionEquality().hash(endDateTime) ^
      runtimeType.hashCode;
}

extension $DateTimeRangeExtension on DateTimeRange {
  DateTimeRange copyWith({DateTime? startDateTime, DateTime? endDateTime}) {
    return DateTimeRange(
        startDateTime: startDateTime ?? this.startDateTime,
        endDateTime: endDateTime ?? this.endDateTime);
  }

  DateTimeRange copyWithWrapped(
      {Wrapped<DateTime>? startDateTime, Wrapped<DateTime>? endDateTime}) {
    return DateTimeRange(
        startDateTime:
            (startDateTime != null ? startDateTime.value : this.startDateTime),
        endDateTime:
            (endDateTime != null ? endDateTime.value : this.endDateTime));
  }
}

@JsonSerializable(explicitToJson: true)
class PhoneChannel {
  PhoneChannel({
    required this.phoneNumber,
    required this.chargePerMinute,
    required this.id,
    required this.type,
    required this.visibleOnPlatforms,
    this.waitingTimeMinutes,
    required this.availability,
  });

  factory PhoneChannel.fromJson(Map<String, dynamic> json) =>
      _$PhoneChannelFromJson(json);

  @JsonKey(name: 'phoneNumber', includeIfNull: false, defaultValue: '')
  final String phoneNumber;
  @JsonKey(name: 'chargePerMinute', includeIfNull: false)
  final int chargePerMinute;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: phoneChannelTypeToJson,
    fromJson: phoneChannelTypeFromJson,
  )
  final enums.PhoneChannelType type;
  @JsonKey(
    name: 'visibleOnPlatforms',
    includeIfNull: false,
    toJson: phoneChannelVisibleOnPlatformsListToJson,
    fromJson: phoneChannelVisibleOnPlatformsListFromJson,
  )
  final List<enums.PhoneChannelVisibleOnPlatforms> visibleOnPlatforms;
  @JsonKey(name: 'waitingTimeMinutes', includeIfNull: false)
  final int? waitingTimeMinutes;
  @JsonKey(name: 'availability', includeIfNull: false)
  final Availability availability;
  static const fromJsonFactory = _$PhoneChannelFromJson;
  static const toJsonFactory = _$PhoneChannelToJson;
  Map<String, dynamic> toJson() => _$PhoneChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PhoneChannel &&
            (identical(other.phoneNumber, phoneNumber) ||
                const DeepCollectionEquality()
                    .equals(other.phoneNumber, phoneNumber)) &&
            (identical(other.chargePerMinute, chargePerMinute) ||
                const DeepCollectionEquality()
                    .equals(other.chargePerMinute, chargePerMinute)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.visibleOnPlatforms, visibleOnPlatforms) ||
                const DeepCollectionEquality()
                    .equals(other.visibleOnPlatforms, visibleOnPlatforms)) &&
            (identical(other.waitingTimeMinutes, waitingTimeMinutes) ||
                const DeepCollectionEquality()
                    .equals(other.waitingTimeMinutes, waitingTimeMinutes)) &&
            (identical(other.availability, availability) ||
                const DeepCollectionEquality()
                    .equals(other.availability, availability)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(phoneNumber) ^
      const DeepCollectionEquality().hash(chargePerMinute) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(visibleOnPlatforms) ^
      const DeepCollectionEquality().hash(waitingTimeMinutes) ^
      const DeepCollectionEquality().hash(availability) ^
      runtimeType.hashCode;
}

extension $PhoneChannelExtension on PhoneChannel {
  PhoneChannel copyWith(
      {String? phoneNumber,
      int? chargePerMinute,
      String? id,
      enums.PhoneChannelType? type,
      List<enums.PhoneChannelVisibleOnPlatforms>? visibleOnPlatforms,
      int? waitingTimeMinutes,
      Availability? availability}) {
    return PhoneChannel(
        phoneNumber: phoneNumber ?? this.phoneNumber,
        chargePerMinute: chargePerMinute ?? this.chargePerMinute,
        id: id ?? this.id,
        type: type ?? this.type,
        visibleOnPlatforms: visibleOnPlatforms ?? this.visibleOnPlatforms,
        waitingTimeMinutes: waitingTimeMinutes ?? this.waitingTimeMinutes,
        availability: availability ?? this.availability);
  }

  PhoneChannel copyWithWrapped(
      {Wrapped<String>? phoneNumber,
      Wrapped<int>? chargePerMinute,
      Wrapped<String>? id,
      Wrapped<enums.PhoneChannelType>? type,
      Wrapped<List<enums.PhoneChannelVisibleOnPlatforms>>? visibleOnPlatforms,
      Wrapped<int?>? waitingTimeMinutes,
      Wrapped<Availability>? availability}) {
    return PhoneChannel(
        phoneNumber:
            (phoneNumber != null ? phoneNumber.value : this.phoneNumber),
        chargePerMinute: (chargePerMinute != null
            ? chargePerMinute.value
            : this.chargePerMinute),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        visibleOnPlatforms: (visibleOnPlatforms != null
            ? visibleOnPlatforms.value
            : this.visibleOnPlatforms),
        waitingTimeMinutes: (waitingTimeMinutes != null
            ? waitingTimeMinutes.value
            : this.waitingTimeMinutes),
        availability:
            (availability != null ? availability.value : this.availability));
  }
}

@JsonSerializable(explicitToJson: true)
class SocialMediaChannel {
  SocialMediaChannel({
    required this.url,
    required this.id,
    required this.type,
    required this.visibleOnPlatforms,
    this.waitingTimeMinutes,
    required this.availability,
  });

  factory SocialMediaChannel.fromJson(Map<String, dynamic> json) =>
      _$SocialMediaChannelFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: socialMediaChannelTypeToJson,
    fromJson: socialMediaChannelTypeFromJson,
  )
  final enums.SocialMediaChannelType type;
  @JsonKey(
    name: 'visibleOnPlatforms',
    includeIfNull: false,
    toJson: socialMediaChannelVisibleOnPlatformsListToJson,
    fromJson: socialMediaChannelVisibleOnPlatformsListFromJson,
  )
  final List<enums.SocialMediaChannelVisibleOnPlatforms> visibleOnPlatforms;
  @JsonKey(name: 'waitingTimeMinutes', includeIfNull: false)
  final int? waitingTimeMinutes;
  @JsonKey(name: 'availability', includeIfNull: false)
  final Availability availability;
  static const fromJsonFactory = _$SocialMediaChannelFromJson;
  static const toJsonFactory = _$SocialMediaChannelToJson;
  Map<String, dynamic> toJson() => _$SocialMediaChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SocialMediaChannel &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.visibleOnPlatforms, visibleOnPlatforms) ||
                const DeepCollectionEquality()
                    .equals(other.visibleOnPlatforms, visibleOnPlatforms)) &&
            (identical(other.waitingTimeMinutes, waitingTimeMinutes) ||
                const DeepCollectionEquality()
                    .equals(other.waitingTimeMinutes, waitingTimeMinutes)) &&
            (identical(other.availability, availability) ||
                const DeepCollectionEquality()
                    .equals(other.availability, availability)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(visibleOnPlatforms) ^
      const DeepCollectionEquality().hash(waitingTimeMinutes) ^
      const DeepCollectionEquality().hash(availability) ^
      runtimeType.hashCode;
}

extension $SocialMediaChannelExtension on SocialMediaChannel {
  SocialMediaChannel copyWith(
      {String? url,
      String? id,
      enums.SocialMediaChannelType? type,
      List<enums.SocialMediaChannelVisibleOnPlatforms>? visibleOnPlatforms,
      int? waitingTimeMinutes,
      Availability? availability}) {
    return SocialMediaChannel(
        url: url ?? this.url,
        id: id ?? this.id,
        type: type ?? this.type,
        visibleOnPlatforms: visibleOnPlatforms ?? this.visibleOnPlatforms,
        waitingTimeMinutes: waitingTimeMinutes ?? this.waitingTimeMinutes,
        availability: availability ?? this.availability);
  }

  SocialMediaChannel copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String>? id,
      Wrapped<enums.SocialMediaChannelType>? type,
      Wrapped<List<enums.SocialMediaChannelVisibleOnPlatforms>>?
          visibleOnPlatforms,
      Wrapped<int?>? waitingTimeMinutes,
      Wrapped<Availability>? availability}) {
    return SocialMediaChannel(
        url: (url != null ? url.value : this.url),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        visibleOnPlatforms: (visibleOnPlatforms != null
            ? visibleOnPlatforms.value
            : this.visibleOnPlatforms),
        waitingTimeMinutes: (waitingTimeMinutes != null
            ? waitingTimeMinutes.value
            : this.waitingTimeMinutes),
        availability:
            (availability != null ? availability.value : this.availability));
  }
}

String? sectionTypeToJson(enums.SectionType? sectionType) {
  return enums.$SectionTypeMap[sectionType];
}

enums.SectionType sectionTypeFromJson(
  Object? sectionType, [
  enums.SectionType? defaultValue,
]) {
  if (sectionType is String) {
    return enums.$SectionTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == sectionType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.SectionType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SectionTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SectionType.swaggerGeneratedUnknown;
}

List<String> sectionTypeListToJson(List<enums.SectionType>? sectionType) {
  if (sectionType == null) {
    return [];
  }

  return sectionType.map((e) => enums.$SectionTypeMap[e]!).toList();
}

List<enums.SectionType> sectionTypeListFromJson(
  List? sectionType, [
  List<enums.SectionType>? defaultValue,
]) {
  if (sectionType == null) {
    return defaultValue ?? [];
  }

  return sectionType.map((e) => sectionTypeFromJson(e.toString())).toList();
}

List<enums.SectionType>? sectionTypeNullableListFromJson(
  List? sectionType, [
  List<enums.SectionType>? defaultValue,
]) {
  if (sectionType == null) {
    return defaultValue;
  }

  return sectionType.map((e) => sectionTypeFromJson(e.toString())).toList();
}

String? availabilityStatusToJson(enums.AvailabilityStatus? availabilityStatus) {
  return enums.$AvailabilityStatusMap[availabilityStatus];
}

enums.AvailabilityStatus availabilityStatusFromJson(
  Object? availabilityStatus, [
  enums.AvailabilityStatus? defaultValue,
]) {
  if (availabilityStatus is String) {
    return enums.$AvailabilityStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == availabilityStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.AvailabilityStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$AvailabilityStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.AvailabilityStatus.swaggerGeneratedUnknown;
}

List<String> availabilityStatusListToJson(
    List<enums.AvailabilityStatus>? availabilityStatus) {
  if (availabilityStatus == null) {
    return [];
  }

  return availabilityStatus
      .map((e) => enums.$AvailabilityStatusMap[e]!)
      .toList();
}

List<enums.AvailabilityStatus> availabilityStatusListFromJson(
  List? availabilityStatus, [
  List<enums.AvailabilityStatus>? defaultValue,
]) {
  if (availabilityStatus == null) {
    return defaultValue ?? [];
  }

  return availabilityStatus
      .map((e) => availabilityStatusFromJson(e.toString()))
      .toList();
}

List<enums.AvailabilityStatus>? availabilityStatusNullableListFromJson(
  List? availabilityStatus, [
  List<enums.AvailabilityStatus>? defaultValue,
]) {
  if (availabilityStatus == null) {
    return defaultValue;
  }

  return availabilityStatus
      .map((e) => availabilityStatusFromJson(e.toString()))
      .toList();
}

String? channelTypeToJson(enums.ChannelType? channelType) {
  return enums.$ChannelTypeMap[channelType];
}

enums.ChannelType channelTypeFromJson(
  Object? channelType, [
  enums.ChannelType? defaultValue,
]) {
  if (channelType is String) {
    return enums.$ChannelTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == channelType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ChannelType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelType.swaggerGeneratedUnknown;
}

List<String> channelTypeListToJson(List<enums.ChannelType>? channelType) {
  if (channelType == null) {
    return [];
  }

  return channelType.map((e) => enums.$ChannelTypeMap[e]!).toList();
}

List<enums.ChannelType> channelTypeListFromJson(
  List? channelType, [
  List<enums.ChannelType>? defaultValue,
]) {
  if (channelType == null) {
    return defaultValue ?? [];
  }

  return channelType.map((e) => channelTypeFromJson(e.toString())).toList();
}

List<enums.ChannelType>? channelTypeNullableListFromJson(
  List? channelType, [
  List<enums.ChannelType>? defaultValue,
]) {
  if (channelType == null) {
    return defaultValue;
  }

  return channelType.map((e) => channelTypeFromJson(e.toString())).toList();
}

String? channelVisibleOnPlatformsToJson(
    enums.ChannelVisibleOnPlatforms? channelVisibleOnPlatforms) {
  return enums.$ChannelVisibleOnPlatformsMap[channelVisibleOnPlatforms];
}

enums.ChannelVisibleOnPlatforms channelVisibleOnPlatformsFromJson(
  Object? channelVisibleOnPlatforms, [
  enums.ChannelVisibleOnPlatforms? defaultValue,
]) {
  if (channelVisibleOnPlatforms is String) {
    return enums.$ChannelVisibleOnPlatformsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                channelVisibleOnPlatforms.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelVisibleOnPlatforms.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelVisibleOnPlatformsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelVisibleOnPlatforms.swaggerGeneratedUnknown;
}

List<String> channelVisibleOnPlatformsListToJson(
    List<enums.ChannelVisibleOnPlatforms>? channelVisibleOnPlatforms) {
  if (channelVisibleOnPlatforms == null) {
    return [];
  }

  return channelVisibleOnPlatforms
      .map((e) => enums.$ChannelVisibleOnPlatformsMap[e]!)
      .toList();
}

List<enums.ChannelVisibleOnPlatforms> channelVisibleOnPlatformsListFromJson(
  List? channelVisibleOnPlatforms, [
  List<enums.ChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (channelVisibleOnPlatforms == null) {
    return defaultValue ?? [];
  }

  return channelVisibleOnPlatforms
      .map((e) => channelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

List<enums.ChannelVisibleOnPlatforms>?
    channelVisibleOnPlatformsNullableListFromJson(
  List? channelVisibleOnPlatforms, [
  List<enums.ChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (channelVisibleOnPlatforms == null) {
    return defaultValue;
  }

  return channelVisibleOnPlatforms
      .map((e) => channelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

String? chatChannelTypeToJson(enums.ChatChannelType? chatChannelType) {
  return enums.$ChatChannelTypeMap[chatChannelType];
}

enums.ChatChannelType chatChannelTypeFromJson(
  Object? chatChannelType, [
  enums.ChatChannelType? defaultValue,
]) {
  if (chatChannelType is String) {
    return enums.$ChatChannelTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == chatChannelType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChatChannelType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChatChannelTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChatChannelType.swaggerGeneratedUnknown;
}

List<String> chatChannelTypeListToJson(
    List<enums.ChatChannelType>? chatChannelType) {
  if (chatChannelType == null) {
    return [];
  }

  return chatChannelType.map((e) => enums.$ChatChannelTypeMap[e]!).toList();
}

List<enums.ChatChannelType> chatChannelTypeListFromJson(
  List? chatChannelType, [
  List<enums.ChatChannelType>? defaultValue,
]) {
  if (chatChannelType == null) {
    return defaultValue ?? [];
  }

  return chatChannelType
      .map((e) => chatChannelTypeFromJson(e.toString()))
      .toList();
}

List<enums.ChatChannelType>? chatChannelTypeNullableListFromJson(
  List? chatChannelType, [
  List<enums.ChatChannelType>? defaultValue,
]) {
  if (chatChannelType == null) {
    return defaultValue;
  }

  return chatChannelType
      .map((e) => chatChannelTypeFromJson(e.toString()))
      .toList();
}

String? chatChannelVisibleOnPlatformsToJson(
    enums.ChatChannelVisibleOnPlatforms? chatChannelVisibleOnPlatforms) {
  return enums.$ChatChannelVisibleOnPlatformsMap[chatChannelVisibleOnPlatforms];
}

enums.ChatChannelVisibleOnPlatforms chatChannelVisibleOnPlatformsFromJson(
  Object? chatChannelVisibleOnPlatforms, [
  enums.ChatChannelVisibleOnPlatforms? defaultValue,
]) {
  if (chatChannelVisibleOnPlatforms is String) {
    return enums.$ChatChannelVisibleOnPlatformsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                chatChannelVisibleOnPlatforms.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChatChannelVisibleOnPlatforms.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChatChannelVisibleOnPlatformsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChatChannelVisibleOnPlatforms.swaggerGeneratedUnknown;
}

List<String> chatChannelVisibleOnPlatformsListToJson(
    List<enums.ChatChannelVisibleOnPlatforms>? chatChannelVisibleOnPlatforms) {
  if (chatChannelVisibleOnPlatforms == null) {
    return [];
  }

  return chatChannelVisibleOnPlatforms
      .map((e) => enums.$ChatChannelVisibleOnPlatformsMap[e]!)
      .toList();
}

List<enums.ChatChannelVisibleOnPlatforms>
    chatChannelVisibleOnPlatformsListFromJson(
  List? chatChannelVisibleOnPlatforms, [
  List<enums.ChatChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (chatChannelVisibleOnPlatforms == null) {
    return defaultValue ?? [];
  }

  return chatChannelVisibleOnPlatforms
      .map((e) => chatChannelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

List<enums.ChatChannelVisibleOnPlatforms>?
    chatChannelVisibleOnPlatformsNullableListFromJson(
  List? chatChannelVisibleOnPlatforms, [
  List<enums.ChatChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (chatChannelVisibleOnPlatforms == null) {
    return defaultValue;
  }

  return chatChannelVisibleOnPlatforms
      .map((e) => chatChannelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

String? phoneChannelTypeToJson(enums.PhoneChannelType? phoneChannelType) {
  return enums.$PhoneChannelTypeMap[phoneChannelType];
}

enums.PhoneChannelType phoneChannelTypeFromJson(
  Object? phoneChannelType, [
  enums.PhoneChannelType? defaultValue,
]) {
  if (phoneChannelType is String) {
    return enums.$PhoneChannelTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == phoneChannelType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PhoneChannelType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PhoneChannelTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PhoneChannelType.swaggerGeneratedUnknown;
}

List<String> phoneChannelTypeListToJson(
    List<enums.PhoneChannelType>? phoneChannelType) {
  if (phoneChannelType == null) {
    return [];
  }

  return phoneChannelType.map((e) => enums.$PhoneChannelTypeMap[e]!).toList();
}

List<enums.PhoneChannelType> phoneChannelTypeListFromJson(
  List? phoneChannelType, [
  List<enums.PhoneChannelType>? defaultValue,
]) {
  if (phoneChannelType == null) {
    return defaultValue ?? [];
  }

  return phoneChannelType
      .map((e) => phoneChannelTypeFromJson(e.toString()))
      .toList();
}

List<enums.PhoneChannelType>? phoneChannelTypeNullableListFromJson(
  List? phoneChannelType, [
  List<enums.PhoneChannelType>? defaultValue,
]) {
  if (phoneChannelType == null) {
    return defaultValue;
  }

  return phoneChannelType
      .map((e) => phoneChannelTypeFromJson(e.toString()))
      .toList();
}

String? phoneChannelVisibleOnPlatformsToJson(
    enums.PhoneChannelVisibleOnPlatforms? phoneChannelVisibleOnPlatforms) {
  return enums
      .$PhoneChannelVisibleOnPlatformsMap[phoneChannelVisibleOnPlatforms];
}

enums.PhoneChannelVisibleOnPlatforms phoneChannelVisibleOnPlatformsFromJson(
  Object? phoneChannelVisibleOnPlatforms, [
  enums.PhoneChannelVisibleOnPlatforms? defaultValue,
]) {
  if (phoneChannelVisibleOnPlatforms is String) {
    return enums.$PhoneChannelVisibleOnPlatformsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                phoneChannelVisibleOnPlatforms.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PhoneChannelVisibleOnPlatforms.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PhoneChannelVisibleOnPlatformsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PhoneChannelVisibleOnPlatforms.swaggerGeneratedUnknown;
}

List<String> phoneChannelVisibleOnPlatformsListToJson(
    List<enums.PhoneChannelVisibleOnPlatforms>?
        phoneChannelVisibleOnPlatforms) {
  if (phoneChannelVisibleOnPlatforms == null) {
    return [];
  }

  return phoneChannelVisibleOnPlatforms
      .map((e) => enums.$PhoneChannelVisibleOnPlatformsMap[e]!)
      .toList();
}

List<enums.PhoneChannelVisibleOnPlatforms>
    phoneChannelVisibleOnPlatformsListFromJson(
  List? phoneChannelVisibleOnPlatforms, [
  List<enums.PhoneChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (phoneChannelVisibleOnPlatforms == null) {
    return defaultValue ?? [];
  }

  return phoneChannelVisibleOnPlatforms
      .map((e) => phoneChannelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

List<enums.PhoneChannelVisibleOnPlatforms>?
    phoneChannelVisibleOnPlatformsNullableListFromJson(
  List? phoneChannelVisibleOnPlatforms, [
  List<enums.PhoneChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (phoneChannelVisibleOnPlatforms == null) {
    return defaultValue;
  }

  return phoneChannelVisibleOnPlatforms
      .map((e) => phoneChannelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

String? socialMediaChannelTypeToJson(
    enums.SocialMediaChannelType? socialMediaChannelType) {
  return enums.$SocialMediaChannelTypeMap[socialMediaChannelType];
}

enums.SocialMediaChannelType socialMediaChannelTypeFromJson(
  Object? socialMediaChannelType, [
  enums.SocialMediaChannelType? defaultValue,
]) {
  if (socialMediaChannelType is String) {
    return enums.$SocialMediaChannelTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                socialMediaChannelType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SocialMediaChannelType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SocialMediaChannelTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SocialMediaChannelType.swaggerGeneratedUnknown;
}

List<String> socialMediaChannelTypeListToJson(
    List<enums.SocialMediaChannelType>? socialMediaChannelType) {
  if (socialMediaChannelType == null) {
    return [];
  }

  return socialMediaChannelType
      .map((e) => enums.$SocialMediaChannelTypeMap[e]!)
      .toList();
}

List<enums.SocialMediaChannelType> socialMediaChannelTypeListFromJson(
  List? socialMediaChannelType, [
  List<enums.SocialMediaChannelType>? defaultValue,
]) {
  if (socialMediaChannelType == null) {
    return defaultValue ?? [];
  }

  return socialMediaChannelType
      .map((e) => socialMediaChannelTypeFromJson(e.toString()))
      .toList();
}

List<enums.SocialMediaChannelType>? socialMediaChannelTypeNullableListFromJson(
  List? socialMediaChannelType, [
  List<enums.SocialMediaChannelType>? defaultValue,
]) {
  if (socialMediaChannelType == null) {
    return defaultValue;
  }

  return socialMediaChannelType
      .map((e) => socialMediaChannelTypeFromJson(e.toString()))
      .toList();
}

String? socialMediaChannelVisibleOnPlatformsToJson(
    enums.SocialMediaChannelVisibleOnPlatforms?
        socialMediaChannelVisibleOnPlatforms) {
  return enums.$SocialMediaChannelVisibleOnPlatformsMap[
      socialMediaChannelVisibleOnPlatforms];
}

enums.SocialMediaChannelVisibleOnPlatforms
    socialMediaChannelVisibleOnPlatformsFromJson(
  Object? socialMediaChannelVisibleOnPlatforms, [
  enums.SocialMediaChannelVisibleOnPlatforms? defaultValue,
]) {
  if (socialMediaChannelVisibleOnPlatforms is String) {
    return enums.$SocialMediaChannelVisibleOnPlatformsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                socialMediaChannelVisibleOnPlatforms.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SocialMediaChannelVisibleOnPlatforms
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SocialMediaChannelVisibleOnPlatformsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SocialMediaChannelVisibleOnPlatforms.swaggerGeneratedUnknown;
}

List<String> socialMediaChannelVisibleOnPlatformsListToJson(
    List<enums.SocialMediaChannelVisibleOnPlatforms>?
        socialMediaChannelVisibleOnPlatforms) {
  if (socialMediaChannelVisibleOnPlatforms == null) {
    return [];
  }

  return socialMediaChannelVisibleOnPlatforms
      .map((e) => enums.$SocialMediaChannelVisibleOnPlatformsMap[e]!)
      .toList();
}

List<enums.SocialMediaChannelVisibleOnPlatforms>
    socialMediaChannelVisibleOnPlatformsListFromJson(
  List? socialMediaChannelVisibleOnPlatforms, [
  List<enums.SocialMediaChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (socialMediaChannelVisibleOnPlatforms == null) {
    return defaultValue ?? [];
  }

  return socialMediaChannelVisibleOnPlatforms
      .map((e) => socialMediaChannelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

List<enums.SocialMediaChannelVisibleOnPlatforms>?
    socialMediaChannelVisibleOnPlatformsNullableListFromJson(
  List? socialMediaChannelVisibleOnPlatforms, [
  List<enums.SocialMediaChannelVisibleOnPlatforms>? defaultValue,
]) {
  if (socialMediaChannelVisibleOnPlatforms == null) {
    return defaultValue;
  }

  return socialMediaChannelVisibleOnPlatforms
      .map((e) => socialMediaChannelVisibleOnPlatformsFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
