// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'demo_api_platform.enums.swagger.dart' as enums;
export 'demo_api_platform.enums.swagger.dart';

part 'demo_api_platform.swagger.chopper.dart';
part 'demo_api_platform.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class DemoApiPlatform extends ChopperService {
  static DemoApiPlatform create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$DemoApiPlatform(client);
    }

    final newClient = ChopperClient(
        services: [_$DemoApiPlatform()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$DemoApiPlatform(newClient);
  }

  ///Retrieves the collection of Book resources.
  ///@param page The collection page number
  ///@param properties[]
  ///@param order[id]
  ///@param order[title]
  ///@param order[author]
  ///@param order[isbn]
  ///@param order[publicationDate]
  ///@param title
  ///@param author
  Future<chopper.Response<Object>> booksGet({
    int? page,
    List<String>? properties,
    enums.BooksGetOrderId? orderId,
    enums.BooksGetOrderTitle? orderTitle,
    enums.BooksGetOrderAuthor? orderAuthor,
    enums.BooksGetOrderIsbn? orderIsbn,
    enums.BooksGetOrderPublicationDate? orderPublicationDate,
    String? title,
    String? author,
    String? cacheControl,
  }) {
    return _booksGet(
        page: page,
        properties: properties,
        orderId: enums.$BooksGetOrderIdMap[orderId]?.toString(),
        orderTitle: enums.$BooksGetOrderTitleMap[orderTitle]?.toString(),
        orderAuthor: enums.$BooksGetOrderAuthorMap[orderAuthor]?.toString(),
        orderIsbn: enums.$BooksGetOrderIsbnMap[orderIsbn]?.toString(),
        orderPublicationDate: enums
            .$BooksGetOrderPublicationDateMap[orderPublicationDate]
            ?.toString(),
        title: title,
        author: author,
        cacheControl: cacheControl);
  }

  ///Retrieves the collection of Book resources.
  ///@param page The collection page number
  ///@param properties[]
  ///@param order[id]
  ///@param order[title]
  ///@param order[author]
  ///@param order[isbn]
  ///@param order[publicationDate]
  ///@param title
  ///@param author
  @Get(path: '/books')
  Future<chopper.Response<Object>> _booksGet({
    @Query('page') int? page,
    @Query('properties[]') List<String>? properties,
    @Query('order[id]') String? orderId,
    @Query('order[title]') String? orderTitle,
    @Query('order[author]') String? orderAuthor,
    @Query('order[isbn]') String? orderIsbn,
    @Query('order[publicationDate]') String? orderPublicationDate,
    @Query('title') String? title,
    @Query('author') String? author,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Book resource.
  Future<chopper.Response<BookJsonldBookRead>> booksPost({
    String? cacheControl,
    required BookJsonld? body,
  }) {
    generatedMapping.putIfAbsent(
        BookJsonldBookRead, () => BookJsonldBookRead.fromJsonFactory);

    return _booksPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Book resource.
  @Post(path: '/books')
  Future<chopper.Response<BookJsonldBookRead>> _booksPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required BookJsonld? body,
  });

  ///Retrieves a Book resource.
  ///@param id Resource identifier
  Future<chopper.Response<BookJsonldBookRead>> booksIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BookJsonldBookRead, () => BookJsonldBookRead.fromJsonFactory);

    return _booksIdGet(id: id, cacheControl: cacheControl);
  }

  ///Retrieves a Book resource.
  ///@param id Resource identifier
  @Get(path: '/books/{id}')
  Future<chopper.Response<BookJsonldBookRead>> _booksIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Replaces the Book resource.
  ///@param id Resource identifier
  Future<chopper.Response<BookJsonldBookRead>> booksIdPut({
    required String? id,
    String? cacheControl,
    required BookJsonld? body,
  }) {
    generatedMapping.putIfAbsent(
        BookJsonldBookRead, () => BookJsonldBookRead.fromJsonFactory);

    return _booksIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Replaces the Book resource.
  ///@param id Resource identifier
  @Put(path: '/books/{id}')
  Future<chopper.Response<BookJsonldBookRead>> _booksIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required BookJsonld? body,
  });

  ///Removes the Book resource.
  ///@param id Resource identifier
  Future<chopper.Response> booksIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _booksIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Removes the Book resource.
  ///@param id Resource identifier
  @Delete(path: '/books/{id}')
  Future<chopper.Response> _booksIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates the Book resource.
  ///@param id Resource identifier
  Future<chopper.Response<BookJsonldBookRead>> booksIdPatch({
    required String? id,
    String? cacheControl,
    required Book? body,
  }) {
    generatedMapping.putIfAbsent(
        BookJsonldBookRead, () => BookJsonldBookRead.fromJsonFactory);

    return _booksIdPatch(id: id, cacheControl: cacheControl, body: body);
  }

  ///Updates the Book resource.
  ///@param id Resource identifier
  @Patch(path: '/books/{id}')
  Future<chopper.Response<BookJsonldBookRead>> _booksIdPatch({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Book? body,
  });

  ///Replaces the Book resource.
  ///@param id Resource identifier
  Future<chopper.Response> booksIdGenerateCoverPut({
    required String? id,
    String? cacheControl,
    required BookJsonld? body,
  }) {
    return _booksIdGenerateCoverPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Replaces the Book resource.
  ///@param id Resource identifier
  @Put(path: '/books/{id}/generate-cover')
  Future<chopper.Response> _booksIdGenerateCoverPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required BookJsonld? body,
  });

  ///Retrieves a Book resource.
  ///@param id Book identifier
  ///@param page The collection page number
  ///@param order[id]
  ///@param order[publicationDate]
  ///@param book
  ///@param book[]
  Future<chopper.Response<Object>> booksIdReviewsGet({
    required String? id,
    int? page,
    enums.BooksIdReviewsGetOrderId? orderId,
    enums.BooksIdReviewsGetOrderPublicationDate? orderPublicationDate,
    String? book,
    List<String>? book$,
    String? cacheControl,
  }) {
    return _booksIdReviewsGet(
        id: id,
        page: page,
        orderId: enums.$BooksIdReviewsGetOrderIdMap[orderId]?.toString(),
        orderPublicationDate: enums
            .$BooksIdReviewsGetOrderPublicationDateMap[orderPublicationDate]
            ?.toString(),
        book: book,
        book$: book$,
        cacheControl: cacheControl);
  }

  ///Retrieves a Book resource.
  ///@param id Book identifier
  ///@param page The collection page number
  ///@param order[id]
  ///@param order[publicationDate]
  ///@param book
  ///@param book[]
  @Get(path: '/books/{id}/reviews')
  Future<chopper.Response<Object>> _booksIdReviewsGet({
    @Path('id') required String? id,
    @Query('page') int? page,
    @Query('order[id]') String? orderId,
    @Query('order[publicationDate]') String? orderPublicationDate,
    @Query('book') String? book,
    @Query('book[]') List<String>? book$,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves the collection of Parchment resources.
  ///@param page The collection page number
  Future<chopper.Response<Object>> parchmentsGet({
    int? page,
    String? cacheControl,
  }) {
    return _parchmentsGet(page: page, cacheControl: cacheControl);
  }

  ///Retrieves the collection of Parchment resources.
  ///@param page The collection page number
  @Get(path: '/parchments')
  Future<chopper.Response<Object>> _parchmentsGet({
    @Query('page') int? page,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Parchment resource.
  Future<chopper.Response<ParchmentJsonld>> parchmentsPost({
    String? cacheControl,
    required ParchmentJsonld? body,
  }) {
    generatedMapping.putIfAbsent(
        ParchmentJsonld, () => ParchmentJsonld.fromJsonFactory);

    return _parchmentsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Parchment resource.
  @Post(path: '/parchments')
  Future<chopper.Response<ParchmentJsonld>> _parchmentsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ParchmentJsonld? body,
  });

  ///Retrieves a Parchment resource.
  ///@param id Resource identifier
  Future<chopper.Response<ParchmentJsonld>> parchmentsIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ParchmentJsonld, () => ParchmentJsonld.fromJsonFactory);

    return _parchmentsIdGet(id: id, cacheControl: cacheControl);
  }

  ///Retrieves a Parchment resource.
  ///@param id Resource identifier
  @Get(path: '/parchments/{id}')
  Future<chopper.Response<ParchmentJsonld>> _parchmentsIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Replaces the Parchment resource.
  ///@param id Resource identifier
  Future<chopper.Response<ParchmentJsonld>> parchmentsIdPut({
    required String? id,
    String? cacheControl,
    required ParchmentJsonld? body,
  }) {
    generatedMapping.putIfAbsent(
        ParchmentJsonld, () => ParchmentJsonld.fromJsonFactory);

    return _parchmentsIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Replaces the Parchment resource.
  ///@param id Resource identifier
  @Put(path: '/parchments/{id}')
  Future<chopper.Response<ParchmentJsonld>> _parchmentsIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ParchmentJsonld? body,
  });

  ///Removes the Parchment resource.
  ///@param id Resource identifier
  Future<chopper.Response> parchmentsIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _parchmentsIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Removes the Parchment resource.
  ///@param id Resource identifier
  @Delete(path: '/parchments/{id}')
  Future<chopper.Response> _parchmentsIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates the Parchment resource.
  ///@param id Resource identifier
  Future<chopper.Response<ParchmentJsonld>> parchmentsIdPatch({
    required String? id,
    String? cacheControl,
    required Parchment? body,
  }) {
    generatedMapping.putIfAbsent(
        ParchmentJsonld, () => ParchmentJsonld.fromJsonFactory);

    return _parchmentsIdPatch(id: id, cacheControl: cacheControl, body: body);
  }

  ///Updates the Parchment resource.
  ///@param id Resource identifier
  @Patch(path: '/parchments/{id}')
  Future<chopper.Response<ParchmentJsonld>> _parchmentsIdPatch({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Parchment? body,
  });

  ///Retrieves the collection of Review resources.
  ///@param page The collection page number
  ///@param order[id]
  ///@param order[publicationDate]
  ///@param book
  ///@param book[]
  Future<chopper.Response<Object>> reviewsGet({
    int? page,
    enums.ReviewsGetOrderId? orderId,
    enums.ReviewsGetOrderPublicationDate? orderPublicationDate,
    String? book,
    List<String>? book$,
    String? cacheControl,
  }) {
    return _reviewsGet(
        page: page,
        orderId: enums.$ReviewsGetOrderIdMap[orderId]?.toString(),
        orderPublicationDate: enums
            .$ReviewsGetOrderPublicationDateMap[orderPublicationDate]
            ?.toString(),
        book: book,
        book$: book$,
        cacheControl: cacheControl);
  }

  ///Retrieves the collection of Review resources.
  ///@param page The collection page number
  ///@param order[id]
  ///@param order[publicationDate]
  ///@param book
  ///@param book[]
  @Get(path: '/reviews')
  Future<chopper.Response<Object>> _reviewsGet({
    @Query('page') int? page,
    @Query('order[id]') String? orderId,
    @Query('order[publicationDate]') String? orderPublicationDate,
    @Query('book') String? book,
    @Query('book[]') List<String>? book$,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Review resource.
  Future<chopper.Response<ReviewJsonldReviewRead>> reviewsPost({
    String? cacheControl,
    required ReviewJsonldReviewWrite? body,
  }) {
    generatedMapping.putIfAbsent(
        ReviewJsonldReviewRead, () => ReviewJsonldReviewRead.fromJsonFactory);

    return _reviewsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Review resource.
  @Post(path: '/reviews')
  Future<chopper.Response<ReviewJsonldReviewRead>> _reviewsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ReviewJsonldReviewWrite? body,
  });

  ///Retrieves a Review resource.
  ///@param id Resource identifier
  Future<chopper.Response<ReviewJsonldReviewRead>> reviewsIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReviewJsonldReviewRead, () => ReviewJsonldReviewRead.fromJsonFactory);

    return _reviewsIdGet(id: id, cacheControl: cacheControl);
  }

  ///Retrieves a Review resource.
  ///@param id Resource identifier
  @Get(path: '/reviews/{id}')
  Future<chopper.Response<ReviewJsonldReviewRead>> _reviewsIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Replaces the Review resource.
  ///@param id Resource identifier
  Future<chopper.Response<ReviewJsonldReviewRead>> reviewsIdPut({
    required String? id,
    String? cacheControl,
    required ReviewJsonldReviewWrite? body,
  }) {
    generatedMapping.putIfAbsent(
        ReviewJsonldReviewRead, () => ReviewJsonldReviewRead.fromJsonFactory);

    return _reviewsIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Replaces the Review resource.
  ///@param id Resource identifier
  @Put(path: '/reviews/{id}')
  Future<chopper.Response<ReviewJsonldReviewRead>> _reviewsIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ReviewJsonldReviewWrite? body,
  });

  ///Removes the Review resource.
  ///@param id Resource identifier
  Future<chopper.Response> reviewsIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _reviewsIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Removes the Review resource.
  ///@param id Resource identifier
  @Delete(path: '/reviews/{id}')
  Future<chopper.Response> _reviewsIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates the Review resource.
  ///@param id Resource identifier
  Future<chopper.Response<ReviewJsonldReviewRead>> reviewsIdPatch({
    required String? id,
    String? cacheControl,
    required ReviewReviewWrite? body,
  }) {
    generatedMapping.putIfAbsent(
        ReviewJsonldReviewRead, () => ReviewJsonldReviewRead.fromJsonFactory);

    return _reviewsIdPatch(id: id, cacheControl: cacheControl, body: body);
  }

  ///Updates the Review resource.
  ///@param id Resource identifier
  @Patch(path: '/reviews/{id}')
  Future<chopper.Response<ReviewJsonldReviewRead>> _reviewsIdPatch({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ReviewReviewWrite? body,
  });

  ///Retrieves the number of books and top books (legacy endpoint).
  Future<chopper.Response<Object>> statsGet({String? cacheControl}) {
    return _statsGet(cacheControl: cacheControl);
  }

  ///Retrieves the number of books and top books (legacy endpoint).
  @Get(path: '/stats')
  Future<chopper.Response<Object>> _statsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Retrieves the collection of TopBook resources.
  ///@param page The collection page number
  Future<chopper.Response<Object>> topBooksGet({
    int? page,
    String? cacheControl,
  }) {
    return _topBooksGet(page: page, cacheControl: cacheControl);
  }

  ///Retrieves the collection of TopBook resources.
  ///@param page The collection page number
  @Get(path: '/top_books')
  Future<chopper.Response<Object>> _topBooksGet({
    @Query('page') int? page,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves a TopBook resource.
  ///@param id Resource identifier
  Future<chopper.Response<TopBookJsonld>> topBooksIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopBookJsonld, () => TopBookJsonld.fromJsonFactory);

    return _topBooksIdGet(id: id, cacheControl: cacheControl);
  }

  ///Retrieves a TopBook resource.
  ///@param id Resource identifier
  @Get(path: '/top_books/{id}')
  Future<chopper.Response<TopBookJsonld>> _topBooksIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Book {
  Book({
    this.isbn,
    required this.title,
    required this.description,
    required this.author,
    required this.publicationDate,
    this.reviews,
    this.cover,
  });

  factory Book.fromJson(Map<String, dynamic> json) => _$BookFromJson(json);

  @JsonKey(name: 'isbn', includeIfNull: false, defaultValue: '')
  final String? isbn;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime publicationDate;
  @JsonKey(name: 'reviews', includeIfNull: false, defaultValue: <Review>[])
  final List<Review>? reviews;
  @JsonKey(name: 'cover', includeIfNull: false, defaultValue: '')
  final String? cover;
  static const fromJsonFactory = _$BookFromJson;
  static const toJsonFactory = _$BookToJson;
  Map<String, dynamic> toJson() => _$BookToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Book &&
            (identical(other.isbn, isbn) ||
                const DeepCollectionEquality().equals(other.isbn, isbn)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)) &&
            (identical(other.reviews, reviews) ||
                const DeepCollectionEquality()
                    .equals(other.reviews, reviews)) &&
            (identical(other.cover, cover) ||
                const DeepCollectionEquality().equals(other.cover, cover)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isbn) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      const DeepCollectionEquality().hash(reviews) ^
      const DeepCollectionEquality().hash(cover) ^
      runtimeType.hashCode;
}

extension $BookExtension on Book {
  Book copyWith(
      {String? isbn,
      String? title,
      String? description,
      String? author,
      DateTime? publicationDate,
      List<Review>? reviews,
      String? cover}) {
    return Book(
        isbn: isbn ?? this.isbn,
        title: title ?? this.title,
        description: description ?? this.description,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate,
        reviews: reviews ?? this.reviews,
        cover: cover ?? this.cover);
  }

  Book copyWithWrapped(
      {Wrapped<String?>? isbn,
      Wrapped<String>? title,
      Wrapped<String>? description,
      Wrapped<String>? author,
      Wrapped<DateTime>? publicationDate,
      Wrapped<List<Review>?>? reviews,
      Wrapped<String?>? cover}) {
    return Book(
        isbn: (isbn != null ? isbn.value : this.isbn),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate),
        reviews: (reviews != null ? reviews.value : this.reviews),
        cover: (cover != null ? cover.value : this.cover));
  }
}

@JsonSerializable(explicitToJson: true)
class BookBookRead {
  BookBookRead({
    this.isbn,
    required this.title,
    required this.description,
    required this.author,
    required this.publicationDate,
    this.reviews,
  });

  factory BookBookRead.fromJson(Map<String, dynamic> json) =>
      _$BookBookReadFromJson(json);

  @JsonKey(name: 'isbn', includeIfNull: false, defaultValue: '')
  final String? isbn;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime publicationDate;
  @JsonKey(
      name: 'reviews', includeIfNull: false, defaultValue: <ReviewBookRead>[])
  final List<ReviewBookRead>? reviews;
  static const fromJsonFactory = _$BookBookReadFromJson;
  static const toJsonFactory = _$BookBookReadToJson;
  Map<String, dynamic> toJson() => _$BookBookReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookBookRead &&
            (identical(other.isbn, isbn) ||
                const DeepCollectionEquality().equals(other.isbn, isbn)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)) &&
            (identical(other.reviews, reviews) ||
                const DeepCollectionEquality().equals(other.reviews, reviews)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isbn) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      const DeepCollectionEquality().hash(reviews) ^
      runtimeType.hashCode;
}

extension $BookBookReadExtension on BookBookRead {
  BookBookRead copyWith(
      {String? isbn,
      String? title,
      String? description,
      String? author,
      DateTime? publicationDate,
      List<ReviewBookRead>? reviews}) {
    return BookBookRead(
        isbn: isbn ?? this.isbn,
        title: title ?? this.title,
        description: description ?? this.description,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate,
        reviews: reviews ?? this.reviews);
  }

  BookBookRead copyWithWrapped(
      {Wrapped<String?>? isbn,
      Wrapped<String>? title,
      Wrapped<String>? description,
      Wrapped<String>? author,
      Wrapped<DateTime>? publicationDate,
      Wrapped<List<ReviewBookRead>?>? reviews}) {
    return BookBookRead(
        isbn: (isbn != null ? isbn.value : this.isbn),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate),
        reviews: (reviews != null ? reviews.value : this.reviews));
  }
}

@JsonSerializable(explicitToJson: true)
class BookReviewRead {
  BookReviewRead({
    required this.title,
  });

  factory BookReviewRead.fromJson(Map<String, dynamic> json) =>
      _$BookReviewReadFromJson(json);

  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  static const fromJsonFactory = _$BookReviewReadFromJson;
  static const toJsonFactory = _$BookReviewReadToJson;
  Map<String, dynamic> toJson() => _$BookReviewReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookReviewRead &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(title) ^ runtimeType.hashCode;
}

extension $BookReviewReadExtension on BookReviewRead {
  BookReviewRead copyWith({String? title}) {
    return BookReviewRead(title: title ?? this.title);
  }

  BookReviewRead copyWithWrapped({Wrapped<String>? title}) {
    return BookReviewRead(title: (title != null ? title.value : this.title));
  }
}

@JsonSerializable(explicitToJson: true)
class BookJsonld {
  BookJsonld({
    this.context,
    this.id,
    this.type,
    this.isbn,
    required this.title,
    required this.description,
    required this.author,
    required this.publicationDate,
    this.reviews,
    this.cover,
  });

  factory BookJsonld.fromJson(Map<String, dynamic> json) =>
      _$BookJsonldFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isbn', includeIfNull: false, defaultValue: '')
  final String? isbn;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime publicationDate;
  @JsonKey(
      name: 'reviews', includeIfNull: false, defaultValue: <ReviewJsonld>[])
  final List<ReviewJsonld>? reviews;
  @JsonKey(name: 'cover', includeIfNull: false, defaultValue: '')
  final String? cover;
  static const fromJsonFactory = _$BookJsonldFromJson;
  static const toJsonFactory = _$BookJsonldToJson;
  Map<String, dynamic> toJson() => _$BookJsonldToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookJsonld &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isbn, isbn) ||
                const DeepCollectionEquality().equals(other.isbn, isbn)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)) &&
            (identical(other.reviews, reviews) ||
                const DeepCollectionEquality()
                    .equals(other.reviews, reviews)) &&
            (identical(other.cover, cover) ||
                const DeepCollectionEquality().equals(other.cover, cover)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isbn) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      const DeepCollectionEquality().hash(reviews) ^
      const DeepCollectionEquality().hash(cover) ^
      runtimeType.hashCode;
}

extension $BookJsonldExtension on BookJsonld {
  BookJsonld copyWith(
      {dynamic context,
      String? id,
      String? type,
      String? isbn,
      String? title,
      String? description,
      String? author,
      DateTime? publicationDate,
      List<ReviewJsonld>? reviews,
      String? cover}) {
    return BookJsonld(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        isbn: isbn ?? this.isbn,
        title: title ?? this.title,
        description: description ?? this.description,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate,
        reviews: reviews ?? this.reviews,
        cover: cover ?? this.cover);
  }

  BookJsonld copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String?>? isbn,
      Wrapped<String>? title,
      Wrapped<String>? description,
      Wrapped<String>? author,
      Wrapped<DateTime>? publicationDate,
      Wrapped<List<ReviewJsonld>?>? reviews,
      Wrapped<String?>? cover}) {
    return BookJsonld(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        isbn: (isbn != null ? isbn.value : this.isbn),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate),
        reviews: (reviews != null ? reviews.value : this.reviews),
        cover: (cover != null ? cover.value : this.cover));
  }
}

@JsonSerializable(explicitToJson: true)
class BookJsonldBookRead {
  BookJsonldBookRead({
    this.context,
    this.id,
    this.type,
    this.isbn,
    required this.title,
    required this.description,
    required this.author,
    required this.publicationDate,
    this.reviews,
  });

  factory BookJsonldBookRead.fromJson(Map<String, dynamic> json) =>
      _$BookJsonldBookReadFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isbn', includeIfNull: false, defaultValue: '')
  final String? isbn;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime publicationDate;
  @JsonKey(
      name: 'reviews',
      includeIfNull: false,
      defaultValue: <ReviewJsonldBookRead>[])
  final List<ReviewJsonldBookRead>? reviews;
  static const fromJsonFactory = _$BookJsonldBookReadFromJson;
  static const toJsonFactory = _$BookJsonldBookReadToJson;
  Map<String, dynamic> toJson() => _$BookJsonldBookReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookJsonldBookRead &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isbn, isbn) ||
                const DeepCollectionEquality().equals(other.isbn, isbn)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)) &&
            (identical(other.reviews, reviews) ||
                const DeepCollectionEquality().equals(other.reviews, reviews)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isbn) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      const DeepCollectionEquality().hash(reviews) ^
      runtimeType.hashCode;
}

extension $BookJsonldBookReadExtension on BookJsonldBookRead {
  BookJsonldBookRead copyWith(
      {dynamic context,
      String? id,
      String? type,
      String? isbn,
      String? title,
      String? description,
      String? author,
      DateTime? publicationDate,
      List<ReviewJsonldBookRead>? reviews}) {
    return BookJsonldBookRead(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        isbn: isbn ?? this.isbn,
        title: title ?? this.title,
        description: description ?? this.description,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate,
        reviews: reviews ?? this.reviews);
  }

  BookJsonldBookRead copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String?>? isbn,
      Wrapped<String>? title,
      Wrapped<String>? description,
      Wrapped<String>? author,
      Wrapped<DateTime>? publicationDate,
      Wrapped<List<ReviewJsonldBookRead>?>? reviews}) {
    return BookJsonldBookRead(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        isbn: (isbn != null ? isbn.value : this.isbn),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate),
        reviews: (reviews != null ? reviews.value : this.reviews));
  }
}

@JsonSerializable(explicitToJson: true)
class BookJsonldReviewRead {
  BookJsonldReviewRead({
    this.context,
    this.id,
    this.type,
    required this.title,
  });

  factory BookJsonldReviewRead.fromJson(Map<String, dynamic> json) =>
      _$BookJsonldReviewReadFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  static const fromJsonFactory = _$BookJsonldReviewReadFromJson;
  static const toJsonFactory = _$BookJsonldReviewReadToJson;
  Map<String, dynamic> toJson() => _$BookJsonldReviewReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookJsonldReviewRead &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      runtimeType.hashCode;
}

extension $BookJsonldReviewReadExtension on BookJsonldReviewRead {
  BookJsonldReviewRead copyWith(
      {dynamic context, String? id, String? type, String? title}) {
    return BookJsonldReviewRead(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        title: title ?? this.title);
  }

  BookJsonldReviewRead copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String>? title}) {
    return BookJsonldReviewRead(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title));
  }
}

@JsonSerializable(explicitToJson: true)
class Parchment {
  Parchment({
    this.id,
    required this.title,
    required this.description,
  });

  factory Parchment.fromJson(Map<String, dynamic> json) =>
      _$ParchmentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  static const fromJsonFactory = _$ParchmentFromJson;
  static const toJsonFactory = _$ParchmentToJson;
  Map<String, dynamic> toJson() => _$ParchmentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Parchment &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $ParchmentExtension on Parchment {
  Parchment copyWith({String? id, String? title, String? description}) {
    return Parchment(
        id: id ?? this.id,
        title: title ?? this.title,
        description: description ?? this.description);
  }

  Parchment copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? title,
      Wrapped<String>? description}) {
    return Parchment(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class ParchmentJsonld {
  ParchmentJsonld({
    this.context,
    this.id,
    this.type,
    this.$id,
    required this.title,
    required this.description,
  });

  factory ParchmentJsonld.fromJson(Map<String, dynamic> json) =>
      _$ParchmentJsonldFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? $id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  static const fromJsonFactory = _$ParchmentJsonldFromJson;
  static const toJsonFactory = _$ParchmentJsonldToJson;
  Map<String, dynamic> toJson() => _$ParchmentJsonldToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ParchmentJsonld &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.$id, $id) ||
                const DeepCollectionEquality().equals(other.$id, $id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash($id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $ParchmentJsonldExtension on ParchmentJsonld {
  ParchmentJsonld copyWith(
      {dynamic context,
      String? id,
      String? type,
      String? $id,
      String? title,
      String? description}) {
    return ParchmentJsonld(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        $id: $id ?? this.$id,
        title: title ?? this.title,
        description: description ?? this.description);
  }

  ParchmentJsonld copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String?>? $id,
      Wrapped<String>? title,
      Wrapped<String>? description}) {
    return ParchmentJsonld(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        $id: ($id != null ? $id.value : this.$id),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class Review {
  Review({
    required this.body,
    required this.rating,
    this.letter,
    required this.book,
    this.author,
    this.publicationDate,
  });

  factory Review.fromJson(Map<String, dynamic> json) => _$ReviewFromJson(json);

  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  @JsonKey(name: 'rating', includeIfNull: false)
  final int rating;
  @JsonKey(name: 'letter', includeIfNull: false, defaultValue: '')
  final String? letter;
  @JsonKey(name: 'book', includeIfNull: false)
  final Book book;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime? publicationDate;
  static const fromJsonFactory = _$ReviewFromJson;
  static const toJsonFactory = _$ReviewToJson;
  Map<String, dynamic> toJson() => _$ReviewToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Review &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.letter, letter) ||
                const DeepCollectionEquality().equals(other.letter, letter)) &&
            (identical(other.book, book) ||
                const DeepCollectionEquality().equals(other.book, book)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(letter) ^
      const DeepCollectionEquality().hash(book) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      runtimeType.hashCode;
}

extension $ReviewExtension on Review {
  Review copyWith(
      {String? body,
      int? rating,
      String? letter,
      Book? book,
      String? author,
      DateTime? publicationDate}) {
    return Review(
        body: body ?? this.body,
        rating: rating ?? this.rating,
        letter: letter ?? this.letter,
        book: book ?? this.book,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate);
  }

  Review copyWithWrapped(
      {Wrapped<String>? body,
      Wrapped<int>? rating,
      Wrapped<String?>? letter,
      Wrapped<Book>? book,
      Wrapped<String?>? author,
      Wrapped<DateTime?>? publicationDate}) {
    return Review(
        body: (body != null ? body.value : this.body),
        rating: (rating != null ? rating.value : this.rating),
        letter: (letter != null ? letter.value : this.letter),
        book: (book != null ? book.value : this.book),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewBookRead {
  ReviewBookRead({
    required this.body,
  });

  factory ReviewBookRead.fromJson(Map<String, dynamic> json) =>
      _$ReviewBookReadFromJson(json);

  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  static const fromJsonFactory = _$ReviewBookReadFromJson;
  static const toJsonFactory = _$ReviewBookReadToJson;
  Map<String, dynamic> toJson() => _$ReviewBookReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewBookRead &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(body) ^ runtimeType.hashCode;
}

extension $ReviewBookReadExtension on ReviewBookRead {
  ReviewBookRead copyWith({String? body}) {
    return ReviewBookRead(body: body ?? this.body);
  }

  ReviewBookRead copyWithWrapped({Wrapped<String>? body}) {
    return ReviewBookRead(body: (body != null ? body.value : this.body));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewReviewRead {
  ReviewReviewRead({
    required this.body,
    required this.rating,
    this.letter,
    required this.book,
    this.author,
    this.publicationDate,
  });

  factory ReviewReviewRead.fromJson(Map<String, dynamic> json) =>
      _$ReviewReviewReadFromJson(json);

  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  @JsonKey(name: 'rating', includeIfNull: false)
  final int rating;
  @JsonKey(name: 'letter', includeIfNull: false, defaultValue: '')
  final String? letter;
  @JsonKey(name: 'book', includeIfNull: false)
  final BookReviewRead book;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime? publicationDate;
  static const fromJsonFactory = _$ReviewReviewReadFromJson;
  static const toJsonFactory = _$ReviewReviewReadToJson;
  Map<String, dynamic> toJson() => _$ReviewReviewReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewReviewRead &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.letter, letter) ||
                const DeepCollectionEquality().equals(other.letter, letter)) &&
            (identical(other.book, book) ||
                const DeepCollectionEquality().equals(other.book, book)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(letter) ^
      const DeepCollectionEquality().hash(book) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      runtimeType.hashCode;
}

extension $ReviewReviewReadExtension on ReviewReviewRead {
  ReviewReviewRead copyWith(
      {String? body,
      int? rating,
      String? letter,
      BookReviewRead? book,
      String? author,
      DateTime? publicationDate}) {
    return ReviewReviewRead(
        body: body ?? this.body,
        rating: rating ?? this.rating,
        letter: letter ?? this.letter,
        book: book ?? this.book,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate);
  }

  ReviewReviewRead copyWithWrapped(
      {Wrapped<String>? body,
      Wrapped<int>? rating,
      Wrapped<String?>? letter,
      Wrapped<BookReviewRead>? book,
      Wrapped<String?>? author,
      Wrapped<DateTime?>? publicationDate}) {
    return ReviewReviewRead(
        body: (body != null ? body.value : this.body),
        rating: (rating != null ? rating.value : this.rating),
        letter: (letter != null ? letter.value : this.letter),
        book: (book != null ? book.value : this.book),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewReviewWrite {
  ReviewReviewWrite({
    required this.body,
    required this.rating,
    this.letter,
    required this.book,
    this.author,
    this.publicationDate,
  });

  factory ReviewReviewWrite.fromJson(Map<String, dynamic> json) =>
      _$ReviewReviewWriteFromJson(json);

  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  @JsonKey(name: 'rating', includeIfNull: false)
  final int rating;
  @JsonKey(name: 'letter', includeIfNull: false, defaultValue: '')
  final String? letter;
  @JsonKey(name: 'book', includeIfNull: false, defaultValue: '')
  final String book;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime? publicationDate;
  static const fromJsonFactory = _$ReviewReviewWriteFromJson;
  static const toJsonFactory = _$ReviewReviewWriteToJson;
  Map<String, dynamic> toJson() => _$ReviewReviewWriteToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewReviewWrite &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.letter, letter) ||
                const DeepCollectionEquality().equals(other.letter, letter)) &&
            (identical(other.book, book) ||
                const DeepCollectionEquality().equals(other.book, book)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(letter) ^
      const DeepCollectionEquality().hash(book) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      runtimeType.hashCode;
}

extension $ReviewReviewWriteExtension on ReviewReviewWrite {
  ReviewReviewWrite copyWith(
      {String? body,
      int? rating,
      String? letter,
      String? book,
      String? author,
      DateTime? publicationDate}) {
    return ReviewReviewWrite(
        body: body ?? this.body,
        rating: rating ?? this.rating,
        letter: letter ?? this.letter,
        book: book ?? this.book,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate);
  }

  ReviewReviewWrite copyWithWrapped(
      {Wrapped<String>? body,
      Wrapped<int>? rating,
      Wrapped<String?>? letter,
      Wrapped<String>? book,
      Wrapped<String?>? author,
      Wrapped<DateTime?>? publicationDate}) {
    return ReviewReviewWrite(
        body: (body != null ? body.value : this.body),
        rating: (rating != null ? rating.value : this.rating),
        letter: (letter != null ? letter.value : this.letter),
        book: (book != null ? book.value : this.book),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewJsonld {
  ReviewJsonld({
    this.context,
    this.id,
    this.type,
    required this.body,
    required this.rating,
    this.letter,
    required this.book,
    this.author,
    this.publicationDate,
  });

  factory ReviewJsonld.fromJson(Map<String, dynamic> json) =>
      _$ReviewJsonldFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  @JsonKey(name: 'rating', includeIfNull: false)
  final int rating;
  @JsonKey(name: 'letter', includeIfNull: false, defaultValue: '')
  final String? letter;
  @JsonKey(name: 'book', includeIfNull: false)
  final BookJsonld book;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime? publicationDate;
  static const fromJsonFactory = _$ReviewJsonldFromJson;
  static const toJsonFactory = _$ReviewJsonldToJson;
  Map<String, dynamic> toJson() => _$ReviewJsonldToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewJsonld &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.letter, letter) ||
                const DeepCollectionEquality().equals(other.letter, letter)) &&
            (identical(other.book, book) ||
                const DeepCollectionEquality().equals(other.book, book)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(letter) ^
      const DeepCollectionEquality().hash(book) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      runtimeType.hashCode;
}

extension $ReviewJsonldExtension on ReviewJsonld {
  ReviewJsonld copyWith(
      {dynamic context,
      String? id,
      String? type,
      String? body,
      int? rating,
      String? letter,
      BookJsonld? book,
      String? author,
      DateTime? publicationDate}) {
    return ReviewJsonld(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        body: body ?? this.body,
        rating: rating ?? this.rating,
        letter: letter ?? this.letter,
        book: book ?? this.book,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate);
  }

  ReviewJsonld copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String>? body,
      Wrapped<int>? rating,
      Wrapped<String?>? letter,
      Wrapped<BookJsonld>? book,
      Wrapped<String?>? author,
      Wrapped<DateTime?>? publicationDate}) {
    return ReviewJsonld(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        body: (body != null ? body.value : this.body),
        rating: (rating != null ? rating.value : this.rating),
        letter: (letter != null ? letter.value : this.letter),
        book: (book != null ? book.value : this.book),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewJsonldBookRead {
  ReviewJsonldBookRead({
    this.context,
    this.id,
    this.type,
    required this.body,
  });

  factory ReviewJsonldBookRead.fromJson(Map<String, dynamic> json) =>
      _$ReviewJsonldBookReadFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  static const fromJsonFactory = _$ReviewJsonldBookReadFromJson;
  static const toJsonFactory = _$ReviewJsonldBookReadToJson;
  Map<String, dynamic> toJson() => _$ReviewJsonldBookReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewJsonldBookRead &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(body) ^
      runtimeType.hashCode;
}

extension $ReviewJsonldBookReadExtension on ReviewJsonldBookRead {
  ReviewJsonldBookRead copyWith(
      {dynamic context, String? id, String? type, String? body}) {
    return ReviewJsonldBookRead(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        body: body ?? this.body);
  }

  ReviewJsonldBookRead copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String>? body}) {
    return ReviewJsonldBookRead(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        body: (body != null ? body.value : this.body));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewJsonldReviewRead {
  ReviewJsonldReviewRead({
    this.context,
    this.id,
    this.type,
    required this.body,
    required this.rating,
    this.letter,
    required this.book,
    this.author,
    this.publicationDate,
  });

  factory ReviewJsonldReviewRead.fromJson(Map<String, dynamic> json) =>
      _$ReviewJsonldReviewReadFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  @JsonKey(name: 'rating', includeIfNull: false)
  final int rating;
  @JsonKey(name: 'letter', includeIfNull: false, defaultValue: '')
  final String? letter;
  @JsonKey(name: 'book', includeIfNull: false)
  final BookJsonldReviewRead book;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime? publicationDate;
  static const fromJsonFactory = _$ReviewJsonldReviewReadFromJson;
  static const toJsonFactory = _$ReviewJsonldReviewReadToJson;
  Map<String, dynamic> toJson() => _$ReviewJsonldReviewReadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewJsonldReviewRead &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.letter, letter) ||
                const DeepCollectionEquality().equals(other.letter, letter)) &&
            (identical(other.book, book) ||
                const DeepCollectionEquality().equals(other.book, book)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(letter) ^
      const DeepCollectionEquality().hash(book) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      runtimeType.hashCode;
}

extension $ReviewJsonldReviewReadExtension on ReviewJsonldReviewRead {
  ReviewJsonldReviewRead copyWith(
      {dynamic context,
      String? id,
      String? type,
      String? body,
      int? rating,
      String? letter,
      BookJsonldReviewRead? book,
      String? author,
      DateTime? publicationDate}) {
    return ReviewJsonldReviewRead(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        body: body ?? this.body,
        rating: rating ?? this.rating,
        letter: letter ?? this.letter,
        book: book ?? this.book,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate);
  }

  ReviewJsonldReviewRead copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String>? body,
      Wrapped<int>? rating,
      Wrapped<String?>? letter,
      Wrapped<BookJsonldReviewRead>? book,
      Wrapped<String?>? author,
      Wrapped<DateTime?>? publicationDate}) {
    return ReviewJsonldReviewRead(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        body: (body != null ? body.value : this.body),
        rating: (rating != null ? rating.value : this.rating),
        letter: (letter != null ? letter.value : this.letter),
        book: (book != null ? book.value : this.book),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewJsonldReviewWrite {
  ReviewJsonldReviewWrite({
    this.context,
    this.id,
    this.type,
    required this.body,
    required this.rating,
    this.letter,
    required this.book,
    this.author,
    this.publicationDate,
  });

  factory ReviewJsonldReviewWrite.fromJson(Map<String, dynamic> json) =>
      _$ReviewJsonldReviewWriteFromJson(json);

  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String body;
  @JsonKey(name: 'rating', includeIfNull: false)
  final int rating;
  @JsonKey(name: 'letter', includeIfNull: false, defaultValue: '')
  final String? letter;
  @JsonKey(name: 'book', includeIfNull: false, defaultValue: '')
  final String book;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'publicationDate', includeIfNull: false)
  final DateTime? publicationDate;
  static const fromJsonFactory = _$ReviewJsonldReviewWriteFromJson;
  static const toJsonFactory = _$ReviewJsonldReviewWriteToJson;
  Map<String, dynamic> toJson() => _$ReviewJsonldReviewWriteToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewJsonldReviewWrite &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.letter, letter) ||
                const DeepCollectionEquality().equals(other.letter, letter)) &&
            (identical(other.book, book) ||
                const DeepCollectionEquality().equals(other.book, book)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.publicationDate, publicationDate) ||
                const DeepCollectionEquality()
                    .equals(other.publicationDate, publicationDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(letter) ^
      const DeepCollectionEquality().hash(book) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash(publicationDate) ^
      runtimeType.hashCode;
}

extension $ReviewJsonldReviewWriteExtension on ReviewJsonldReviewWrite {
  ReviewJsonldReviewWrite copyWith(
      {dynamic context,
      String? id,
      String? type,
      String? body,
      int? rating,
      String? letter,
      String? book,
      String? author,
      DateTime? publicationDate}) {
    return ReviewJsonldReviewWrite(
        context: context ?? this.context,
        id: id ?? this.id,
        type: type ?? this.type,
        body: body ?? this.body,
        rating: rating ?? this.rating,
        letter: letter ?? this.letter,
        book: book ?? this.book,
        author: author ?? this.author,
        publicationDate: publicationDate ?? this.publicationDate);
  }

  ReviewJsonldReviewWrite copyWithWrapped(
      {Wrapped<dynamic>? context,
      Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<String>? body,
      Wrapped<int>? rating,
      Wrapped<String?>? letter,
      Wrapped<String>? book,
      Wrapped<String?>? author,
      Wrapped<DateTime?>? publicationDate}) {
    return ReviewJsonldReviewWrite(
        context: (context != null ? context.value : this.context),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        body: (body != null ? body.value : this.body),
        rating: (rating != null ? rating.value : this.rating),
        letter: (letter != null ? letter.value : this.letter),
        book: (book != null ? book.value : this.book),
        author: (author != null ? author.value : this.author),
        publicationDate: (publicationDate != null
            ? publicationDate.value
            : this.publicationDate));
  }
}

@JsonSerializable(explicitToJson: true)
class TopBook {
  TopBook({
    this.id,
    this.title,
    this.author,
    this.$part,
    this.place,
    this.borrowCount,
  });

  factory TopBook.fromJson(Map<String, dynamic> json) =>
      _$TopBookFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'part', includeIfNull: false, defaultValue: '')
  final String? $part;
  @JsonKey(name: 'place', includeIfNull: false, defaultValue: '')
  final String? place;
  @JsonKey(name: 'borrowCount', includeIfNull: false)
  final int? borrowCount;
  static const fromJsonFactory = _$TopBookFromJson;
  static const toJsonFactory = _$TopBookToJson;
  Map<String, dynamic> toJson() => _$TopBookToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopBook &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.$part, $part) ||
                const DeepCollectionEquality().equals(other.$part, $part)) &&
            (identical(other.place, place) ||
                const DeepCollectionEquality().equals(other.place, place)) &&
            (identical(other.borrowCount, borrowCount) ||
                const DeepCollectionEquality()
                    .equals(other.borrowCount, borrowCount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash($part) ^
      const DeepCollectionEquality().hash(place) ^
      const DeepCollectionEquality().hash(borrowCount) ^
      runtimeType.hashCode;
}

extension $TopBookExtension on TopBook {
  TopBook copyWith(
      {int? id,
      String? title,
      String? author,
      String? $part,
      String? place,
      int? borrowCount}) {
    return TopBook(
        id: id ?? this.id,
        title: title ?? this.title,
        author: author ?? this.author,
        $part: $part ?? this.$part,
        place: place ?? this.place,
        borrowCount: borrowCount ?? this.borrowCount);
  }

  TopBook copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? author,
      Wrapped<String?>? $part,
      Wrapped<String?>? place,
      Wrapped<int?>? borrowCount}) {
    return TopBook(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        author: (author != null ? author.value : this.author),
        $part: ($part != null ? $part.value : this.$part),
        place: (place != null ? place.value : this.place),
        borrowCount:
            (borrowCount != null ? borrowCount.value : this.borrowCount));
  }
}

@JsonSerializable(explicitToJson: true)
class TopBookJsonld {
  TopBookJsonld({
    this.id,
    this.type,
    this.context,
    this.$id,
    this.title,
    this.author,
    this.$part,
    this.place,
    this.borrowCount,
  });

  factory TopBookJsonld.fromJson(Map<String, dynamic> json) =>
      _$TopBookJsonldFromJson(json);

  @JsonKey(name: '@id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: '@type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'context', includeIfNull: false)
  final dynamic context;
  @JsonKey(name: 'id', includeIfNull: false)
  final int? $id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'author', includeIfNull: false, defaultValue: '')
  final String? author;
  @JsonKey(name: 'part', includeIfNull: false, defaultValue: '')
  final String? $part;
  @JsonKey(name: 'place', includeIfNull: false, defaultValue: '')
  final String? place;
  @JsonKey(name: 'borrowCount', includeIfNull: false)
  final int? borrowCount;
  static const fromJsonFactory = _$TopBookJsonldFromJson;
  static const toJsonFactory = _$TopBookJsonldToJson;
  Map<String, dynamic> toJson() => _$TopBookJsonldToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopBookJsonld &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.$id, $id) ||
                const DeepCollectionEquality().equals(other.$id, $id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.author, author) ||
                const DeepCollectionEquality().equals(other.author, author)) &&
            (identical(other.$part, $part) ||
                const DeepCollectionEquality().equals(other.$part, $part)) &&
            (identical(other.place, place) ||
                const DeepCollectionEquality().equals(other.place, place)) &&
            (identical(other.borrowCount, borrowCount) ||
                const DeepCollectionEquality()
                    .equals(other.borrowCount, borrowCount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash($id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(author) ^
      const DeepCollectionEquality().hash($part) ^
      const DeepCollectionEquality().hash(place) ^
      const DeepCollectionEquality().hash(borrowCount) ^
      runtimeType.hashCode;
}

extension $TopBookJsonldExtension on TopBookJsonld {
  TopBookJsonld copyWith(
      {String? id,
      String? type,
      dynamic context,
      int? $id,
      String? title,
      String? author,
      String? $part,
      String? place,
      int? borrowCount}) {
    return TopBookJsonld(
        id: id ?? this.id,
        type: type ?? this.type,
        context: context ?? this.context,
        $id: $id ?? this.$id,
        title: title ?? this.title,
        author: author ?? this.author,
        $part: $part ?? this.$part,
        place: place ?? this.place,
        borrowCount: borrowCount ?? this.borrowCount);
  }

  TopBookJsonld copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<dynamic>? context,
      Wrapped<int?>? $id,
      Wrapped<String?>? title,
      Wrapped<String?>? author,
      Wrapped<String?>? $part,
      Wrapped<String?>? place,
      Wrapped<int?>? borrowCount}) {
    return TopBookJsonld(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        context: (context != null ? context.value : this.context),
        $id: ($id != null ? $id.value : this.$id),
        title: (title != null ? title.value : this.title),
        author: (author != null ? author.value : this.author),
        $part: ($part != null ? $part.value : this.$part),
        place: (place != null ? place.value : this.place),
        borrowCount:
            (borrowCount != null ? borrowCount.value : this.borrowCount));
  }
}

String? booksGetOrderIdToJson(enums.BooksGetOrderId? booksGetOrderId) {
  return enums.$BooksGetOrderIdMap[booksGetOrderId];
}

enums.BooksGetOrderId booksGetOrderIdFromJson(
  Object? booksGetOrderId, [
  enums.BooksGetOrderId? defaultValue,
]) {
  if (booksGetOrderId is String) {
    return enums.$BooksGetOrderIdMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == booksGetOrderId.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksGetOrderId.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksGetOrderIdMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksGetOrderId.swaggerGeneratedUnknown;
}

List<String> booksGetOrderIdListToJson(
    List<enums.BooksGetOrderId>? booksGetOrderId) {
  if (booksGetOrderId == null) {
    return [];
  }

  return booksGetOrderId.map((e) => enums.$BooksGetOrderIdMap[e]!).toList();
}

List<enums.BooksGetOrderId> booksGetOrderIdListFromJson(
  List? booksGetOrderId, [
  List<enums.BooksGetOrderId>? defaultValue,
]) {
  if (booksGetOrderId == null) {
    return defaultValue ?? [];
  }

  return booksGetOrderId
      .map((e) => booksGetOrderIdFromJson(e.toString()))
      .toList();
}

List<enums.BooksGetOrderId>? booksGetOrderIdNullableListFromJson(
  List? booksGetOrderId, [
  List<enums.BooksGetOrderId>? defaultValue,
]) {
  if (booksGetOrderId == null) {
    return defaultValue;
  }

  return booksGetOrderId
      .map((e) => booksGetOrderIdFromJson(e.toString()))
      .toList();
}

String? booksGetOrderTitleToJson(enums.BooksGetOrderTitle? booksGetOrderTitle) {
  return enums.$BooksGetOrderTitleMap[booksGetOrderTitle];
}

enums.BooksGetOrderTitle booksGetOrderTitleFromJson(
  Object? booksGetOrderTitle, [
  enums.BooksGetOrderTitle? defaultValue,
]) {
  if (booksGetOrderTitle is String) {
    return enums.$BooksGetOrderTitleMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == booksGetOrderTitle.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksGetOrderTitle.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksGetOrderTitleMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksGetOrderTitle.swaggerGeneratedUnknown;
}

List<String> booksGetOrderTitleListToJson(
    List<enums.BooksGetOrderTitle>? booksGetOrderTitle) {
  if (booksGetOrderTitle == null) {
    return [];
  }

  return booksGetOrderTitle
      .map((e) => enums.$BooksGetOrderTitleMap[e]!)
      .toList();
}

List<enums.BooksGetOrderTitle> booksGetOrderTitleListFromJson(
  List? booksGetOrderTitle, [
  List<enums.BooksGetOrderTitle>? defaultValue,
]) {
  if (booksGetOrderTitle == null) {
    return defaultValue ?? [];
  }

  return booksGetOrderTitle
      .map((e) => booksGetOrderTitleFromJson(e.toString()))
      .toList();
}

List<enums.BooksGetOrderTitle>? booksGetOrderTitleNullableListFromJson(
  List? booksGetOrderTitle, [
  List<enums.BooksGetOrderTitle>? defaultValue,
]) {
  if (booksGetOrderTitle == null) {
    return defaultValue;
  }

  return booksGetOrderTitle
      .map((e) => booksGetOrderTitleFromJson(e.toString()))
      .toList();
}

String? booksGetOrderAuthorToJson(
    enums.BooksGetOrderAuthor? booksGetOrderAuthor) {
  return enums.$BooksGetOrderAuthorMap[booksGetOrderAuthor];
}

enums.BooksGetOrderAuthor booksGetOrderAuthorFromJson(
  Object? booksGetOrderAuthor, [
  enums.BooksGetOrderAuthor? defaultValue,
]) {
  if (booksGetOrderAuthor is String) {
    return enums.$BooksGetOrderAuthorMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                booksGetOrderAuthor.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksGetOrderAuthor.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksGetOrderAuthorMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksGetOrderAuthor.swaggerGeneratedUnknown;
}

List<String> booksGetOrderAuthorListToJson(
    List<enums.BooksGetOrderAuthor>? booksGetOrderAuthor) {
  if (booksGetOrderAuthor == null) {
    return [];
  }

  return booksGetOrderAuthor
      .map((e) => enums.$BooksGetOrderAuthorMap[e]!)
      .toList();
}

List<enums.BooksGetOrderAuthor> booksGetOrderAuthorListFromJson(
  List? booksGetOrderAuthor, [
  List<enums.BooksGetOrderAuthor>? defaultValue,
]) {
  if (booksGetOrderAuthor == null) {
    return defaultValue ?? [];
  }

  return booksGetOrderAuthor
      .map((e) => booksGetOrderAuthorFromJson(e.toString()))
      .toList();
}

List<enums.BooksGetOrderAuthor>? booksGetOrderAuthorNullableListFromJson(
  List? booksGetOrderAuthor, [
  List<enums.BooksGetOrderAuthor>? defaultValue,
]) {
  if (booksGetOrderAuthor == null) {
    return defaultValue;
  }

  return booksGetOrderAuthor
      .map((e) => booksGetOrderAuthorFromJson(e.toString()))
      .toList();
}

String? booksGetOrderIsbnToJson(enums.BooksGetOrderIsbn? booksGetOrderIsbn) {
  return enums.$BooksGetOrderIsbnMap[booksGetOrderIsbn];
}

enums.BooksGetOrderIsbn booksGetOrderIsbnFromJson(
  Object? booksGetOrderIsbn, [
  enums.BooksGetOrderIsbn? defaultValue,
]) {
  if (booksGetOrderIsbn is String) {
    return enums.$BooksGetOrderIsbnMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == booksGetOrderIsbn.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksGetOrderIsbn.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksGetOrderIsbnMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksGetOrderIsbn.swaggerGeneratedUnknown;
}

List<String> booksGetOrderIsbnListToJson(
    List<enums.BooksGetOrderIsbn>? booksGetOrderIsbn) {
  if (booksGetOrderIsbn == null) {
    return [];
  }

  return booksGetOrderIsbn.map((e) => enums.$BooksGetOrderIsbnMap[e]!).toList();
}

List<enums.BooksGetOrderIsbn> booksGetOrderIsbnListFromJson(
  List? booksGetOrderIsbn, [
  List<enums.BooksGetOrderIsbn>? defaultValue,
]) {
  if (booksGetOrderIsbn == null) {
    return defaultValue ?? [];
  }

  return booksGetOrderIsbn
      .map((e) => booksGetOrderIsbnFromJson(e.toString()))
      .toList();
}

List<enums.BooksGetOrderIsbn>? booksGetOrderIsbnNullableListFromJson(
  List? booksGetOrderIsbn, [
  List<enums.BooksGetOrderIsbn>? defaultValue,
]) {
  if (booksGetOrderIsbn == null) {
    return defaultValue;
  }

  return booksGetOrderIsbn
      .map((e) => booksGetOrderIsbnFromJson(e.toString()))
      .toList();
}

String? booksGetOrderPublicationDateToJson(
    enums.BooksGetOrderPublicationDate? booksGetOrderPublicationDate) {
  return enums.$BooksGetOrderPublicationDateMap[booksGetOrderPublicationDate];
}

enums.BooksGetOrderPublicationDate booksGetOrderPublicationDateFromJson(
  Object? booksGetOrderPublicationDate, [
  enums.BooksGetOrderPublicationDate? defaultValue,
]) {
  if (booksGetOrderPublicationDate is String) {
    return enums.$BooksGetOrderPublicationDateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                booksGetOrderPublicationDate.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksGetOrderPublicationDate.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksGetOrderPublicationDateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksGetOrderPublicationDate.swaggerGeneratedUnknown;
}

List<String> booksGetOrderPublicationDateListToJson(
    List<enums.BooksGetOrderPublicationDate>? booksGetOrderPublicationDate) {
  if (booksGetOrderPublicationDate == null) {
    return [];
  }

  return booksGetOrderPublicationDate
      .map((e) => enums.$BooksGetOrderPublicationDateMap[e]!)
      .toList();
}

List<enums.BooksGetOrderPublicationDate>
    booksGetOrderPublicationDateListFromJson(
  List? booksGetOrderPublicationDate, [
  List<enums.BooksGetOrderPublicationDate>? defaultValue,
]) {
  if (booksGetOrderPublicationDate == null) {
    return defaultValue ?? [];
  }

  return booksGetOrderPublicationDate
      .map((e) => booksGetOrderPublicationDateFromJson(e.toString()))
      .toList();
}

List<enums.BooksGetOrderPublicationDate>?
    booksGetOrderPublicationDateNullableListFromJson(
  List? booksGetOrderPublicationDate, [
  List<enums.BooksGetOrderPublicationDate>? defaultValue,
]) {
  if (booksGetOrderPublicationDate == null) {
    return defaultValue;
  }

  return booksGetOrderPublicationDate
      .map((e) => booksGetOrderPublicationDateFromJson(e.toString()))
      .toList();
}

String? booksIdReviewsGetOrderIdToJson(
    enums.BooksIdReviewsGetOrderId? booksIdReviewsGetOrderId) {
  return enums.$BooksIdReviewsGetOrderIdMap[booksIdReviewsGetOrderId];
}

enums.BooksIdReviewsGetOrderId booksIdReviewsGetOrderIdFromJson(
  Object? booksIdReviewsGetOrderId, [
  enums.BooksIdReviewsGetOrderId? defaultValue,
]) {
  if (booksIdReviewsGetOrderId is String) {
    return enums.$BooksIdReviewsGetOrderIdMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                booksIdReviewsGetOrderId.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksIdReviewsGetOrderId.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksIdReviewsGetOrderIdMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksIdReviewsGetOrderId.swaggerGeneratedUnknown;
}

List<String> booksIdReviewsGetOrderIdListToJson(
    List<enums.BooksIdReviewsGetOrderId>? booksIdReviewsGetOrderId) {
  if (booksIdReviewsGetOrderId == null) {
    return [];
  }

  return booksIdReviewsGetOrderId
      .map((e) => enums.$BooksIdReviewsGetOrderIdMap[e]!)
      .toList();
}

List<enums.BooksIdReviewsGetOrderId> booksIdReviewsGetOrderIdListFromJson(
  List? booksIdReviewsGetOrderId, [
  List<enums.BooksIdReviewsGetOrderId>? defaultValue,
]) {
  if (booksIdReviewsGetOrderId == null) {
    return defaultValue ?? [];
  }

  return booksIdReviewsGetOrderId
      .map((e) => booksIdReviewsGetOrderIdFromJson(e.toString()))
      .toList();
}

List<enums.BooksIdReviewsGetOrderId>?
    booksIdReviewsGetOrderIdNullableListFromJson(
  List? booksIdReviewsGetOrderId, [
  List<enums.BooksIdReviewsGetOrderId>? defaultValue,
]) {
  if (booksIdReviewsGetOrderId == null) {
    return defaultValue;
  }

  return booksIdReviewsGetOrderId
      .map((e) => booksIdReviewsGetOrderIdFromJson(e.toString()))
      .toList();
}

String? booksIdReviewsGetOrderPublicationDateToJson(
    enums.BooksIdReviewsGetOrderPublicationDate?
        booksIdReviewsGetOrderPublicationDate) {
  return enums.$BooksIdReviewsGetOrderPublicationDateMap[
      booksIdReviewsGetOrderPublicationDate];
}

enums.BooksIdReviewsGetOrderPublicationDate
    booksIdReviewsGetOrderPublicationDateFromJson(
  Object? booksIdReviewsGetOrderPublicationDate, [
  enums.BooksIdReviewsGetOrderPublicationDate? defaultValue,
]) {
  if (booksIdReviewsGetOrderPublicationDate is String) {
    return enums.$BooksIdReviewsGetOrderPublicationDateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                booksIdReviewsGetOrderPublicationDate.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BooksIdReviewsGetOrderPublicationDate
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BooksIdReviewsGetOrderPublicationDateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BooksIdReviewsGetOrderPublicationDate.swaggerGeneratedUnknown;
}

List<String> booksIdReviewsGetOrderPublicationDateListToJson(
    List<enums.BooksIdReviewsGetOrderPublicationDate>?
        booksIdReviewsGetOrderPublicationDate) {
  if (booksIdReviewsGetOrderPublicationDate == null) {
    return [];
  }

  return booksIdReviewsGetOrderPublicationDate
      .map((e) => enums.$BooksIdReviewsGetOrderPublicationDateMap[e]!)
      .toList();
}

List<enums.BooksIdReviewsGetOrderPublicationDate>
    booksIdReviewsGetOrderPublicationDateListFromJson(
  List? booksIdReviewsGetOrderPublicationDate, [
  List<enums.BooksIdReviewsGetOrderPublicationDate>? defaultValue,
]) {
  if (booksIdReviewsGetOrderPublicationDate == null) {
    return defaultValue ?? [];
  }

  return booksIdReviewsGetOrderPublicationDate
      .map((e) => booksIdReviewsGetOrderPublicationDateFromJson(e.toString()))
      .toList();
}

List<enums.BooksIdReviewsGetOrderPublicationDate>?
    booksIdReviewsGetOrderPublicationDateNullableListFromJson(
  List? booksIdReviewsGetOrderPublicationDate, [
  List<enums.BooksIdReviewsGetOrderPublicationDate>? defaultValue,
]) {
  if (booksIdReviewsGetOrderPublicationDate == null) {
    return defaultValue;
  }

  return booksIdReviewsGetOrderPublicationDate
      .map((e) => booksIdReviewsGetOrderPublicationDateFromJson(e.toString()))
      .toList();
}

String? reviewsGetOrderIdToJson(enums.ReviewsGetOrderId? reviewsGetOrderId) {
  return enums.$ReviewsGetOrderIdMap[reviewsGetOrderId];
}

enums.ReviewsGetOrderId reviewsGetOrderIdFromJson(
  Object? reviewsGetOrderId, [
  enums.ReviewsGetOrderId? defaultValue,
]) {
  if (reviewsGetOrderId is String) {
    return enums.$ReviewsGetOrderIdMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == reviewsGetOrderId.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReviewsGetOrderId.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReviewsGetOrderIdMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReviewsGetOrderId.swaggerGeneratedUnknown;
}

List<String> reviewsGetOrderIdListToJson(
    List<enums.ReviewsGetOrderId>? reviewsGetOrderId) {
  if (reviewsGetOrderId == null) {
    return [];
  }

  return reviewsGetOrderId.map((e) => enums.$ReviewsGetOrderIdMap[e]!).toList();
}

List<enums.ReviewsGetOrderId> reviewsGetOrderIdListFromJson(
  List? reviewsGetOrderId, [
  List<enums.ReviewsGetOrderId>? defaultValue,
]) {
  if (reviewsGetOrderId == null) {
    return defaultValue ?? [];
  }

  return reviewsGetOrderId
      .map((e) => reviewsGetOrderIdFromJson(e.toString()))
      .toList();
}

List<enums.ReviewsGetOrderId>? reviewsGetOrderIdNullableListFromJson(
  List? reviewsGetOrderId, [
  List<enums.ReviewsGetOrderId>? defaultValue,
]) {
  if (reviewsGetOrderId == null) {
    return defaultValue;
  }

  return reviewsGetOrderId
      .map((e) => reviewsGetOrderIdFromJson(e.toString()))
      .toList();
}

String? reviewsGetOrderPublicationDateToJson(
    enums.ReviewsGetOrderPublicationDate? reviewsGetOrderPublicationDate) {
  return enums
      .$ReviewsGetOrderPublicationDateMap[reviewsGetOrderPublicationDate];
}

enums.ReviewsGetOrderPublicationDate reviewsGetOrderPublicationDateFromJson(
  Object? reviewsGetOrderPublicationDate, [
  enums.ReviewsGetOrderPublicationDate? defaultValue,
]) {
  if (reviewsGetOrderPublicationDate is String) {
    return enums.$ReviewsGetOrderPublicationDateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                reviewsGetOrderPublicationDate.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReviewsGetOrderPublicationDate.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReviewsGetOrderPublicationDateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReviewsGetOrderPublicationDate.swaggerGeneratedUnknown;
}

List<String> reviewsGetOrderPublicationDateListToJson(
    List<enums.ReviewsGetOrderPublicationDate>?
        reviewsGetOrderPublicationDate) {
  if (reviewsGetOrderPublicationDate == null) {
    return [];
  }

  return reviewsGetOrderPublicationDate
      .map((e) => enums.$ReviewsGetOrderPublicationDateMap[e]!)
      .toList();
}

List<enums.ReviewsGetOrderPublicationDate>
    reviewsGetOrderPublicationDateListFromJson(
  List? reviewsGetOrderPublicationDate, [
  List<enums.ReviewsGetOrderPublicationDate>? defaultValue,
]) {
  if (reviewsGetOrderPublicationDate == null) {
    return defaultValue ?? [];
  }

  return reviewsGetOrderPublicationDate
      .map((e) => reviewsGetOrderPublicationDateFromJson(e.toString()))
      .toList();
}

List<enums.ReviewsGetOrderPublicationDate>?
    reviewsGetOrderPublicationDateNullableListFromJson(
  List? reviewsGetOrderPublicationDate, [
  List<enums.ReviewsGetOrderPublicationDate>? defaultValue,
]) {
  if (reviewsGetOrderPublicationDate == null) {
    return defaultValue;
  }

  return reviewsGetOrderPublicationDate
      .map((e) => reviewsGetOrderPublicationDateFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
