// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'epg_application_service.enums.swagger.dart' as enums;
export 'epg_application_service.enums.swagger.dart';

part 'epg_application_service.swagger.chopper.dart';
part 'epg_application_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class EpgApplicationService extends ChopperService {
  static EpgApplicationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$EpgApplicationService(client);
    }

    final newClient = ChopperClient(
        services: [_$EpgApplicationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://localhost:10014/epg');
    return _$EpgApplicationService(newClient);
  }

  ///Returns (non detailed) EPG events for a specified time range.
  ///
  ///@param params
  Future<chopper.Response<List<ChannelWithEvents>>> getEPGEventsPut({
    required GetEPGEventsParams? params,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GetEPGEventsParams, () => GetEPGEventsParams.fromJsonFactory);
    generatedMapping.putIfAbsent(
        ChannelWithEvents, () => ChannelWithEvents.fromJsonFactory);

    return _getEPGEventsPut(params: params, cacheControl: cacheControl);
  }

  ///Returns (non detailed) EPG events for a specified time range.
  ///
  ///@param params
  @Put(path: '/getEPGEvents')
  Future<chopper.Response<List<ChannelWithEvents>>> _getEPGEventsPut({
    @Body() required GetEPGEventsParams? params,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns (non detailed) EPG events for a given channel at a given time with a specified number of events around it (before and after).
  ///
  ///@param params
  Future<chopper.Response<GetEPGEventsAroundResponse>> getEPGEventsAroundPut({
    required GetEPGEventsAroundParams? params,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GetEPGEventsAroundParams,
        () => GetEPGEventsAroundParams.fromJsonFactory);
    generatedMapping.putIfAbsent(GetEPGEventsAroundResponse,
        () => GetEPGEventsAroundResponse.fromJsonFactory);

    return _getEPGEventsAroundPut(params: params, cacheControl: cacheControl);
  }

  ///Returns (non detailed) EPG events for a given channel at a given time with a specified number of events around it (before and after).
  ///
  ///@param params
  @Put(path: '/getEPGEventsAround')
  Future<chopper.Response<GetEPGEventsAroundResponse>> _getEPGEventsAroundPut({
    @Body() required GetEPGEventsAroundParams? params,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns detailed event info.
  ///
  ///@param params
  Future<chopper.Response<DetailedEvent>> getDetailedEventPut({
    required GetDetailedEventParams? params,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GetDetailedEventParams, () => GetDetailedEventParams.fromJsonFactory);
    generatedMapping.putIfAbsent(
        DetailedEvent, () => DetailedEvent.fromJsonFactory);

    return _getDetailedEventPut(params: params, cacheControl: cacheControl);
  }

  ///Returns detailed event info.
  ///
  ///@param params
  @Put(path: '/getDetailedEvent')
  Future<chopper.Response<DetailedEvent>> _getDetailedEventPut({
    @Body() required GetDetailedEventParams? params,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns detailed events info.
  ///
  ///@param params
  Future<chopper.Response<List<DetailedEvent>>> getDetailedEventsPut({
    required List<GetDetailedEventParams>? params,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DetailedEvent, () => DetailedEvent.fromJsonFactory);

    return _getDetailedEventsPut(params: params, cacheControl: cacheControl);
  }

  ///Returns detailed events info.
  ///
  ///@param params
  @Put(path: '/getDetailedEvents')
  Future<chopper.Response<List<DetailedEvent>>> _getDetailedEventsPut({
    @Body() required List<GetDetailedEventParams>? params,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns bounds of cached EPG events.
  ///
  Future<chopper.Response<CacheBounds>> getCacheBoundsGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        CacheBounds, () => CacheBounds.fromJsonFactory);

    return _getCacheBoundsGet(cacheControl: cacheControl);
  }

  ///Returns bounds of cached EPG events.
  ///
  @Get(path: '/getCacheBounds')
  Future<chopper.Response<CacheBounds>> _getCacheBoundsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///EPG events change event.
  Future<chopper.Response<ChangeEvent>> eventsChangeGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ChangeEvent, () => ChangeEvent.fromJsonFactory);

    return _eventsChangeGet(cacheControl: cacheControl);
  }

  ///EPG events change event.
  @Get(path: '/eventsChange')
  Future<chopper.Response<ChangeEvent>> _eventsChangeGet(
      {@Header('Cache-Control') String? cacheControl});

  ///EPG events cache bounds change event.
  Future<chopper.Response<CacheBounds>> cacheBoundsChangeGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        CacheBounds, () => CacheBounds.fromJsonFactory);

    return _cacheBoundsChangeGet(cacheControl: cacheControl);
  }

  ///EPG events cache bounds change event.
  @Get(path: '/cacheBoundsChange')
  Future<chopper.Response<CacheBounds>> _cacheBoundsChangeGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.message,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({String? message}) {
    return ErrorResponse(message: message ?? this.message);
  }

  ErrorResponse copyWithWrapped({Wrapped<String>? message}) {
    return ErrorResponse(
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class CacheBounds {
  CacheBounds({
    required this.startTime,
    required this.endTime,
  });

  factory CacheBounds.fromJson(Map<String, dynamic> json) =>
      _$CacheBoundsFromJson(json);

  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num endTime;
  static const fromJsonFactory = _$CacheBoundsFromJson;
  static const toJsonFactory = _$CacheBoundsToJson;
  Map<String, dynamic> toJson() => _$CacheBoundsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CacheBounds &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality().equals(other.endTime, endTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      runtimeType.hashCode;
}

extension $CacheBoundsExtension on CacheBounds {
  CacheBounds copyWith({num? startTime, num? endTime}) {
    return CacheBounds(
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime);
  }

  CacheBounds copyWithWrapped(
      {Wrapped<num>? startTime, Wrapped<num>? endTime}) {
    return CacheBounds(
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ChangeEvent {
  ChangeEvent({
    this.channelIds,
    this.startTime,
    this.endTime,
  });

  factory ChangeEvent.fromJson(Map<String, dynamic> json) =>
      _$ChangeEventFromJson(json);

  @JsonKey(name: 'channelIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? channelIds;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num? endTime;
  static const fromJsonFactory = _$ChangeEventFromJson;
  static const toJsonFactory = _$ChangeEventToJson;
  Map<String, dynamic> toJson() => _$ChangeEventToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChangeEvent &&
            (identical(other.channelIds, channelIds) ||
                const DeepCollectionEquality()
                    .equals(other.channelIds, channelIds)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality().equals(other.endTime, endTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelIds) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      runtimeType.hashCode;
}

extension $ChangeEventExtension on ChangeEvent {
  ChangeEvent copyWith(
      {List<String>? channelIds, num? startTime, num? endTime}) {
    return ChangeEvent(
        channelIds: channelIds ?? this.channelIds,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime);
  }

  ChangeEvent copyWithWrapped(
      {Wrapped<List<String>?>? channelIds,
      Wrapped<num?>? startTime,
      Wrapped<num?>? endTime}) {
    return ChangeEvent(
        channelIds: (channelIds != null ? channelIds.value : this.channelIds),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelWithEvents {
  ChannelWithEvents({
    this.channelId,
    this.events,
  });

  factory ChannelWithEvents.fromJson(Map<String, dynamic> json) =>
      _$ChannelWithEventsFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'events', includeIfNull: false, defaultValue: <Event>[])
  final List<Event>? events;
  static const fromJsonFactory = _$ChannelWithEventsFromJson;
  static const toJsonFactory = _$ChannelWithEventsToJson;
  Map<String, dynamic> toJson() => _$ChannelWithEventsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelWithEvents &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(events) ^
      runtimeType.hashCode;
}

extension $ChannelWithEventsExtension on ChannelWithEvents {
  ChannelWithEvents copyWith({String? channelId, List<Event>? events}) {
    return ChannelWithEvents(
        channelId: channelId ?? this.channelId, events: events ?? this.events);
  }

  ChannelWithEvents copyWithWrapped(
      {Wrapped<String?>? channelId, Wrapped<List<Event>?>? events}) {
    return ChannelWithEvents(
        channelId: (channelId != null ? channelId.value : this.channelId),
        events: (events != null ? events.value : this.events));
  }
}

@JsonSerializable(explicitToJson: true)
class Event {
  Event({
    required this.eventId,
    required this.channelId,
    this.mergedId,
    required this.title,
    required this.startTime,
    required this.endTime,
    this.minimumAge,
    this.replayTVMinAge,
    this.replayTVAdult,
    this.seriesId,
    this.parentSeriesId,
    this.seriesName,
    this.seasonNumber,
    this.episodeNumber,
    this.isAdult,
    this.hasReplayTV,
    this.hasStartOver,
    this.isOpen,
    this.isPurchasable,
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.replayTVDisplayAge,
    this.audioLanguages,
    this.signLanguages,
  });

  factory Event.fromJson(Map<String, dynamic> json) => _$EventFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num endTime;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'replayTVMinAge', includeIfNull: false)
  final int? replayTVMinAge;
  @JsonKey(name: 'replayTVAdult', includeIfNull: false)
  final bool? replayTVAdult;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'hasReplayTV', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTV;
  @JsonKey(name: 'hasStartOver', includeIfNull: false, defaultValue: true)
  final bool? hasStartOver;
  @JsonKey(name: 'isOpen', includeIfNull: false)
  final bool? isOpen;
  @JsonKey(name: 'isPurchasable', includeIfNull: false, defaultValue: false)
  final bool? isPurchasable;
  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final num? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final num? replayAvailabilityEnd;
  @JsonKey(
      name: 'replayTVDisplayAge', includeIfNull: false, defaultValue: false)
  final bool? replayTVDisplayAge;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  static const fromJsonFactory = _$EventFromJson;
  static const toJsonFactory = _$EventToJson;
  Map<String, dynamic> toJson() => _$EventToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Event &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.replayTVMinAge, replayTVMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayTVMinAge, replayTVMinAge)) &&
            (identical(other.replayTVAdult, replayTVAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayTVAdult, replayTVAdult)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.hasReplayTV, hasReplayTV) ||
                const DeepCollectionEquality()
                    .equals(other.hasReplayTV, hasReplayTV)) &&
            (identical(other.hasStartOver, hasStartOver) ||
                const DeepCollectionEquality()
                    .equals(other.hasStartOver, hasStartOver)) &&
            (identical(other.isOpen, isOpen) ||
                const DeepCollectionEquality().equals(other.isOpen, isOpen)) &&
            (identical(other.isPurchasable, isPurchasable) ||
                const DeepCollectionEquality()
                    .equals(other.isPurchasable, isPurchasable)) &&
            (identical(other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.replayTVDisplayAge, replayTVDisplayAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayTVDisplayAge, replayTVDisplayAge)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(replayTVMinAge) ^
      const DeepCollectionEquality().hash(replayTVAdult) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(hasReplayTV) ^
      const DeepCollectionEquality().hash(hasStartOver) ^
      const DeepCollectionEquality().hash(isOpen) ^
      const DeepCollectionEquality().hash(isPurchasable) ^
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(replayTVDisplayAge) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      runtimeType.hashCode;
}

extension $EventExtension on Event {
  Event copyWith(
      {String? eventId,
      String? channelId,
      String? mergedId,
      String? title,
      num? startTime,
      num? endTime,
      int? minimumAge,
      int? replayTVMinAge,
      bool? replayTVAdult,
      String? seriesId,
      String? parentSeriesId,
      String? seriesName,
      int? seasonNumber,
      int? episodeNumber,
      bool? isAdult,
      bool? hasReplayTV,
      bool? hasStartOver,
      bool? isOpen,
      bool? isPurchasable,
      num? replayAvailabilityStart,
      num? replayAvailabilityEnd,
      bool? replayTVDisplayAge,
      List<AudioLanguage>? audioLanguages,
      List<SignLanguage>? signLanguages}) {
    return Event(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        mergedId: mergedId ?? this.mergedId,
        title: title ?? this.title,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        minimumAge: minimumAge ?? this.minimumAge,
        replayTVMinAge: replayTVMinAge ?? this.replayTVMinAge,
        replayTVAdult: replayTVAdult ?? this.replayTVAdult,
        seriesId: seriesId ?? this.seriesId,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        isAdult: isAdult ?? this.isAdult,
        hasReplayTV: hasReplayTV ?? this.hasReplayTV,
        hasStartOver: hasStartOver ?? this.hasStartOver,
        isOpen: isOpen ?? this.isOpen,
        isPurchasable: isPurchasable ?? this.isPurchasable,
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        replayTVDisplayAge: replayTVDisplayAge ?? this.replayTVDisplayAge,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        signLanguages: signLanguages ?? this.signLanguages);
  }

  Event copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<String?>? mergedId,
      Wrapped<String>? title,
      Wrapped<num>? startTime,
      Wrapped<num>? endTime,
      Wrapped<int?>? minimumAge,
      Wrapped<int?>? replayTVMinAge,
      Wrapped<bool?>? replayTVAdult,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? hasReplayTV,
      Wrapped<bool?>? hasStartOver,
      Wrapped<bool?>? isOpen,
      Wrapped<bool?>? isPurchasable,
      Wrapped<num?>? replayAvailabilityStart,
      Wrapped<num?>? replayAvailabilityEnd,
      Wrapped<bool?>? replayTVDisplayAge,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages}) {
    return Event(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        title: (title != null ? title.value : this.title),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        replayTVMinAge: (replayTVMinAge != null
            ? replayTVMinAge.value
            : this.replayTVMinAge),
        replayTVAdult:
            (replayTVAdult != null ? replayTVAdult.value : this.replayTVAdult),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        hasReplayTV:
            (hasReplayTV != null ? hasReplayTV.value : this.hasReplayTV),
        hasStartOver:
            (hasStartOver != null ? hasStartOver.value : this.hasStartOver),
        isOpen: (isOpen != null ? isOpen.value : this.isOpen),
        isPurchasable:
            (isPurchasable != null ? isPurchasable.value : this.isPurchasable),
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        replayTVDisplayAge: (replayTVDisplayAge != null
            ? replayTVDisplayAge.value
            : this.replayTVDisplayAge),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages));
  }
}

@JsonSerializable(explicitToJson: true)
class DetailedEvent {
  DetailedEvent({
    this.shortDescription,
    this.longDescription,
    this.actors,
    this.directors,
    this.producers,
    this.audioType,
    this.captionLanguages,
    this.productionDate,
    this.countryOfOrigin,
    this.wall,
    this.poster,
    this.titleTreatment,
    this.genres,
    this.resolution,
    this.isLive,
    this.actualStartOffset,
    this.actualEndOffset,
    required this.eventId,
    required this.channelId,
    this.mergedId,
    required this.title,
    required this.startTime,
    required this.endTime,
    this.minimumAge,
    this.replayTVMinAge,
    this.replayTVAdult,
    this.seriesId,
    this.parentSeriesId,
    this.seriesName,
    this.seasonNumber,
    this.episodeNumber,
    this.isAdult,
    this.hasReplayTV,
    this.hasStartOver,
    this.isOpen,
    this.isPurchasable,
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.replayTVDisplayAge,
    this.audioLanguages,
    this.signLanguages,
  });

  factory DetailedEvent.fromJson(Map<String, dynamic> json) =>
      _$DetailedEventFromJson(json);

  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'actors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? actors;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'producers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? producers;
  @JsonKey(name: 'audioType', includeIfNull: false)
  final int? audioType;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <CaptionLanguage>[])
  final List<CaptionLanguage>? captionLanguages;
  @JsonKey(name: 'productionDate', includeIfNull: false, defaultValue: '')
  final String? productionDate;
  @JsonKey(name: 'countryOfOrigin', includeIfNull: false, defaultValue: '')
  final String? countryOfOrigin;
  @JsonKey(name: 'wall', includeIfNull: false, defaultValue: '')
  final String? wall;
  @JsonKey(name: 'poster', includeIfNull: false, defaultValue: '')
  final String? poster;
  @JsonKey(name: 'titleTreatment', includeIfNull: false, defaultValue: '')
  final String? titleTreatment;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(
    name: 'resolution',
    includeIfNull: false,
    toJson: detailedEventResolutionToJson,
    fromJson: detailedEventResolutionFromJson,
  )
  final enums.DetailedEventResolution? resolution;
  @JsonKey(name: 'isLive', includeIfNull: false)
  final bool? isLive;
  @JsonKey(name: 'actualStartOffset', includeIfNull: false)
  final num? actualStartOffset;
  @JsonKey(name: 'actualEndOffset', includeIfNull: false)
  final num? actualEndOffset;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num endTime;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'replayTVMinAge', includeIfNull: false)
  final int? replayTVMinAge;
  @JsonKey(name: 'replayTVAdult', includeIfNull: false)
  final bool? replayTVAdult;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'hasReplayTV', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTV;
  @JsonKey(name: 'hasStartOver', includeIfNull: false, defaultValue: true)
  final bool? hasStartOver;
  @JsonKey(name: 'isOpen', includeIfNull: false)
  final bool? isOpen;
  @JsonKey(name: 'isPurchasable', includeIfNull: false, defaultValue: false)
  final bool? isPurchasable;
  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final num? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final num? replayAvailabilityEnd;
  @JsonKey(
      name: 'replayTVDisplayAge', includeIfNull: false, defaultValue: false)
  final bool? replayTVDisplayAge;
  @JsonKey(
      name: 'audioLanguages',
      includeIfNull: false,
      defaultValue: <AudioLanguage>[])
  final List<AudioLanguage>? audioLanguages;
  @JsonKey(
      name: 'signLanguages',
      includeIfNull: false,
      defaultValue: <SignLanguage>[])
  final List<SignLanguage>? signLanguages;
  static const fromJsonFactory = _$DetailedEventFromJson;
  static const toJsonFactory = _$DetailedEventToJson;
  Map<String, dynamic> toJson() => _$DetailedEventToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DetailedEvent &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.longDescription, longDescription) ||
                const DeepCollectionEquality()
                    .equals(other.longDescription, longDescription)) &&
            (identical(other.actors, actors) ||
                const DeepCollectionEquality().equals(other.actors, actors)) &&
            (identical(other.directors, directors) ||
                const DeepCollectionEquality()
                    .equals(other.directors, directors)) &&
            (identical(other.producers, producers) ||
                const DeepCollectionEquality()
                    .equals(other.producers, producers)) &&
            (identical(other.audioType, audioType) ||
                const DeepCollectionEquality()
                    .equals(other.audioType, audioType)) &&
            (identical(other.captionLanguages, captionLanguages) ||
                const DeepCollectionEquality()
                    .equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.productionDate, productionDate) ||
                const DeepCollectionEquality()
                    .equals(other.productionDate, productionDate)) &&
            (identical(other.countryOfOrigin, countryOfOrigin) ||
                const DeepCollectionEquality()
                    .equals(other.countryOfOrigin, countryOfOrigin)) &&
            (identical(other.wall, wall) ||
                const DeepCollectionEquality().equals(other.wall, wall)) &&
            (identical(other.poster, poster) ||
                const DeepCollectionEquality().equals(other.poster, poster)) &&
            (identical(other.titleTreatment, titleTreatment) ||
                const DeepCollectionEquality()
                    .equals(other.titleTreatment, titleTreatment)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.isLive, isLive) ||
                const DeepCollectionEquality().equals(other.isLive, isLive)) &&
            (identical(other.actualStartOffset, actualStartOffset) ||
                const DeepCollectionEquality()
                    .equals(other.actualStartOffset, actualStartOffset)) &&
            (identical(other.actualEndOffset, actualEndOffset) ||
                const DeepCollectionEquality()
                    .equals(other.actualEndOffset, actualEndOffset)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.replayTVMinAge, replayTVMinAge) ||
                const DeepCollectionEquality().equals(other.replayTVMinAge, replayTVMinAge)) &&
            (identical(other.replayTVAdult, replayTVAdult) || const DeepCollectionEquality().equals(other.replayTVAdult, replayTVAdult)) &&
            (identical(other.seriesId, seriesId) || const DeepCollectionEquality().equals(other.seriesId, seriesId)) &&
            (identical(other.parentSeriesId, parentSeriesId) || const DeepCollectionEquality().equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesName, seriesName) || const DeepCollectionEquality().equals(other.seriesName, seriesName)) &&
            (identical(other.seasonNumber, seasonNumber) || const DeepCollectionEquality().equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) || const DeepCollectionEquality().equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.isAdult, isAdult) || const DeepCollectionEquality().equals(other.isAdult, isAdult)) &&
            (identical(other.hasReplayTV, hasReplayTV) || const DeepCollectionEquality().equals(other.hasReplayTV, hasReplayTV)) &&
            (identical(other.hasStartOver, hasStartOver) || const DeepCollectionEquality().equals(other.hasStartOver, hasStartOver)) &&
            (identical(other.isOpen, isOpen) || const DeepCollectionEquality().equals(other.isOpen, isOpen)) &&
            (identical(other.isPurchasable, isPurchasable) || const DeepCollectionEquality().equals(other.isPurchasable, isPurchasable)) &&
            (identical(other.replayAvailabilityStart, replayAvailabilityStart) || const DeepCollectionEquality().equals(other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) || const DeepCollectionEquality().equals(other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.replayTVDisplayAge, replayTVDisplayAge) || const DeepCollectionEquality().equals(other.replayTVDisplayAge, replayTVDisplayAge)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(actors) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(producers) ^
      const DeepCollectionEquality().hash(audioType) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(productionDate) ^
      const DeepCollectionEquality().hash(countryOfOrigin) ^
      const DeepCollectionEquality().hash(wall) ^
      const DeepCollectionEquality().hash(poster) ^
      const DeepCollectionEquality().hash(titleTreatment) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(isLive) ^
      const DeepCollectionEquality().hash(actualStartOffset) ^
      const DeepCollectionEquality().hash(actualEndOffset) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(replayTVMinAge) ^
      const DeepCollectionEquality().hash(replayTVAdult) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(hasReplayTV) ^
      const DeepCollectionEquality().hash(hasStartOver) ^
      const DeepCollectionEquality().hash(isOpen) ^
      const DeepCollectionEquality().hash(isPurchasable) ^
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(replayTVDisplayAge) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      runtimeType.hashCode;
}

extension $DetailedEventExtension on DetailedEvent {
  DetailedEvent copyWith(
      {String? shortDescription,
      String? longDescription,
      List<String>? actors,
      List<String>? directors,
      List<String>? producers,
      int? audioType,
      List<CaptionLanguage>? captionLanguages,
      String? productionDate,
      String? countryOfOrigin,
      String? wall,
      String? poster,
      String? titleTreatment,
      List<String>? genres,
      enums.DetailedEventResolution? resolution,
      bool? isLive,
      num? actualStartOffset,
      num? actualEndOffset,
      String? eventId,
      String? channelId,
      String? mergedId,
      String? title,
      num? startTime,
      num? endTime,
      int? minimumAge,
      int? replayTVMinAge,
      bool? replayTVAdult,
      String? seriesId,
      String? parentSeriesId,
      String? seriesName,
      int? seasonNumber,
      int? episodeNumber,
      bool? isAdult,
      bool? hasReplayTV,
      bool? hasStartOver,
      bool? isOpen,
      bool? isPurchasable,
      num? replayAvailabilityStart,
      num? replayAvailabilityEnd,
      bool? replayTVDisplayAge,
      List<AudioLanguage>? audioLanguages,
      List<SignLanguage>? signLanguages}) {
    return DetailedEvent(
        shortDescription: shortDescription ?? this.shortDescription,
        longDescription: longDescription ?? this.longDescription,
        actors: actors ?? this.actors,
        directors: directors ?? this.directors,
        producers: producers ?? this.producers,
        audioType: audioType ?? this.audioType,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        productionDate: productionDate ?? this.productionDate,
        countryOfOrigin: countryOfOrigin ?? this.countryOfOrigin,
        wall: wall ?? this.wall,
        poster: poster ?? this.poster,
        titleTreatment: titleTreatment ?? this.titleTreatment,
        genres: genres ?? this.genres,
        resolution: resolution ?? this.resolution,
        isLive: isLive ?? this.isLive,
        actualStartOffset: actualStartOffset ?? this.actualStartOffset,
        actualEndOffset: actualEndOffset ?? this.actualEndOffset,
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        mergedId: mergedId ?? this.mergedId,
        title: title ?? this.title,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        minimumAge: minimumAge ?? this.minimumAge,
        replayTVMinAge: replayTVMinAge ?? this.replayTVMinAge,
        replayTVAdult: replayTVAdult ?? this.replayTVAdult,
        seriesId: seriesId ?? this.seriesId,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        isAdult: isAdult ?? this.isAdult,
        hasReplayTV: hasReplayTV ?? this.hasReplayTV,
        hasStartOver: hasStartOver ?? this.hasStartOver,
        isOpen: isOpen ?? this.isOpen,
        isPurchasable: isPurchasable ?? this.isPurchasable,
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        replayTVDisplayAge: replayTVDisplayAge ?? this.replayTVDisplayAge,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        signLanguages: signLanguages ?? this.signLanguages);
  }

  DetailedEvent copyWithWrapped(
      {Wrapped<String?>? shortDescription,
      Wrapped<String?>? longDescription,
      Wrapped<List<String>?>? actors,
      Wrapped<List<String>?>? directors,
      Wrapped<List<String>?>? producers,
      Wrapped<int?>? audioType,
      Wrapped<List<CaptionLanguage>?>? captionLanguages,
      Wrapped<String?>? productionDate,
      Wrapped<String?>? countryOfOrigin,
      Wrapped<String?>? wall,
      Wrapped<String?>? poster,
      Wrapped<String?>? titleTreatment,
      Wrapped<List<String>?>? genres,
      Wrapped<enums.DetailedEventResolution?>? resolution,
      Wrapped<bool?>? isLive,
      Wrapped<num?>? actualStartOffset,
      Wrapped<num?>? actualEndOffset,
      Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<String?>? mergedId,
      Wrapped<String>? title,
      Wrapped<num>? startTime,
      Wrapped<num>? endTime,
      Wrapped<int?>? minimumAge,
      Wrapped<int?>? replayTVMinAge,
      Wrapped<bool?>? replayTVAdult,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? hasReplayTV,
      Wrapped<bool?>? hasStartOver,
      Wrapped<bool?>? isOpen,
      Wrapped<bool?>? isPurchasable,
      Wrapped<num?>? replayAvailabilityStart,
      Wrapped<num?>? replayAvailabilityEnd,
      Wrapped<bool?>? replayTVDisplayAge,
      Wrapped<List<AudioLanguage>?>? audioLanguages,
      Wrapped<List<SignLanguage>?>? signLanguages}) {
    return DetailedEvent(
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        actors: (actors != null ? actors.value : this.actors),
        directors: (directors != null ? directors.value : this.directors),
        producers: (producers != null ? producers.value : this.producers),
        audioType: (audioType != null ? audioType.value : this.audioType),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        productionDate: (productionDate != null
            ? productionDate.value
            : this.productionDate),
        countryOfOrigin: (countryOfOrigin != null
            ? countryOfOrigin.value
            : this.countryOfOrigin),
        wall: (wall != null ? wall.value : this.wall),
        poster: (poster != null ? poster.value : this.poster),
        titleTreatment: (titleTreatment != null
            ? titleTreatment.value
            : this.titleTreatment),
        genres: (genres != null ? genres.value : this.genres),
        resolution: (resolution != null ? resolution.value : this.resolution),
        isLive: (isLive != null ? isLive.value : this.isLive),
        actualStartOffset: (actualStartOffset != null
            ? actualStartOffset.value
            : this.actualStartOffset),
        actualEndOffset: (actualEndOffset != null
            ? actualEndOffset.value
            : this.actualEndOffset),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        title: (title != null ? title.value : this.title),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        replayTVMinAge: (replayTVMinAge != null
            ? replayTVMinAge.value
            : this.replayTVMinAge),
        replayTVAdult:
            (replayTVAdult != null ? replayTVAdult.value : this.replayTVAdult),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        hasReplayTV:
            (hasReplayTV != null ? hasReplayTV.value : this.hasReplayTV),
        hasStartOver:
            (hasStartOver != null ? hasStartOver.value : this.hasStartOver),
        isOpen: (isOpen != null ? isOpen.value : this.isOpen),
        isPurchasable:
            (isPurchasable != null ? isPurchasable.value : this.isPurchasable),
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        replayTVDisplayAge: (replayTVDisplayAge != null
            ? replayTVDisplayAge.value
            : this.replayTVDisplayAge),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages));
  }
}

@JsonSerializable(explicitToJson: true)
class AudioLanguage {
  AudioLanguage({
    required this.lang,
    this.purpose,
  });

  factory AudioLanguage.fromJson(Map<String, dynamic> json) =>
      _$AudioLanguageFromJson(json);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$AudioLanguageFromJson;
  static const toJsonFactory = _$AudioLanguageToJson;
  Map<String, dynamic> toJson() => _$AudioLanguageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AudioLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $AudioLanguageExtension on AudioLanguage {
  AudioLanguage copyWith({String? lang, int? purpose}) {
    return AudioLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  AudioLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return AudioLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class CaptionLanguage {
  CaptionLanguage({
    required this.lang,
    this.purpose,
  });

  factory CaptionLanguage.fromJson(Map<String, dynamic> json) =>
      _$CaptionLanguageFromJson(json);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$CaptionLanguageFromJson;
  static const toJsonFactory = _$CaptionLanguageToJson;
  Map<String, dynamic> toJson() => _$CaptionLanguageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CaptionLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $CaptionLanguageExtension on CaptionLanguage {
  CaptionLanguage copyWith({String? lang, int? purpose}) {
    return CaptionLanguage(
        lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  CaptionLanguage copyWithWrapped(
      {Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return CaptionLanguage(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class SignLanguage {
  SignLanguage({
    required this.lang,
  });

  factory SignLanguage.fromJson(Map<String, dynamic> json) =>
      _$SignLanguageFromJson(json);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  static const fromJsonFactory = _$SignLanguageFromJson;
  static const toJsonFactory = _$SignLanguageToJson;
  Map<String, dynamic> toJson() => _$SignLanguageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SignLanguage &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^ runtimeType.hashCode;
}

extension $SignLanguageExtension on SignLanguage {
  SignLanguage copyWith({String? lang}) {
    return SignLanguage(lang: lang ?? this.lang);
  }

  SignLanguage copyWithWrapped({Wrapped<String>? lang}) {
    return SignLanguage(lang: (lang != null ? lang.value : this.lang));
  }
}

@JsonSerializable(explicitToJson: true)
class GetEPGEventsParams {
  GetEPGEventsParams({
    required this.startTime,
    required this.endTime,
    required this.channelIds,
  });

  factory GetEPGEventsParams.fromJson(Map<String, dynamic> json) =>
      _$GetEPGEventsParamsFromJson(json);

  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num endTime;
  @JsonKey(name: 'channelIds', includeIfNull: false, defaultValue: <String>[])
  final List<String> channelIds;
  static const fromJsonFactory = _$GetEPGEventsParamsFromJson;
  static const toJsonFactory = _$GetEPGEventsParamsToJson;
  Map<String, dynamic> toJson() => _$GetEPGEventsParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetEPGEventsParams &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.channelIds, channelIds) ||
                const DeepCollectionEquality()
                    .equals(other.channelIds, channelIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(channelIds) ^
      runtimeType.hashCode;
}

extension $GetEPGEventsParamsExtension on GetEPGEventsParams {
  GetEPGEventsParams copyWith(
      {num? startTime, num? endTime, List<String>? channelIds}) {
    return GetEPGEventsParams(
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        channelIds: channelIds ?? this.channelIds);
  }

  GetEPGEventsParams copyWithWrapped(
      {Wrapped<num>? startTime,
      Wrapped<num>? endTime,
      Wrapped<List<String>>? channelIds}) {
    return GetEPGEventsParams(
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        channelIds: (channelIds != null ? channelIds.value : this.channelIds));
  }
}

@JsonSerializable(explicitToJson: true)
class GetDetailedEventParams {
  GetDetailedEventParams({
    required this.eventId,
    required this.channelId,
    required this.startTime,
  });

  factory GetDetailedEventParams.fromJson(Map<String, dynamic> json) =>
      _$GetDetailedEventParamsFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  static const fromJsonFactory = _$GetDetailedEventParamsFromJson;
  static const toJsonFactory = _$GetDetailedEventParamsToJson;
  Map<String, dynamic> toJson() => _$GetDetailedEventParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetDetailedEventParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      runtimeType.hashCode;
}

extension $GetDetailedEventParamsExtension on GetDetailedEventParams {
  GetDetailedEventParams copyWith(
      {String? eventId, String? channelId, num? startTime}) {
    return GetDetailedEventParams(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime);
  }

  GetDetailedEventParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<num>? startTime}) {
    return GetDetailedEventParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime));
  }
}

@JsonSerializable(explicitToJson: true)
class GetEPGEventsAroundParams {
  GetEPGEventsAroundParams({
    required this.channelId,
    required this.startTime,
    required this.numberOfEventsBefore,
    required this.numberOfEventsAfter,
    this.minLookupTime,
    this.maxLookupTime,
    this.filterTimeboxes,
  });

  factory GetEPGEventsAroundParams.fromJson(Map<String, dynamic> json) =>
      _$GetEPGEventsAroundParamsFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'numberOfEventsBefore', includeIfNull: false)
  final int numberOfEventsBefore;
  @JsonKey(name: 'numberOfEventsAfter', includeIfNull: false)
  final int numberOfEventsAfter;
  @JsonKey(name: 'minLookupTime', includeIfNull: false)
  final int? minLookupTime;
  @JsonKey(name: 'maxLookupTime', includeIfNull: false)
  final int? maxLookupTime;
  @JsonKey(
      name: 'filterTimeboxes', includeIfNull: false, defaultValue: <Timebox>[])
  final List<Timebox>? filterTimeboxes;
  static const fromJsonFactory = _$GetEPGEventsAroundParamsFromJson;
  static const toJsonFactory = _$GetEPGEventsAroundParamsToJson;
  Map<String, dynamic> toJson() => _$GetEPGEventsAroundParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetEPGEventsAroundParams &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.numberOfEventsBefore, numberOfEventsBefore) ||
                const DeepCollectionEquality().equals(
                    other.numberOfEventsBefore, numberOfEventsBefore)) &&
            (identical(other.numberOfEventsAfter, numberOfEventsAfter) ||
                const DeepCollectionEquality()
                    .equals(other.numberOfEventsAfter, numberOfEventsAfter)) &&
            (identical(other.minLookupTime, minLookupTime) ||
                const DeepCollectionEquality()
                    .equals(other.minLookupTime, minLookupTime)) &&
            (identical(other.maxLookupTime, maxLookupTime) ||
                const DeepCollectionEquality()
                    .equals(other.maxLookupTime, maxLookupTime)) &&
            (identical(other.filterTimeboxes, filterTimeboxes) ||
                const DeepCollectionEquality()
                    .equals(other.filterTimeboxes, filterTimeboxes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(numberOfEventsBefore) ^
      const DeepCollectionEquality().hash(numberOfEventsAfter) ^
      const DeepCollectionEquality().hash(minLookupTime) ^
      const DeepCollectionEquality().hash(maxLookupTime) ^
      const DeepCollectionEquality().hash(filterTimeboxes) ^
      runtimeType.hashCode;
}

extension $GetEPGEventsAroundParamsExtension on GetEPGEventsAroundParams {
  GetEPGEventsAroundParams copyWith(
      {String? channelId,
      num? startTime,
      int? numberOfEventsBefore,
      int? numberOfEventsAfter,
      int? minLookupTime,
      int? maxLookupTime,
      List<Timebox>? filterTimeboxes}) {
    return GetEPGEventsAroundParams(
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        numberOfEventsBefore: numberOfEventsBefore ?? this.numberOfEventsBefore,
        numberOfEventsAfter: numberOfEventsAfter ?? this.numberOfEventsAfter,
        minLookupTime: minLookupTime ?? this.minLookupTime,
        maxLookupTime: maxLookupTime ?? this.maxLookupTime,
        filterTimeboxes: filterTimeboxes ?? this.filterTimeboxes);
  }

  GetEPGEventsAroundParams copyWithWrapped(
      {Wrapped<String>? channelId,
      Wrapped<num>? startTime,
      Wrapped<int>? numberOfEventsBefore,
      Wrapped<int>? numberOfEventsAfter,
      Wrapped<int?>? minLookupTime,
      Wrapped<int?>? maxLookupTime,
      Wrapped<List<Timebox>?>? filterTimeboxes}) {
    return GetEPGEventsAroundParams(
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        numberOfEventsBefore: (numberOfEventsBefore != null
            ? numberOfEventsBefore.value
            : this.numberOfEventsBefore),
        numberOfEventsAfter: (numberOfEventsAfter != null
            ? numberOfEventsAfter.value
            : this.numberOfEventsAfter),
        minLookupTime:
            (minLookupTime != null ? minLookupTime.value : this.minLookupTime),
        maxLookupTime:
            (maxLookupTime != null ? maxLookupTime.value : this.maxLookupTime),
        filterTimeboxes: (filterTimeboxes != null
            ? filterTimeboxes.value
            : this.filterTimeboxes));
  }
}

@JsonSerializable(explicitToJson: true)
class Timebox {
  Timebox({
    required this.start,
    required this.end,
  });

  factory Timebox.fromJson(Map<String, dynamic> json) =>
      _$TimeboxFromJson(json);

  @JsonKey(name: 'start', includeIfNull: false)
  final int start;
  @JsonKey(name: 'end', includeIfNull: false)
  final int end;
  static const fromJsonFactory = _$TimeboxFromJson;
  static const toJsonFactory = _$TimeboxToJson;
  Map<String, dynamic> toJson() => _$TimeboxToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Timebox &&
            (identical(other.start, start) ||
                const DeepCollectionEquality().equals(other.start, start)) &&
            (identical(other.end, end) ||
                const DeepCollectionEquality().equals(other.end, end)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(start) ^
      const DeepCollectionEquality().hash(end) ^
      runtimeType.hashCode;
}

extension $TimeboxExtension on Timebox {
  Timebox copyWith({int? start, int? end}) {
    return Timebox(start: start ?? this.start, end: end ?? this.end);
  }

  Timebox copyWithWrapped({Wrapped<int>? start, Wrapped<int>? end}) {
    return Timebox(
        start: (start != null ? start.value : this.start),
        end: (end != null ? end.value : this.end));
  }
}

@JsonSerializable(explicitToJson: true)
class GetEPGEventsAroundResponse {
  GetEPGEventsAroundResponse({
    this.event,
    this.eventsBefore,
    this.eventsAfter,
  });

  factory GetEPGEventsAroundResponse.fromJson(Map<String, dynamic> json) =>
      _$GetEPGEventsAroundResponseFromJson(json);

  @JsonKey(name: 'event', includeIfNull: false)
  final Event? event;
  @JsonKey(name: 'eventsBefore', includeIfNull: false, defaultValue: <Event>[])
  final List<Event>? eventsBefore;
  @JsonKey(name: 'eventsAfter', includeIfNull: false, defaultValue: <Event>[])
  final List<Event>? eventsAfter;
  static const fromJsonFactory = _$GetEPGEventsAroundResponseFromJson;
  static const toJsonFactory = _$GetEPGEventsAroundResponseToJson;
  Map<String, dynamic> toJson() => _$GetEPGEventsAroundResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetEPGEventsAroundResponse &&
            (identical(other.event, event) ||
                const DeepCollectionEquality().equals(other.event, event)) &&
            (identical(other.eventsBefore, eventsBefore) ||
                const DeepCollectionEquality()
                    .equals(other.eventsBefore, eventsBefore)) &&
            (identical(other.eventsAfter, eventsAfter) ||
                const DeepCollectionEquality()
                    .equals(other.eventsAfter, eventsAfter)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(event) ^
      const DeepCollectionEquality().hash(eventsBefore) ^
      const DeepCollectionEquality().hash(eventsAfter) ^
      runtimeType.hashCode;
}

extension $GetEPGEventsAroundResponseExtension on GetEPGEventsAroundResponse {
  GetEPGEventsAroundResponse copyWith(
      {Event? event, List<Event>? eventsBefore, List<Event>? eventsAfter}) {
    return GetEPGEventsAroundResponse(
        event: event ?? this.event,
        eventsBefore: eventsBefore ?? this.eventsBefore,
        eventsAfter: eventsAfter ?? this.eventsAfter);
  }

  GetEPGEventsAroundResponse copyWithWrapped(
      {Wrapped<Event?>? event,
      Wrapped<List<Event>?>? eventsBefore,
      Wrapped<List<Event>?>? eventsAfter}) {
    return GetEPGEventsAroundResponse(
        event: (event != null ? event.value : this.event),
        eventsBefore:
            (eventsBefore != null ? eventsBefore.value : this.eventsBefore),
        eventsAfter:
            (eventsAfter != null ? eventsAfter.value : this.eventsAfter));
  }
}

String? detailedEventResolutionToJson(
    enums.DetailedEventResolution? detailedEventResolution) {
  return enums.$DetailedEventResolutionMap[detailedEventResolution];
}

enums.DetailedEventResolution detailedEventResolutionFromJson(
  Object? detailedEventResolution, [
  enums.DetailedEventResolution? defaultValue,
]) {
  if (detailedEventResolution is String) {
    return enums.$DetailedEventResolutionMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                detailedEventResolution.toLowerCase(),
            orElse: () => const MapEntry(
                enums.DetailedEventResolution.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$DetailedEventResolutionMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.DetailedEventResolution.swaggerGeneratedUnknown;
}

List<String> detailedEventResolutionListToJson(
    List<enums.DetailedEventResolution>? detailedEventResolution) {
  if (detailedEventResolution == null) {
    return [];
  }

  return detailedEventResolution
      .map((e) => enums.$DetailedEventResolutionMap[e]!)
      .toList();
}

List<enums.DetailedEventResolution> detailedEventResolutionListFromJson(
  List? detailedEventResolution, [
  List<enums.DetailedEventResolution>? defaultValue,
]) {
  if (detailedEventResolution == null) {
    return defaultValue ?? [];
  }

  return detailedEventResolution
      .map((e) => detailedEventResolutionFromJson(e.toString()))
      .toList();
}

List<enums.DetailedEventResolution>?
    detailedEventResolutionNullableListFromJson(
  List? detailedEventResolution, [
  List<enums.DetailedEventResolution>? defaultValue,
]) {
  if (detailedEventResolution == null) {
    return defaultValue;
  }

  return detailedEventResolution
      .map((e) => detailedEventResolutionFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
