// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'faq_service.swagger.chopper.dart';
part 'faq_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class FaqService extends ChopperService {
  static FaqService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$FaqService(client);
    }

    final newClient = ChopperClient(
        services: [_$FaqService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$FaqService(newClient);
  }

  ///Config file provides formatted text for F.A.Q. section to be displayed in the application.
  ///@param faqFileName faq file name. faq.nl as example
  ///@param country Is the active language of the application following ISO 639-1 (two-letter codes).
  ///@param lang Is the active language of the application following ISO 639-1 (two-letter codes).
  Future<chopper.Response<FAQResult>>
      countryLangConfigServiceConfGenericFaqFileNameJsonGet({
    required String? faqFileName,
    required String? country,
    required String? lang,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FAQResult, () => FAQResult.fromJsonFactory);

    return _countryLangConfigServiceConfGenericFaqFileNameJsonGet(
        faqFileName: faqFileName,
        country: country,
        lang: lang,
        cacheControl: cacheControl);
  }

  ///Config file provides formatted text for F.A.Q. section to be displayed in the application.
  ///@param faqFileName faq file name. faq.nl as example
  ///@param country Is the active language of the application following ISO 639-1 (two-letter codes).
  ///@param lang Is the active language of the application following ISO 639-1 (two-letter codes).
  @Get(path: '/{country}/{lang}/config-service/conf/generic/{faqFileName}.json')
  Future<chopper.Response<FAQResult>>
      _countryLangConfigServiceConfGenericFaqFileNameJsonGet({
    @Path('faqFileName') required String? faqFileName,
    @Path('country') required String? country,
    @Path('lang') required String? lang,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class FAQResult {
  FAQResult({
    this.entries,
  });

  factory FAQResult.fromJson(Map<String, dynamic> json) =>
      _$FAQResultFromJson(json);

  @JsonKey(name: 'entries', includeIfNull: false, defaultValue: <FAQEntry>[])
  final List<FAQEntry>? entries;
  static const fromJsonFactory = _$FAQResultFromJson;
  static const toJsonFactory = _$FAQResultToJson;
  Map<String, dynamic> toJson() => _$FAQResultToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FAQResult &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality().equals(other.entries, entries)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entries) ^ runtimeType.hashCode;
}

extension $FAQResultExtension on FAQResult {
  FAQResult copyWith({List<FAQEntry>? entries}) {
    return FAQResult(entries: entries ?? this.entries);
  }

  FAQResult copyWithWrapped({Wrapped<List<FAQEntry>?>? entries}) {
    return FAQResult(entries: (entries != null ? entries.value : this.entries));
  }
}

@JsonSerializable(explicitToJson: true)
class FAQEntry {
  FAQEntry({
    this.q,
    this.a,
  });

  factory FAQEntry.fromJson(Map<String, dynamic> json) =>
      _$FAQEntryFromJson(json);

  @JsonKey(name: 'q', includeIfNull: false, defaultValue: '')
  final String? q;
  @JsonKey(name: 'a', includeIfNull: false, defaultValue: '')
  final String? a;
  static const fromJsonFactory = _$FAQEntryFromJson;
  static const toJsonFactory = _$FAQEntryToJson;
  Map<String, dynamic> toJson() => _$FAQEntryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FAQEntry &&
            (identical(other.q, q) ||
                const DeepCollectionEquality().equals(other.q, q)) &&
            (identical(other.a, a) ||
                const DeepCollectionEquality().equals(other.a, a)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(q) ^
      const DeepCollectionEquality().hash(a) ^
      runtimeType.hashCode;
}

extension $FAQEntryExtension on FAQEntry {
  FAQEntry copyWith({String? q, String? a}) {
    return FAQEntry(q: q ?? this.q, a: a ?? this.a);
  }

  FAQEntry copyWithWrapped({Wrapped<String?>? q, Wrapped<String?>? a}) {
    return FAQEntry(
        q: (q != null ? q.value : this.q), a: (a != null ? a.value : this.a));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
