// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'image_service.enums.swagger.dart' as enums;
export 'image_service.enums.swagger.dart';

part 'image_service.swagger.chopper.dart';
part 'image_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ImageService extends ChopperService {
  static ImageService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ImageService(client);
    }

    final newClient = ChopperClient(
        services: [_$ImageService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$ImageService(newClient);
  }

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  ///@param jsonBody JSON body
  Future<chopper.Response<List<ContentResponse>>> intentGet({
    required String? jsonBody,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContentResponse, () => ContentResponse.fromJsonFactory);

    return _intentGet(jsonBody: jsonBody, cacheControl: cacheControl);
  }

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  ///@param jsonBody JSON body
  @Get(path: '/intent')
  Future<chopper.Response<List<ContentResponse>>> _intentGet({
    @Query('jsonBody') required String? jsonBody,
    @Header('Cache-Control') String? cacheControl,
  });

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  Future<chopper.Response<List<ContentResponse>>> intentPost({
    String? cacheControl,
    required List<ContentRequest>? body,
  }) {
    generatedMapping.putIfAbsent(
        ContentResponse, () => ContentResponse.fromJsonFactory);

    return _intentPost(cacheControl: cacheControl, body: body);
  }

  ///API for retrieving the actual location of images matching certain CRID + imageType combinations
  @Post(path: '/intent')
  Future<chopper.Response<List<ContentResponse>>> _intentPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required List<ContentRequest>? body,
  });

  ///API for retrieving the actual location of the image matching the resource id + imageType
  ///@param width The width the picture should be resized to
  ///@param height The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorSpace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param resourceId Resource id
  ///@param type The type the resource id represents
  ///@param imageType The requested imageType
  ///@param If-None-Match If-None-Match
  Future<chopper.Response> intentResourceIdImageTypeGet({
    int? width,
    int? height,
    enums.IntentResourceIdImageTypeGetMode? mode,
    num? blur,
    int? brightness,
    enums.IntentResourceIdImageTypeGetFormat? format,
    String? style,
    enums.IntentResourceIdImageTypeGetChannel? channel,
    enums.IntentResourceIdImageTypeGetColorSpace? colorSpace,
    List<String>? overlay,
    bool? metadata,
    num? quality,
    String? stylePlaceholders,
    String? cornerRadius,
    required String? resourceId,
    enums.IntentResourceIdImageTypeGetType? type,
    required String? imageType,
    String? ifNoneMatch,
    String? cacheControl,
  }) {
    return _intentResourceIdImageTypeGet(
        width: width,
        height: height,
        mode: enums.$IntentResourceIdImageTypeGetModeMap[mode]?.toString(),
        blur: blur,
        brightness: brightness,
        format:
            enums.$IntentResourceIdImageTypeGetFormatMap[format]?.toString(),
        style: style,
        channel:
            enums.$IntentResourceIdImageTypeGetChannelMap[channel]?.toString(),
        colorSpace: enums.$IntentResourceIdImageTypeGetColorSpaceMap[colorSpace]
            ?.toString(),
        overlay: overlay,
        metadata: metadata,
        quality: quality,
        stylePlaceholders: stylePlaceholders,
        cornerRadius: cornerRadius,
        resourceId: resourceId,
        type: enums.$IntentResourceIdImageTypeGetTypeMap[type]?.toString(),
        imageType: imageType,
        ifNoneMatch: ifNoneMatch,
        cacheControl: cacheControl);
  }

  ///API for retrieving the actual location of the image matching the resource id + imageType
  ///@param width The width the picture should be resized to
  ///@param height The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorSpace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param resourceId Resource id
  ///@param type The type the resource id represents
  ///@param imageType The requested imageType
  ///@param If-None-Match If-None-Match
  @Get(path: '/intent/{resourceId}/{imageType}')
  Future<chopper.Response> _intentResourceIdImageTypeGet({
    @Query('width') int? width,
    @Query('height') int? height,
    @Query('mode') String? mode,
    @Query('blur') num? blur,
    @Query('brightness') int? brightness,
    @Query('format') String? format,
    @Query('style') String? style,
    @Query('channel') String? channel,
    @Query('colorSpace') String? colorSpace,
    @Query('overlay') List<String>? overlay,
    @Query('metadata') bool? metadata,
    @Query('quality') num? quality,
    @Query('stylePlaceholders') String? stylePlaceholders,
    @Query('cornerRadius') String? cornerRadius,
    @Path('resourceId') required String? resourceId,
    @Query('type') String? type,
    @Path('imageType') required String? imageType,
    @Header('If-None-Match') String? ifNoneMatch,
    @Header('Cache-Control') String? cacheControl,
  });

  ///API for deleting images
  ///@param resourceLocation The image resource location
  Future<chopper.Response<List<String>>> resourceLocationDelete({
    required String? resourceLocation,
    String? cacheControl,
  }) {
    return _resourceLocationDelete(
        resourceLocation: resourceLocation, cacheControl: cacheControl);
  }

  ///API for deleting images
  ///@param resourceLocation The image resource location
  @Delete(path: '/{resourceLocation}')
  Future<chopper.Response<List<String>>> _resourceLocationDelete({
    @Path('resourceLocation') required String? resourceLocation,
    @Header('Cache-Control') String? cacheControl,
  });

  ///API for uploading images
  ///@param folder The folder the files (located in the body) should be stored
  Future<chopper.Response<List<String>>> folderPost({
    required String? folder,
    String? cacheControl,
    required List<int> files,
  }) {
    return _folderPost(
        folder: folder, cacheControl: cacheControl, files: files);
  }

  ///API for uploading images
  ///@param folder The folder the files (located in the body) should be stored
  @Post(path: '/{folder}')
  @Multipart()
  Future<chopper.Response<List<String>>> _folderPost({
    @Path('folder') required String? folder,
    @Header('Cache-Control') String? cacheControl,
    @PartFile() required List<int> files,
  });

  ///API for requesting images with filters and mutation capabilities. When request contains a style and additional manipulations (width, height, resize_mode, blur), those parameters will override the style manipulation value.
  ///Modifications are applied in order:
  ///1. Resize image	 2. Blur 	 3. Brighten	 4. Image quality 	 5. Channel 	 6. Color space	 7. Overlays 	 8. CornerRadius
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidth The minimum width used for Wedge shape resize
  ///@param wedgeHeight The minimum height used for wedge shape resize
  Future<chopper.Response<List<String>>> pathGet({
    required String? path,
    String? ifNoneMatch,
    int? w,
    int? h,
    enums.PathGetMode? mode,
    num? blur,
    int? brightness,
    enums.PathGetFormat? format,
    String? style,
    enums.PathGetChannel? channel,
    enums.PathGetColorspace? colorspace,
    List<String>? overlay,
    bool? metadata,
    num? quality,
    String? stylePlaceholders,
    String? cornerRadius,
    bool? trim,
    int? wedgeWidth,
    int? wedgeHeight,
    String? cacheControl,
  }) {
    return _pathGet(
        path: path,
        ifNoneMatch: ifNoneMatch,
        w: w,
        h: h,
        mode: enums.$PathGetModeMap[mode]?.toString(),
        blur: blur,
        brightness: brightness,
        format: enums.$PathGetFormatMap[format]?.toString(),
        style: style,
        channel: enums.$PathGetChannelMap[channel]?.toString(),
        colorspace: enums.$PathGetColorspaceMap[colorspace]?.toString(),
        overlay: overlay,
        metadata: metadata,
        quality: quality,
        stylePlaceholders: stylePlaceholders,
        cornerRadius: cornerRadius,
        trim: trim,
        wedgeWidth: wedgeWidth,
        wedgeHeight: wedgeHeight,
        cacheControl: cacheControl);
  }

  ///API for requesting images with filters and mutation capabilities. When request contains a style and additional manipulations (width, height, resize_mode, blur), those parameters will override the style manipulation value.
  ///Modifications are applied in order:
  ///1. Resize image	 2. Blur 	 3. Brighten	 4. Image quality 	 5. Channel 	 6. Color space	 7. Overlays 	 8. CornerRadius
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given.  Note2: when resize mode is set to stretch or box and either height or width is missing → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture. Style values can be overriden by parameters in query.
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for a specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param overlay The overlay support (specification: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BOverlay%2Bsupport)
  ///@param metadata The flag specifying if image metadata (dominant colors) should added to headers
  ///@param quality The output image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param stylePlaceholders Styles can have dynamic content which is replaced by value from properties in stylePlaceholders. More details: https://wikiprojects.upc.biz/display/SPARK/Image-Service%2B-%2BDynamic%2Bstyle%2Bplaceholders
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidth The minimum width used for Wedge shape resize
  ///@param wedgeHeight The minimum height used for wedge shape resize
  @Get(path: '/{path}')
  Future<chopper.Response<List<String>>> _pathGet({
    @Path('path') required String? path,
    @Header('If-None-Match') String? ifNoneMatch,
    @Query('w') int? w,
    @Query('h') int? h,
    @Query('mode') String? mode,
    @Query('blur') num? blur,
    @Query('brightness') int? brightness,
    @Query('format') String? format,
    @Query('style') String? style,
    @Query('channel') String? channel,
    @Query('colorspace') String? colorspace,
    @Query('overlay') List<String>? overlay,
    @Query('metadata') bool? metadata,
    @Query('quality') num? quality,
    @Query('stylePlaceholders') String? stylePlaceholders,
    @Query('cornerRadius') String? cornerRadius,
    @Query('trim') bool? trim,
    @Query('wedgeWidth') int? wedgeWidth,
    @Query('wedgeHeight') int? wedgeHeight,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns json with dominant colours from the image after optional processing given as query parameters.
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given  Note2: when resize mode is set to stretch or box and either height or width is missng → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightnening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param quality The image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidth The minimum width used for Wedge shape resize
  ///@param wedgeHeight The minimum height used for wedge shape resize
  Future<chopper.Response<DominantColorPaletteOutput>> metadataPathGet({
    required String? path,
    String? ifNoneMatch,
    int? w,
    int? h,
    enums.MetadataPathGetMode? mode,
    num? blur,
    int? brightness,
    enums.MetadataPathGetFormat? format,
    String? style,
    enums.MetadataPathGetChannel? channel,
    enums.MetadataPathGetColorspace? colorspace,
    num? quality,
    String? cornerRadius,
    bool? trim,
    int? wedgeWidth,
    int? wedgeHeight,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(DominantColorPaletteOutput,
        () => DominantColorPaletteOutput.fromJsonFactory);

    return _metadataPathGet(
        path: path,
        ifNoneMatch: ifNoneMatch,
        w: w,
        h: h,
        mode: enums.$MetadataPathGetModeMap[mode]?.toString(),
        blur: blur,
        brightness: brightness,
        format: enums.$MetadataPathGetFormatMap[format]?.toString(),
        style: style,
        channel: enums.$MetadataPathGetChannelMap[channel]?.toString(),
        colorspace: enums.$MetadataPathGetColorspaceMap[colorspace]?.toString(),
        quality: quality,
        cornerRadius: cornerRadius,
        trim: trim,
        wedgeWidth: wedgeWidth,
        wedgeHeight: wedgeHeight,
        cacheControl: cacheControl);
  }

  ///Returns json with dominant colours from the image after optional processing given as query parameters.
  ///@param path The image resource location
  ///@param If-None-Match E-tag values for standard 'IF-NONE-MATCH' header behavior
  ///@param w The width the picture should be resized to
  ///@param h The height the picture should be resized to
  ///@param mode One of the resize modes for returned image: crop, box, stretch, fill. Note: when resize mode is set to crop then both width and height must be given  Note2: when resize mode is set to stretch or box and either height or width is missng → the image is resized keeping the original aspect ratio.
  ///@param blur The blurring value for manipulating the picture
  ///@param brightness The brightness value in percents for manipulating the picture. Negative numbers are for darkening the image, positive numbers for brightnening the image. Min value -100, max value 100.
  ///@param format The output image format (supported formats: jpg, jpeg, png, webp, jp2, jxr)
  ///@param style The style used for manipulating the picture
  ///@param channel The grayscale image made of just one of primary colors (RED, GREEN, BLUE, OPACITY, GRAY)
  ///@param colorspace The color space type for specific organization of colors (one of: CineonLog, CMYK, GRAY, HSL, HWB, OHTA, RGB, Rec601Luma, Rec709Luma, Rec601YCbCr, Rec709YCbCr, Transparent, XYZ, YCbCr, YIQ, YPbPr, YUV)
  ///@param quality The image compression level. Min value 1, max value 100. If quality argument is not provided the default compression level is 89.
  ///@param cornerRadius The radius of rounded corners of an image ('max' equals an ellipse)
  ///@param trim The flag specifying if image should be trimmed
  ///@param wedgeWidth The minimum width used for Wedge shape resize
  ///@param wedgeHeight The minimum height used for wedge shape resize
  @Get(path: '/metadata/{path}')
  Future<chopper.Response<DominantColorPaletteOutput>> _metadataPathGet({
    @Path('path') required String? path,
    @Header('If-None-Match') String? ifNoneMatch,
    @Query('w') int? w,
    @Query('h') int? h,
    @Query('mode') String? mode,
    @Query('blur') num? blur,
    @Query('brightness') int? brightness,
    @Query('format') String? format,
    @Query('style') String? style,
    @Query('channel') String? channel,
    @Query('colorspace') String? colorspace,
    @Query('quality') num? quality,
    @Query('cornerRadius') String? cornerRadius,
    @Query('trim') bool? trim,
    @Query('wedgeWidth') int? wedgeWidth,
    @Query('wedgeHeight') int? wedgeHeight,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class ContentResponse {
  ContentResponse({
    this.intents,
    this.id,
  });

  factory ContentResponse.fromJson(Map<String, dynamic> json) =>
      _$ContentResponseFromJson(json);

  @JsonKey(
      name: 'intents',
      includeIfNull: false,
      defaultValue: <IntentResultResponse>[])
  final List<IntentResultResponse>? intents;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$ContentResponseFromJson;
  static const toJsonFactory = _$ContentResponseToJson;
  Map<String, dynamic> toJson() => _$ContentResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContentResponse &&
            (identical(other.intents, intents) ||
                const DeepCollectionEquality()
                    .equals(other.intents, intents)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intents) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $ContentResponseExtension on ContentResponse {
  ContentResponse copyWith({List<IntentResultResponse>? intents, String? id}) {
    return ContentResponse(intents: intents ?? this.intents, id: id ?? this.id);
  }

  ContentResponse copyWithWrapped(
      {Wrapped<List<IntentResultResponse>?>? intents, Wrapped<String?>? id}) {
    return ContentResponse(
        intents: (intents != null ? intents.value : this.intents),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class IntentResultResponse {
  IntentResultResponse({
    this.intent,
    this.url,
    this.imageAge,
  });

  factory IntentResultResponse.fromJson(Map<String, dynamic> json) =>
      _$IntentResultResponseFromJson(json);

  @JsonKey(name: 'intent', includeIfNull: false, defaultValue: '')
  final String? intent;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'imageAge', includeIfNull: false)
  final IntentResultResponse$ImageAge? imageAge;
  static const fromJsonFactory = _$IntentResultResponseFromJson;
  static const toJsonFactory = _$IntentResultResponseToJson;
  Map<String, dynamic> toJson() => _$IntentResultResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IntentResultResponse &&
            (identical(other.intent, intent) ||
                const DeepCollectionEquality().equals(other.intent, intent)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.imageAge, imageAge) ||
                const DeepCollectionEquality()
                    .equals(other.imageAge, imageAge)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intent) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(imageAge) ^
      runtimeType.hashCode;
}

extension $IntentResultResponseExtension on IntentResultResponse {
  IntentResultResponse copyWith(
      {String? intent, String? url, IntentResultResponse$ImageAge? imageAge}) {
    return IntentResultResponse(
        intent: intent ?? this.intent,
        url: url ?? this.url,
        imageAge: imageAge ?? this.imageAge);
  }

  IntentResultResponse copyWithWrapped(
      {Wrapped<String?>? intent,
      Wrapped<String?>? url,
      Wrapped<IntentResultResponse$ImageAge?>? imageAge}) {
    return IntentResultResponse(
        intent: (intent != null ? intent.value : this.intent),
        url: (url != null ? url.value : this.url),
        imageAge: (imageAge != null ? imageAge.value : this.imageAge));
  }
}

@JsonSerializable(explicitToJson: true)
class ContentRequest {
  ContentRequest({
    required this.id,
    this.type,
    required this.intents,
    this.allowMultipleImages,
  });

  factory ContentRequest.fromJson(Map<String, dynamic> json) =>
      _$ContentRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: contentRequestTypeToJson,
    fromJson: contentRequestTypeFromJson,
  )
  final enums.ContentRequestType? type;
  @JsonKey(name: 'intents', includeIfNull: false, defaultValue: <String>[])
  final List<String> intents;
  @JsonKey(name: 'allowMultipleImages', includeIfNull: false)
  final bool? allowMultipleImages;
  static const fromJsonFactory = _$ContentRequestFromJson;
  static const toJsonFactory = _$ContentRequestToJson;
  Map<String, dynamic> toJson() => _$ContentRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContentRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.intents, intents) ||
                const DeepCollectionEquality()
                    .equals(other.intents, intents)) &&
            (identical(other.allowMultipleImages, allowMultipleImages) ||
                const DeepCollectionEquality()
                    .equals(other.allowMultipleImages, allowMultipleImages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(intents) ^
      const DeepCollectionEquality().hash(allowMultipleImages) ^
      runtimeType.hashCode;
}

extension $ContentRequestExtension on ContentRequest {
  ContentRequest copyWith(
      {String? id,
      enums.ContentRequestType? type,
      List<String>? intents,
      bool? allowMultipleImages}) {
    return ContentRequest(
        id: id ?? this.id,
        type: type ?? this.type,
        intents: intents ?? this.intents,
        allowMultipleImages: allowMultipleImages ?? this.allowMultipleImages);
  }

  ContentRequest copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.ContentRequestType?>? type,
      Wrapped<List<String>>? intents,
      Wrapped<bool?>? allowMultipleImages}) {
    return ContentRequest(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        intents: (intents != null ? intents.value : this.intents),
        allowMultipleImages: (allowMultipleImages != null
            ? allowMultipleImages.value
            : this.allowMultipleImages));
  }
}

@JsonSerializable(explicitToJson: true)
class MultiRequest {
  MultiRequest({
    required this.files,
  });

  factory MultiRequest.fromJson(Map<String, dynamic> json) =>
      _$MultiRequestFromJson(json);

  @JsonKey(name: 'files', includeIfNull: false, defaultValue: '')
  final String files;
  static const fromJsonFactory = _$MultiRequestFromJson;
  static const toJsonFactory = _$MultiRequestToJson;
  Map<String, dynamic> toJson() => _$MultiRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MultiRequest &&
            (identical(other.files, files) ||
                const DeepCollectionEquality().equals(other.files, files)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(files) ^ runtimeType.hashCode;
}

extension $MultiRequestExtension on MultiRequest {
  MultiRequest copyWith({String? files}) {
    return MultiRequest(files: files ?? this.files);
  }

  MultiRequest copyWithWrapped({Wrapped<String>? files}) {
    return MultiRequest(files: (files != null ? files.value : this.files));
  }
}

@JsonSerializable(explicitToJson: true)
class DominantColorPaletteOutput {
  DominantColorPaletteOutput({
    this.dominantColorCodes,
  });

  factory DominantColorPaletteOutput.fromJson(Map<String, dynamic> json) =>
      _$DominantColorPaletteOutputFromJson(json);

  @JsonKey(
      name: 'dominantColorCodes',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? dominantColorCodes;
  static const fromJsonFactory = _$DominantColorPaletteOutputFromJson;
  static const toJsonFactory = _$DominantColorPaletteOutputToJson;
  Map<String, dynamic> toJson() => _$DominantColorPaletteOutputToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DominantColorPaletteOutput &&
            (identical(other.dominantColorCodes, dominantColorCodes) ||
                const DeepCollectionEquality()
                    .equals(other.dominantColorCodes, dominantColorCodes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(dominantColorCodes) ^
      runtimeType.hashCode;
}

extension $DominantColorPaletteOutputExtension on DominantColorPaletteOutput {
  DominantColorPaletteOutput copyWith({List<String>? dominantColorCodes}) {
    return DominantColorPaletteOutput(
        dominantColorCodes: dominantColorCodes ?? this.dominantColorCodes);
  }

  DominantColorPaletteOutput copyWithWrapped(
      {Wrapped<List<String>?>? dominantColorCodes}) {
    return DominantColorPaletteOutput(
        dominantColorCodes: (dominantColorCodes != null
            ? dominantColorCodes.value
            : this.dominantColorCodes));
  }
}

@JsonSerializable(explicitToJson: true)
class IntentResultResponse$ImageAge {
  IntentResultResponse$ImageAge({
    this.seconds,
    this.nano,
    this.negative,
    this.zero,
    this.units,
  });

  factory IntentResultResponse$ImageAge.fromJson(Map<String, dynamic> json) =>
      _$IntentResultResponse$ImageAgeFromJson(json);

  @JsonKey(name: 'seconds', includeIfNull: false)
  final num? seconds;
  @JsonKey(name: 'nano', includeIfNull: false)
  final int? nano;
  @JsonKey(name: 'negative', includeIfNull: false)
  final bool? negative;
  @JsonKey(name: 'zero', includeIfNull: false)
  final bool? zero;
  @JsonKey(
      name: 'units',
      includeIfNull: false,
      defaultValue: <IntentResultResponse$ImageAge$Units>[])
  final List<IntentResultResponse$ImageAge$Units>? units;
  static const fromJsonFactory = _$IntentResultResponse$ImageAgeFromJson;
  static const toJsonFactory = _$IntentResultResponse$ImageAgeToJson;
  Map<String, dynamic> toJson() => _$IntentResultResponse$ImageAgeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IntentResultResponse$ImageAge &&
            (identical(other.seconds, seconds) ||
                const DeepCollectionEquality()
                    .equals(other.seconds, seconds)) &&
            (identical(other.nano, nano) ||
                const DeepCollectionEquality().equals(other.nano, nano)) &&
            (identical(other.negative, negative) ||
                const DeepCollectionEquality()
                    .equals(other.negative, negative)) &&
            (identical(other.zero, zero) ||
                const DeepCollectionEquality().equals(other.zero, zero)) &&
            (identical(other.units, units) ||
                const DeepCollectionEquality().equals(other.units, units)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seconds) ^
      const DeepCollectionEquality().hash(nano) ^
      const DeepCollectionEquality().hash(negative) ^
      const DeepCollectionEquality().hash(zero) ^
      const DeepCollectionEquality().hash(units) ^
      runtimeType.hashCode;
}

extension $IntentResultResponse$ImageAgeExtension
    on IntentResultResponse$ImageAge {
  IntentResultResponse$ImageAge copyWith(
      {num? seconds,
      int? nano,
      bool? negative,
      bool? zero,
      List<IntentResultResponse$ImageAge$Units>? units}) {
    return IntentResultResponse$ImageAge(
        seconds: seconds ?? this.seconds,
        nano: nano ?? this.nano,
        negative: negative ?? this.negative,
        zero: zero ?? this.zero,
        units: units ?? this.units);
  }

  IntentResultResponse$ImageAge copyWithWrapped(
      {Wrapped<num?>? seconds,
      Wrapped<int?>? nano,
      Wrapped<bool?>? negative,
      Wrapped<bool?>? zero,
      Wrapped<List<IntentResultResponse$ImageAge$Units>?>? units}) {
    return IntentResultResponse$ImageAge(
        seconds: (seconds != null ? seconds.value : this.seconds),
        nano: (nano != null ? nano.value : this.nano),
        negative: (negative != null ? negative.value : this.negative),
        zero: (zero != null ? zero.value : this.zero),
        units: (units != null ? units.value : this.units));
  }
}

typedef IntentResultResponse$ImageAge$Units
    = List<IntentResultResponse$ImageAge$Units$Item>;

@JsonSerializable(explicitToJson: true)
class IntentResultResponse$ImageAge$Units$Item {
  IntentResultResponse$ImageAge$Units$Item({
    this.durationEstimated,
    this.dateBased,
    this.timeBased,
  });

  factory IntentResultResponse$ImageAge$Units$Item.fromJson(
          Map<String, dynamic> json) =>
      _$IntentResultResponse$ImageAge$Units$ItemFromJson(json);

  @JsonKey(name: 'durationEstimated', includeIfNull: false)
  final bool? durationEstimated;
  @JsonKey(name: 'dateBased', includeIfNull: false)
  final bool? dateBased;
  @JsonKey(name: 'timeBased', includeIfNull: false)
  final bool? timeBased;
  static const fromJsonFactory =
      _$IntentResultResponse$ImageAge$Units$ItemFromJson;
  static const toJsonFactory = _$IntentResultResponse$ImageAge$Units$ItemToJson;
  Map<String, dynamic> toJson() =>
      _$IntentResultResponse$ImageAge$Units$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IntentResultResponse$ImageAge$Units$Item &&
            (identical(other.durationEstimated, durationEstimated) ||
                const DeepCollectionEquality()
                    .equals(other.durationEstimated, durationEstimated)) &&
            (identical(other.dateBased, dateBased) ||
                const DeepCollectionEquality()
                    .equals(other.dateBased, dateBased)) &&
            (identical(other.timeBased, timeBased) ||
                const DeepCollectionEquality()
                    .equals(other.timeBased, timeBased)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(durationEstimated) ^
      const DeepCollectionEquality().hash(dateBased) ^
      const DeepCollectionEquality().hash(timeBased) ^
      runtimeType.hashCode;
}

extension $IntentResultResponse$ImageAge$Units$ItemExtension
    on IntentResultResponse$ImageAge$Units$Item {
  IntentResultResponse$ImageAge$Units$Item copyWith(
      {bool? durationEstimated, bool? dateBased, bool? timeBased}) {
    return IntentResultResponse$ImageAge$Units$Item(
        durationEstimated: durationEstimated ?? this.durationEstimated,
        dateBased: dateBased ?? this.dateBased,
        timeBased: timeBased ?? this.timeBased);
  }

  IntentResultResponse$ImageAge$Units$Item copyWithWrapped(
      {Wrapped<bool?>? durationEstimated,
      Wrapped<bool?>? dateBased,
      Wrapped<bool?>? timeBased}) {
    return IntentResultResponse$ImageAge$Units$Item(
        durationEstimated: (durationEstimated != null
            ? durationEstimated.value
            : this.durationEstimated),
        dateBased: (dateBased != null ? dateBased.value : this.dateBased),
        timeBased: (timeBased != null ? timeBased.value : this.timeBased));
  }
}

String? intentResourceIdImageTypeGetModeToJson(
    enums.IntentResourceIdImageTypeGetMode? intentResourceIdImageTypeGetMode) {
  return enums
      .$IntentResourceIdImageTypeGetModeMap[intentResourceIdImageTypeGetMode];
}

enums.IntentResourceIdImageTypeGetMode intentResourceIdImageTypeGetModeFromJson(
  Object? intentResourceIdImageTypeGetMode, [
  enums.IntentResourceIdImageTypeGetMode? defaultValue,
]) {
  if (intentResourceIdImageTypeGetMode is String) {
    return enums.$IntentResourceIdImageTypeGetModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                intentResourceIdImageTypeGetMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.IntentResourceIdImageTypeGetMode.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$IntentResourceIdImageTypeGetModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetMode.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetModeListToJson(
    List<enums.IntentResourceIdImageTypeGetMode>?
        intentResourceIdImageTypeGetMode) {
  if (intentResourceIdImageTypeGetMode == null) {
    return [];
  }

  return intentResourceIdImageTypeGetMode
      .map((e) => enums.$IntentResourceIdImageTypeGetModeMap[e]!)
      .toList();
}

List<enums.IntentResourceIdImageTypeGetMode>
    intentResourceIdImageTypeGetModeListFromJson(
  List? intentResourceIdImageTypeGetMode, [
  List<enums.IntentResourceIdImageTypeGetMode>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetMode == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetMode
      .map((e) => intentResourceIdImageTypeGetModeFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetMode>?
    intentResourceIdImageTypeGetModeNullableListFromJson(
  List? intentResourceIdImageTypeGetMode, [
  List<enums.IntentResourceIdImageTypeGetMode>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetMode == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetMode
      .map((e) => intentResourceIdImageTypeGetModeFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetFormatToJson(
    enums.IntentResourceIdImageTypeGetFormat?
        intentResourceIdImageTypeGetFormat) {
  return enums.$IntentResourceIdImageTypeGetFormatMap[
      intentResourceIdImageTypeGetFormat];
}

enums.IntentResourceIdImageTypeGetFormat
    intentResourceIdImageTypeGetFormatFromJson(
  Object? intentResourceIdImageTypeGetFormat, [
  enums.IntentResourceIdImageTypeGetFormat? defaultValue,
]) {
  if (intentResourceIdImageTypeGetFormat is String) {
    return enums.$IntentResourceIdImageTypeGetFormatMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                intentResourceIdImageTypeGetFormat.toLowerCase(),
            orElse: () => const MapEntry(
                enums
                    .IntentResourceIdImageTypeGetFormat.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$IntentResourceIdImageTypeGetFormatMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetFormat.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetFormatListToJson(
    List<enums.IntentResourceIdImageTypeGetFormat>?
        intentResourceIdImageTypeGetFormat) {
  if (intentResourceIdImageTypeGetFormat == null) {
    return [];
  }

  return intentResourceIdImageTypeGetFormat
      .map((e) => enums.$IntentResourceIdImageTypeGetFormatMap[e]!)
      .toList();
}

List<enums.IntentResourceIdImageTypeGetFormat>
    intentResourceIdImageTypeGetFormatListFromJson(
  List? intentResourceIdImageTypeGetFormat, [
  List<enums.IntentResourceIdImageTypeGetFormat>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetFormat == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetFormat
      .map((e) => intentResourceIdImageTypeGetFormatFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetFormat>?
    intentResourceIdImageTypeGetFormatNullableListFromJson(
  List? intentResourceIdImageTypeGetFormat, [
  List<enums.IntentResourceIdImageTypeGetFormat>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetFormat == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetFormat
      .map((e) => intentResourceIdImageTypeGetFormatFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetChannelToJson(
    enums.IntentResourceIdImageTypeGetChannel?
        intentResourceIdImageTypeGetChannel) {
  return enums.$IntentResourceIdImageTypeGetChannelMap[
      intentResourceIdImageTypeGetChannel];
}

enums.IntentResourceIdImageTypeGetChannel
    intentResourceIdImageTypeGetChannelFromJson(
  Object? intentResourceIdImageTypeGetChannel, [
  enums.IntentResourceIdImageTypeGetChannel? defaultValue,
]) {
  if (intentResourceIdImageTypeGetChannel is String) {
    return enums.$IntentResourceIdImageTypeGetChannelMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                intentResourceIdImageTypeGetChannel.toLowerCase(),
            orElse: () => const MapEntry(
                enums.IntentResourceIdImageTypeGetChannel
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$IntentResourceIdImageTypeGetChannelMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetChannel.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetChannelListToJson(
    List<enums.IntentResourceIdImageTypeGetChannel>?
        intentResourceIdImageTypeGetChannel) {
  if (intentResourceIdImageTypeGetChannel == null) {
    return [];
  }

  return intentResourceIdImageTypeGetChannel
      .map((e) => enums.$IntentResourceIdImageTypeGetChannelMap[e]!)
      .toList();
}

List<enums.IntentResourceIdImageTypeGetChannel>
    intentResourceIdImageTypeGetChannelListFromJson(
  List? intentResourceIdImageTypeGetChannel, [
  List<enums.IntentResourceIdImageTypeGetChannel>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetChannel == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetChannel
      .map((e) => intentResourceIdImageTypeGetChannelFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetChannel>?
    intentResourceIdImageTypeGetChannelNullableListFromJson(
  List? intentResourceIdImageTypeGetChannel, [
  List<enums.IntentResourceIdImageTypeGetChannel>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetChannel == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetChannel
      .map((e) => intentResourceIdImageTypeGetChannelFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetColorSpaceToJson(
    enums.IntentResourceIdImageTypeGetColorSpace?
        intentResourceIdImageTypeGetColorSpace) {
  return enums.$IntentResourceIdImageTypeGetColorSpaceMap[
      intentResourceIdImageTypeGetColorSpace];
}

enums.IntentResourceIdImageTypeGetColorSpace
    intentResourceIdImageTypeGetColorSpaceFromJson(
  Object? intentResourceIdImageTypeGetColorSpace, [
  enums.IntentResourceIdImageTypeGetColorSpace? defaultValue,
]) {
  if (intentResourceIdImageTypeGetColorSpace is String) {
    return enums.$IntentResourceIdImageTypeGetColorSpaceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                intentResourceIdImageTypeGetColorSpace.toLowerCase(),
            orElse: () => const MapEntry(
                enums.IntentResourceIdImageTypeGetColorSpace
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$IntentResourceIdImageTypeGetColorSpaceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetColorSpace.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetColorSpaceListToJson(
    List<enums.IntentResourceIdImageTypeGetColorSpace>?
        intentResourceIdImageTypeGetColorSpace) {
  if (intentResourceIdImageTypeGetColorSpace == null) {
    return [];
  }

  return intentResourceIdImageTypeGetColorSpace
      .map((e) => enums.$IntentResourceIdImageTypeGetColorSpaceMap[e]!)
      .toList();
}

List<enums.IntentResourceIdImageTypeGetColorSpace>
    intentResourceIdImageTypeGetColorSpaceListFromJson(
  List? intentResourceIdImageTypeGetColorSpace, [
  List<enums.IntentResourceIdImageTypeGetColorSpace>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetColorSpace == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetColorSpace
      .map((e) => intentResourceIdImageTypeGetColorSpaceFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetColorSpace>?
    intentResourceIdImageTypeGetColorSpaceNullableListFromJson(
  List? intentResourceIdImageTypeGetColorSpace, [
  List<enums.IntentResourceIdImageTypeGetColorSpace>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetColorSpace == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetColorSpace
      .map((e) => intentResourceIdImageTypeGetColorSpaceFromJson(e.toString()))
      .toList();
}

String? intentResourceIdImageTypeGetTypeToJson(
    enums.IntentResourceIdImageTypeGetType? intentResourceIdImageTypeGetType) {
  return enums
      .$IntentResourceIdImageTypeGetTypeMap[intentResourceIdImageTypeGetType];
}

enums.IntentResourceIdImageTypeGetType intentResourceIdImageTypeGetTypeFromJson(
  Object? intentResourceIdImageTypeGetType, [
  enums.IntentResourceIdImageTypeGetType? defaultValue,
]) {
  if (intentResourceIdImageTypeGetType is String) {
    return enums.$IntentResourceIdImageTypeGetTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                intentResourceIdImageTypeGetType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.IntentResourceIdImageTypeGetType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$IntentResourceIdImageTypeGetTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.IntentResourceIdImageTypeGetType.swaggerGeneratedUnknown;
}

List<String> intentResourceIdImageTypeGetTypeListToJson(
    List<enums.IntentResourceIdImageTypeGetType>?
        intentResourceIdImageTypeGetType) {
  if (intentResourceIdImageTypeGetType == null) {
    return [];
  }

  return intentResourceIdImageTypeGetType
      .map((e) => enums.$IntentResourceIdImageTypeGetTypeMap[e]!)
      .toList();
}

List<enums.IntentResourceIdImageTypeGetType>
    intentResourceIdImageTypeGetTypeListFromJson(
  List? intentResourceIdImageTypeGetType, [
  List<enums.IntentResourceIdImageTypeGetType>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetType == null) {
    return defaultValue ?? [];
  }

  return intentResourceIdImageTypeGetType
      .map((e) => intentResourceIdImageTypeGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.IntentResourceIdImageTypeGetType>?
    intentResourceIdImageTypeGetTypeNullableListFromJson(
  List? intentResourceIdImageTypeGetType, [
  List<enums.IntentResourceIdImageTypeGetType>? defaultValue,
]) {
  if (intentResourceIdImageTypeGetType == null) {
    return defaultValue;
  }

  return intentResourceIdImageTypeGetType
      .map((e) => intentResourceIdImageTypeGetTypeFromJson(e.toString()))
      .toList();
}

String? pathGetModeToJson(enums.PathGetMode? pathGetMode) {
  return enums.$PathGetModeMap[pathGetMode];
}

enums.PathGetMode pathGetModeFromJson(
  Object? pathGetMode, [
  enums.PathGetMode? defaultValue,
]) {
  if (pathGetMode is String) {
    return enums.$PathGetModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == pathGetMode.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PathGetMode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PathGetModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PathGetMode.swaggerGeneratedUnknown;
}

List<String> pathGetModeListToJson(List<enums.PathGetMode>? pathGetMode) {
  if (pathGetMode == null) {
    return [];
  }

  return pathGetMode.map((e) => enums.$PathGetModeMap[e]!).toList();
}

List<enums.PathGetMode> pathGetModeListFromJson(
  List? pathGetMode, [
  List<enums.PathGetMode>? defaultValue,
]) {
  if (pathGetMode == null) {
    return defaultValue ?? [];
  }

  return pathGetMode.map((e) => pathGetModeFromJson(e.toString())).toList();
}

List<enums.PathGetMode>? pathGetModeNullableListFromJson(
  List? pathGetMode, [
  List<enums.PathGetMode>? defaultValue,
]) {
  if (pathGetMode == null) {
    return defaultValue;
  }

  return pathGetMode.map((e) => pathGetModeFromJson(e.toString())).toList();
}

String? pathGetFormatToJson(enums.PathGetFormat? pathGetFormat) {
  return enums.$PathGetFormatMap[pathGetFormat];
}

enums.PathGetFormat pathGetFormatFromJson(
  Object? pathGetFormat, [
  enums.PathGetFormat? defaultValue,
]) {
  if (pathGetFormat is String) {
    return enums.$PathGetFormatMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == pathGetFormat.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PathGetFormat.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PathGetFormatMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PathGetFormat.swaggerGeneratedUnknown;
}

List<String> pathGetFormatListToJson(List<enums.PathGetFormat>? pathGetFormat) {
  if (pathGetFormat == null) {
    return [];
  }

  return pathGetFormat.map((e) => enums.$PathGetFormatMap[e]!).toList();
}

List<enums.PathGetFormat> pathGetFormatListFromJson(
  List? pathGetFormat, [
  List<enums.PathGetFormat>? defaultValue,
]) {
  if (pathGetFormat == null) {
    return defaultValue ?? [];
  }

  return pathGetFormat.map((e) => pathGetFormatFromJson(e.toString())).toList();
}

List<enums.PathGetFormat>? pathGetFormatNullableListFromJson(
  List? pathGetFormat, [
  List<enums.PathGetFormat>? defaultValue,
]) {
  if (pathGetFormat == null) {
    return defaultValue;
  }

  return pathGetFormat.map((e) => pathGetFormatFromJson(e.toString())).toList();
}

String? pathGetChannelToJson(enums.PathGetChannel? pathGetChannel) {
  return enums.$PathGetChannelMap[pathGetChannel];
}

enums.PathGetChannel pathGetChannelFromJson(
  Object? pathGetChannel, [
  enums.PathGetChannel? defaultValue,
]) {
  if (pathGetChannel is String) {
    return enums.$PathGetChannelMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == pathGetChannel.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PathGetChannel.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PathGetChannelMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PathGetChannel.swaggerGeneratedUnknown;
}

List<String> pathGetChannelListToJson(
    List<enums.PathGetChannel>? pathGetChannel) {
  if (pathGetChannel == null) {
    return [];
  }

  return pathGetChannel.map((e) => enums.$PathGetChannelMap[e]!).toList();
}

List<enums.PathGetChannel> pathGetChannelListFromJson(
  List? pathGetChannel, [
  List<enums.PathGetChannel>? defaultValue,
]) {
  if (pathGetChannel == null) {
    return defaultValue ?? [];
  }

  return pathGetChannel
      .map((e) => pathGetChannelFromJson(e.toString()))
      .toList();
}

List<enums.PathGetChannel>? pathGetChannelNullableListFromJson(
  List? pathGetChannel, [
  List<enums.PathGetChannel>? defaultValue,
]) {
  if (pathGetChannel == null) {
    return defaultValue;
  }

  return pathGetChannel
      .map((e) => pathGetChannelFromJson(e.toString()))
      .toList();
}

String? pathGetColorspaceToJson(enums.PathGetColorspace? pathGetColorspace) {
  return enums.$PathGetColorspaceMap[pathGetColorspace];
}

enums.PathGetColorspace pathGetColorspaceFromJson(
  Object? pathGetColorspace, [
  enums.PathGetColorspace? defaultValue,
]) {
  if (pathGetColorspace is String) {
    return enums.$PathGetColorspaceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == pathGetColorspace.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PathGetColorspace.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PathGetColorspaceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PathGetColorspace.swaggerGeneratedUnknown;
}

List<String> pathGetColorspaceListToJson(
    List<enums.PathGetColorspace>? pathGetColorspace) {
  if (pathGetColorspace == null) {
    return [];
  }

  return pathGetColorspace.map((e) => enums.$PathGetColorspaceMap[e]!).toList();
}

List<enums.PathGetColorspace> pathGetColorspaceListFromJson(
  List? pathGetColorspace, [
  List<enums.PathGetColorspace>? defaultValue,
]) {
  if (pathGetColorspace == null) {
    return defaultValue ?? [];
  }

  return pathGetColorspace
      .map((e) => pathGetColorspaceFromJson(e.toString()))
      .toList();
}

List<enums.PathGetColorspace>? pathGetColorspaceNullableListFromJson(
  List? pathGetColorspace, [
  List<enums.PathGetColorspace>? defaultValue,
]) {
  if (pathGetColorspace == null) {
    return defaultValue;
  }

  return pathGetColorspace
      .map((e) => pathGetColorspaceFromJson(e.toString()))
      .toList();
}

String? metadataPathGetModeToJson(
    enums.MetadataPathGetMode? metadataPathGetMode) {
  return enums.$MetadataPathGetModeMap[metadataPathGetMode];
}

enums.MetadataPathGetMode metadataPathGetModeFromJson(
  Object? metadataPathGetMode, [
  enums.MetadataPathGetMode? defaultValue,
]) {
  if (metadataPathGetMode is String) {
    return enums.$MetadataPathGetModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                metadataPathGetMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MetadataPathGetMode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MetadataPathGetModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MetadataPathGetMode.swaggerGeneratedUnknown;
}

List<String> metadataPathGetModeListToJson(
    List<enums.MetadataPathGetMode>? metadataPathGetMode) {
  if (metadataPathGetMode == null) {
    return [];
  }

  return metadataPathGetMode
      .map((e) => enums.$MetadataPathGetModeMap[e]!)
      .toList();
}

List<enums.MetadataPathGetMode> metadataPathGetModeListFromJson(
  List? metadataPathGetMode, [
  List<enums.MetadataPathGetMode>? defaultValue,
]) {
  if (metadataPathGetMode == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetMode
      .map((e) => metadataPathGetModeFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetMode>? metadataPathGetModeNullableListFromJson(
  List? metadataPathGetMode, [
  List<enums.MetadataPathGetMode>? defaultValue,
]) {
  if (metadataPathGetMode == null) {
    return defaultValue;
  }

  return metadataPathGetMode
      .map((e) => metadataPathGetModeFromJson(e.toString()))
      .toList();
}

String? metadataPathGetFormatToJson(
    enums.MetadataPathGetFormat? metadataPathGetFormat) {
  return enums.$MetadataPathGetFormatMap[metadataPathGetFormat];
}

enums.MetadataPathGetFormat metadataPathGetFormatFromJson(
  Object? metadataPathGetFormat, [
  enums.MetadataPathGetFormat? defaultValue,
]) {
  if (metadataPathGetFormat is String) {
    return enums.$MetadataPathGetFormatMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                metadataPathGetFormat.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MetadataPathGetFormat.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MetadataPathGetFormatMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MetadataPathGetFormat.swaggerGeneratedUnknown;
}

List<String> metadataPathGetFormatListToJson(
    List<enums.MetadataPathGetFormat>? metadataPathGetFormat) {
  if (metadataPathGetFormat == null) {
    return [];
  }

  return metadataPathGetFormat
      .map((e) => enums.$MetadataPathGetFormatMap[e]!)
      .toList();
}

List<enums.MetadataPathGetFormat> metadataPathGetFormatListFromJson(
  List? metadataPathGetFormat, [
  List<enums.MetadataPathGetFormat>? defaultValue,
]) {
  if (metadataPathGetFormat == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetFormat
      .map((e) => metadataPathGetFormatFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetFormat>? metadataPathGetFormatNullableListFromJson(
  List? metadataPathGetFormat, [
  List<enums.MetadataPathGetFormat>? defaultValue,
]) {
  if (metadataPathGetFormat == null) {
    return defaultValue;
  }

  return metadataPathGetFormat
      .map((e) => metadataPathGetFormatFromJson(e.toString()))
      .toList();
}

String? metadataPathGetChannelToJson(
    enums.MetadataPathGetChannel? metadataPathGetChannel) {
  return enums.$MetadataPathGetChannelMap[metadataPathGetChannel];
}

enums.MetadataPathGetChannel metadataPathGetChannelFromJson(
  Object? metadataPathGetChannel, [
  enums.MetadataPathGetChannel? defaultValue,
]) {
  if (metadataPathGetChannel is String) {
    return enums.$MetadataPathGetChannelMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                metadataPathGetChannel.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MetadataPathGetChannel.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MetadataPathGetChannelMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MetadataPathGetChannel.swaggerGeneratedUnknown;
}

List<String> metadataPathGetChannelListToJson(
    List<enums.MetadataPathGetChannel>? metadataPathGetChannel) {
  if (metadataPathGetChannel == null) {
    return [];
  }

  return metadataPathGetChannel
      .map((e) => enums.$MetadataPathGetChannelMap[e]!)
      .toList();
}

List<enums.MetadataPathGetChannel> metadataPathGetChannelListFromJson(
  List? metadataPathGetChannel, [
  List<enums.MetadataPathGetChannel>? defaultValue,
]) {
  if (metadataPathGetChannel == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetChannel
      .map((e) => metadataPathGetChannelFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetChannel>? metadataPathGetChannelNullableListFromJson(
  List? metadataPathGetChannel, [
  List<enums.MetadataPathGetChannel>? defaultValue,
]) {
  if (metadataPathGetChannel == null) {
    return defaultValue;
  }

  return metadataPathGetChannel
      .map((e) => metadataPathGetChannelFromJson(e.toString()))
      .toList();
}

String? metadataPathGetColorspaceToJson(
    enums.MetadataPathGetColorspace? metadataPathGetColorspace) {
  return enums.$MetadataPathGetColorspaceMap[metadataPathGetColorspace];
}

enums.MetadataPathGetColorspace metadataPathGetColorspaceFromJson(
  Object? metadataPathGetColorspace, [
  enums.MetadataPathGetColorspace? defaultValue,
]) {
  if (metadataPathGetColorspace is String) {
    return enums.$MetadataPathGetColorspaceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                metadataPathGetColorspace.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MetadataPathGetColorspace.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MetadataPathGetColorspaceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MetadataPathGetColorspace.swaggerGeneratedUnknown;
}

List<String> metadataPathGetColorspaceListToJson(
    List<enums.MetadataPathGetColorspace>? metadataPathGetColorspace) {
  if (metadataPathGetColorspace == null) {
    return [];
  }

  return metadataPathGetColorspace
      .map((e) => enums.$MetadataPathGetColorspaceMap[e]!)
      .toList();
}

List<enums.MetadataPathGetColorspace> metadataPathGetColorspaceListFromJson(
  List? metadataPathGetColorspace, [
  List<enums.MetadataPathGetColorspace>? defaultValue,
]) {
  if (metadataPathGetColorspace == null) {
    return defaultValue ?? [];
  }

  return metadataPathGetColorspace
      .map((e) => metadataPathGetColorspaceFromJson(e.toString()))
      .toList();
}

List<enums.MetadataPathGetColorspace>?
    metadataPathGetColorspaceNullableListFromJson(
  List? metadataPathGetColorspace, [
  List<enums.MetadataPathGetColorspace>? defaultValue,
]) {
  if (metadataPathGetColorspace == null) {
    return defaultValue;
  }

  return metadataPathGetColorspace
      .map((e) => metadataPathGetColorspaceFromJson(e.toString()))
      .toList();
}

String? contentRequestTypeToJson(enums.ContentRequestType? contentRequestType) {
  return enums.$ContentRequestTypeMap[contentRequestType];
}

enums.ContentRequestType contentRequestTypeFromJson(
  Object? contentRequestType, [
  enums.ContentRequestType? defaultValue,
]) {
  if (contentRequestType is String) {
    return enums.$ContentRequestTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == contentRequestType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ContentRequestType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContentRequestTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContentRequestType.swaggerGeneratedUnknown;
}

List<String> contentRequestTypeListToJson(
    List<enums.ContentRequestType>? contentRequestType) {
  if (contentRequestType == null) {
    return [];
  }

  return contentRequestType
      .map((e) => enums.$ContentRequestTypeMap[e]!)
      .toList();
}

List<enums.ContentRequestType> contentRequestTypeListFromJson(
  List? contentRequestType, [
  List<enums.ContentRequestType>? defaultValue,
]) {
  if (contentRequestType == null) {
    return defaultValue ?? [];
  }

  return contentRequestType
      .map((e) => contentRequestTypeFromJson(e.toString()))
      .toList();
}

List<enums.ContentRequestType>? contentRequestTypeNullableListFromJson(
  List? contentRequestType, [
  List<enums.ContentRequestType>? defaultValue,
]) {
  if (contentRequestType == null) {
    return defaultValue;
  }

  return contentRequestType
      .map((e) => contentRequestTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
