// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'issue_469.enums.swagger.dart' as enums;
export 'issue_469.enums.swagger.dart';

part 'issue_469.swagger.chopper.dart';
part 'issue_469.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class Issue469 extends ChopperService {
  static Issue469 create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$Issue469(client);
    }

    final newClient = ChopperClient(
        services: [_$Issue469()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$Issue469(newClient);
  }

  ///Read system information
  Future<chopper.Response<SystemInfo>> systemGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(SystemInfo, () => SystemInfo.fromJsonFactory);

    return _systemGet(cacheControl: cacheControl);
  }

  ///Read system information
  @Get(path: '/system')
  Future<chopper.Response<SystemInfo>> _systemGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Reboot the system
  Future<chopper.Response> systemRebootPost({String? cacheControl}) {
    return _systemRebootPost(cacheControl: cacheControl);
  }

  ///Reboot the system
  @Post(
    path: '/system/reboot',
    optionalBody: true,
  )
  Future<chopper.Response> _systemRebootPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Shut down the system
  Future<chopper.Response> systemShutdownPost({
    String? cacheControl,
    required SystemShutdownPost$RequestBody? body,
  }) {
    return _systemShutdownPost(cacheControl: cacheControl, body: body);
  }

  ///Shut down the system
  @Post(path: '/system/shutdown')
  Future<chopper.Response> _systemShutdownPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SystemShutdownPost$RequestBody? body,
  });

  ///Get screen
  Future<chopper.Response<Object>> screensScreenIdGet({
    required int? screenId,
    String? cacheControl,
    required Object? body,
  }) {
    return _screensScreenIdGet(
        screenId: screenId, cacheControl: cacheControl, body: body);
  }

  ///Get screen
  @Get(path: '/screens/{screenId}')
  Future<chopper.Response<Object>> _screensScreenIdGet({
    @Path('screenId') required int? screenId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Object? body,
  });

  ///Recall a preset from memory to a single screen
  Future<chopper.Response> screensScreenIdLoadMemoryPost({
    required int? screenId,
    String? cacheControl,
    required ScreensScreenIdLoadMemoryPost$RequestBody? body,
  }) {
    return _screensScreenIdLoadMemoryPost(
        screenId: screenId, cacheControl: cacheControl, body: body);
  }

  ///Recall a preset from memory to a single screen
  @Post(path: '/screens/{screenId}/load-memory')
  Future<chopper.Response> _screensScreenIdLoadMemoryPost({
    @Path('screenId') required int? screenId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ScreensScreenIdLoadMemoryPost$RequestBody? body,
  });

  ///Recall a master preset from memory
  Future<chopper.Response> loadMasterMemoryPost({
    String? cacheControl,
    required LoadMasterMemoryPost$RequestBody? body,
  }) {
    return _loadMasterMemoryPost(cacheControl: cacheControl, body: body);
  }

  ///Recall a master preset from memory
  @Post(path: '/load-master-memory')
  Future<chopper.Response> _loadMasterMemoryPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required LoadMasterMemoryPost$RequestBody? body,
  });

  ///Read layer information
  Future<chopper.Response<Object>> screensScreenIdLayersLayerIdGet({
    required int? screenId,
    required int? layerId,
    String? cacheControl,
  }) {
    return _screensScreenIdLayersLayerIdGet(
        screenId: screenId, layerId: layerId, cacheControl: cacheControl);
  }

  ///Read layer information
  @Get(path: '/screens/{screenId}/layers/{layerId}')
  Future<chopper.Response<Object>> _screensScreenIdLayersLayerIdGet({
    @Path('screenId') required int? screenId,
    @Path('layerId') required int? layerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read a layer status
  Future<chopper.Response<Object>>
      screensScreenIdLayersLayerIdPresetsTargetGet({
    required int? screenId,
    required int? layerId,
    required enums.Target? target,
    String? cacheControl,
  }) {
    return _screensScreenIdLayersLayerIdPresetsTargetGet(
        screenId: screenId,
        layerId: layerId,
        target: enums.$TargetMap[target]?.toString(),
        cacheControl: cacheControl);
  }

  ///Read a layer status
  @Get(path: '/screens/{screenId}/layers/{layerId}/presets/{target}')
  Future<chopper.Response<Object>>
      _screensScreenIdLayersLayerIdPresetsTargetGet({
    @Path('screenId') required int? screenId,
    @Path('layerId') required int? layerId,
    @Path('target') required String? target,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set a layer source
  Future<chopper.Response> screensScreenIdLayersLayerIdPresetsTargetSourcePost({
    required int? screenId,
    required int? layerId,
    required enums.Target? target,
    String? cacheControl,
    required ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody?
        body,
  }) {
    return _screensScreenIdLayersLayerIdPresetsTargetSourcePost(
        screenId: screenId,
        layerId: layerId,
        target: enums.$TargetMap[target]?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Set a layer source
  @Post(path: '/screens/{screenId}/layers/{layerId}/presets/{target}/source')
  Future<chopper.Response>
      _screensScreenIdLayersLayerIdPresetsTargetSourcePost({
    @Path('screenId') required int? screenId,
    @Path('layerId') required int? layerId,
    @Path('target') required String? target,
    @Header('Cache-Control') String? cacheControl,
    @Body()
        required ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody?
            body,
  });

  ///Read background layer status
  Future<chopper.Response<Object>>
      screensScreenIdBackgroundLayerPresetsTargetGet({
    required int? screenId,
    required enums.Target? target,
    String? cacheControl,
  }) {
    return _screensScreenIdBackgroundLayerPresetsTargetGet(
        screenId: screenId,
        target: enums.$TargetMap[target]?.toString(),
        cacheControl: cacheControl);
  }

  ///Read background layer status
  @Get(path: '/screens/{screenId}/background-layer/presets/{target}')
  Future<chopper.Response<Object>>
      _screensScreenIdBackgroundLayerPresetsTargetGet({
    @Path('screenId') required int? screenId,
    @Path('target') required String? target,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set background layer source
  Future<chopper.Response>
      screensScreenIdBackgroundLayerPresetsTargetSourcePost({
    required int? screenId,
    required enums.Target? target,
    String? cacheControl,
    required ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody?
        body,
  }) {
    return _screensScreenIdBackgroundLayerPresetsTargetSourcePost(
        screenId: screenId,
        target: enums.$TargetMap[target]?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Set background layer source
  @Post(path: '/screens/{screenId}/background-layer/presets/{target}/source')
  Future<chopper.Response>
      _screensScreenIdBackgroundLayerPresetsTargetSourcePost({
    @Path('screenId') required int? screenId,
    @Path('target') required String? target,
    @Header('Cache-Control') String? cacheControl,
    @Body()
        required ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody?
            body,
  });

  ///Single TAKE: Transitioning the Preview content to the Program (single screen)
  Future<chopper.Response> screensScreenIdTakePost({
    required int? screenId,
    String? cacheControl,
  }) {
    return _screensScreenIdTakePost(
        screenId: screenId, cacheControl: cacheControl);
  }

  ///Single TAKE: Transitioning the Preview content to the Program (single screen)
  @Post(
    path: '/screens/{screenId}/take',
    optionalBody: true,
  )
  Future<chopper.Response> _screensScreenIdTakePost({
    @Path('screenId') required int? screenId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Global TAKE: Transitioning the Preview content to the Program (multiple screens)
  Future<chopper.Response> takePost({
    String? cacheControl,
    required TakePost$RequestBody? body,
  }) {
    return _takePost(cacheControl: cacheControl, body: body);
  }

  ///Global TAKE: Transitioning the Preview content to the Program (multiple screens)
  @Post(path: '/take')
  Future<chopper.Response> _takePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TakePost$RequestBody? body,
  });

  ///Read auxiliary screen information
  Future<chopper.Response<Object>> auxiliaryScreensAuxIdGet({
    required int? auxId,
    String? cacheControl,
  }) {
    return _auxiliaryScreensAuxIdGet(auxId: auxId, cacheControl: cacheControl);
  }

  ///Read auxiliary screen information
  @Get(path: '/auxiliary-screens/{auxId}')
  Future<chopper.Response<Object>> _auxiliaryScreensAuxIdGet({
    @Path('auxId') required int? auxId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Recall a preset from memory to a single auxiliary screen
  Future<chopper.Response> auxiliaryScreensAuxIdLoadMemoryPost({
    required int? auxId,
    String? cacheControl,
    required AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody? body,
  }) {
    return _auxiliaryScreensAuxIdLoadMemoryPost(
        auxId: auxId, cacheControl: cacheControl, body: body);
  }

  ///Recall a preset from memory to a single auxiliary screen
  @Post(path: '/auxiliary-screens/{auxId}/load-memory')
  Future<chopper.Response> _auxiliaryScreensAuxIdLoadMemoryPost({
    @Path('auxId') required int? auxId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody? body,
  });

  ///Read the layer capacity of an auxiliary screen
  Future<chopper.Response<Object>> auxiliaryScreensAuxIdLayersLayerIdGet({
    required int? auxId,
    required int? layerId,
    String? cacheControl,
  }) {
    return _auxiliaryScreensAuxIdLayersLayerIdGet(
        auxId: auxId, layerId: layerId, cacheControl: cacheControl);
  }

  ///Read the layer capacity of an auxiliary screen
  @Get(path: '/auxiliary-screens/{auxId}/layers/{layerId}')
  Future<chopper.Response<Object>> _auxiliaryScreensAuxIdLayersLayerIdGet({
    @Path('auxId') required int? auxId,
    @Path('layerId') required int? layerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read the layer source of an auxiliary screen
  Future<chopper.Response<Object>>
      auxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourceGet({
    required int? auxId,
    required int? layerId,
    required enums.Target? target,
    String? cacheControl,
  }) {
    return _auxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourceGet(
        auxId: auxId,
        layerId: layerId,
        target: enums.$TargetMap[target]?.toString(),
        cacheControl: cacheControl);
  }

  ///Read the layer source of an auxiliary screen
  @Get(
      path:
          '/auxiliary-screens/{auxId}/layers/{layerId}/presets/{target}/source')
  Future<chopper.Response<Object>>
      _auxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourceGet({
    @Path('auxId') required int? auxId,
    @Path('layerId') required int? layerId,
    @Path('target') required String? target,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set the layer source of an auxiliary screen
  Future<chopper.Response>
      auxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost({
    required int? auxId,
    required int? layerId,
    required enums.Target? target,
    String? cacheControl,
    required AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody?
        body,
  }) {
    return _auxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost(
        auxId: auxId,
        layerId: layerId,
        target: enums.$TargetMap[target]?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Set the layer source of an auxiliary screen
  @Post(
      path:
          '/auxiliary-screens/{auxId}/layers/{layerId}/presets/{target}/source')
  Future<chopper.Response>
      _auxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost({
    @Path('auxId') required int? auxId,
    @Path('layerId') required int? layerId,
    @Path('target') required String? target,
    @Header('Cache-Control') String? cacheControl,
    @Body()
        required AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody?
            body,
  });

  ///TAKE: Transitioning the Preview content to the Program (single auxiliary screen)
  Future<chopper.Response> auxiliaryScreensAuxIdTakePost({
    required int? auxId,
    String? cacheControl,
  }) {
    return _auxiliaryScreensAuxIdTakePost(
        auxId: auxId, cacheControl: cacheControl);
  }

  ///TAKE: Transitioning the Preview content to the Program (single auxiliary screen)
  @Post(
    path: '/auxiliary-screens/{auxId}/take',
    optionalBody: true,
  )
  Future<chopper.Response> _auxiliaryScreensAuxIdTakePost({
    @Path('auxId') required int? auxId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read multiviewer output information
  Future<chopper.Response<Object>> multiviewersMvwIdGet({
    required int? mvwId,
    String? cacheControl,
  }) {
    return _multiviewersMvwIdGet(mvwId: mvwId, cacheControl: cacheControl);
  }

  ///Read multiviewer output information
  @Get(path: '/multiviewers/{mvwId}')
  Future<chopper.Response<Object>> _multiviewersMvwIdGet({
    @Path('mvwId') required int? mvwId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Recall a preset from memory to a multiviewer output
  Future<chopper.Response> multiviewersMvwIdLoadMemoryPost({
    required int? mvwId,
    String? cacheControl,
    required MultiviewersMvwIdLoadMemoryPost$RequestBody? body,
  }) {
    return _multiviewersMvwIdLoadMemoryPost(
        mvwId: mvwId, cacheControl: cacheControl, body: body);
  }

  ///Recall a preset from memory to a multiviewer output
  @Post(path: '/multiviewers/{mvwId}/load-memory')
  Future<chopper.Response> _multiviewersMvwIdLoadMemoryPost({
    @Path('mvwId') required int? mvwId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required MultiviewersMvwIdLoadMemoryPost$RequestBody? body,
  });

  ///Read the source of a multiviewer output widget
  Future<chopper.Response<Object>> multiviewersMvwIdWidgetsWidgetIdSourceGet({
    required int? mvwId,
    required int? widgetId,
    String? cacheControl,
  }) {
    return _multiviewersMvwIdWidgetsWidgetIdSourceGet(
        mvwId: mvwId, widgetId: widgetId, cacheControl: cacheControl);
  }

  ///Read the source of a multiviewer output widget
  @Get(path: '/multiviewers/{mvwId}/widgets/{widgetId}/source')
  Future<chopper.Response<Object>> _multiviewersMvwIdWidgetsWidgetIdSourceGet({
    @Path('mvwId') required int? mvwId,
    @Path('widgetId') required int? widgetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set the source of a multiviewer output widget
  Future<chopper.Response> multiviewersMvwIdWidgetsWidgetIdSourcePost({
    required int? mvwId,
    required int? widgetId,
    String? cacheControl,
    required MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody? body,
  }) {
    return _multiviewersMvwIdWidgetsWidgetIdSourcePost(
        mvwId: mvwId,
        widgetId: widgetId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Set the source of a multiviewer output widget
  @Post(path: '/multiviewers/{mvwId}/widgets/{widgetId}/source')
  Future<chopper.Response> _multiviewersMvwIdWidgetsWidgetIdSourcePost({
    @Path('mvwId') required int? mvwId,
    @Path('widgetId') required int? widgetId,
    @Header('Cache-Control') String? cacheControl,
    @Body()
        required MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody? body,
  });

  ///Read the status of a multiviewer output widget
  Future<chopper.Response<Object>> multiviewersMvwIdWidgetsWidgetIdGet({
    required int? mvwId,
    required int? widgetId,
    String? cacheControl,
  }) {
    return _multiviewersMvwIdWidgetsWidgetIdGet(
        mvwId: mvwId, widgetId: widgetId, cacheControl: cacheControl);
  }

  ///Read the status of a multiviewer output widget
  @Get(path: '/multiviewers/{mvwId}/widgets/{widgetId}')
  Future<chopper.Response<Object>> _multiviewersMvwIdWidgetsWidgetIdGet({
    @Path('mvwId') required int? mvwId,
    @Path('widgetId') required int? widgetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read input information
  Future<chopper.Response<Object>> inputsInputIdGet({
    required int? inputId,
    String? cacheControl,
  }) {
    return _inputsInputIdGet(inputId: inputId, cacheControl: cacheControl);
  }

  ///Read input information
  @Get(path: '/inputs/{inputId}')
  Future<chopper.Response<Object>> _inputsInputIdGet({
    @Path('inputId') required int? inputId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read still image information
  Future<chopper.Response<Object>> imagesImageIdGet({
    required int? imageId,
    String? cacheControl,
  }) {
    return _imagesImageIdGet(imageId: imageId, cacheControl: cacheControl);
  }

  ///Read still image information
  @Get(path: '/images/{imageId}')
  Future<chopper.Response<Object>> _imagesImageIdGet({
    @Path('imageId') required int? imageId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read background set information
  Future<chopper.Response<Object>>
      screensScreenIdBackgroundSetsBackgroundSetIdGet({
    required int? screenId,
    required int? backgroundSetId,
    String? cacheControl,
  }) {
    return _screensScreenIdBackgroundSetsBackgroundSetIdGet(
        screenId: screenId,
        backgroundSetId: backgroundSetId,
        cacheControl: cacheControl);
  }

  ///Read background set information
  @Get(path: '/screens/{screenId}/background-sets/{backgroundSetId}')
  Future<chopper.Response<Object>>
      _screensScreenIdBackgroundSetsBackgroundSetIdGet({
    @Path('screenId') required int? screenId,
    @Path('backgroundSetId') required int? backgroundSetId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class SystemInfo {
  SystemInfo({
    this.type,
    this.label,
    this.version,
  });

  factory SystemInfo.fromJson(Map<String, dynamic> json) =>
      _$SystemInfoFromJson(json);

  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'label', includeIfNull: false, defaultValue: '')
  final String? label;
  @JsonKey(name: 'version', includeIfNull: false)
  final SystemInfo$Version? version;
  static const fromJsonFactory = _$SystemInfoFromJson;
  static const toJsonFactory = _$SystemInfoToJson;
  Map<String, dynamic> toJson() => _$SystemInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemInfo &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.label, label) ||
                const DeepCollectionEquality().equals(other.label, label)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality().equals(other.version, version)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(label) ^
      const DeepCollectionEquality().hash(version) ^
      runtimeType.hashCode;
}

extension $SystemInfoExtension on SystemInfo {
  SystemInfo copyWith(
      {String? type, String? label, SystemInfo$Version? version}) {
    return SystemInfo(
        type: type ?? this.type,
        label: label ?? this.label,
        version: version ?? this.version);
  }

  SystemInfo copyWithWrapped(
      {Wrapped<String?>? type,
      Wrapped<String?>? label,
      Wrapped<SystemInfo$Version?>? version}) {
    return SystemInfo(
        type: (type != null ? type.value : this.type),
        label: (label != null ? label.value : this.label),
        version: (version != null ? version.value : this.version));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenId {
  ScreenId({
    this.id,
  });

  factory ScreenId.fromJson(Map<String, dynamic> json) =>
      _$ScreenIdFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  static const fromJsonFactory = _$ScreenIdFromJson;
  static const toJsonFactory = _$ScreenIdToJson;
  Map<String, dynamic> toJson() => _$ScreenIdToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenId &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $ScreenIdExtension on ScreenId {
  ScreenId copyWith({int? id}) {
    return ScreenId(id: id ?? this.id);
  }

  ScreenId copyWithWrapped({Wrapped<int?>? id}) {
    return ScreenId(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemInfo$Version {
  SystemInfo$Version({
    this.major,
    this.minor,
    this.patch,
    this.beta,
  });

  factory SystemInfo$Version.fromJson(Map<String, dynamic> json) =>
      _$SystemInfo$VersionFromJson(json);

  @JsonKey(name: 'major', includeIfNull: false)
  final int? major;
  @JsonKey(name: 'minor', includeIfNull: false)
  final int? minor;
  @JsonKey(name: 'patch', includeIfNull: false)
  final int? patch;
  @JsonKey(name: 'beta', includeIfNull: false)
  final bool? beta;
  static const fromJsonFactory = _$SystemInfo$VersionFromJson;
  static const toJsonFactory = _$SystemInfo$VersionToJson;
  Map<String, dynamic> toJson() => _$SystemInfo$VersionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemInfo$Version &&
            (identical(other.major, major) ||
                const DeepCollectionEquality().equals(other.major, major)) &&
            (identical(other.minor, minor) ||
                const DeepCollectionEquality().equals(other.minor, minor)) &&
            (identical(other.patch, patch) ||
                const DeepCollectionEquality().equals(other.patch, patch)) &&
            (identical(other.beta, beta) ||
                const DeepCollectionEquality().equals(other.beta, beta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(major) ^
      const DeepCollectionEquality().hash(minor) ^
      const DeepCollectionEquality().hash(patch) ^
      const DeepCollectionEquality().hash(beta) ^
      runtimeType.hashCode;
}

extension $SystemInfo$VersionExtension on SystemInfo$Version {
  SystemInfo$Version copyWith(
      {int? major, int? minor, int? patch, bool? beta}) {
    return SystemInfo$Version(
        major: major ?? this.major,
        minor: minor ?? this.minor,
        patch: patch ?? this.patch,
        beta: beta ?? this.beta);
  }

  SystemInfo$Version copyWithWrapped(
      {Wrapped<int?>? major,
      Wrapped<int?>? minor,
      Wrapped<int?>? patch,
      Wrapped<bool?>? beta}) {
    return SystemInfo$Version(
        major: (major != null ? major.value : this.major),
        minor: (minor != null ? minor.value : this.minor),
        patch: (patch != null ? patch.value : this.patch),
        beta: (beta != null ? beta.value : this.beta));
  }
}

String? targetToJson(enums.Target? target) {
  return enums.$TargetMap[target];
}

enums.Target targetFromJson(
  Object? target, [
  enums.Target? defaultValue,
]) {
  if (target is String) {
    return enums.$TargetMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == target.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.Target.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TargetMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.Target.swaggerGeneratedUnknown;
}

List<String> targetListToJson(List<enums.Target>? target) {
  if (target == null) {
    return [];
  }

  return target.map((e) => enums.$TargetMap[e]!).toList();
}

List<enums.Target> targetListFromJson(
  List? target, [
  List<enums.Target>? defaultValue,
]) {
  if (target == null) {
    return defaultValue ?? [];
  }

  return target.map((e) => targetFromJson(e.toString())).toList();
}

List<enums.Target>? targetNullableListFromJson(
  List? target, [
  List<enums.Target>? defaultValue,
]) {
  if (target == null) {
    return defaultValue;
  }

  return target.map((e) => targetFromJson(e.toString())).toList();
}

String? sourceTypeToJson(enums.SourceType? sourceType) {
  return enums.$SourceTypeMap[sourceType];
}

enums.SourceType sourceTypeFromJson(
  Object? sourceType, [
  enums.SourceType? defaultValue,
]) {
  if (sourceType is String) {
    return enums.$SourceTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == sourceType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.SourceType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SourceTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SourceType.swaggerGeneratedUnknown;
}

List<String> sourceTypeListToJson(List<enums.SourceType>? sourceType) {
  if (sourceType == null) {
    return [];
  }

  return sourceType.map((e) => enums.$SourceTypeMap[e]!).toList();
}

List<enums.SourceType> sourceTypeListFromJson(
  List? sourceType, [
  List<enums.SourceType>? defaultValue,
]) {
  if (sourceType == null) {
    return defaultValue ?? [];
  }

  return sourceType.map((e) => sourceTypeFromJson(e.toString())).toList();
}

List<enums.SourceType>? sourceTypeNullableListFromJson(
  List? sourceType, [
  List<enums.SourceType>? defaultValue,
]) {
  if (sourceType == null) {
    return defaultValue;
  }

  return sourceType.map((e) => sourceTypeFromJson(e.toString())).toList();
}

String? mvwSourceTypeToJson(enums.MvwSourceType? mvwSourceType) {
  return enums.$MvwSourceTypeMap[mvwSourceType];
}

enums.MvwSourceType mvwSourceTypeFromJson(
  Object? mvwSourceType, [
  enums.MvwSourceType? defaultValue,
]) {
  if (mvwSourceType is String) {
    return enums.$MvwSourceTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == mvwSourceType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.MvwSourceType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MvwSourceTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MvwSourceType.swaggerGeneratedUnknown;
}

List<String> mvwSourceTypeListToJson(List<enums.MvwSourceType>? mvwSourceType) {
  if (mvwSourceType == null) {
    return [];
  }

  return mvwSourceType.map((e) => enums.$MvwSourceTypeMap[e]!).toList();
}

List<enums.MvwSourceType> mvwSourceTypeListFromJson(
  List? mvwSourceType, [
  List<enums.MvwSourceType>? defaultValue,
]) {
  if (mvwSourceType == null) {
    return defaultValue ?? [];
  }

  return mvwSourceType.map((e) => mvwSourceTypeFromJson(e.toString())).toList();
}

List<enums.MvwSourceType>? mvwSourceTypeNullableListFromJson(
  List? mvwSourceType, [
  List<enums.MvwSourceType>? defaultValue,
]) {
  if (mvwSourceType == null) {
    return defaultValue;
  }

  return mvwSourceType.map((e) => mvwSourceTypeFromJson(e.toString())).toList();
}

String? loadMasterMemoryPost$RequestBodyTargetToJson(
    enums.LoadMasterMemoryPost$RequestBodyTarget?
        loadMasterMemoryPost$RequestBodyTarget) {
  return enums.$LoadMasterMemoryPost$RequestBodyTargetMap[
      loadMasterMemoryPost$RequestBodyTarget];
}

enums.LoadMasterMemoryPost$RequestBodyTarget
    loadMasterMemoryPost$RequestBodyTargetFromJson(
  Object? loadMasterMemoryPost$RequestBodyTarget, [
  enums.LoadMasterMemoryPost$RequestBodyTarget? defaultValue,
]) {
  if (loadMasterMemoryPost$RequestBodyTarget is String) {
    return enums.$LoadMasterMemoryPost$RequestBodyTargetMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                loadMasterMemoryPost$RequestBodyTarget.toLowerCase(),
            orElse: () => const MapEntry(
                enums.LoadMasterMemoryPost$RequestBodyTarget
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LoadMasterMemoryPost$RequestBodyTargetMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LoadMasterMemoryPost$RequestBodyTarget.swaggerGeneratedUnknown;
}

List<String> loadMasterMemoryPost$RequestBodyTargetListToJson(
    List<enums.LoadMasterMemoryPost$RequestBodyTarget>?
        loadMasterMemoryPost$RequestBodyTarget) {
  if (loadMasterMemoryPost$RequestBodyTarget == null) {
    return [];
  }

  return loadMasterMemoryPost$RequestBodyTarget
      .map((e) => enums.$LoadMasterMemoryPost$RequestBodyTargetMap[e]!)
      .toList();
}

List<enums.LoadMasterMemoryPost$RequestBodyTarget>
    loadMasterMemoryPost$RequestBodyTargetListFromJson(
  List? loadMasterMemoryPost$RequestBodyTarget, [
  List<enums.LoadMasterMemoryPost$RequestBodyTarget>? defaultValue,
]) {
  if (loadMasterMemoryPost$RequestBodyTarget == null) {
    return defaultValue ?? [];
  }

  return loadMasterMemoryPost$RequestBodyTarget
      .map((e) => loadMasterMemoryPost$RequestBodyTargetFromJson(e.toString()))
      .toList();
}

List<enums.LoadMasterMemoryPost$RequestBodyTarget>?
    loadMasterMemoryPost$RequestBodyTargetNullableListFromJson(
  List? loadMasterMemoryPost$RequestBodyTarget, [
  List<enums.LoadMasterMemoryPost$RequestBodyTarget>? defaultValue,
]) {
  if (loadMasterMemoryPost$RequestBodyTarget == null) {
    return defaultValue;
  }

  return loadMasterMemoryPost$RequestBodyTarget
      .map((e) => loadMasterMemoryPost$RequestBodyTargetFromJson(e.toString()))
      .toList();
}

String? screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeToJson(
    enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType?
        screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType) {
  return enums
          .$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeMap[
      screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType];
}

enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
    screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeFromJson(
  Object?
      screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType, [
  enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType?
      defaultValue,
]) {
  if (screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
      is String) {
    return enums
        .$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeMap
        .entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums
                    .ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums
          .$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeMap
          .entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums
          .ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
          .swaggerGeneratedUnknown;
}

List<String>
    screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeListToJson(
        List<enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType>?
            screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType) {
  if (screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType ==
      null) {
    return [];
  }

  return screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
      .map((e) => enums
          .$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeMap[e]!)
      .toList();
}

List<enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType>
    screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeListFromJson(
  List?
      screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType, [
  List<enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType>?
      defaultValue,
]) {
  if (screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType ==
      null) {
    return defaultValue ?? [];
  }

  return screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
      .map((e) =>
          screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeFromJson(
              e.toString()))
      .toList();
}

List<enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType>?
    screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeNullableListFromJson(
  List?
      screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType, [
  List<enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType>?
      defaultValue,
]) {
  if (screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType ==
      null) {
    return defaultValue;
  }

  return screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType
      .map((e) =>
          screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeFromJson(
              e.toString()))
      .toList();
}

String? screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeToJson(
    enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType?
        screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType) {
  return enums
          .$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeMap[
      screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType];
}

enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
    screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeFromJson(
  Object?
      screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType, [
  enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType?
      defaultValue,
]) {
  if (screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
      is String) {
    return enums
        .$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeMap
        .entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums
                    .ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums
          .$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeMap
          .entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums
          .ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
          .swaggerGeneratedUnknown;
}

List<String>
    screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeListToJson(
        List<enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType>?
            screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType) {
  if (screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType ==
      null) {
    return [];
  }

  return screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
      .map((e) => enums
          .$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeMap[e]!)
      .toList();
}

List<enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType>
    screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeListFromJson(
  List?
      screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType, [
  List<enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType>?
      defaultValue,
]) {
  if (screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType ==
      null) {
    return defaultValue ?? [];
  }

  return screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
      .map((e) =>
          screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeFromJson(
              e.toString()))
      .toList();
}

List<enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType>?
    screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeNullableListFromJson(
  List?
      screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType, [
  List<enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType>?
      defaultValue,
]) {
  if (screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType ==
      null) {
    return defaultValue;
  }

  return screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
      .map((e) =>
          screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeFromJson(
              e.toString()))
      .toList();
}

@JsonSerializable(explicitToJson: true)
class SystemShutdownPost$RequestBody {
  SystemShutdownPost$RequestBody({
    this.enableWakeOnLAN,
  });

  factory SystemShutdownPost$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$SystemShutdownPost$RequestBodyFromJson(json);

  @JsonKey(name: 'enableWakeOnLAN', includeIfNull: false, defaultValue: false)
  final bool? enableWakeOnLAN;
  static const fromJsonFactory = _$SystemShutdownPost$RequestBodyFromJson;
  static const toJsonFactory = _$SystemShutdownPost$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$SystemShutdownPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemShutdownPost$RequestBody &&
            (identical(other.enableWakeOnLAN, enableWakeOnLAN) ||
                const DeepCollectionEquality()
                    .equals(other.enableWakeOnLAN, enableWakeOnLAN)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(enableWakeOnLAN) ^
      runtimeType.hashCode;
}

extension $SystemShutdownPost$RequestBodyExtension
    on SystemShutdownPost$RequestBody {
  SystemShutdownPost$RequestBody copyWith({bool? enableWakeOnLAN}) {
    return SystemShutdownPost$RequestBody(
        enableWakeOnLAN: enableWakeOnLAN ?? this.enableWakeOnLAN);
  }

  SystemShutdownPost$RequestBody copyWithWrapped(
      {Wrapped<bool?>? enableWakeOnLAN}) {
    return SystemShutdownPost$RequestBody(
        enableWakeOnLAN: (enableWakeOnLAN != null
            ? enableWakeOnLAN.value
            : this.enableWakeOnLAN));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreensScreenIdLoadMemoryPost$RequestBody {
  ScreensScreenIdLoadMemoryPost$RequestBody({
    required this.memoryId,
    this.target,
  });

  factory ScreensScreenIdLoadMemoryPost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$ScreensScreenIdLoadMemoryPost$RequestBodyFromJson(json);

  @JsonKey(name: 'memoryId', includeIfNull: false)
  final int memoryId;
  @JsonKey(
    name: 'target',
    includeIfNull: false,
    toJson: targetToJson,
    fromJson: targetFromJson,
  )
  final enums.Target? target;
  static const fromJsonFactory =
      _$ScreensScreenIdLoadMemoryPost$RequestBodyFromJson;
  static const toJsonFactory =
      _$ScreensScreenIdLoadMemoryPost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$ScreensScreenIdLoadMemoryPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreensScreenIdLoadMemoryPost$RequestBody &&
            (identical(other.memoryId, memoryId) ||
                const DeepCollectionEquality()
                    .equals(other.memoryId, memoryId)) &&
            (identical(other.target, target) ||
                const DeepCollectionEquality().equals(other.target, target)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(memoryId) ^
      const DeepCollectionEquality().hash(target) ^
      runtimeType.hashCode;
}

extension $ScreensScreenIdLoadMemoryPost$RequestBodyExtension
    on ScreensScreenIdLoadMemoryPost$RequestBody {
  ScreensScreenIdLoadMemoryPost$RequestBody copyWith(
      {int? memoryId, enums.Target? target}) {
    return ScreensScreenIdLoadMemoryPost$RequestBody(
        memoryId: memoryId ?? this.memoryId, target: target ?? this.target);
  }

  ScreensScreenIdLoadMemoryPost$RequestBody copyWithWrapped(
      {Wrapped<int>? memoryId, Wrapped<enums.Target?>? target}) {
    return ScreensScreenIdLoadMemoryPost$RequestBody(
        memoryId: (memoryId != null ? memoryId.value : this.memoryId),
        target: (target != null ? target.value : this.target));
  }
}

@JsonSerializable(explicitToJson: true)
class LoadMasterMemoryPost$RequestBody {
  LoadMasterMemoryPost$RequestBody({
    required this.memoryId,
    this.target,
  });

  factory LoadMasterMemoryPost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$LoadMasterMemoryPost$RequestBodyFromJson(json);

  @JsonKey(name: 'memoryId', includeIfNull: false)
  final int memoryId;
  @JsonKey(
    name: 'target',
    includeIfNull: false,
    toJson: loadMasterMemoryPost$RequestBodyTargetToJson,
    fromJson: loadMasterMemoryPost$RequestBodyTargetTargetFromJson,
  )
  final enums.LoadMasterMemoryPost$RequestBodyTarget? target;
  static enums.LoadMasterMemoryPost$RequestBodyTarget
      loadMasterMemoryPost$RequestBodyTargetTargetFromJson(Object? value) =>
          loadMasterMemoryPost$RequestBodyTargetFromJson(
              value, enums.LoadMasterMemoryPost$RequestBodyTarget.preview);

  static const fromJsonFactory = _$LoadMasterMemoryPost$RequestBodyFromJson;
  static const toJsonFactory = _$LoadMasterMemoryPost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$LoadMasterMemoryPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LoadMasterMemoryPost$RequestBody &&
            (identical(other.memoryId, memoryId) ||
                const DeepCollectionEquality()
                    .equals(other.memoryId, memoryId)) &&
            (identical(other.target, target) ||
                const DeepCollectionEquality().equals(other.target, target)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(memoryId) ^
      const DeepCollectionEquality().hash(target) ^
      runtimeType.hashCode;
}

extension $LoadMasterMemoryPost$RequestBodyExtension
    on LoadMasterMemoryPost$RequestBody {
  LoadMasterMemoryPost$RequestBody copyWith(
      {int? memoryId, enums.LoadMasterMemoryPost$RequestBodyTarget? target}) {
    return LoadMasterMemoryPost$RequestBody(
        memoryId: memoryId ?? this.memoryId, target: target ?? this.target);
  }

  LoadMasterMemoryPost$RequestBody copyWithWrapped(
      {Wrapped<int>? memoryId,
      Wrapped<enums.LoadMasterMemoryPost$RequestBodyTarget?>? target}) {
    return LoadMasterMemoryPost$RequestBody(
        memoryId: (memoryId != null ? memoryId.value : this.memoryId),
        target: (target != null ? target.value : this.target));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody {
  ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody({
    this.sourceType,
    this.sourceId,
  });

  factory ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodyFromJson(
          json);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson:
        screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeToJson,
    fromJson:
        screensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceTypeFromJson,
  )
  final enums
          .ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType?
      sourceType;
  @JsonKey(name: 'sourceId', includeIfNull: false)
  final int? sourceId;
  static const fromJsonFactory =
      _$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodyFromJson;
  static const toJsonFactory =
      _$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodyToJson(
          this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.sourceId, sourceId) ||
                const DeepCollectionEquality()
                    .equals(other.sourceId, sourceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(sourceId) ^
      runtimeType.hashCode;
}

extension $ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodyExtension
    on ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody {
  ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody copyWith(
      {enums.ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType?
          sourceType,
      int? sourceId}) {
    return ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody(
        sourceType: sourceType ?? this.sourceType,
        sourceId: sourceId ?? this.sourceId);
  }

  ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody copyWithWrapped(
      {Wrapped<
              enums
                  .ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBodySourceType?>?
          sourceType,
      Wrapped<int?>? sourceId}) {
    return ScreensScreenIdLayersLayerIdPresetsTargetSourcePost$RequestBody(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        sourceId: (sourceId != null ? sourceId.value : this.sourceId));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody {
  ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody({
    required this.sourceType,
    required this.sourceId,
  });

  factory ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodyFromJson(
          json);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson:
        screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeToJson,
    fromJson:
        screensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceTypeFromJson,
  )
  final enums
          .ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType
      sourceType;
  @JsonKey(name: 'sourceId', includeIfNull: false)
  final int sourceId;
  static const fromJsonFactory =
      _$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodyFromJson;
  static const toJsonFactory =
      _$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodyToJson(
          this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.sourceId, sourceId) ||
                const DeepCollectionEquality()
                    .equals(other.sourceId, sourceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(sourceId) ^
      runtimeType.hashCode;
}

extension $ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodyExtension
    on ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody {
  ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody copyWith(
      {enums.ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType?
          sourceType,
      int? sourceId}) {
    return ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody(
        sourceType: sourceType ?? this.sourceType,
        sourceId: sourceId ?? this.sourceId);
  }

  ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody copyWithWrapped(
      {Wrapped<
              enums
                  .ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBodySourceType>?
          sourceType,
      Wrapped<int>? sourceId}) {
    return ScreensScreenIdBackgroundLayerPresetsTargetSourcePost$RequestBody(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        sourceId: (sourceId != null ? sourceId.value : this.sourceId));
  }
}

@JsonSerializable(explicitToJson: true)
class TakePost$RequestBody {
  TakePost$RequestBody({
    required this.screenIds,
    required this.auxiliaryScreenIds,
  });

  factory TakePost$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$TakePost$RequestBodyFromJson(json);

  @JsonKey(name: 'screenIds', includeIfNull: false, defaultValue: <ScreenId>[])
  final List<ScreenId> screenIds;
  @JsonKey(
      name: 'auxiliaryScreenIds',
      includeIfNull: false,
      defaultValue: <ScreenId>[])
  final List<ScreenId> auxiliaryScreenIds;
  static const fromJsonFactory = _$TakePost$RequestBodyFromJson;
  static const toJsonFactory = _$TakePost$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$TakePost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TakePost$RequestBody &&
            (identical(other.screenIds, screenIds) ||
                const DeepCollectionEquality()
                    .equals(other.screenIds, screenIds)) &&
            (identical(other.auxiliaryScreenIds, auxiliaryScreenIds) ||
                const DeepCollectionEquality()
                    .equals(other.auxiliaryScreenIds, auxiliaryScreenIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(screenIds) ^
      const DeepCollectionEquality().hash(auxiliaryScreenIds) ^
      runtimeType.hashCode;
}

extension $TakePost$RequestBodyExtension on TakePost$RequestBody {
  TakePost$RequestBody copyWith(
      {List<ScreenId>? screenIds, List<ScreenId>? auxiliaryScreenIds}) {
    return TakePost$RequestBody(
        screenIds: screenIds ?? this.screenIds,
        auxiliaryScreenIds: auxiliaryScreenIds ?? this.auxiliaryScreenIds);
  }

  TakePost$RequestBody copyWithWrapped(
      {Wrapped<List<ScreenId>>? screenIds,
      Wrapped<List<ScreenId>>? auxiliaryScreenIds}) {
    return TakePost$RequestBody(
        screenIds: (screenIds != null ? screenIds.value : this.screenIds),
        auxiliaryScreenIds: (auxiliaryScreenIds != null
            ? auxiliaryScreenIds.value
            : this.auxiliaryScreenIds));
  }
}

@JsonSerializable(explicitToJson: true)
class AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody {
  AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody({
    required this.memoryId,
    this.target,
  });

  factory AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$AuxiliaryScreensAuxIdLoadMemoryPost$RequestBodyFromJson(json);

  @JsonKey(name: 'memoryId', includeIfNull: false)
  final int memoryId;
  @JsonKey(
    name: 'target',
    includeIfNull: false,
    toJson: targetToJson,
    fromJson: targetFromJson,
  )
  final enums.Target? target;
  static const fromJsonFactory =
      _$AuxiliaryScreensAuxIdLoadMemoryPost$RequestBodyFromJson;
  static const toJsonFactory =
      _$AuxiliaryScreensAuxIdLoadMemoryPost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$AuxiliaryScreensAuxIdLoadMemoryPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody &&
            (identical(other.memoryId, memoryId) ||
                const DeepCollectionEquality()
                    .equals(other.memoryId, memoryId)) &&
            (identical(other.target, target) ||
                const DeepCollectionEquality().equals(other.target, target)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(memoryId) ^
      const DeepCollectionEquality().hash(target) ^
      runtimeType.hashCode;
}

extension $AuxiliaryScreensAuxIdLoadMemoryPost$RequestBodyExtension
    on AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody {
  AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody copyWith(
      {int? memoryId, enums.Target? target}) {
    return AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody(
        memoryId: memoryId ?? this.memoryId, target: target ?? this.target);
  }

  AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody copyWithWrapped(
      {Wrapped<int>? memoryId, Wrapped<enums.Target?>? target}) {
    return AuxiliaryScreensAuxIdLoadMemoryPost$RequestBody(
        memoryId: (memoryId != null ? memoryId.value : this.memoryId),
        target: (target != null ? target.value : this.target));
  }
}

@JsonSerializable(explicitToJson: true)
class AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody {
  AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody({
    this.sourceType,
    this.sourceId,
  });

  factory AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBodyFromJson(
          json);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeToJson,
    fromJson: sourceTypeFromJson,
  )
  final enums.SourceType? sourceType;
  @JsonKey(name: 'sourceId', includeIfNull: false)
  final int? sourceId;
  static const fromJsonFactory =
      _$AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBodyFromJson;
  static const toJsonFactory =
      _$AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBodyToJson(
          this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.sourceId, sourceId) ||
                const DeepCollectionEquality()
                    .equals(other.sourceId, sourceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(sourceId) ^
      runtimeType.hashCode;
}

extension $AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBodyExtension
    on AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody {
  AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody
      copyWith({enums.SourceType? sourceType, int? sourceId}) {
    return AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody(
        sourceType: sourceType ?? this.sourceType,
        sourceId: sourceId ?? this.sourceId);
  }

  AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody
      copyWithWrapped(
          {Wrapped<enums.SourceType?>? sourceType, Wrapped<int?>? sourceId}) {
    return AuxiliaryScreensAuxIdLayersLayerIdPresetsTargetSourcePost$RequestBody(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        sourceId: (sourceId != null ? sourceId.value : this.sourceId));
  }
}

@JsonSerializable(explicitToJson: true)
class MultiviewersMvwIdLoadMemoryPost$RequestBody {
  MultiviewersMvwIdLoadMemoryPost$RequestBody({
    this.memoryId,
  });

  factory MultiviewersMvwIdLoadMemoryPost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$MultiviewersMvwIdLoadMemoryPost$RequestBodyFromJson(json);

  @JsonKey(name: 'memoryId', includeIfNull: false)
  final int? memoryId;
  static const fromJsonFactory =
      _$MultiviewersMvwIdLoadMemoryPost$RequestBodyFromJson;
  static const toJsonFactory =
      _$MultiviewersMvwIdLoadMemoryPost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$MultiviewersMvwIdLoadMemoryPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MultiviewersMvwIdLoadMemoryPost$RequestBody &&
            (identical(other.memoryId, memoryId) ||
                const DeepCollectionEquality()
                    .equals(other.memoryId, memoryId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(memoryId) ^ runtimeType.hashCode;
}

extension $MultiviewersMvwIdLoadMemoryPost$RequestBodyExtension
    on MultiviewersMvwIdLoadMemoryPost$RequestBody {
  MultiviewersMvwIdLoadMemoryPost$RequestBody copyWith({int? memoryId}) {
    return MultiviewersMvwIdLoadMemoryPost$RequestBody(
        memoryId: memoryId ?? this.memoryId);
  }

  MultiviewersMvwIdLoadMemoryPost$RequestBody copyWithWrapped(
      {Wrapped<int?>? memoryId}) {
    return MultiviewersMvwIdLoadMemoryPost$RequestBody(
        memoryId: (memoryId != null ? memoryId.value : this.memoryId));
  }
}

@JsonSerializable(explicitToJson: true)
class MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody {
  MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody({
    required this.sourceType,
    required this.sourceId,
  });

  factory MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBodyFromJson(json);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: mvwSourceTypeToJson,
    fromJson: mvwSourceTypeFromJson,
  )
  final enums.MvwSourceType sourceType;
  @JsonKey(name: 'sourceId', includeIfNull: false)
  final int sourceId;
  static const fromJsonFactory =
      _$MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBodyFromJson;
  static const toJsonFactory =
      _$MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.sourceId, sourceId) ||
                const DeepCollectionEquality()
                    .equals(other.sourceId, sourceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(sourceId) ^
      runtimeType.hashCode;
}

extension $MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBodyExtension
    on MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody {
  MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody copyWith(
      {enums.MvwSourceType? sourceType, int? sourceId}) {
    return MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody(
        sourceType: sourceType ?? this.sourceType,
        sourceId: sourceId ?? this.sourceId);
  }

  MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody copyWithWrapped(
      {Wrapped<enums.MvwSourceType>? sourceType, Wrapped<int>? sourceId}) {
    return MultiviewersMvwIdWidgetsWidgetIdSourcePost$RequestBody(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        sourceId: (sourceId != null ? sourceId.value : this.sourceId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
