// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'json_map_example.swagger.chopper.dart';
part 'json_map_example.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class JsonMapExample extends ChopperService {
  static JsonMapExample create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$JsonMapExample(client);
    }

    final newClient = ChopperClient(
        services: [_$JsonMapExample()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$JsonMapExample(newClient);
  }

  ///Authenticate user and return JWT access and refresh tokens
  Future<chopper.Response<AccessToken>> tokenPost({
    String? cacheControl,
    required Credentials? body,
  }) {
    generatedMapping.putIfAbsent(
        AccessToken, () => AccessToken.fromJsonFactory);

    return _tokenPost(cacheControl: cacheControl, body: body);
  }

  ///Authenticate user and return JWT access and refresh tokens
  @Post(path: '/token')
  Future<chopper.Response<AccessToken>> _tokenPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Credentials? body,
  });

  ///Refresh a JWT token
  Future<chopper.Response<AccessToken>> tokenRefreshPost({
    String? cacheControl,
    required RefreshToken? body,
  }) {
    generatedMapping.putIfAbsent(
        AccessToken, () => AccessToken.fromJsonFactory);

    return _tokenRefreshPost(cacheControl: cacheControl, body: body);
  }

  ///Refresh a JWT token
  @Post(path: '/token/refresh')
  Future<chopper.Response<AccessToken>> _tokenRefreshPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RefreshToken? body,
  });
}

@JsonSerializable(explicitToJson: true)
class Credentials {
  Credentials({
    required this.username,
    required this.password,
  });

  factory Credentials.fromJson(Map<String, dynamic> json) =>
      _$CredentialsFromJson(json);

  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  static const fromJsonFactory = _$CredentialsFromJson;
  static const toJsonFactory = _$CredentialsToJson;
  Map<String, dynamic> toJson() => _$CredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Credentials &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $CredentialsExtension on Credentials {
  Credentials copyWith({String? username, String? password}) {
    return Credentials(
        username: username ?? this.username,
        password: password ?? this.password);
  }

  Credentials copyWithWrapped(
      {Wrapped<String>? username, Wrapped<String>? password}) {
    return Credentials(
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class AccessToken {
  AccessToken({
    required this.token,
    required this.refreshToken,
  });

  factory AccessToken.fromJson(Map<String, dynamic> json) =>
      _$AccessTokenFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String token;
  @JsonKey(name: 'refresh_token', includeIfNull: false, defaultValue: '')
  final String refreshToken;
  static const fromJsonFactory = _$AccessTokenFromJson;
  static const toJsonFactory = _$AccessTokenToJson;
  Map<String, dynamic> toJson() => _$AccessTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AccessToken &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      runtimeType.hashCode;
}

extension $AccessTokenExtension on AccessToken {
  AccessToken copyWith({String? token, String? refreshToken}) {
    return AccessToken(
        token: token ?? this.token,
        refreshToken: refreshToken ?? this.refreshToken);
  }

  AccessToken copyWithWrapped(
      {Wrapped<String>? token, Wrapped<String>? refreshToken}) {
    return AccessToken(
        token: (token != null ? token.value : this.token),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class RefreshToken {
  RefreshToken({
    required this.refreshToken,
  });

  factory RefreshToken.fromJson(Map<String, dynamic> json) =>
      _$RefreshTokenFromJson(json);

  @JsonKey(name: 'refresh_token', includeIfNull: false, defaultValue: '')
  final String refreshToken;
  static const fromJsonFactory = _$RefreshTokenFromJson;
  static const toJsonFactory = _$RefreshTokenToJson;
  Map<String, dynamic> toJson() => _$RefreshTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RefreshToken &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(refreshToken) ^ runtimeType.hashCode;
}

extension $RefreshTokenExtension on RefreshToken {
  RefreshToken copyWith({String? refreshToken}) {
    return RefreshToken(refreshToken: refreshToken ?? this.refreshToken);
  }

  RefreshToken copyWithWrapped({Wrapped<String>? refreshToken}) {
    return RefreshToken(
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class Error {
  Error({
    this.code,
    this.message,
  });

  factory Error.fromJson(Map<String, dynamic> json) => _$ErrorFromJson(json);

  @JsonKey(name: 'code', includeIfNull: false)
  final int? code;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  static const fromJsonFactory = _$ErrorFromJson;
  static const toJsonFactory = _$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(message) ^
      runtimeType.hashCode;
}

extension $ErrorExtension on Error {
  Error copyWith({int? code, String? message}) {
    return Error(code: code ?? this.code, message: message ?? this.message);
  }

  Error copyWithWrapped({Wrapped<int?>? code, Wrapped<String?>? message}) {
    return Error(
        code: (code != null ? code.value : this.code),
        message: (message != null ? message.value : this.message));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
