// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_ad_service.swagger.chopper.dart';
part 'liberty_ad_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyAdService extends ChopperService {
  static LibertyAdService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyAdService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyAdService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyAdService(newClient);
  }

  ///
  ///@param sessionId SessionId generated by Session Service
  ///@param airflowId AirflowId of the title being played in the session
  ///@param providerId ProviderId (domain-name) of the content / entertainment being played in the session
  ///@param providerAssetId ProviderAssetId of the title being played in the session
  ///@param externalRef externalRef of the title being played in the session
  ///@param contentUri Url to the video manifest file of the entertainment to be played
  ///@param cpeId CpeId of the client requesting the session.
  Future<chopper.Response> sessionStartGet({
    required String? sessionId,
    required String? airflowId,
    required String? providerId,
    required String? providerAssetId,
    required String? externalRef,
    required String? contentUri,
    required String? cpeId,
    String? cacheControl,
  }) {
    return _sessionStartGet(
        sessionId: sessionId,
        airflowId: airflowId,
        providerId: providerId,
        providerAssetId: providerAssetId,
        externalRef: externalRef,
        contentUri: contentUri,
        cpeId: cpeId,
        cacheControl: cacheControl);
  }

  ///
  ///@param sessionId SessionId generated by Session Service
  ///@param airflowId AirflowId of the title being played in the session
  ///@param providerId ProviderId (domain-name) of the content / entertainment being played in the session
  ///@param providerAssetId ProviderAssetId of the title being played in the session
  ///@param externalRef externalRef of the title being played in the session
  ///@param contentUri Url to the video manifest file of the entertainment to be played
  ///@param cpeId CpeId of the client requesting the session.
  @Get(path: '/sessionStart')
  Future<chopper.Response> _sessionStartGet({
    @Query('sessionId') required String? sessionId,
    @Query('airflowId') required String? airflowId,
    @Query('providerId') required String? providerId,
    @Query('providerAssetId') required String? providerAssetId,
    @Query('externalRef') required String? externalRef,
    @Query('contentUri') required String? contentUri,
    @Query('cpeId') required String? cpeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param sessionId SessionId of stream
  Future<chopper.Response> placementRequestGet({
    required String? sessionId,
    String? cacheControl,
  }) {
    return _placementRequestGet(
        sessionId: sessionId, cacheControl: cacheControl);
  }

  ///
  ///@param sessionId SessionId of stream
  @Get(path: '/placementRequest')
  Future<chopper.Response> _placementRequestGet({
    @Query('sessionId') required String? sessionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param sessionId SessionId of stream
  Future<chopper.Response<Object>> playlistGet({
    required String? sessionId,
    String? cacheControl,
  }) {
    return _playlistGet(sessionId: sessionId, cacheControl: cacheControl);
  }

  ///
  ///@param sessionId SessionId of stream
  @Get(path: '/playlist')
  Future<chopper.Response<Object>> _playlistGet({
    @Query('sessionId') required String? sessionId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class GeneralError {
  GeneralError({
    this.error,
  });

  factory GeneralError.fromJson(Map<String, dynamic> json) =>
      _$GeneralErrorFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final GeneralError$Error? error;
  static const fromJsonFactory = _$GeneralErrorFromJson;
  static const toJsonFactory = _$GeneralErrorToJson;
  Map<String, dynamic> toJson() => _$GeneralErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GeneralError &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $GeneralErrorExtension on GeneralError {
  GeneralError copyWith({GeneralError$Error? error}) {
    return GeneralError(error: error ?? this.error);
  }

  GeneralError copyWithWrapped({Wrapped<GeneralError$Error?>? error}) {
    return GeneralError(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class GeneralError$Error {
  GeneralError$Error({
    this.httpStatusCode,
    this.statusCode,
    this.message,
    this.details,
    this.correlationId,
  });

  factory GeneralError$Error.fromJson(Map<String, dynamic> json) =>
      _$GeneralError$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int? httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$GeneralError$ErrorFromJson;
  static const toJsonFactory = _$GeneralError$ErrorToJson;
  Map<String, dynamic> toJson() => _$GeneralError$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GeneralError$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $GeneralError$ErrorExtension on GeneralError$Error {
  GeneralError$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return GeneralError$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  GeneralError$Error copyWithWrapped(
      {Wrapped<int?>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String?>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return GeneralError$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
