// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_analytics_service.swagger.chopper.dart';
part 'liberty_analytics_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyAnalyticsService extends ChopperService {
  static LibertyAnalyticsService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyAnalyticsService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyAnalyticsService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyAnalyticsService(newClient);
  }

  ///Return all replay view top-lists
  Future<chopper.Response<TopListsResponse>> toplistsReplayGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        TopListsResponse, () => TopListsResponse.fromJsonFactory);

    return _toplistsReplayGet(cacheControl: cacheControl);
  }

  ///Return all replay view top-lists
  @Get(path: '/toplists/replay')
  Future<chopper.Response<TopListsResponse>> _toplistsReplayGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Return most watched replay crids in descending order for the given toplist
  ///@param toplistId Identifier of Toplist
  Future<chopper.Response<TopListsByIdResponse>> toplistsReplayToplistIdGet({
    required String? toplistId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopListsByIdResponse, () => TopListsByIdResponse.fromJsonFactory);

    return _toplistsReplayToplistIdGet(
        toplistId: toplistId, cacheControl: cacheControl);
  }

  ///Return most watched replay crids in descending order for the given toplist
  ///@param toplistId Identifier of Toplist
  @Get(path: '/toplists/replay/{toplistId}')
  Future<chopper.Response<TopListsByIdResponse>> _toplistsReplayToplistIdGet({
    @Path('toplistId') required String? toplistId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class TopListsResponse {
  TopListsResponse({
    this.topLists,
    this.links,
  });

  factory TopListsResponse.fromJson(Map<String, dynamic> json) =>
      _$TopListsResponseFromJson(json);

  @JsonKey(name: 'topLists', includeIfNull: false, defaultValue: <TopList>[])
  final List<TopList>? topLists;
  @JsonKey(name: 'links', includeIfNull: false)
  final LinksAllTopLists? links;
  static const fromJsonFactory = _$TopListsResponseFromJson;
  static const toJsonFactory = _$TopListsResponseToJson;
  Map<String, dynamic> toJson() => _$TopListsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopListsResponse &&
            (identical(other.topLists, topLists) ||
                const DeepCollectionEquality()
                    .equals(other.topLists, topLists)) &&
            (identical(other.links, links) ||
                const DeepCollectionEquality().equals(other.links, links)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(topLists) ^
      const DeepCollectionEquality().hash(links) ^
      runtimeType.hashCode;
}

extension $TopListsResponseExtension on TopListsResponse {
  TopListsResponse copyWith(
      {List<TopList>? topLists, LinksAllTopLists? links}) {
    return TopListsResponse(
        topLists: topLists ?? this.topLists, links: links ?? this.links);
  }

  TopListsResponse copyWithWrapped(
      {Wrapped<List<TopList>?>? topLists, Wrapped<LinksAllTopLists?>? links}) {
    return TopListsResponse(
        topLists: (topLists != null ? topLists.value : this.topLists),
        links: (links != null ? links.value : this.links));
  }
}

@JsonSerializable(explicitToJson: true)
class TopListsByIdResponse {
  TopListsByIdResponse({
    this.id,
    this.language,
    this.titleCrids,
    this.links,
  });

  factory TopListsByIdResponse.fromJson(Map<String, dynamic> json) =>
      _$TopListsByIdResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  @JsonKey(name: 'titleCrids', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleCrids;
  @JsonKey(name: 'links', includeIfNull: false)
  final Links? links;
  static const fromJsonFactory = _$TopListsByIdResponseFromJson;
  static const toJsonFactory = _$TopListsByIdResponseToJson;
  Map<String, dynamic> toJson() => _$TopListsByIdResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopListsByIdResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.titleCrids, titleCrids) ||
                const DeepCollectionEquality()
                    .equals(other.titleCrids, titleCrids)) &&
            (identical(other.links, links) ||
                const DeepCollectionEquality().equals(other.links, links)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(titleCrids) ^
      const DeepCollectionEquality().hash(links) ^
      runtimeType.hashCode;
}

extension $TopListsByIdResponseExtension on TopListsByIdResponse {
  TopListsByIdResponse copyWith(
      {String? id, String? language, List<String>? titleCrids, Links? links}) {
    return TopListsByIdResponse(
        id: id ?? this.id,
        language: language ?? this.language,
        titleCrids: titleCrids ?? this.titleCrids,
        links: links ?? this.links);
  }

  TopListsByIdResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? language,
      Wrapped<List<String>?>? titleCrids,
      Wrapped<Links?>? links}) {
    return TopListsByIdResponse(
        id: (id != null ? id.value : this.id),
        language: (language != null ? language.value : this.language),
        titleCrids: (titleCrids != null ? titleCrids.value : this.titleCrids),
        links: (links != null ? links.value : this.links));
  }
}

@JsonSerializable(explicitToJson: true)
class TopList {
  TopList({
    this.id,
    this.language,
    this.links,
  });

  factory TopList.fromJson(Map<String, dynamic> json) =>
      _$TopListFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  @JsonKey(name: 'links', includeIfNull: false)
  final Links? links;
  static const fromJsonFactory = _$TopListFromJson;
  static const toJsonFactory = _$TopListToJson;
  Map<String, dynamic> toJson() => _$TopListToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopList &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.links, links) ||
                const DeepCollectionEquality().equals(other.links, links)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(links) ^
      runtimeType.hashCode;
}

extension $TopListExtension on TopList {
  TopList copyWith({String? id, String? language, Links? links}) {
    return TopList(
        id: id ?? this.id,
        language: language ?? this.language,
        links: links ?? this.links);
  }

  TopList copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? language,
      Wrapped<Links?>? links}) {
    return TopList(
        id: (id != null ? id.value : this.id),
        language: (language != null ? language.value : this.language),
        links: (links != null ? links.value : this.links));
  }
}

@JsonSerializable(explicitToJson: true)
class Links {
  Links({
    this.self,
  });

  factory Links.fromJson(Map<String, dynamic> json) => _$LinksFromJson(json);

  @JsonKey(name: 'self', includeIfNull: false, defaultValue: '')
  final String? self;
  static const fromJsonFactory = _$LinksFromJson;
  static const toJsonFactory = _$LinksToJson;
  Map<String, dynamic> toJson() => _$LinksToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Links &&
            (identical(other.self, self) ||
                const DeepCollectionEquality().equals(other.self, self)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(self) ^ runtimeType.hashCode;
}

extension $LinksExtension on Links {
  Links copyWith({String? self}) {
    return Links(self: self ?? this.self);
  }

  Links copyWithWrapped({Wrapped<String?>? self}) {
    return Links(self: (self != null ? self.value : this.self));
  }
}

@JsonSerializable(explicitToJson: true)
class LinksAllTopLists {
  LinksAllTopLists({
    this.self,
  });

  factory LinksAllTopLists.fromJson(Map<String, dynamic> json) =>
      _$LinksAllTopListsFromJson(json);

  @JsonKey(name: 'self', includeIfNull: false, defaultValue: '')
  final String? self;
  static const fromJsonFactory = _$LinksAllTopListsFromJson;
  static const toJsonFactory = _$LinksAllTopListsToJson;
  Map<String, dynamic> toJson() => _$LinksAllTopListsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LinksAllTopLists &&
            (identical(other.self, self) ||
                const DeepCollectionEquality().equals(other.self, self)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(self) ^ runtimeType.hashCode;
}

extension $LinksAllTopListsExtension on LinksAllTopLists {
  LinksAllTopLists copyWith({String? self}) {
    return LinksAllTopLists(self: self ?? this.self);
  }

  LinksAllTopLists copyWithWrapped({Wrapped<String?>? self}) {
    return LinksAllTopLists(self: (self != null ? self.value : this.self));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;
  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
