// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_auth_service.enums.swagger.dart' as enums;
export 'liberty_auth_service.enums.swagger.dart';

part 'liberty_auth_service.swagger.chopper.dart';
part 'liberty_auth_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyAuthService extends ChopperService {
  static LibertyAuthService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyAuthService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyAuthService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyAuthService(newClient);
  }

  ///Receive authorization details
  Future<chopper.Response<AuthorizationDetails>> authorizationGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AuthorizationDetails, () => AuthorizationDetails.fromJsonFactory);

    return _authorizationGet(cacheControl: cacheControl);
  }

  ///Receive authorization details
  @Get(path: '/authorization')
  Future<chopper.Response<AuthorizationDetails>> _authorizationGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Complete authorization, create a session, create tokens
  Future<chopper.Response<TokensResponse>> authorizationPost({
    String? cacheControl,
    required CompleteAuthorizationRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        TokensResponse, () => TokensResponse.fromJsonFactory);

    return _authorizationPost(cacheControl: cacheControl, body: body);
  }

  ///Complete authorization, create a session, create tokens
  @Post(path: '/authorization')
  Future<chopper.Response<TokensResponse>> _authorizationPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CompleteAuthorizationRequest? body,
  });

  ///Refresh authorization, get new tokens
  ///@param ACCESSTOKEN
  Future<chopper.Response<TokensResponse>> authorizationRefreshPost({
    String? cacheControl,
    required RefreshAuthorizationRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        TokensResponse, () => TokensResponse.fromJsonFactory);

    return _authorizationRefreshPost(cacheControl: cacheControl, body: body);
  }

  ///Refresh authorization, get new tokens
  ///@param ACCESSTOKEN
  @Post(path: '/authorization/refresh')
  Future<chopper.Response<TokensResponse>> _authorizationRefreshPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RefreshAuthorizationRequest? body,
  });

  ///Logout (revoke tokens)
  ///@param ACCESSTOKEN
  Future<chopper.Response> authorizationRevokePost({
    String? cacheControl,
    required DeleteAuthorizationRequest? body,
  }) {
    return _authorizationRevokePost(cacheControl: cacheControl, body: body);
  }

  ///Logout (revoke tokens)
  ///@param ACCESSTOKEN
  @Post(path: '/authorization/revoke')
  Future<chopper.Response> _authorizationRevokePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeleteAuthorizationRequest? body,
  });

  ///Perform authorization. Redirects to logon form
  ///@param response_type response type expected
  ///@param client_id one of the allowed client types, ie: 'alexa'
  ///@param redirect_uri allowed redirect_uri. if redirect is required
  ///@param scope scopes requested
  ///@param state uuid used to maintain state between client and authorization server. should be unique
  Future<chopper.Response> ouath2AuthorizeGet({
    required enums.Ouath2AuthorizeGetResponseType? responseType,
    required String? clientId,
    String? redirectUri,
    String? scope,
    required String? state,
    String? cacheControl,
  }) {
    return _ouath2AuthorizeGet(
        responseType:
            enums.$Ouath2AuthorizeGetResponseTypeMap[responseType]?.toString(),
        clientId: clientId,
        redirectUri: redirectUri,
        scope: scope,
        state: state,
        cacheControl: cacheControl);
  }

  ///Perform authorization. Redirects to logon form
  ///@param response_type response type expected
  ///@param client_id one of the allowed client types, ie: 'alexa'
  ///@param redirect_uri allowed redirect_uri. if redirect is required
  ///@param scope scopes requested
  ///@param state uuid used to maintain state between client and authorization server. should be unique
  @Get(path: '/ouath2/authorize')
  Future<chopper.Response> _ouath2AuthorizeGet({
    @Query('response_type') required String? responseType,
    @Query('client_id') required String? clientId,
    @Query('redirect_uri') String? redirectUri,
    @Query('scope') String? scope,
    @Query('state') required String? state,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Exchange code or refresh token for tokens
  ///@param Authorization Basic authentication header: clientId:clientSecret
  Future<chopper.Response<TokensResponse>> oauth2TokenPost({
    String? authorization,
    String? cacheControl,
    required Oauth2TokenPost$RequestBody? body,
  }) {
    generatedMapping.putIfAbsent(
        TokensResponse, () => TokensResponse.fromJsonFactory);

    return _oauth2TokenPost(
        authorization: authorization, cacheControl: cacheControl, body: body);
  }

  ///Exchange code or refresh token for tokens
  ///@param Authorization Basic authentication header: clientId:clientSecret
  @Post(path: '/oauth2/token')
  Future<chopper.Response<TokensResponse>> _oauth2TokenPost({
    @Header('Authorization') String? authorization,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Oauth2TokenPost$RequestBody? body,
  });
}

@JsonSerializable(explicitToJson: true)
class AuthorizationDetails {
  AuthorizationDetails({
    this.state,
    this.authorizationUri,
    this.redirectUri,
    this.logoutUri,
    this.validityToken,
  });

  factory AuthorizationDetails.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationDetailsFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'authorizationUri', includeIfNull: false, defaultValue: '')
  final String? authorizationUri;
  @JsonKey(name: 'redirectUri', includeIfNull: false, defaultValue: '')
  final String? redirectUri;
  @JsonKey(name: 'logoutUri', includeIfNull: false, defaultValue: '')
  final String? logoutUri;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$AuthorizationDetailsFromJson;
  static const toJsonFactory = _$AuthorizationDetailsToJson;
  Map<String, dynamic> toJson() => _$AuthorizationDetailsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationDetails &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.authorizationUri, authorizationUri) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationUri, authorizationUri)) &&
            (identical(other.redirectUri, redirectUri) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUri, redirectUri)) &&
            (identical(other.logoutUri, logoutUri) ||
                const DeepCollectionEquality()
                    .equals(other.logoutUri, logoutUri)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(authorizationUri) ^
      const DeepCollectionEquality().hash(redirectUri) ^
      const DeepCollectionEquality().hash(logoutUri) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $AuthorizationDetailsExtension on AuthorizationDetails {
  AuthorizationDetails copyWith(
      {String? state,
      String? authorizationUri,
      String? redirectUri,
      String? logoutUri,
      String? validityToken}) {
    return AuthorizationDetails(
        state: state ?? this.state,
        authorizationUri: authorizationUri ?? this.authorizationUri,
        redirectUri: redirectUri ?? this.redirectUri,
        logoutUri: logoutUri ?? this.logoutUri,
        validityToken: validityToken ?? this.validityToken);
  }

  AuthorizationDetails copyWithWrapped(
      {Wrapped<String?>? state,
      Wrapped<String?>? authorizationUri,
      Wrapped<String?>? redirectUri,
      Wrapped<String?>? logoutUri,
      Wrapped<String?>? validityToken}) {
    return AuthorizationDetails(
        state: (state != null ? state.value : this.state),
        authorizationUri: (authorizationUri != null
            ? authorizationUri.value
            : this.authorizationUri),
        redirectUri:
            (redirectUri != null ? redirectUri.value : this.redirectUri),
        logoutUri: (logoutUri != null ? logoutUri.value : this.logoutUri),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class CompleteAuthorizationRequest {
  CompleteAuthorizationRequest({
    this.code,
    this.state,
    this.validityToken,
  });

  factory CompleteAuthorizationRequest.fromJson(Map<String, dynamic> json) =>
      _$CompleteAuthorizationRequestFromJson(json);

  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String? code;
  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  static const fromJsonFactory = _$CompleteAuthorizationRequestFromJson;
  static const toJsonFactory = _$CompleteAuthorizationRequestToJson;
  Map<String, dynamic> toJson() => _$CompleteAuthorizationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompleteAuthorizationRequest &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(validityToken) ^
      runtimeType.hashCode;
}

extension $CompleteAuthorizationRequestExtension
    on CompleteAuthorizationRequest {
  CompleteAuthorizationRequest copyWith(
      {String? code, String? state, String? validityToken}) {
    return CompleteAuthorizationRequest(
        code: code ?? this.code,
        state: state ?? this.state,
        validityToken: validityToken ?? this.validityToken);
  }

  CompleteAuthorizationRequest copyWithWrapped(
      {Wrapped<String?>? code,
      Wrapped<String?>? state,
      Wrapped<String?>? validityToken}) {
    return CompleteAuthorizationRequest(
        code: (code != null ? code.value : this.code),
        state: (state != null ? state.value : this.state),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class TokensResponse {
  TokensResponse({
    this.tokenType,
    this.accessToken,
    this.refreshToken,
    this.expiresIn,
    this.username,
    this.givenName,
    this.familyName,
  });

  factory TokensResponse.fromJson(Map<String, dynamic> json) =>
      _$TokensResponseFromJson(json);

  @JsonKey(
    name: 'token_type',
    includeIfNull: false,
    toJson: tokensResponseTokenTypeToJson,
    fromJson: tokensResponseTokenTypeFromJson,
  )
  final enums.TokensResponseTokenType? tokenType;
  @JsonKey(name: 'access_token', includeIfNull: false)
  final String? accessToken;
  @JsonKey(name: 'refresh_token', includeIfNull: false)
  final String? refreshToken;
  @JsonKey(name: 'expires_in', includeIfNull: false)
  final int? expiresIn;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'givenName', includeIfNull: false, defaultValue: '')
  final String? givenName;
  @JsonKey(name: 'familyName', includeIfNull: false, defaultValue: '')
  final String? familyName;
  static const fromJsonFactory = _$TokensResponseFromJson;
  static const toJsonFactory = _$TokensResponseToJson;
  Map<String, dynamic> toJson() => _$TokensResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokensResponse &&
            (identical(other.tokenType, tokenType) ||
                const DeepCollectionEquality()
                    .equals(other.tokenType, tokenType)) &&
            (identical(other.accessToken, accessToken) ||
                const DeepCollectionEquality()
                    .equals(other.accessToken, accessToken)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)) &&
            (identical(other.expiresIn, expiresIn) ||
                const DeepCollectionEquality()
                    .equals(other.expiresIn, expiresIn)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.givenName, givenName) ||
                const DeepCollectionEquality()
                    .equals(other.givenName, givenName)) &&
            (identical(other.familyName, familyName) ||
                const DeepCollectionEquality()
                    .equals(other.familyName, familyName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(accessToken) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      const DeepCollectionEquality().hash(expiresIn) ^
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(givenName) ^
      const DeepCollectionEquality().hash(familyName) ^
      runtimeType.hashCode;
}

extension $TokensResponseExtension on TokensResponse {
  TokensResponse copyWith(
      {enums.TokensResponseTokenType? tokenType,
      String? accessToken,
      String? refreshToken,
      int? expiresIn,
      String? username,
      String? givenName,
      String? familyName}) {
    return TokensResponse(
        tokenType: tokenType ?? this.tokenType,
        accessToken: accessToken ?? this.accessToken,
        refreshToken: refreshToken ?? this.refreshToken,
        expiresIn: expiresIn ?? this.expiresIn,
        username: username ?? this.username,
        givenName: givenName ?? this.givenName,
        familyName: familyName ?? this.familyName);
  }

  TokensResponse copyWithWrapped(
      {Wrapped<enums.TokensResponseTokenType?>? tokenType,
      Wrapped<String?>? accessToken,
      Wrapped<String?>? refreshToken,
      Wrapped<int?>? expiresIn,
      Wrapped<String?>? username,
      Wrapped<String?>? givenName,
      Wrapped<String?>? familyName}) {
    return TokensResponse(
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        accessToken:
            (accessToken != null ? accessToken.value : this.accessToken),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken),
        expiresIn: (expiresIn != null ? expiresIn.value : this.expiresIn),
        username: (username != null ? username.value : this.username),
        givenName: (givenName != null ? givenName.value : this.givenName),
        familyName: (familyName != null ? familyName.value : this.familyName));
  }
}

@JsonSerializable(explicitToJson: true)
class RefreshAuthorizationRequest {
  RefreshAuthorizationRequest({
    this.svcRefreshToken,
  });

  factory RefreshAuthorizationRequest.fromJson(Map<String, dynamic> json) =>
      _$RefreshAuthorizationRequestFromJson(json);

  @JsonKey(name: 'svcRefreshToken', includeIfNull: false)
  final String? svcRefreshToken;
  static const fromJsonFactory = _$RefreshAuthorizationRequestFromJson;
  static const toJsonFactory = _$RefreshAuthorizationRequestToJson;
  Map<String, dynamic> toJson() => _$RefreshAuthorizationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RefreshAuthorizationRequest &&
            (identical(other.svcRefreshToken, svcRefreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.svcRefreshToken, svcRefreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(svcRefreshToken) ^
      runtimeType.hashCode;
}

extension $RefreshAuthorizationRequestExtension on RefreshAuthorizationRequest {
  RefreshAuthorizationRequest copyWith({String? svcRefreshToken}) {
    return RefreshAuthorizationRequest(
        svcRefreshToken: svcRefreshToken ?? this.svcRefreshToken);
  }

  RefreshAuthorizationRequest copyWithWrapped(
      {Wrapped<String?>? svcRefreshToken}) {
    return RefreshAuthorizationRequest(
        svcRefreshToken: (svcRefreshToken != null
            ? svcRefreshToken.value
            : this.svcRefreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteAuthorizationRequest {
  DeleteAuthorizationRequest({
    this.svcRefreshToken,
  });

  factory DeleteAuthorizationRequest.fromJson(Map<String, dynamic> json) =>
      _$DeleteAuthorizationRequestFromJson(json);

  @JsonKey(name: 'svcRefreshToken', includeIfNull: false)
  final String? svcRefreshToken;
  static const fromJsonFactory = _$DeleteAuthorizationRequestFromJson;
  static const toJsonFactory = _$DeleteAuthorizationRequestToJson;
  Map<String, dynamic> toJson() => _$DeleteAuthorizationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteAuthorizationRequest &&
            (identical(other.svcRefreshToken, svcRefreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.svcRefreshToken, svcRefreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(svcRefreshToken) ^
      runtimeType.hashCode;
}

extension $DeleteAuthorizationRequestExtension on DeleteAuthorizationRequest {
  DeleteAuthorizationRequest copyWith({String? svcRefreshToken}) {
    return DeleteAuthorizationRequest(
        svcRefreshToken: svcRefreshToken ?? this.svcRefreshToken);
  }

  DeleteAuthorizationRequest copyWithWrapped(
      {Wrapped<String?>? svcRefreshToken}) {
    return DeleteAuthorizationRequest(
        svcRefreshToken: (svcRefreshToken != null
            ? svcRefreshToken.value
            : this.svcRefreshToken));
  }
}

String? ouath2AuthorizeGetResponseTypeToJson(
    enums.Ouath2AuthorizeGetResponseType? ouath2AuthorizeGetResponseType) {
  return enums
      .$Ouath2AuthorizeGetResponseTypeMap[ouath2AuthorizeGetResponseType];
}

enums.Ouath2AuthorizeGetResponseType ouath2AuthorizeGetResponseTypeFromJson(
  Object? ouath2AuthorizeGetResponseType, [
  enums.Ouath2AuthorizeGetResponseType? defaultValue,
]) {
  if (ouath2AuthorizeGetResponseType is String) {
    return enums.$Ouath2AuthorizeGetResponseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                ouath2AuthorizeGetResponseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.Ouath2AuthorizeGetResponseType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$Ouath2AuthorizeGetResponseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.Ouath2AuthorizeGetResponseType.swaggerGeneratedUnknown;
}

List<String> ouath2AuthorizeGetResponseTypeListToJson(
    List<enums.Ouath2AuthorizeGetResponseType>?
        ouath2AuthorizeGetResponseType) {
  if (ouath2AuthorizeGetResponseType == null) {
    return [];
  }

  return ouath2AuthorizeGetResponseType
      .map((e) => enums.$Ouath2AuthorizeGetResponseTypeMap[e]!)
      .toList();
}

List<enums.Ouath2AuthorizeGetResponseType>
    ouath2AuthorizeGetResponseTypeListFromJson(
  List? ouath2AuthorizeGetResponseType, [
  List<enums.Ouath2AuthorizeGetResponseType>? defaultValue,
]) {
  if (ouath2AuthorizeGetResponseType == null) {
    return defaultValue ?? [];
  }

  return ouath2AuthorizeGetResponseType
      .map((e) => ouath2AuthorizeGetResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.Ouath2AuthorizeGetResponseType>?
    ouath2AuthorizeGetResponseTypeNullableListFromJson(
  List? ouath2AuthorizeGetResponseType, [
  List<enums.Ouath2AuthorizeGetResponseType>? defaultValue,
]) {
  if (ouath2AuthorizeGetResponseType == null) {
    return defaultValue;
  }

  return ouath2AuthorizeGetResponseType
      .map((e) => ouath2AuthorizeGetResponseTypeFromJson(e.toString()))
      .toList();
}

String? tokensResponseTokenTypeToJson(
    enums.TokensResponseTokenType? tokensResponseTokenType) {
  return enums.$TokensResponseTokenTypeMap[tokensResponseTokenType];
}

enums.TokensResponseTokenType tokensResponseTokenTypeFromJson(
  Object? tokensResponseTokenType, [
  enums.TokensResponseTokenType? defaultValue,
]) {
  if (tokensResponseTokenType is String) {
    return enums.$TokensResponseTokenTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                tokensResponseTokenType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.TokensResponseTokenType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TokensResponseTokenTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.TokensResponseTokenType.swaggerGeneratedUnknown;
}

List<String> tokensResponseTokenTypeListToJson(
    List<enums.TokensResponseTokenType>? tokensResponseTokenType) {
  if (tokensResponseTokenType == null) {
    return [];
  }

  return tokensResponseTokenType
      .map((e) => enums.$TokensResponseTokenTypeMap[e]!)
      .toList();
}

List<enums.TokensResponseTokenType> tokensResponseTokenTypeListFromJson(
  List? tokensResponseTokenType, [
  List<enums.TokensResponseTokenType>? defaultValue,
]) {
  if (tokensResponseTokenType == null) {
    return defaultValue ?? [];
  }

  return tokensResponseTokenType
      .map((e) => tokensResponseTokenTypeFromJson(e.toString()))
      .toList();
}

List<enums.TokensResponseTokenType>?
    tokensResponseTokenTypeNullableListFromJson(
  List? tokensResponseTokenType, [
  List<enums.TokensResponseTokenType>? defaultValue,
]) {
  if (tokensResponseTokenType == null) {
    return defaultValue;
  }

  return tokensResponseTokenType
      .map((e) => tokensResponseTokenTypeFromJson(e.toString()))
      .toList();
}

String? oauth2TokenPost$RequestBodyGrantTypeToJson(
    enums.Oauth2TokenPost$RequestBodyGrantType?
        oauth2TokenPost$RequestBodyGrantType) {
  return enums.$Oauth2TokenPost$RequestBodyGrantTypeMap[
      oauth2TokenPost$RequestBodyGrantType];
}

enums.Oauth2TokenPost$RequestBodyGrantType
    oauth2TokenPost$RequestBodyGrantTypeFromJson(
  Object? oauth2TokenPost$RequestBodyGrantType, [
  enums.Oauth2TokenPost$RequestBodyGrantType? defaultValue,
]) {
  if (oauth2TokenPost$RequestBodyGrantType is String) {
    return enums.$Oauth2TokenPost$RequestBodyGrantTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                oauth2TokenPost$RequestBodyGrantType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.Oauth2TokenPost$RequestBodyGrantType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$Oauth2TokenPost$RequestBodyGrantTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.Oauth2TokenPost$RequestBodyGrantType.swaggerGeneratedUnknown;
}

List<String> oauth2TokenPost$RequestBodyGrantTypeListToJson(
    List<enums.Oauth2TokenPost$RequestBodyGrantType>?
        oauth2TokenPost$RequestBodyGrantType) {
  if (oauth2TokenPost$RequestBodyGrantType == null) {
    return [];
  }

  return oauth2TokenPost$RequestBodyGrantType
      .map((e) => enums.$Oauth2TokenPost$RequestBodyGrantTypeMap[e]!)
      .toList();
}

List<enums.Oauth2TokenPost$RequestBodyGrantType>
    oauth2TokenPost$RequestBodyGrantTypeListFromJson(
  List? oauth2TokenPost$RequestBodyGrantType, [
  List<enums.Oauth2TokenPost$RequestBodyGrantType>? defaultValue,
]) {
  if (oauth2TokenPost$RequestBodyGrantType == null) {
    return defaultValue ?? [];
  }

  return oauth2TokenPost$RequestBodyGrantType
      .map((e) => oauth2TokenPost$RequestBodyGrantTypeFromJson(e.toString()))
      .toList();
}

List<enums.Oauth2TokenPost$RequestBodyGrantType>?
    oauth2TokenPost$RequestBodyGrantTypeNullableListFromJson(
  List? oauth2TokenPost$RequestBodyGrantType, [
  List<enums.Oauth2TokenPost$RequestBodyGrantType>? defaultValue,
]) {
  if (oauth2TokenPost$RequestBodyGrantType == null) {
    return defaultValue;
  }

  return oauth2TokenPost$RequestBodyGrantType
      .map((e) => oauth2TokenPost$RequestBodyGrantTypeFromJson(e.toString()))
      .toList();
}

@JsonSerializable(explicitToJson: true)
class Oauth2TokenPost$RequestBody {
  Oauth2TokenPost$RequestBody({
    this.grantType,
    this.code,
    this.refreshToken,
    this.redirectUri,
  });

  factory Oauth2TokenPost$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$Oauth2TokenPost$RequestBodyFromJson(json);

  @JsonKey(
    name: 'grant_type',
    includeIfNull: false,
    toJson: oauth2TokenPost$RequestBodyGrantTypeToJson,
    fromJson: oauth2TokenPost$RequestBodyGrantTypeFromJson,
  )
  final enums.Oauth2TokenPost$RequestBodyGrantType? grantType;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String? code;
  @JsonKey(name: 'refresh_token', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  @JsonKey(name: 'redirect_uri', includeIfNull: false, defaultValue: '')
  final String? redirectUri;
  static const fromJsonFactory = _$Oauth2TokenPost$RequestBodyFromJson;
  static const toJsonFactory = _$Oauth2TokenPost$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$Oauth2TokenPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Oauth2TokenPost$RequestBody &&
            (identical(other.grantType, grantType) ||
                const DeepCollectionEquality()
                    .equals(other.grantType, grantType)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)) &&
            (identical(other.redirectUri, redirectUri) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUri, redirectUri)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(grantType) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      const DeepCollectionEquality().hash(redirectUri) ^
      runtimeType.hashCode;
}

extension $Oauth2TokenPost$RequestBodyExtension on Oauth2TokenPost$RequestBody {
  Oauth2TokenPost$RequestBody copyWith(
      {enums.Oauth2TokenPost$RequestBodyGrantType? grantType,
      String? code,
      String? refreshToken,
      String? redirectUri}) {
    return Oauth2TokenPost$RequestBody(
        grantType: grantType ?? this.grantType,
        code: code ?? this.code,
        refreshToken: refreshToken ?? this.refreshToken,
        redirectUri: redirectUri ?? this.redirectUri);
  }

  Oauth2TokenPost$RequestBody copyWithWrapped(
      {Wrapped<enums.Oauth2TokenPost$RequestBodyGrantType?>? grantType,
      Wrapped<String?>? code,
      Wrapped<String?>? refreshToken,
      Wrapped<String?>? redirectUri}) {
    return Oauth2TokenPost$RequestBody(
        grantType: (grantType != null ? grantType.value : this.grantType),
        code: (code != null ? code.value : this.code),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken),
        redirectUri:
            (redirectUri != null ? redirectUri.value : this.redirectUri));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
