// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_bookmarks_service.enums.swagger.dart' as enums;
export 'liberty_bookmarks_service.enums.swagger.dart';

part 'liberty_bookmarks_service.swagger.chopper.dart';
part 'liberty_bookmarks_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyBookmarksService extends ChopperService {
  static LibertyBookmarksService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyBookmarksService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyBookmarksService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyBookmarksService(newClient);
  }

  ///Get all bookmarks for given profile with given content type.
  ///@param profileId profile identifier
  ///@param contentType content source type
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response<BookmarkArray>> profilesProfileIdBookmarksGet({
    required String? profileId,
    String? contentType,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Bookmark, () => Bookmark.fromJsonFactory);

    return _profilesProfileIdBookmarksGet(
        profileId: profileId,
        contentType: contentType,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Get all bookmarks for given profile with given content type.
  ///@param profileId profile identifier
  ///@param contentType content source type
  ///@param X-Claims-Set Encoded customer information
  @Get(path: '/profiles/{profileId}/bookmarks')
  Future<chopper.Response<BookmarkArray>> _profilesProfileIdBookmarksGet({
    @Path('profileId') required String? profileId,
    @Query('contentType') String? contentType,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete all bookmarks for given profile
  ///@param profileId profile identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> profilesProfileIdBookmarksDelete({
    required String? profileId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    return _profilesProfileIdBookmarksDelete(
        profileId: profileId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Delete all bookmarks for given profile
  ///@param profileId profile identifier
  ///@param X-Claims-Set Encoded customer information
  @Delete(path: '/profiles/{profileId}/bookmarks')
  Future<chopper.Response> _profilesProfileIdBookmarksDelete({
    @Path('profileId') required String? profileId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Stores a bookmark for a given profile and content (which can be either vod, replay, or a recording)
  ///@param profileId profile identifier
  ///@param contentId content identifier should be Crid plus Imi, Crid for vod content type also is possible
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param X-Dev Contains device identifier - used for informational purposes
  ///@param X-Claims-Set Encoded customer information
  ///@param bookmarkParams params required to set a bookmark
  Future<chopper.Response> profilesProfileIdBookmarksContentIdPut({
    required String? profileId,
    required String? contentId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xClaimsSet,
    required BookmarkParams? bookmarkParams,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BookmarkParams, () => BookmarkParams.fromJsonFactory);

    return _profilesProfileIdBookmarksContentIdPut(
        profileId: profileId,
        contentId: contentId,
        xCus: xCus,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        bookmarkParams: bookmarkParams,
        cacheControl: cacheControl);
  }

  ///Stores a bookmark for a given profile and content (which can be either vod, replay, or a recording)
  ///@param profileId profile identifier
  ///@param contentId content identifier should be Crid plus Imi, Crid for vod content type also is possible
  ///@param X-Cus Contains customer identifier - used for informational purposes
  ///@param X-Dev Contains device identifier - used for informational purposes
  ///@param X-Claims-Set Encoded customer information
  ///@param bookmarkParams params required to set a bookmark
  @Put(path: '/profiles/{profileId}/bookmarks/{contentId}')
  Future<chopper.Response> _profilesProfileIdBookmarksContentIdPut({
    @Path('profileId') required String? profileId,
    @Path('contentId') required String? contentId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Body() required BookmarkParams? bookmarkParams,
    @Header('Cache-Control') String? cacheControl,
  });

  ///!Deprecated! Use /bookmarks/search. Get bookmark for given profile and content
  ///@param profileId profile identifier
  ///@param contentId content identifier
  Future<chopper.Response<Bookmark>> profilesProfileIdBookmarksContentIdGet({
    required String? profileId,
    required String? contentId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Bookmark, () => Bookmark.fromJsonFactory);

    return _profilesProfileIdBookmarksContentIdGet(
        profileId: profileId, contentId: contentId, cacheControl: cacheControl);
  }

  ///!Deprecated! Use /bookmarks/search. Get bookmark for given profile and content
  ///@param profileId profile identifier
  ///@param contentId content identifier
  @Get(path: '/profiles/{profileId}/bookmarks/{contentId}')
  Future<chopper.Response<Bookmark>> _profilesProfileIdBookmarksContentIdGet({
    @Path('profileId') required String? profileId,
    @Path('contentId') required String? contentId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get continue watching list for given profile, apply grouping by show and apply grouping by title id(with fallback by content id) for single titles
  ///@param profileId profile identifier
  ///@param limit number of bookmarks
  Future<chopper.Response<List<ContinueWatchingItem>>>
      profilesProfileIdContinueWatchingGet({
    required String? profileId,
    int? limit,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContinueWatchingItem, () => ContinueWatchingItem.fromJsonFactory);

    return _profilesProfileIdContinueWatchingGet(
        profileId: profileId, limit: limit, cacheControl: cacheControl);
  }

  ///Get continue watching list for given profile, apply grouping by show and apply grouping by title id(with fallback by content id) for single titles
  ///@param profileId profile identifier
  ///@param limit number of bookmarks
  @Get(path: '/profiles/{profileId}/continue-watching')
  Future<chopper.Response<List<ContinueWatchingItem>>>
      _profilesProfileIdContinueWatchingGet({
    @Path('profileId') required String? profileId,
    @Query('limit') int? limit,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete items from continue watching list for given profile
  ///@param profileId profile identifier
  ///@param continueWatchingDeleteParams params required to delete items from continue watching list
  Future<chopper.Response> profilesProfileIdContinueWatchingDeletePost({
    required String? profileId,
    required ContinueWatchingDeleteParams? continueWatchingDeleteParams,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ContinueWatchingDeleteParams,
        () => ContinueWatchingDeleteParams.fromJsonFactory);

    return _profilesProfileIdContinueWatchingDeletePost(
        profileId: profileId,
        continueWatchingDeleteParams: continueWatchingDeleteParams,
        cacheControl: cacheControl);
  }

  ///Delete items from continue watching list for given profile
  ///@param profileId profile identifier
  ///@param continueWatchingDeleteParams params required to delete items from continue watching list
  @Post(path: '/profiles/{profileId}/continue-watching/delete')
  Future<chopper.Response> _profilesProfileIdContinueWatchingDeletePost({
    @Path('profileId') required String? profileId,
    @Body() required ContinueWatchingDeleteParams? continueWatchingDeleteParams,
    @Header('Cache-Control') String? cacheControl,
  });

  ///!Deprecated! Use /bookmarks/search. Search for specified ones bookmarks for given profile
  ///@param profileId profile identifier
  ///@param contentIds Collection of content Ids for search
  Future<chopper.Response<FoundAndNotFoundBookmarksResponse>>
      profilesProfileIdBookmarksSearchPost({
    required String? profileId,
    required List<String>? contentIds,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FoundAndNotFoundBookmarksResponse,
        () => FoundAndNotFoundBookmarksResponse.fromJsonFactory);

    return _profilesProfileIdBookmarksSearchPost(
        profileId: profileId,
        contentIds: contentIds,
        cacheControl: cacheControl);
  }

  ///!Deprecated! Use /bookmarks/search. Search for specified ones bookmarks for given profile
  ///@param profileId profile identifier
  ///@param contentIds Collection of content Ids for search
  @Post(path: '/profiles/{profileId}/bookmarks/search')
  Future<chopper.Response<FoundAndNotFoundBookmarksResponse>>
      _profilesProfileIdBookmarksSearchPost({
    @Path('profileId') required String? profileId,
    @Body() required List<String>? contentIds,
    @Header('Cache-Control') String? cacheControl,
  });

  ///!Deprecated! Use /bookmarks/search. Search for the bookmarks by criteria specified in bookmark search filter
  ///@param customerId customer identifier
  ///@param bookmarkSearchFilter Bookmark search filter with specified criteria, limit and grouping type
  Future<chopper.Response<List<BookmarkAdvanced>>>
      customersCustomerIdBookmarksSearchPost({
    required String? customerId,
    required BookmarkSearchFilter? bookmarkSearchFilter,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BookmarkSearchFilter, () => BookmarkSearchFilter.fromJsonFactory);
    generatedMapping.putIfAbsent(
        BookmarkAdvanced, () => BookmarkAdvanced.fromJsonFactory);

    return _customersCustomerIdBookmarksSearchPost(
        customerId: customerId,
        bookmarkSearchFilter: bookmarkSearchFilter,
        cacheControl: cacheControl);
  }

  ///!Deprecated! Use /bookmarks/search. Search for the bookmarks by criteria specified in bookmark search filter
  ///@param customerId customer identifier
  ///@param bookmarkSearchFilter Bookmark search filter with specified criteria, limit and grouping type
  @Post(path: '/customers/{customerId}/bookmarks/search')
  Future<chopper.Response<List<BookmarkAdvanced>>>
      _customersCustomerIdBookmarksSearchPost({
    @Path('customerId') required String? customerId,
    @Body() required BookmarkSearchFilter? bookmarkSearchFilter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete all bookmarks for given customer
  ///@param customerId customer identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> customersCustomerIdBookmarksDelete({
    required String? customerId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    return _customersCustomerIdBookmarksDelete(
        customerId: customerId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Delete all bookmarks for given customer
  ///@param customerId customer identifier
  ///@param X-Claims-Set Encoded customer information
  @Delete(path: '/customers/{customerId}/bookmarks')
  Future<chopper.Response> _customersCustomerIdBookmarksDelete({
    @Path('customerId') required String? customerId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param bookmarkSearchFilterWithCustomerId Bookmark search filter with specified criteria(additional customerId), limit and grouping type
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response<List<BookmarkAdvanced>>> bookmarksSearchPost({
    required BookmarkSearchFilterWithCustomerId?
        bookmarkSearchFilterWithCustomerId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(BookmarkSearchFilterWithCustomerId,
        () => BookmarkSearchFilterWithCustomerId.fromJsonFactory);
    generatedMapping.putIfAbsent(
        BookmarkAdvanced, () => BookmarkAdvanced.fromJsonFactory);

    return _bookmarksSearchPost(
        bookmarkSearchFilterWithCustomerId: bookmarkSearchFilterWithCustomerId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param bookmarkSearchFilterWithCustomerId Bookmark search filter with specified criteria(additional customerId), limit and grouping type
  ///@param X-Claims-Set Encoded customer information
  @Post(path: '/bookmarks/search')
  Future<chopper.Response<List<BookmarkAdvanced>>> _bookmarksSearchPost({
    @Body()
        required BookmarkSearchFilterWithCustomerId?
            bookmarkSearchFilterWithCustomerId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param bookmarkSearchFilterWithCustomerIdV2 Bookmark search filter with specified criteria(additional customerId), limit and grouping type
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response<List<BookmarkAdvancedV2>>> v2BookmarksSearchPost({
    required BookmarkSearchFilterWithCustomerIdV2?
        bookmarkSearchFilterWithCustomerIdV2,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(BookmarkSearchFilterWithCustomerIdV2,
        () => BookmarkSearchFilterWithCustomerIdV2.fromJsonFactory);
    generatedMapping.putIfAbsent(
        BookmarkAdvancedV2, () => BookmarkAdvancedV2.fromJsonFactory);

    return _v2BookmarksSearchPost(
        bookmarkSearchFilterWithCustomerIdV2:
            bookmarkSearchFilterWithCustomerIdV2,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Search for the bookmarks by criteria specified in bookmark search filter
  ///@param bookmarkSearchFilterWithCustomerIdV2 Bookmark search filter with specified criteria(additional customerId), limit and grouping type
  ///@param X-Claims-Set Encoded customer information
  @Post(path: '/v2/bookmarks/search')
  Future<chopper.Response<List<BookmarkAdvancedV2>>> _v2BookmarksSearchPost({
    @Body()
        required BookmarkSearchFilterWithCustomerIdV2?
            bookmarkSearchFilterWithCustomerIdV2,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class BookmarkParams {
  BookmarkParams({
    required this.customerId,
    required this.position,
    required this.duration,
    required this.titleId,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.isAdult,
    this.minimumAge,
    required this.contentType,
    this.deletionDate,
    this.channelId,
    this.cpeId,
  });

  factory BookmarkParams.fromJson(Map<String, dynamic> json) =>
      _$BookmarkParamsFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'deletionDate', includeIfNull: false)
  final DateTime? deletionDate;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  static const fromJsonFactory = _$BookmarkParamsFromJson;
  static const toJsonFactory = _$BookmarkParamsToJson;
  Map<String, dynamic> toJson() => _$BookmarkParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkParams &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.deletionDate, deletionDate) ||
                const DeepCollectionEquality()
                    .equals(other.deletionDate, deletionDate)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(deletionDate) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      runtimeType.hashCode;
}

extension $BookmarkParamsExtension on BookmarkParams {
  BookmarkParams copyWith(
      {String? customerId,
      int? position,
      int? duration,
      String? titleId,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      bool? isAdult,
      int? minimumAge,
      enums.ContentType? contentType,
      DateTime? deletionDate,
      String? channelId,
      String? cpeId}) {
    return BookmarkParams(
        customerId: customerId ?? this.customerId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        contentType: contentType ?? this.contentType,
        deletionDate: deletionDate ?? this.deletionDate,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId);
  }

  BookmarkParams copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<String>? titleId,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? minimumAge,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<DateTime?>? deletionDate,
      Wrapped<String?>? channelId,
      Wrapped<String?>? cpeId}) {
    return BookmarkParams(
        customerId: (customerId != null ? customerId.value : this.customerId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        deletionDate:
            (deletionDate != null ? deletionDate.value : this.deletionDate),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId));
  }
}

typedef BookmarkArray = List<Bookmark>;

@JsonSerializable(explicitToJson: true)
class Bookmark {
  Bookmark({
    required this.contentId,
    required this.position,
    required this.contentType,
    this.viewedState,
    this.viewState,
    this.timestamp,
    this.isAdult,
    this.cpeId,
  });

  factory Bookmark.fromJson(Map<String, dynamic> json) =>
      _$BookmarkFromJson(json);

  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateToJson,
    fromJson: viewedStateFromJson,
  )
  final enums.ViewedState? viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  static const fromJsonFactory = _$BookmarkFromJson;
  static const toJsonFactory = _$BookmarkToJson;
  Map<String, dynamic> toJson() => _$BookmarkToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Bookmark &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(cpeId) ^
      runtimeType.hashCode;
}

extension $BookmarkExtension on Bookmark {
  Bookmark copyWith(
      {String? contentId,
      int? position,
      enums.ContentType? contentType,
      enums.ViewedState? viewedState,
      enums.ViewState? viewState,
      DateTime? timestamp,
      bool? isAdult,
      String? cpeId}) {
    return Bookmark(
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        contentType: contentType ?? this.contentType,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        timestamp: timestamp ?? this.timestamp,
        isAdult: isAdult ?? this.isAdult,
        cpeId: cpeId ?? this.cpeId);
  }

  Bookmark copyWithWrapped(
      {Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<enums.ViewedState?>? viewedState,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? timestamp,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? cpeId}) {
    return Bookmark(
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkAdvanced {
  BookmarkAdvanced({
    required this.profileId,
    required this.contentId,
    required this.position,
    required this.duration,
    required this.contentType,
    this.viewedState,
    this.viewState,
    this.timestamp,
    this.isAdult,
    this.titleId,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.minimumAge,
    this.channelId,
    this.cpeId,
  });

  factory BookmarkAdvanced.fromJson(Map<String, dynamic> json) =>
      _$BookmarkAdvancedFromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateToJson,
    fromJson: viewedStateFromJson,
  )
  final enums.ViewedState? viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  static const fromJsonFactory = _$BookmarkAdvancedFromJson;
  static const toJsonFactory = _$BookmarkAdvancedToJson;
  Map<String, dynamic> toJson() => _$BookmarkAdvancedToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkAdvanced &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      runtimeType.hashCode;
}

extension $BookmarkAdvancedExtension on BookmarkAdvanced {
  BookmarkAdvanced copyWith(
      {String? profileId,
      String? contentId,
      int? position,
      int? duration,
      enums.ContentType? contentType,
      enums.ViewedState? viewedState,
      enums.ViewState? viewState,
      DateTime? timestamp,
      bool? isAdult,
      String? titleId,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      int? minimumAge,
      String? channelId,
      String? cpeId}) {
    return BookmarkAdvanced(
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        contentType: contentType ?? this.contentType,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        timestamp: timestamp ?? this.timestamp,
        isAdult: isAdult ?? this.isAdult,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        minimumAge: minimumAge ?? this.minimumAge,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId);
  }

  BookmarkAdvanced copyWithWrapped(
      {Wrapped<String>? profileId,
      Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<enums.ViewedState?>? viewedState,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? timestamp,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? titleId,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? channelId,
      Wrapped<String?>? cpeId}) {
    return BookmarkAdvanced(
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkAdvancedV2 {
  BookmarkAdvancedV2({
    required this.profileId,
    required this.contentId,
    required this.position,
    required this.duration,
    required this.contentType,
    this.viewState,
    this.timestamp,
    this.isAdult,
    this.titleId,
    this.seasonId,
    this.showId,
    this.episodeNumber,
    this.seasonNumber,
    this.minimumAge,
    this.channelId,
    this.cpeId,
  });

  factory BookmarkAdvancedV2.fromJson(Map<String, dynamic> json) =>
      _$BookmarkAdvancedV2FromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime? timestamp;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  static const fromJsonFactory = _$BookmarkAdvancedV2FromJson;
  static const toJsonFactory = _$BookmarkAdvancedV2ToJson;
  Map<String, dynamic> toJson() => _$BookmarkAdvancedV2ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkAdvancedV2 &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      runtimeType.hashCode;
}

extension $BookmarkAdvancedV2Extension on BookmarkAdvancedV2 {
  BookmarkAdvancedV2 copyWith(
      {String? profileId,
      String? contentId,
      int? position,
      int? duration,
      enums.ContentType? contentType,
      enums.ViewState? viewState,
      DateTime? timestamp,
      bool? isAdult,
      String? titleId,
      String? seasonId,
      String? showId,
      int? episodeNumber,
      int? seasonNumber,
      int? minimumAge,
      String? channelId,
      String? cpeId}) {
    return BookmarkAdvancedV2(
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        duration: duration ?? this.duration,
        contentType: contentType ?? this.contentType,
        viewState: viewState ?? this.viewState,
        timestamp: timestamp ?? this.timestamp,
        isAdult: isAdult ?? this.isAdult,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        minimumAge: minimumAge ?? this.minimumAge,
        channelId: channelId ?? this.channelId,
        cpeId: cpeId ?? this.cpeId);
  }

  BookmarkAdvancedV2 copyWithWrapped(
      {Wrapped<String>? profileId,
      Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<DateTime?>? timestamp,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? titleId,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? showId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? channelId,
      Wrapped<String?>? cpeId}) {
    return BookmarkAdvancedV2(
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        viewState: (viewState != null ? viewState.value : this.viewState),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        channelId: (channelId != null ? channelId.value : this.channelId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId));
  }
}

@JsonSerializable(explicitToJson: true)
class NotFoundBookmark {
  NotFoundBookmark({
    required this.contentId,
  });

  factory NotFoundBookmark.fromJson(Map<String, dynamic> json) =>
      _$NotFoundBookmarkFromJson(json);

  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  static const fromJsonFactory = _$NotFoundBookmarkFromJson;
  static const toJsonFactory = _$NotFoundBookmarkToJson;
  Map<String, dynamic> toJson() => _$NotFoundBookmarkToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotFoundBookmark &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentId) ^ runtimeType.hashCode;
}

extension $NotFoundBookmarkExtension on NotFoundBookmark {
  NotFoundBookmark copyWith({String? contentId}) {
    return NotFoundBookmark(contentId: contentId ?? this.contentId);
  }

  NotFoundBookmark copyWithWrapped({Wrapped<String>? contentId}) {
    return NotFoundBookmark(
        contentId: (contentId != null ? contentId.value : this.contentId));
  }
}

@JsonSerializable(explicitToJson: true)
class FoundAndNotFoundBookmarksResponse {
  FoundAndNotFoundBookmarksResponse({
    this.foundBookmarks,
    this.notFoundBookmarks,
  });

  factory FoundAndNotFoundBookmarksResponse.fromJson(
          Map<String, dynamic> json) =>
      _$FoundAndNotFoundBookmarksResponseFromJson(json);

  @JsonKey(
      name: 'foundBookmarks', includeIfNull: false, defaultValue: <Bookmark>[])
  final List<Bookmark>? foundBookmarks;
  @JsonKey(
      name: 'notFoundBookmarks',
      includeIfNull: false,
      defaultValue: <NotFoundBookmark>[])
  final List<NotFoundBookmark>? notFoundBookmarks;
  static const fromJsonFactory = _$FoundAndNotFoundBookmarksResponseFromJson;
  static const toJsonFactory = _$FoundAndNotFoundBookmarksResponseToJson;
  Map<String, dynamic> toJson() =>
      _$FoundAndNotFoundBookmarksResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FoundAndNotFoundBookmarksResponse &&
            (identical(other.foundBookmarks, foundBookmarks) ||
                const DeepCollectionEquality()
                    .equals(other.foundBookmarks, foundBookmarks)) &&
            (identical(other.notFoundBookmarks, notFoundBookmarks) ||
                const DeepCollectionEquality()
                    .equals(other.notFoundBookmarks, notFoundBookmarks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(foundBookmarks) ^
      const DeepCollectionEquality().hash(notFoundBookmarks) ^
      runtimeType.hashCode;
}

extension $FoundAndNotFoundBookmarksResponseExtension
    on FoundAndNotFoundBookmarksResponse {
  FoundAndNotFoundBookmarksResponse copyWith(
      {List<Bookmark>? foundBookmarks,
      List<NotFoundBookmark>? notFoundBookmarks}) {
    return FoundAndNotFoundBookmarksResponse(
        foundBookmarks: foundBookmarks ?? this.foundBookmarks,
        notFoundBookmarks: notFoundBookmarks ?? this.notFoundBookmarks);
  }

  FoundAndNotFoundBookmarksResponse copyWithWrapped(
      {Wrapped<List<Bookmark>?>? foundBookmarks,
      Wrapped<List<NotFoundBookmark>?>? notFoundBookmarks}) {
    return FoundAndNotFoundBookmarksResponse(
        foundBookmarks: (foundBookmarks != null
            ? foundBookmarks.value
            : this.foundBookmarks),
        notFoundBookmarks: (notFoundBookmarks != null
            ? notFoundBookmarks.value
            : this.notFoundBookmarks));
  }
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingItem {
  ContinueWatchingItem({
    required this.contentId,
    required this.position,
    required this.contentType,
    required this.timestamp,
    required this.viewedState,
    required this.viewState,
    this.customerId,
    this.titleId,
    this.showId,
    this.minimumAge,
    this.cpeId,
    required this.duration,
  });

  factory ContinueWatchingItem.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingItemFromJson(json);

  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'timestamp', includeIfNull: false)
  final DateTime timestamp;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateToJson,
    fromJson: viewedStateFromJson,
  )
  final enums.ViewedState viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState viewState;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  static const fromJsonFactory = _$ContinueWatchingItemFromJson;
  static const toJsonFactory = _$ContinueWatchingItemToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingItem &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(duration) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingItemExtension on ContinueWatchingItem {
  ContinueWatchingItem copyWith(
      {String? contentId,
      int? position,
      enums.ContentType? contentType,
      DateTime? timestamp,
      enums.ViewedState? viewedState,
      enums.ViewState? viewState,
      String? customerId,
      String? titleId,
      String? showId,
      int? minimumAge,
      String? cpeId,
      int? duration}) {
    return ContinueWatchingItem(
        contentId: contentId ?? this.contentId,
        position: position ?? this.position,
        contentType: contentType ?? this.contentType,
        timestamp: timestamp ?? this.timestamp,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        customerId: customerId ?? this.customerId,
        titleId: titleId ?? this.titleId,
        showId: showId ?? this.showId,
        minimumAge: minimumAge ?? this.minimumAge,
        cpeId: cpeId ?? this.cpeId,
        duration: duration ?? this.duration);
  }

  ContinueWatchingItem copyWithWrapped(
      {Wrapped<String>? contentId,
      Wrapped<int>? position,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<DateTime>? timestamp,
      Wrapped<enums.ViewedState>? viewedState,
      Wrapped<enums.ViewState>? viewState,
      Wrapped<String?>? customerId,
      Wrapped<String?>? titleId,
      Wrapped<String?>? showId,
      Wrapped<int?>? minimumAge,
      Wrapped<String?>? cpeId,
      Wrapped<int>? duration}) {
    return ContinueWatchingItem(
        contentId: (contentId != null ? contentId.value : this.contentId),
        position: (position != null ? position.value : this.position),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        customerId: (customerId != null ? customerId.value : this.customerId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        showId: (showId != null ? showId.value : this.showId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        duration: (duration != null ? duration.value : this.duration));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkSearchFilter {
  BookmarkSearchFilter({
    this.profileId,
    this.contentId,
    this.titleId,
    this.seasonId,
    this.showId,
    this.viewedState,
    this.viewState,
    this.contentType,
    this.isAdult,
    this.creationDateFrom,
    this.creationDateTo,
    this.cpeId,
    this.limit,
    this.groupBookmarksBy,
  });

  factory BookmarkSearchFilter.fromJson(Map<String, dynamic> json) =>
      _$BookmarkSearchFilterFromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showId;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateListToJson,
    fromJson: viewedStateListFromJson,
  )
  final List<enums.ViewedState>? viewedState;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateListToJson,
    fromJson: viewStateListFromJson,
  )
  final List<enums.ViewState>? viewState;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeListToJson,
    fromJson: contentTypeListFromJson,
  )
  final List<enums.ContentType>? contentType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'creationDateFrom', includeIfNull: false)
  final DateTime? creationDateFrom;
  @JsonKey(name: 'creationDateTo', includeIfNull: false)
  final DateTime? creationDateTo;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(
    name: 'groupBookmarksBy',
    includeIfNull: false,
    toJson: bookmarkSearchFilterGroupBookmarksByToJson,
    fromJson: bookmarkSearchFilterGroupBookmarksByFromJson,
  )
  final enums.BookmarkSearchFilterGroupBookmarksBy? groupBookmarksBy;
  static const fromJsonFactory = _$BookmarkSearchFilterFromJson;
  static const toJsonFactory = _$BookmarkSearchFilterToJson;
  Map<String, dynamic> toJson() => _$BookmarkSearchFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkSearchFilter &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.creationDateFrom, creationDateFrom) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateFrom, creationDateFrom)) &&
            (identical(other.creationDateTo, creationDateTo) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateTo, creationDateTo)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.groupBookmarksBy, groupBookmarksBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupBookmarksBy, groupBookmarksBy)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(creationDateFrom) ^
      const DeepCollectionEquality().hash(creationDateTo) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(groupBookmarksBy) ^
      runtimeType.hashCode;
}

extension $BookmarkSearchFilterExtension on BookmarkSearchFilter {
  BookmarkSearchFilter copyWith(
      {String? profileId,
      List<String>? contentId,
      List<String>? titleId,
      List<String>? seasonId,
      List<String>? showId,
      List<enums.ViewedState>? viewedState,
      List<enums.ViewState>? viewState,
      List<enums.ContentType>? contentType,
      bool? isAdult,
      DateTime? creationDateFrom,
      DateTime? creationDateTo,
      String? cpeId,
      int? limit,
      enums.BookmarkSearchFilterGroupBookmarksBy? groupBookmarksBy}) {
    return BookmarkSearchFilter(
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        viewedState: viewedState ?? this.viewedState,
        viewState: viewState ?? this.viewState,
        contentType: contentType ?? this.contentType,
        isAdult: isAdult ?? this.isAdult,
        creationDateFrom: creationDateFrom ?? this.creationDateFrom,
        creationDateTo: creationDateTo ?? this.creationDateTo,
        cpeId: cpeId ?? this.cpeId,
        limit: limit ?? this.limit,
        groupBookmarksBy: groupBookmarksBy ?? this.groupBookmarksBy);
  }

  BookmarkSearchFilter copyWithWrapped(
      {Wrapped<String?>? profileId,
      Wrapped<List<String>?>? contentId,
      Wrapped<List<String>?>? titleId,
      Wrapped<List<String>?>? seasonId,
      Wrapped<List<String>?>? showId,
      Wrapped<List<enums.ViewedState>?>? viewedState,
      Wrapped<List<enums.ViewState>?>? viewState,
      Wrapped<List<enums.ContentType>?>? contentType,
      Wrapped<bool?>? isAdult,
      Wrapped<DateTime?>? creationDateFrom,
      Wrapped<DateTime?>? creationDateTo,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? limit,
      Wrapped<enums.BookmarkSearchFilterGroupBookmarksBy?>? groupBookmarksBy}) {
    return BookmarkSearchFilter(
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        viewState: (viewState != null ? viewState.value : this.viewState),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        creationDateFrom: (creationDateFrom != null
            ? creationDateFrom.value
            : this.creationDateFrom),
        creationDateTo: (creationDateTo != null
            ? creationDateTo.value
            : this.creationDateTo),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        limit: (limit != null ? limit.value : this.limit),
        groupBookmarksBy: (groupBookmarksBy != null
            ? groupBookmarksBy.value
            : this.groupBookmarksBy));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkSearchFilterWithCustomerId {
  BookmarkSearchFilterWithCustomerId({
    this.customerId,
    this.profileId,
    this.contentId,
    this.titleId,
    this.seasonId,
    this.showId,
    this.viewedState,
    this.contentType,
    this.isAdult,
    this.creationDateFrom,
    this.creationDateTo,
    this.cpeId,
    this.limit,
    this.groupBookmarksBy,
  });

  factory BookmarkSearchFilterWithCustomerId.fromJson(
          Map<String, dynamic> json) =>
      _$BookmarkSearchFilterWithCustomerIdFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showId;
  @JsonKey(
    name: 'viewedState',
    includeIfNull: false,
    toJson: viewedStateListToJson,
    fromJson: viewedStateListFromJson,
  )
  final List<enums.ViewedState>? viewedState;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeListToJson,
    fromJson: contentTypeListFromJson,
  )
  final List<enums.ContentType>? contentType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'creationDateFrom', includeIfNull: false)
  final DateTime? creationDateFrom;
  @JsonKey(name: 'creationDateTo', includeIfNull: false)
  final DateTime? creationDateTo;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(
    name: 'groupBookmarksBy',
    includeIfNull: false,
    toJson: bookmarkSearchFilterWithCustomerIdGroupBookmarksByToJson,
    fromJson: bookmarkSearchFilterWithCustomerIdGroupBookmarksByFromJson,
  )
  final enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy?
      groupBookmarksBy;
  static const fromJsonFactory = _$BookmarkSearchFilterWithCustomerIdFromJson;
  static const toJsonFactory = _$BookmarkSearchFilterWithCustomerIdToJson;
  Map<String, dynamic> toJson() =>
      _$BookmarkSearchFilterWithCustomerIdToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkSearchFilterWithCustomerId &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.viewedState, viewedState) ||
                const DeepCollectionEquality()
                    .equals(other.viewedState, viewedState)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.creationDateFrom, creationDateFrom) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateFrom, creationDateFrom)) &&
            (identical(other.creationDateTo, creationDateTo) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateTo, creationDateTo)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.groupBookmarksBy, groupBookmarksBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupBookmarksBy, groupBookmarksBy)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(creationDateFrom) ^
      const DeepCollectionEquality().hash(creationDateTo) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(groupBookmarksBy) ^
      runtimeType.hashCode;
}

extension $BookmarkSearchFilterWithCustomerIdExtension
    on BookmarkSearchFilterWithCustomerId {
  BookmarkSearchFilterWithCustomerId copyWith(
      {String? customerId,
      String? profileId,
      List<String>? contentId,
      List<String>? titleId,
      List<String>? seasonId,
      List<String>? showId,
      List<enums.ViewedState>? viewedState,
      List<enums.ContentType>? contentType,
      bool? isAdult,
      DateTime? creationDateFrom,
      DateTime? creationDateTo,
      String? cpeId,
      int? limit,
      enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy?
          groupBookmarksBy}) {
    return BookmarkSearchFilterWithCustomerId(
        customerId: customerId ?? this.customerId,
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        viewedState: viewedState ?? this.viewedState,
        contentType: contentType ?? this.contentType,
        isAdult: isAdult ?? this.isAdult,
        creationDateFrom: creationDateFrom ?? this.creationDateFrom,
        creationDateTo: creationDateTo ?? this.creationDateTo,
        cpeId: cpeId ?? this.cpeId,
        limit: limit ?? this.limit,
        groupBookmarksBy: groupBookmarksBy ?? this.groupBookmarksBy);
  }

  BookmarkSearchFilterWithCustomerId copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<String?>? profileId,
      Wrapped<List<String>?>? contentId,
      Wrapped<List<String>?>? titleId,
      Wrapped<List<String>?>? seasonId,
      Wrapped<List<String>?>? showId,
      Wrapped<List<enums.ViewedState>?>? viewedState,
      Wrapped<List<enums.ContentType>?>? contentType,
      Wrapped<bool?>? isAdult,
      Wrapped<DateTime?>? creationDateFrom,
      Wrapped<DateTime?>? creationDateTo,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? limit,
      Wrapped<enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy?>?
          groupBookmarksBy}) {
    return BookmarkSearchFilterWithCustomerId(
        customerId: (customerId != null ? customerId.value : this.customerId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        creationDateFrom: (creationDateFrom != null
            ? creationDateFrom.value
            : this.creationDateFrom),
        creationDateTo: (creationDateTo != null
            ? creationDateTo.value
            : this.creationDateTo),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        limit: (limit != null ? limit.value : this.limit),
        groupBookmarksBy: (groupBookmarksBy != null
            ? groupBookmarksBy.value
            : this.groupBookmarksBy));
  }
}

@JsonSerializable(explicitToJson: true)
class BookmarkSearchFilterWithCustomerIdV2 {
  BookmarkSearchFilterWithCustomerIdV2({
    this.customerId,
    this.profileId,
    this.contentId,
    this.titleId,
    this.seasonId,
    this.showId,
    this.viewState,
    this.contentType,
    this.isAdult,
    this.creationDateFrom,
    this.creationDateTo,
    this.cpeId,
    this.limit,
    this.groupBookmarksBy,
  });

  factory BookmarkSearchFilterWithCustomerIdV2.fromJson(
          Map<String, dynamic> json) =>
      _$BookmarkSearchFilterWithCustomerIdV2FromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showId;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateListToJson,
    fromJson: viewStateListFromJson,
  )
  final List<enums.ViewState>? viewState;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeListToJson,
    fromJson: contentTypeListFromJson,
  )
  final List<enums.ContentType>? contentType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'creationDateFrom', includeIfNull: false)
  final DateTime? creationDateFrom;
  @JsonKey(name: 'creationDateTo', includeIfNull: false)
  final DateTime? creationDateTo;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(
    name: 'groupBookmarksBy',
    includeIfNull: false,
    toJson: bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByToJson,
    fromJson: bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByFromJson,
  )
  final enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy?
      groupBookmarksBy;
  static const fromJsonFactory = _$BookmarkSearchFilterWithCustomerIdV2FromJson;
  static const toJsonFactory = _$BookmarkSearchFilterWithCustomerIdV2ToJson;
  Map<String, dynamic> toJson() =>
      _$BookmarkSearchFilterWithCustomerIdV2ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookmarkSearchFilterWithCustomerIdV2 &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.creationDateFrom, creationDateFrom) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateFrom, creationDateFrom)) &&
            (identical(other.creationDateTo, creationDateTo) ||
                const DeepCollectionEquality()
                    .equals(other.creationDateTo, creationDateTo)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.groupBookmarksBy, groupBookmarksBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupBookmarksBy, groupBookmarksBy)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(creationDateFrom) ^
      const DeepCollectionEquality().hash(creationDateTo) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(groupBookmarksBy) ^
      runtimeType.hashCode;
}

extension $BookmarkSearchFilterWithCustomerIdV2Extension
    on BookmarkSearchFilterWithCustomerIdV2 {
  BookmarkSearchFilterWithCustomerIdV2 copyWith(
      {String? customerId,
      String? profileId,
      List<String>? contentId,
      List<String>? titleId,
      List<String>? seasonId,
      List<String>? showId,
      List<enums.ViewState>? viewState,
      List<enums.ContentType>? contentType,
      bool? isAdult,
      DateTime? creationDateFrom,
      DateTime? creationDateTo,
      String? cpeId,
      int? limit,
      enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy?
          groupBookmarksBy}) {
    return BookmarkSearchFilterWithCustomerIdV2(
        customerId: customerId ?? this.customerId,
        profileId: profileId ?? this.profileId,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        seasonId: seasonId ?? this.seasonId,
        showId: showId ?? this.showId,
        viewState: viewState ?? this.viewState,
        contentType: contentType ?? this.contentType,
        isAdult: isAdult ?? this.isAdult,
        creationDateFrom: creationDateFrom ?? this.creationDateFrom,
        creationDateTo: creationDateTo ?? this.creationDateTo,
        cpeId: cpeId ?? this.cpeId,
        limit: limit ?? this.limit,
        groupBookmarksBy: groupBookmarksBy ?? this.groupBookmarksBy);
  }

  BookmarkSearchFilterWithCustomerIdV2 copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<String?>? profileId,
      Wrapped<List<String>?>? contentId,
      Wrapped<List<String>?>? titleId,
      Wrapped<List<String>?>? seasonId,
      Wrapped<List<String>?>? showId,
      Wrapped<List<enums.ViewState>?>? viewState,
      Wrapped<List<enums.ContentType>?>? contentType,
      Wrapped<bool?>? isAdult,
      Wrapped<DateTime?>? creationDateFrom,
      Wrapped<DateTime?>? creationDateTo,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? limit,
      Wrapped<enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy?>?
          groupBookmarksBy}) {
    return BookmarkSearchFilterWithCustomerIdV2(
        customerId: (customerId != null ? customerId.value : this.customerId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        showId: (showId != null ? showId.value : this.showId),
        viewState: (viewState != null ? viewState.value : this.viewState),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        creationDateFrom: (creationDateFrom != null
            ? creationDateFrom.value
            : this.creationDateFrom),
        creationDateTo: (creationDateTo != null
            ? creationDateTo.value
            : this.creationDateTo),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        limit: (limit != null ? limit.value : this.limit),
        groupBookmarksBy: (groupBookmarksBy != null
            ? groupBookmarksBy.value
            : this.groupBookmarksBy));
  }
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams({
    this.titleIds,
    this.showIds,
  });

  factory ContinueWatchingDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingDeleteParamsFromJson(json);

  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(name: 'showIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showIds;
  static const fromJsonFactory = _$ContinueWatchingDeleteParamsFromJson;
  static const toJsonFactory = _$ContinueWatchingDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingDeleteParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingDeleteParams &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.showIds, showIds) ||
                const DeepCollectionEquality().equals(other.showIds, showIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(showIds) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingDeleteParamsExtension
    on ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams copyWith(
      {List<String>? titleIds, List<String>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: titleIds ?? this.titleIds, showIds: showIds ?? this.showIds);
  }

  ContinueWatchingDeleteParams copyWithWrapped(
      {Wrapped<List<String>?>? titleIds, Wrapped<List<String>?>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        showIds: (showIds != null ? showIds.value : this.showIds));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error error;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    required this.details,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String details;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;
  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality().equals(other.details, details)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String>? details}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details));
  }
}

String? bookmarkSearchFilterGroupBookmarksByToJson(
    enums.BookmarkSearchFilterGroupBookmarksBy?
        bookmarkSearchFilterGroupBookmarksBy) {
  return enums.$BookmarkSearchFilterGroupBookmarksByMap[
      bookmarkSearchFilterGroupBookmarksBy];
}

enums.BookmarkSearchFilterGroupBookmarksBy
    bookmarkSearchFilterGroupBookmarksByFromJson(
  Object? bookmarkSearchFilterGroupBookmarksBy, [
  enums.BookmarkSearchFilterGroupBookmarksBy? defaultValue,
]) {
  if (bookmarkSearchFilterGroupBookmarksBy is String) {
    return enums.$BookmarkSearchFilterGroupBookmarksByMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                bookmarkSearchFilterGroupBookmarksBy.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BookmarkSearchFilterGroupBookmarksBy
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BookmarkSearchFilterGroupBookmarksByMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BookmarkSearchFilterGroupBookmarksBy.swaggerGeneratedUnknown;
}

List<String> bookmarkSearchFilterGroupBookmarksByListToJson(
    List<enums.BookmarkSearchFilterGroupBookmarksBy>?
        bookmarkSearchFilterGroupBookmarksBy) {
  if (bookmarkSearchFilterGroupBookmarksBy == null) {
    return [];
  }

  return bookmarkSearchFilterGroupBookmarksBy
      .map((e) => enums.$BookmarkSearchFilterGroupBookmarksByMap[e]!)
      .toList();
}

List<enums.BookmarkSearchFilterGroupBookmarksBy>
    bookmarkSearchFilterGroupBookmarksByListFromJson(
  List? bookmarkSearchFilterGroupBookmarksBy, [
  List<enums.BookmarkSearchFilterGroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterGroupBookmarksBy == null) {
    return defaultValue ?? [];
  }

  return bookmarkSearchFilterGroupBookmarksBy
      .map((e) => bookmarkSearchFilterGroupBookmarksByFromJson(e.toString()))
      .toList();
}

List<enums.BookmarkSearchFilterGroupBookmarksBy>?
    bookmarkSearchFilterGroupBookmarksByNullableListFromJson(
  List? bookmarkSearchFilterGroupBookmarksBy, [
  List<enums.BookmarkSearchFilterGroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterGroupBookmarksBy == null) {
    return defaultValue;
  }

  return bookmarkSearchFilterGroupBookmarksBy
      .map((e) => bookmarkSearchFilterGroupBookmarksByFromJson(e.toString()))
      .toList();
}

String? bookmarkSearchFilterWithCustomerIdGroupBookmarksByToJson(
    enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy?
        bookmarkSearchFilterWithCustomerIdGroupBookmarksBy) {
  return enums.$BookmarkSearchFilterWithCustomerIdGroupBookmarksByMap[
      bookmarkSearchFilterWithCustomerIdGroupBookmarksBy];
}

enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy
    bookmarkSearchFilterWithCustomerIdGroupBookmarksByFromJson(
  Object? bookmarkSearchFilterWithCustomerIdGroupBookmarksBy, [
  enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy? defaultValue,
]) {
  if (bookmarkSearchFilterWithCustomerIdGroupBookmarksBy is String) {
    return enums.$BookmarkSearchFilterWithCustomerIdGroupBookmarksByMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                bookmarkSearchFilterWithCustomerIdGroupBookmarksBy
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BookmarkSearchFilterWithCustomerIdGroupBookmarksByMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy
          .swaggerGeneratedUnknown;
}

List<String> bookmarkSearchFilterWithCustomerIdGroupBookmarksByListToJson(
    List<enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy>?
        bookmarkSearchFilterWithCustomerIdGroupBookmarksBy) {
  if (bookmarkSearchFilterWithCustomerIdGroupBookmarksBy == null) {
    return [];
  }

  return bookmarkSearchFilterWithCustomerIdGroupBookmarksBy
      .map((e) =>
          enums.$BookmarkSearchFilterWithCustomerIdGroupBookmarksByMap[e]!)
      .toList();
}

List<enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy>
    bookmarkSearchFilterWithCustomerIdGroupBookmarksByListFromJson(
  List? bookmarkSearchFilterWithCustomerIdGroupBookmarksBy, [
  List<enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterWithCustomerIdGroupBookmarksBy == null) {
    return defaultValue ?? [];
  }

  return bookmarkSearchFilterWithCustomerIdGroupBookmarksBy
      .map((e) => bookmarkSearchFilterWithCustomerIdGroupBookmarksByFromJson(
          e.toString()))
      .toList();
}

List<enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy>?
    bookmarkSearchFilterWithCustomerIdGroupBookmarksByNullableListFromJson(
  List? bookmarkSearchFilterWithCustomerIdGroupBookmarksBy, [
  List<enums.BookmarkSearchFilterWithCustomerIdGroupBookmarksBy>? defaultValue,
]) {
  if (bookmarkSearchFilterWithCustomerIdGroupBookmarksBy == null) {
    return defaultValue;
  }

  return bookmarkSearchFilterWithCustomerIdGroupBookmarksBy
      .map((e) => bookmarkSearchFilterWithCustomerIdGroupBookmarksByFromJson(
          e.toString()))
      .toList();
}

String? bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByToJson(
    enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy?
        bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy) {
  return enums.$BookmarkSearchFilterWithCustomerIdV2GroupBookmarksByMap[
      bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy];
}

enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
    bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByFromJson(
  Object? bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy, [
  enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy? defaultValue,
]) {
  if (bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy is String) {
    return enums
        .$BookmarkSearchFilterWithCustomerIdV2GroupBookmarksByMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BookmarkSearchFilterWithCustomerIdV2GroupBookmarksByMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
          .swaggerGeneratedUnknown;
}

List<String> bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByListToJson(
    List<enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy>?
        bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy) {
  if (bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy == null) {
    return [];
  }

  return bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
      .map((e) =>
          enums.$BookmarkSearchFilterWithCustomerIdV2GroupBookmarksByMap[e]!)
      .toList();
}

List<enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy>
    bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByListFromJson(
  List? bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy, [
  List<enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy>?
      defaultValue,
]) {
  if (bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy == null) {
    return defaultValue ?? [];
  }

  return bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
      .map((e) => bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByFromJson(
          e.toString()))
      .toList();
}

List<enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy>?
    bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByNullableListFromJson(
  List? bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy, [
  List<enums.BookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy>?
      defaultValue,
]) {
  if (bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy == null) {
    return defaultValue;
  }

  return bookmarkSearchFilterWithCustomerIdV2GroupBookmarksBy
      .map((e) => bookmarkSearchFilterWithCustomerIdV2GroupBookmarksByFromJson(
          e.toString()))
      .toList();
}

String? contentTypeToJson(enums.ContentType? contentType) {
  return enums.$ContentTypeMap[contentType];
}

enums.ContentType contentTypeFromJson(
  Object? contentType, [
  enums.ContentType? defaultValue,
]) {
  if (contentType is String) {
    return enums.$ContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == contentType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ContentType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContentType.swaggerGeneratedUnknown;
}

List<String> contentTypeListToJson(List<enums.ContentType>? contentType) {
  if (contentType == null) {
    return [];
  }

  return contentType.map((e) => enums.$ContentTypeMap[e]!).toList();
}

List<enums.ContentType> contentTypeListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue ?? [];
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

List<enums.ContentType>? contentTypeNullableListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue;
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

String? viewedStateToJson(enums.ViewedState? viewedState) {
  return enums.$ViewedStateMap[viewedState];
}

enums.ViewedState viewedStateFromJson(
  Object? viewedState, [
  enums.ViewedState? defaultValue,
]) {
  if (viewedState is String) {
    return enums.$ViewedStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == viewedState.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ViewedState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ViewedStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ViewedState.swaggerGeneratedUnknown;
}

List<String> viewedStateListToJson(List<enums.ViewedState>? viewedState) {
  if (viewedState == null) {
    return [];
  }

  return viewedState.map((e) => enums.$ViewedStateMap[e]!).toList();
}

List<enums.ViewedState> viewedStateListFromJson(
  List? viewedState, [
  List<enums.ViewedState>? defaultValue,
]) {
  if (viewedState == null) {
    return defaultValue ?? [];
  }

  return viewedState.map((e) => viewedStateFromJson(e.toString())).toList();
}

List<enums.ViewedState>? viewedStateNullableListFromJson(
  List? viewedState, [
  List<enums.ViewedState>? defaultValue,
]) {
  if (viewedState == null) {
    return defaultValue;
  }

  return viewedState.map((e) => viewedStateFromJson(e.toString())).toList();
}

String? viewStateToJson(enums.ViewState? viewState) {
  return enums.$ViewStateMap[viewState];
}

enums.ViewState viewStateFromJson(
  Object? viewState, [
  enums.ViewState? defaultValue,
]) {
  if (viewState is String) {
    return enums.$ViewStateMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == viewState.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ViewState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ViewStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ViewState.swaggerGeneratedUnknown;
}

List<String> viewStateListToJson(List<enums.ViewState>? viewState) {
  if (viewState == null) {
    return [];
  }

  return viewState.map((e) => enums.$ViewStateMap[e]!).toList();
}

List<enums.ViewState> viewStateListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue ?? [];
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

List<enums.ViewState>? viewStateNullableListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue;
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
