// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_continue_watching_service.enums.swagger.dart' as enums;
export 'liberty_continue_watching_service.enums.swagger.dart';

part 'liberty_continue_watching_service.swagger.chopper.dart';
part 'liberty_continue_watching_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyContinueWatchingService extends ChopperService {
  static LibertyContinueWatchingService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyContinueWatchingService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyContinueWatchingService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyContinueWatchingService(newClient);
  }

  ///Returns a continue watching list enriched with metadata
  ///@param profileId profile identifier
  ///@param customerId Customer identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param clientType
  ///@param maxRes
  ///@param cityId
  ///@param limit Determines how many continue watching items should be returned at once
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param X-Claims-Set Encoded customer information.
  ///@param x-entitlements-token Entitlements token
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<List<ContinueWatchingItem>>>
      profilesProfileIdContinueWatchingGet({
    required String? profileId,
    String? customerId,
    String? language,
    enums.ProfilesProfileIdContinueWatchingGetContentType? contentType,
    enums.ProfilesProfileIdContinueWatchingGetClientType? clientType,
    enums.ProfilesProfileIdContinueWatchingGetMaxRes? maxRes,
    int? cityId,
    int? limit,
    String? replayOptInDate,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xClaimsSet,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xCWSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ContinueWatchingItem, () => ContinueWatchingItem.fromJsonFactory);

    return _profilesProfileIdContinueWatchingGet(
        profileId: profileId,
        customerId: customerId,
        language: language,
        contentType: enums
            .$ProfilesProfileIdContinueWatchingGetContentTypeMap[contentType]
            ?.toString(),
        clientType: enums
            .$ProfilesProfileIdContinueWatchingGetClientTypeMap[clientType]
            ?.toString(),
        maxRes: enums.$ProfilesProfileIdContinueWatchingGetMaxResMap[maxRes]
            ?.toString(),
        cityId: cityId,
        limit: limit,
        replayOptInDate: replayOptInDate,
        xCus: xCus,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        xEntitlementsToken: xEntitlementsToken,
        xCWSExplicitLogging: xCWSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Returns a continue watching list enriched with metadata
  ///@param profileId profile identifier
  ///@param customerId Customer identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param clientType
  ///@param maxRes
  ///@param cityId
  ///@param limit Determines how many continue watching items should be returned at once
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param X-Claims-Set Encoded customer information.
  ///@param x-entitlements-token Entitlements token
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/profiles/{profileId}/continue-watching')
  Future<chopper.Response<List<ContinueWatchingItem>>>
      _profilesProfileIdContinueWatchingGet({
    @Path('profileId') required String? profileId,
    @Query('customerId') String? customerId,
    @Query('language') String? language,
    @Query('contentType') String? contentType,
    @Query('clientType') String? clientType,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('limit') int? limit,
    @Query('replayOptInDate') String? replayOptInDate,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-CWS-Explicit-Logging') String? xCWSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete items from continue watching list for given profile
  ///@param profileId profile identifier
  Future<chopper.Response> profilesProfileIdContinueWatchingDeletePost({
    required String? profileId,
    String? cacheControl,
    required ContinueWatchingDeleteParams? body,
  }) {
    return _profilesProfileIdContinueWatchingDeletePost(
        profileId: profileId, cacheControl: cacheControl, body: body);
  }

  ///Delete items from continue watching list for given profile
  ///@param profileId profile identifier
  @Post(path: '/profiles/{profileId}/continue-watching/delete')
  Future<chopper.Response> _profilesProfileIdContinueWatchingDeletePost({
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ContinueWatchingDeleteParams? body,
  });

  ///Returns a next episode enriched with metadata
  ///@param customerId customer id identifier
  ///@param contentId content id identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param cityId
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  ///@param X-Claims-Set Encoded customer information.
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  Future<chopper.Response<NextEpisode>>
      customersCustomerIdNextEpisodeContentIdGet({
    required String? customerId,
    required String? contentId,
    String? language,
    required enums.CustomersCustomerIdNextEpisodeContentIdGetContentType?
        contentType,
    int? cityId,
    String? replayOptInDate,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xClaimsSet,
    String? xCWSExplicitLogging,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NextEpisode, () => NextEpisode.fromJsonFactory);

    return _customersCustomerIdNextEpisodeContentIdGet(
        customerId: customerId,
        contentId: contentId,
        language: language,
        contentType: enums
            .$CustomersCustomerIdNextEpisodeContentIdGetContentTypeMap[
                contentType]
            ?.toString(),
        cityId: cityId,
        replayOptInDate: replayOptInDate,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xClaimsSet: xClaimsSet,
        xCWSExplicitLogging: xCWSExplicitLogging,
        cacheControl: cacheControl);
  }

  ///Returns a next episode enriched with metadata
  ///@param customerId customer id identifier
  ///@param contentId content id identifier
  ///@param language Two letter ISO 639-1 compliant language code
  ///@param contentType Allows to filter results by a content type
  ///@param cityId
  ///@param replayOptInDate Required based on deployment configuration. Indicates time when customer opted in to use replays. If not provided, then its retrieved from personalization service.
  ///@param X-Cus Contains customer identifier
  ///@param x-entitlements-token Entitlements token
  ///@param X-Claims-Set Encoded customer information.
  ///@param X-CWS-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for CWS components.
  @Get(path: '/customers/{customerId}/nextEpisode/{contentId}')
  Future<chopper.Response<NextEpisode>>
      _customersCustomerIdNextEpisodeContentIdGet({
    @Path('customerId') required String? customerId,
    @Path('contentId') required String? contentId,
    @Query('language') String? language,
    @Query('contentType') required String? contentType,
    @Query('cityId') int? cityId,
    @Query('replayOptInDate') String? replayOptInDate,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('X-CWS-Explicit-Logging') String? xCWSExplicitLogging,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingItem {
  ContinueWatchingItem({
    required this.id,
    required this.contentType,
    required this.name,
    this.minimumAge,
    required this.duration,
    this.pictureUrl,
    this.posterUrl,
    required this.bookmark,
    this.channelId,
    required this.startTime,
    required this.endTime,
    this.episodeNumber,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.showId,
    this.showName,
    this.currency,
    this.entitlementState,
    this.entitlementEnd,
    this.price,
    this.priceDisplay,
    this.rentalPeriod,
    this.listingId,
    this.containsAdult,
    this.trickPlayRestrictions,
    this.cpeId,
    this.viewState,
    this.hasMultipleProducts,
    required this.titleId,
    this.recordingState,
    this.restricted,
    this.channelBasedAuthorization,
    this.resolution,
    this.brandingProviderId,
    this.isGoPlayable,
  });

  factory ContinueWatchingItem.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingItemFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'pictureUrl', includeIfNull: false, defaultValue: '')
  final String? pictureUrl;
  @JsonKey(name: 'posterUrl', includeIfNull: false, defaultValue: '')
  final String? posterUrl;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'listingId', includeIfNull: false, defaultValue: '')
  final String? listingId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(
      name: 'trickPlayRestrictions', includeIfNull: false, defaultValue: '')
  final String? trickPlayRestrictions;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewStateToJson,
    fromJson: viewStateFromJson,
  )
  final enums.ViewState? viewState;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  static const fromJsonFactory = _$ContinueWatchingItemFromJson;
  static const toJsonFactory = _$ContinueWatchingItemToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.pictureUrl, pictureUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pictureUrl, pictureUrl)) &&
            (identical(other.posterUrl, posterUrl) ||
                const DeepCollectionEquality()
                    .equals(other.posterUrl, posterUrl)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.listingId, listingId) ||
                const DeepCollectionEquality().equals(other.listingId, listingId)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.trickPlayRestrictions, trickPlayRestrictions) || const DeepCollectionEquality().equals(other.trickPlayRestrictions, trickPlayRestrictions)) &&
            (identical(other.cpeId, cpeId) || const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.viewState, viewState) || const DeepCollectionEquality().equals(other.viewState, viewState)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) || const DeepCollectionEquality().equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.titleId, titleId) || const DeepCollectionEquality().equals(other.titleId, titleId)) &&
            (identical(other.recordingState, recordingState) || const DeepCollectionEquality().equals(other.recordingState, recordingState)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.brandingProviderId, brandingProviderId) || const DeepCollectionEquality().equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.isGoPlayable, isGoPlayable) || const DeepCollectionEquality().equals(other.isGoPlayable, isGoPlayable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(pictureUrl) ^
      const DeepCollectionEquality().hash(posterUrl) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(listingId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(trickPlayRestrictions) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingItemExtension on ContinueWatchingItem {
  ContinueWatchingItem copyWith(
      {String? id,
      enums.ContentType? contentType,
      String? name,
      int? minimumAge,
      int? duration,
      String? pictureUrl,
      String? posterUrl,
      int? bookmark,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      int? episodeNumber,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      String? showId,
      String? showName,
      String? currency,
      String? entitlementState,
      DateTime? entitlementEnd,
      String? price,
      String? priceDisplay,
      String? rentalPeriod,
      String? listingId,
      bool? containsAdult,
      String? trickPlayRestrictions,
      String? cpeId,
      enums.ViewState? viewState,
      bool? hasMultipleProducts,
      String? titleId,
      enums.RecordingState? recordingState,
      bool? restricted,
      bool? channelBasedAuthorization,
      String? resolution,
      String? brandingProviderId,
      bool? isGoPlayable}) {
    return ContinueWatchingItem(
        id: id ?? this.id,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        minimumAge: minimumAge ?? this.minimumAge,
        duration: duration ?? this.duration,
        pictureUrl: pictureUrl ?? this.pictureUrl,
        posterUrl: posterUrl ?? this.posterUrl,
        bookmark: bookmark ?? this.bookmark,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        showId: showId ?? this.showId,
        showName: showName ?? this.showName,
        currency: currency ?? this.currency,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        price: price ?? this.price,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        listingId: listingId ?? this.listingId,
        containsAdult: containsAdult ?? this.containsAdult,
        trickPlayRestrictions:
            trickPlayRestrictions ?? this.trickPlayRestrictions,
        cpeId: cpeId ?? this.cpeId,
        viewState: viewState ?? this.viewState,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        titleId: titleId ?? this.titleId,
        recordingState: recordingState ?? this.recordingState,
        restricted: restricted ?? this.restricted,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        resolution: resolution ?? this.resolution,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable);
  }

  ContinueWatchingItem copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<String>? name,
      Wrapped<int?>? minimumAge,
      Wrapped<int>? duration,
      Wrapped<String?>? pictureUrl,
      Wrapped<String?>? posterUrl,
      Wrapped<int>? bookmark,
      Wrapped<String?>? channelId,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? showName,
      Wrapped<String?>? currency,
      Wrapped<String?>? entitlementState,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<String?>? price,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? rentalPeriod,
      Wrapped<String?>? listingId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? trickPlayRestrictions,
      Wrapped<String?>? cpeId,
      Wrapped<enums.ViewState?>? viewState,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<String>? titleId,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<String?>? resolution,
      Wrapped<String?>? brandingProviderId,
      Wrapped<bool?>? isGoPlayable}) {
    return ContinueWatchingItem(
        id: (id != null ? id.value : this.id),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        duration: (duration != null ? duration.value : this.duration),
        pictureUrl: (pictureUrl != null ? pictureUrl.value : this.pictureUrl),
        posterUrl: (posterUrl != null ? posterUrl.value : this.posterUrl),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        showId: (showId != null ? showId.value : this.showId),
        showName: (showName != null ? showName.value : this.showName),
        currency: (currency != null ? currency.value : this.currency),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        price: (price != null ? price.value : this.price),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        listingId: (listingId != null ? listingId.value : this.listingId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        trickPlayRestrictions: (trickPlayRestrictions != null
            ? trickPlayRestrictions.value
            : this.trickPlayRestrictions),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        viewState: (viewState != null ? viewState.value : this.viewState),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        titleId: (titleId != null ? titleId.value : this.titleId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        restricted: (restricted != null ? restricted.value : this.restricted),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        resolution: (resolution != null ? resolution.value : this.resolution),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable));
  }
}

@JsonSerializable(explicitToJson: true)
class ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams({
    this.titleIds,
    this.showIds,
  });

  factory ContinueWatchingDeleteParams.fromJson(Map<String, dynamic> json) =>
      _$ContinueWatchingDeleteParamsFromJson(json);

  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(name: 'showIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? showIds;
  static const fromJsonFactory = _$ContinueWatchingDeleteParamsFromJson;
  static const toJsonFactory = _$ContinueWatchingDeleteParamsToJson;
  Map<String, dynamic> toJson() => _$ContinueWatchingDeleteParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContinueWatchingDeleteParams &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.showIds, showIds) ||
                const DeepCollectionEquality().equals(other.showIds, showIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(showIds) ^
      runtimeType.hashCode;
}

extension $ContinueWatchingDeleteParamsExtension
    on ContinueWatchingDeleteParams {
  ContinueWatchingDeleteParams copyWith(
      {List<String>? titleIds, List<String>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: titleIds ?? this.titleIds, showIds: showIds ?? this.showIds);
  }

  ContinueWatchingDeleteParams copyWithWrapped(
      {Wrapped<List<String>?>? titleIds, Wrapped<List<String>?>? showIds}) {
    return ContinueWatchingDeleteParams(
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        showIds: (showIds != null ? showIds.value : this.showIds));
  }
}

@JsonSerializable(explicitToJson: true)
class NextEpisode {
  NextEpisode({
    required this.nextEpisodeId,
    required this.contentType,
    required this.name,
    this.minimumAge,
    required this.duration,
    this.pictureUrl,
    this.posterUrl,
    this.channelId,
    required this.startTime,
    required this.endTime,
    this.episodeNumber,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.showId,
    this.showName,
    this.entitlementState,
    this.entitlementEnd,
    this.rentalPeriod,
    this.listingId,
    this.containsAdult,
    this.trickPlayRestrictions,
    this.cpeId,
    required this.titleId,
    this.restricted,
    this.channelBasedAuthorization,
    this.resolution,
  });

  factory NextEpisode.fromJson(Map<String, dynamic> json) =>
      _$NextEpisodeFromJson(json);

  @JsonKey(name: 'nextEpisodeId', includeIfNull: false, defaultValue: '')
  final String nextEpisodeId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'pictureUrl', includeIfNull: false, defaultValue: '')
  final String? pictureUrl;
  @JsonKey(name: 'posterUrl', includeIfNull: false, defaultValue: '')
  final String? posterUrl;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime endTime;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'listingId', includeIfNull: false, defaultValue: '')
  final String? listingId;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(
      name: 'trickPlayRestrictions', includeIfNull: false, defaultValue: '')
  final String? trickPlayRestrictions;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  static const fromJsonFactory = _$NextEpisodeFromJson;
  static const toJsonFactory = _$NextEpisodeToJson;
  Map<String, dynamic> toJson() => _$NextEpisodeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NextEpisode &&
            (identical(other.nextEpisodeId, nextEpisodeId) ||
                const DeepCollectionEquality()
                    .equals(other.nextEpisodeId, nextEpisodeId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.pictureUrl, pictureUrl) ||
                const DeepCollectionEquality()
                    .equals(other.pictureUrl, pictureUrl)) &&
            (identical(other.posterUrl, posterUrl) ||
                const DeepCollectionEquality()
                    .equals(other.posterUrl, posterUrl)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.listingId, listingId) ||
                const DeepCollectionEquality()
                    .equals(other.listingId, listingId)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.trickPlayRestrictions, trickPlayRestrictions) ||
                const DeepCollectionEquality().equals(
                    other.trickPlayRestrictions, trickPlayRestrictions)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.titleId, titleId) || const DeepCollectionEquality().equals(other.titleId, titleId)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nextEpisodeId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(pictureUrl) ^
      const DeepCollectionEquality().hash(posterUrl) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(listingId) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(trickPlayRestrictions) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(resolution) ^
      runtimeType.hashCode;
}

extension $NextEpisodeExtension on NextEpisode {
  NextEpisode copyWith(
      {String? nextEpisodeId,
      enums.ContentType? contentType,
      String? name,
      int? minimumAge,
      int? duration,
      String? pictureUrl,
      String? posterUrl,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      int? episodeNumber,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      String? showId,
      String? showName,
      String? entitlementState,
      DateTime? entitlementEnd,
      String? rentalPeriod,
      String? listingId,
      bool? containsAdult,
      String? trickPlayRestrictions,
      String? cpeId,
      String? titleId,
      bool? restricted,
      bool? channelBasedAuthorization,
      String? resolution}) {
    return NextEpisode(
        nextEpisodeId: nextEpisodeId ?? this.nextEpisodeId,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        minimumAge: minimumAge ?? this.minimumAge,
        duration: duration ?? this.duration,
        pictureUrl: pictureUrl ?? this.pictureUrl,
        posterUrl: posterUrl ?? this.posterUrl,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        showId: showId ?? this.showId,
        showName: showName ?? this.showName,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        listingId: listingId ?? this.listingId,
        containsAdult: containsAdult ?? this.containsAdult,
        trickPlayRestrictions:
            trickPlayRestrictions ?? this.trickPlayRestrictions,
        cpeId: cpeId ?? this.cpeId,
        titleId: titleId ?? this.titleId,
        restricted: restricted ?? this.restricted,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        resolution: resolution ?? this.resolution);
  }

  NextEpisode copyWithWrapped(
      {Wrapped<String>? nextEpisodeId,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<String>? name,
      Wrapped<int?>? minimumAge,
      Wrapped<int>? duration,
      Wrapped<String?>? pictureUrl,
      Wrapped<String?>? posterUrl,
      Wrapped<String?>? channelId,
      Wrapped<DateTime>? startTime,
      Wrapped<DateTime>? endTime,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? showName,
      Wrapped<String?>? entitlementState,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<String?>? rentalPeriod,
      Wrapped<String?>? listingId,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? trickPlayRestrictions,
      Wrapped<String?>? cpeId,
      Wrapped<String>? titleId,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<String?>? resolution}) {
    return NextEpisode(
        nextEpisodeId:
            (nextEpisodeId != null ? nextEpisodeId.value : this.nextEpisodeId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        duration: (duration != null ? duration.value : this.duration),
        pictureUrl: (pictureUrl != null ? pictureUrl.value : this.pictureUrl),
        posterUrl: (posterUrl != null ? posterUrl.value : this.posterUrl),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        showId: (showId != null ? showId.value : this.showId),
        showName: (showName != null ? showName.value : this.showName),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        listingId: (listingId != null ? listingId.value : this.listingId),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        trickPlayRestrictions: (trickPlayRestrictions != null
            ? trickPlayRestrictions.value
            : this.trickPlayRestrictions),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        restricted: (restricted != null ? restricted.value : this.restricted),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        resolution: (resolution != null ? resolution.value : this.resolution));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error error;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    required this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;
  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<String>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? profilesProfileIdContinueWatchingGetContentTypeToJson(
    enums.ProfilesProfileIdContinueWatchingGetContentType?
        profilesProfileIdContinueWatchingGetContentType) {
  return enums.$ProfilesProfileIdContinueWatchingGetContentTypeMap[
      profilesProfileIdContinueWatchingGetContentType];
}

enums.ProfilesProfileIdContinueWatchingGetContentType
    profilesProfileIdContinueWatchingGetContentTypeFromJson(
  Object? profilesProfileIdContinueWatchingGetContentType, [
  enums.ProfilesProfileIdContinueWatchingGetContentType? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetContentType is String) {
    return enums.$ProfilesProfileIdContinueWatchingGetContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                profilesProfileIdContinueWatchingGetContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfilesProfileIdContinueWatchingGetContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfilesProfileIdContinueWatchingGetContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfilesProfileIdContinueWatchingGetContentType
          .swaggerGeneratedUnknown;
}

List<String> profilesProfileIdContinueWatchingGetContentTypeListToJson(
    List<enums.ProfilesProfileIdContinueWatchingGetContentType>?
        profilesProfileIdContinueWatchingGetContentType) {
  if (profilesProfileIdContinueWatchingGetContentType == null) {
    return [];
  }

  return profilesProfileIdContinueWatchingGetContentType
      .map((e) => enums.$ProfilesProfileIdContinueWatchingGetContentTypeMap[e]!)
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetContentType>
    profilesProfileIdContinueWatchingGetContentTypeListFromJson(
  List? profilesProfileIdContinueWatchingGetContentType, [
  List<enums.ProfilesProfileIdContinueWatchingGetContentType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetContentType == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdContinueWatchingGetContentType
      .map((e) =>
          profilesProfileIdContinueWatchingGetContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetContentType>?
    profilesProfileIdContinueWatchingGetContentTypeNullableListFromJson(
  List? profilesProfileIdContinueWatchingGetContentType, [
  List<enums.ProfilesProfileIdContinueWatchingGetContentType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetContentType == null) {
    return defaultValue;
  }

  return profilesProfileIdContinueWatchingGetContentType
      .map((e) =>
          profilesProfileIdContinueWatchingGetContentTypeFromJson(e.toString()))
      .toList();
}

String? profilesProfileIdContinueWatchingGetClientTypeToJson(
    enums.ProfilesProfileIdContinueWatchingGetClientType?
        profilesProfileIdContinueWatchingGetClientType) {
  return enums.$ProfilesProfileIdContinueWatchingGetClientTypeMap[
      profilesProfileIdContinueWatchingGetClientType];
}

enums.ProfilesProfileIdContinueWatchingGetClientType
    profilesProfileIdContinueWatchingGetClientTypeFromJson(
  Object? profilesProfileIdContinueWatchingGetClientType, [
  enums.ProfilesProfileIdContinueWatchingGetClientType? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetClientType is String) {
    return enums.$ProfilesProfileIdContinueWatchingGetClientTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                profilesProfileIdContinueWatchingGetClientType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfilesProfileIdContinueWatchingGetClientType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfilesProfileIdContinueWatchingGetClientTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfilesProfileIdContinueWatchingGetClientType
          .swaggerGeneratedUnknown;
}

List<String> profilesProfileIdContinueWatchingGetClientTypeListToJson(
    List<enums.ProfilesProfileIdContinueWatchingGetClientType>?
        profilesProfileIdContinueWatchingGetClientType) {
  if (profilesProfileIdContinueWatchingGetClientType == null) {
    return [];
  }

  return profilesProfileIdContinueWatchingGetClientType
      .map((e) => enums.$ProfilesProfileIdContinueWatchingGetClientTypeMap[e]!)
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetClientType>
    profilesProfileIdContinueWatchingGetClientTypeListFromJson(
  List? profilesProfileIdContinueWatchingGetClientType, [
  List<enums.ProfilesProfileIdContinueWatchingGetClientType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetClientType == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdContinueWatchingGetClientType
      .map((e) =>
          profilesProfileIdContinueWatchingGetClientTypeFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetClientType>?
    profilesProfileIdContinueWatchingGetClientTypeNullableListFromJson(
  List? profilesProfileIdContinueWatchingGetClientType, [
  List<enums.ProfilesProfileIdContinueWatchingGetClientType>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetClientType == null) {
    return defaultValue;
  }

  return profilesProfileIdContinueWatchingGetClientType
      .map((e) =>
          profilesProfileIdContinueWatchingGetClientTypeFromJson(e.toString()))
      .toList();
}

String? profilesProfileIdContinueWatchingGetMaxResToJson(
    enums.ProfilesProfileIdContinueWatchingGetMaxRes?
        profilesProfileIdContinueWatchingGetMaxRes) {
  return enums.$ProfilesProfileIdContinueWatchingGetMaxResMap[
      profilesProfileIdContinueWatchingGetMaxRes];
}

enums.ProfilesProfileIdContinueWatchingGetMaxRes
    profilesProfileIdContinueWatchingGetMaxResFromJson(
  Object? profilesProfileIdContinueWatchingGetMaxRes, [
  enums.ProfilesProfileIdContinueWatchingGetMaxRes? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetMaxRes is String) {
    return enums.$ProfilesProfileIdContinueWatchingGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                profilesProfileIdContinueWatchingGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfilesProfileIdContinueWatchingGetMaxRes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfilesProfileIdContinueWatchingGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfilesProfileIdContinueWatchingGetMaxRes.swaggerGeneratedUnknown;
}

List<String> profilesProfileIdContinueWatchingGetMaxResListToJson(
    List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>?
        profilesProfileIdContinueWatchingGetMaxRes) {
  if (profilesProfileIdContinueWatchingGetMaxRes == null) {
    return [];
  }

  return profilesProfileIdContinueWatchingGetMaxRes
      .map((e) => enums.$ProfilesProfileIdContinueWatchingGetMaxResMap[e]!)
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>
    profilesProfileIdContinueWatchingGetMaxResListFromJson(
  List? profilesProfileIdContinueWatchingGetMaxRes, [
  List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return profilesProfileIdContinueWatchingGetMaxRes
      .map((e) =>
          profilesProfileIdContinueWatchingGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>?
    profilesProfileIdContinueWatchingGetMaxResNullableListFromJson(
  List? profilesProfileIdContinueWatchingGetMaxRes, [
  List<enums.ProfilesProfileIdContinueWatchingGetMaxRes>? defaultValue,
]) {
  if (profilesProfileIdContinueWatchingGetMaxRes == null) {
    return defaultValue;
  }

  return profilesProfileIdContinueWatchingGetMaxRes
      .map((e) =>
          profilesProfileIdContinueWatchingGetMaxResFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdNextEpisodeContentIdGetContentTypeToJson(
    enums.CustomersCustomerIdNextEpisodeContentIdGetContentType?
        customersCustomerIdNextEpisodeContentIdGetContentType) {
  return enums.$CustomersCustomerIdNextEpisodeContentIdGetContentTypeMap[
      customersCustomerIdNextEpisodeContentIdGetContentType];
}

enums.CustomersCustomerIdNextEpisodeContentIdGetContentType
    customersCustomerIdNextEpisodeContentIdGetContentTypeFromJson(
  Object? customersCustomerIdNextEpisodeContentIdGetContentType, [
  enums.CustomersCustomerIdNextEpisodeContentIdGetContentType? defaultValue,
]) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType is String) {
    return enums
        .$CustomersCustomerIdNextEpisodeContentIdGetContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customersCustomerIdNextEpisodeContentIdGetContentType
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomersCustomerIdNextEpisodeContentIdGetContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomersCustomerIdNextEpisodeContentIdGetContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomersCustomerIdNextEpisodeContentIdGetContentType
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdNextEpisodeContentIdGetContentTypeListToJson(
    List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
        customersCustomerIdNextEpisodeContentIdGetContentType) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType == null) {
    return [];
  }

  return customersCustomerIdNextEpisodeContentIdGetContentType
      .map((e) =>
          enums.$CustomersCustomerIdNextEpisodeContentIdGetContentTypeMap[e]!)
      .toList();
}

List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>
    customersCustomerIdNextEpisodeContentIdGetContentTypeListFromJson(
  List? customersCustomerIdNextEpisodeContentIdGetContentType, [
  List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
      defaultValue,
]) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdNextEpisodeContentIdGetContentType
      .map((e) => customersCustomerIdNextEpisodeContentIdGetContentTypeFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
    customersCustomerIdNextEpisodeContentIdGetContentTypeNullableListFromJson(
  List? customersCustomerIdNextEpisodeContentIdGetContentType, [
  List<enums.CustomersCustomerIdNextEpisodeContentIdGetContentType>?
      defaultValue,
]) {
  if (customersCustomerIdNextEpisodeContentIdGetContentType == null) {
    return defaultValue;
  }

  return customersCustomerIdNextEpisodeContentIdGetContentType
      .map((e) => customersCustomerIdNextEpisodeContentIdGetContentTypeFromJson(
          e.toString()))
      .toList();
}

String? contentTypeToJson(enums.ContentType? contentType) {
  return enums.$ContentTypeMap[contentType];
}

enums.ContentType contentTypeFromJson(
  Object? contentType, [
  enums.ContentType? defaultValue,
]) {
  if (contentType is String) {
    return enums.$ContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == contentType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ContentType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContentType.swaggerGeneratedUnknown;
}

List<String> contentTypeListToJson(List<enums.ContentType>? contentType) {
  if (contentType == null) {
    return [];
  }

  return contentType.map((e) => enums.$ContentTypeMap[e]!).toList();
}

List<enums.ContentType> contentTypeListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue ?? [];
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

List<enums.ContentType>? contentTypeNullableListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue;
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

String? viewStateToJson(enums.ViewState? viewState) {
  return enums.$ViewStateMap[viewState];
}

enums.ViewState viewStateFromJson(
  Object? viewState, [
  enums.ViewState? defaultValue,
]) {
  if (viewState is String) {
    return enums.$ViewStateMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == viewState.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ViewState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ViewStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ViewState.swaggerGeneratedUnknown;
}

List<String> viewStateListToJson(List<enums.ViewState>? viewState) {
  if (viewState == null) {
    return [];
  }

  return viewState.map((e) => enums.$ViewStateMap[e]!).toList();
}

List<enums.ViewState> viewStateListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue ?? [];
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

List<enums.ViewState>? viewStateNullableListFromJson(
  List? viewState, [
  List<enums.ViewState>? defaultValue,
]) {
  if (viewState == null) {
    return defaultValue;
  }

  return viewState.map((e) => viewStateFromJson(e.toString())).toList();
}

String? recordingStateToJson(enums.RecordingState? recordingState) {
  return enums.$RecordingStateMap[recordingState];
}

enums.RecordingState recordingStateFromJson(
  Object? recordingState, [
  enums.RecordingState? defaultValue,
]) {
  if (recordingState is String) {
    return enums.$RecordingStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == recordingState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.RecordingState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RecordingStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RecordingState.swaggerGeneratedUnknown;
}

List<String> recordingStateListToJson(
    List<enums.RecordingState>? recordingState) {
  if (recordingState == null) {
    return [];
  }

  return recordingState.map((e) => enums.$RecordingStateMap[e]!).toList();
}

List<enums.RecordingState> recordingStateListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue ?? [];
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

List<enums.RecordingState>? recordingStateNullableListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue;
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
