// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_customer_communication_service.enums.swagger.dart' as enums;
export 'liberty_customer_communication_service.enums.swagger.dart';

part 'liberty_customer_communication_service.swagger.chopper.dart';
part 'liberty_customer_communication_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyCustomerCommunicationService extends ChopperService {
  static LibertyCustomerCommunicationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyCustomerCommunicationService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyCustomerCommunicationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyCustomerCommunicationService(newClient);
  }

  ///Authenticate user credentials
  ///@param userName
  ///@param password
  Future<chopper.Response>
      customercommunicationV1AuthorizationAuthenticatePost({
    String? userName,
    String? password,
    String? cacheControl,
  }) {
    return _customercommunicationV1AuthorizationAuthenticatePost(
        userName: userName, password: password, cacheControl: cacheControl);
  }

  ///Authenticate user credentials
  ///@param userName
  ///@param password
  @Post(
    path: '/customercommunication/v1/authorization/authenticate',
    optionalBody: true,
  )
  Future<chopper.Response>
      _customercommunicationV1AuthorizationAuthenticatePost({
    @Header('userName') String? userName,
    @Header('password') String? password,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve the configurable properties
  Future<chopper.Response> customercommunicationV1ConfigConfigsGet(
      {String? cacheControl}) {
    return _customercommunicationV1ConfigConfigsGet(cacheControl: cacheControl);
  }

  ///Retrieve the configurable properties
  @Get(path: '/customercommunication/v1/config/configs')
  Future<chopper.Response> _customercommunicationV1ConfigConfigsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Adds a new message to the store
  ///@param file
  Future<chopper.Response> customercommunicationV1MessagePost({
    List<String>? file,
    String? cacheControl,
  }) {
    return _customercommunicationV1MessagePost(
        file: file, cacheControl: cacheControl);
  }

  ///Adds a new message to the store
  ///@param file
  @Post(
    path: '/customercommunication/v1/message',
    optionalBody: true,
  )
  Future<chopper.Response> _customercommunicationV1MessagePost({
    @Field('file') List<String>? file,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get message by ID
  ///@param messageId ID of message
  Future<chopper.Response<Message>> customercommunicationV1MessageMessageIdGet({
    required String? messageId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Message, () => Message.fromJsonFactory);

    return _customercommunicationV1MessageMessageIdGet(
        messageId: messageId, cacheControl: cacheControl);
  }

  ///Get message by ID
  ///@param messageId ID of message
  @Get(path: '/customercommunication/v1/message/{messageId}')
  Future<chopper.Response<Message>>
      _customercommunicationV1MessageMessageIdGet({
    @Path('messageId') required String? messageId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Deletes a message
  ///@param messageId ID of message
  Future<chopper.Response> customercommunicationV1MessageMessageIdDelete({
    required String? messageId,
    String? cacheControl,
  }) {
    return _customercommunicationV1MessageMessageIdDelete(
        messageId: messageId, cacheControl: cacheControl);
  }

  ///Deletes a message
  ///@param messageId ID of message
  @Delete(path: '/customercommunication/v1/message/{messageId}')
  Future<chopper.Response> _customercommunicationV1MessageMessageIdDelete({
    @Path('messageId') required String? messageId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates the status of a message
  ///@param messageId ID of message to return
  ///@param status Status of the message
  Future<chopper.Response>
      customercommunicationV1MessageStatusMessageIdStatusPut({
    required String? messageId,
    required int? status,
    String? cacheControl,
  }) {
    return _customercommunicationV1MessageStatusMessageIdStatusPut(
        messageId: messageId, status: status, cacheControl: cacheControl);
  }

  ///Updates the status of a message
  ///@param messageId ID of message to return
  ///@param status Status of the message
  @Put(
    path: '/customercommunication/v1/message/status/{messageId}/{status}',
    optionalBody: true,
  )
  Future<chopper.Response>
      _customercommunicationV1MessageStatusMessageIdStatusPut({
    @Path('messageId') required String? messageId,
    @Path('status') required int? status,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve all messages
  Future<chopper.Response<List<Message>>> customercommunicationV1MessagesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(Message, () => Message.fromJsonFactory);

    return _customercommunicationV1MessagesGet(cacheControl: cacheControl);
  }

  ///Retrieve all messages
  @Get(path: '/customercommunication/v1/messages')
  Future<chopper.Response<List<Message>>> _customercommunicationV1MessagesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Retrieve messages with specified labels
  ///@param body
  Future<chopper.Response<List<CPEMessage>>>
      customercommunicationV1MessagesPost({
    List<CPELabel>? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(CPEMessage, () => CPEMessage.fromJsonFactory);

    return _customercommunicationV1MessagesPost(
        body: body, cacheControl: cacheControl);
  }

  ///Retrieve messages with specified labels
  ///@param body
  @Post(path: '/customercommunication/v1/messages')
  Future<chopper.Response<List<CPEMessage>>>
      _customercommunicationV1MessagesPost({
    @Body() List<CPELabel>? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves image for given message
  ///@param messageId ID of message
  Future<chopper.Response> customercommunicationV1MessageImageMessageIdGet({
    required String? messageId,
    String? cacheControl,
  }) {
    return _customercommunicationV1MessageImageMessageIdGet(
        messageId: messageId, cacheControl: cacheControl);
  }

  ///Retrieves image for given message
  ///@param messageId ID of message
  @Get(path: '/customercommunication/v1/message/image/{messageId}')
  Future<chopper.Response> _customercommunicationV1MessageImageMessageIdGet({
    @Path('messageId') required String? messageId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class CPEMessage {
  CPEMessage({
    this.id,
    this.title,
    this.message,
    this.startDate,
    this.endDate,
    this.targetScreen,
    this.imageLocation,
    this.language,
    this.labels,
    this.status,
  });

  factory CPEMessage.fromJson(Map<String, dynamic> json) =>
      _$CPEMessageFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  @JsonKey(name: 'targetScreen', includeIfNull: false, defaultValue: '')
  final String? targetScreen;
  @JsonKey(name: 'imageLocation', includeIfNull: false, defaultValue: '')
  final String? imageLocation;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  @JsonKey(name: 'labels', includeIfNull: false, defaultValue: <CPELabel>[])
  final List<CPELabel>? labels;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: cPEMessageStatusToJson,
    fromJson: cPEMessageStatusFromJson,
  )
  final enums.CPEMessageStatus? status;
  static const fromJsonFactory = _$CPEMessageFromJson;
  static const toJsonFactory = _$CPEMessageToJson;
  Map<String, dynamic> toJson() => _$CPEMessageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CPEMessage &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.targetScreen, targetScreen) ||
                const DeepCollectionEquality()
                    .equals(other.targetScreen, targetScreen)) &&
            (identical(other.imageLocation, imageLocation) ||
                const DeepCollectionEquality()
                    .equals(other.imageLocation, imageLocation)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.labels, labels) ||
                const DeepCollectionEquality().equals(other.labels, labels)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(targetScreen) ^
      const DeepCollectionEquality().hash(imageLocation) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(labels) ^
      const DeepCollectionEquality().hash(status) ^
      runtimeType.hashCode;
}

extension $CPEMessageExtension on CPEMessage {
  CPEMessage copyWith(
      {String? id,
      String? title,
      String? message,
      DateTime? startDate,
      DateTime? endDate,
      String? targetScreen,
      String? imageLocation,
      String? language,
      List<CPELabel>? labels,
      enums.CPEMessageStatus? status}) {
    return CPEMessage(
        id: id ?? this.id,
        title: title ?? this.title,
        message: message ?? this.message,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        targetScreen: targetScreen ?? this.targetScreen,
        imageLocation: imageLocation ?? this.imageLocation,
        language: language ?? this.language,
        labels: labels ?? this.labels,
        status: status ?? this.status);
  }

  CPEMessage copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? message,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate,
      Wrapped<String?>? targetScreen,
      Wrapped<String?>? imageLocation,
      Wrapped<String?>? language,
      Wrapped<List<CPELabel>?>? labels,
      Wrapped<enums.CPEMessageStatus?>? status}) {
    return CPEMessage(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        message: (message != null ? message.value : this.message),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        targetScreen:
            (targetScreen != null ? targetScreen.value : this.targetScreen),
        imageLocation:
            (imageLocation != null ? imageLocation.value : this.imageLocation),
        language: (language != null ? language.value : this.language),
        labels: (labels != null ? labels.value : this.labels),
        status: (status != null ? status.value : this.status));
  }
}

@JsonSerializable(explicitToJson: true)
class CPELabel {
  CPELabel({
    this.name,
    this.values,
  });

  factory CPELabel.fromJson(Map<String, dynamic> json) =>
      _$CPELabelFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'values', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? values;
  static const fromJsonFactory = _$CPELabelFromJson;
  static const toJsonFactory = _$CPELabelToJson;
  Map<String, dynamic> toJson() => _$CPELabelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CPELabel &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.values, values) ||
                const DeepCollectionEquality().equals(other.values, values)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(values) ^
      runtimeType.hashCode;
}

extension $CPELabelExtension on CPELabel {
  CPELabel copyWith({String? name, List<Object>? values}) {
    return CPELabel(name: name ?? this.name, values: values ?? this.values);
  }

  CPELabel copyWithWrapped(
      {Wrapped<String?>? name, Wrapped<List<Object>?>? values}) {
    return CPELabel(
        name: (name != null ? name.value : this.name),
        values: (values != null ? values.value : this.values));
  }
}

@JsonSerializable(explicitToJson: true)
class Message {
  Message({
    this.id,
    this.title,
    this.message,
    this.startDate,
    this.endDate,
    this.created,
    this.targetScreen,
    this.imageLocation,
    this.language,
    this.labels,
    this.status,
  });

  factory Message.fromJson(Map<String, dynamic> json) =>
      _$MessageFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  @JsonKey(name: 'created', includeIfNull: false)
  final DateTime? created;
  @JsonKey(name: 'targetScreen', includeIfNull: false, defaultValue: '')
  final String? targetScreen;
  @JsonKey(name: 'imageLocation', includeIfNull: false, defaultValue: '')
  final String? imageLocation;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  @JsonKey(name: 'labels', includeIfNull: false, defaultValue: <Label>[])
  final List<Label>? labels;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: messageStatusToJson,
    fromJson: messageStatusFromJson,
  )
  final enums.MessageStatus? status;
  static const fromJsonFactory = _$MessageFromJson;
  static const toJsonFactory = _$MessageToJson;
  Map<String, dynamic> toJson() => _$MessageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Message &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.created, created) ||
                const DeepCollectionEquality()
                    .equals(other.created, created)) &&
            (identical(other.targetScreen, targetScreen) ||
                const DeepCollectionEquality()
                    .equals(other.targetScreen, targetScreen)) &&
            (identical(other.imageLocation, imageLocation) ||
                const DeepCollectionEquality()
                    .equals(other.imageLocation, imageLocation)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.labels, labels) ||
                const DeepCollectionEquality().equals(other.labels, labels)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(created) ^
      const DeepCollectionEquality().hash(targetScreen) ^
      const DeepCollectionEquality().hash(imageLocation) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(labels) ^
      const DeepCollectionEquality().hash(status) ^
      runtimeType.hashCode;
}

extension $MessageExtension on Message {
  Message copyWith(
      {String? id,
      String? title,
      String? message,
      DateTime? startDate,
      DateTime? endDate,
      DateTime? created,
      String? targetScreen,
      String? imageLocation,
      String? language,
      List<Label>? labels,
      enums.MessageStatus? status}) {
    return Message(
        id: id ?? this.id,
        title: title ?? this.title,
        message: message ?? this.message,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        created: created ?? this.created,
        targetScreen: targetScreen ?? this.targetScreen,
        imageLocation: imageLocation ?? this.imageLocation,
        language: language ?? this.language,
        labels: labels ?? this.labels,
        status: status ?? this.status);
  }

  Message copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? message,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate,
      Wrapped<DateTime?>? created,
      Wrapped<String?>? targetScreen,
      Wrapped<String?>? imageLocation,
      Wrapped<String?>? language,
      Wrapped<List<Label>?>? labels,
      Wrapped<enums.MessageStatus?>? status}) {
    return Message(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        message: (message != null ? message.value : this.message),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        created: (created != null ? created.value : this.created),
        targetScreen:
            (targetScreen != null ? targetScreen.value : this.targetScreen),
        imageLocation:
            (imageLocation != null ? imageLocation.value : this.imageLocation),
        language: (language != null ? language.value : this.language),
        labels: (labels != null ? labels.value : this.labels),
        status: (status != null ? status.value : this.status));
  }
}

@JsonSerializable(explicitToJson: true)
class Label {
  Label({
    this.id,
    this.name,
    this.values,
  });

  factory Label.fromJson(Map<String, dynamic> json) => _$LabelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'values', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? values;
  static const fromJsonFactory = _$LabelFromJson;
  static const toJsonFactory = _$LabelToJson;
  Map<String, dynamic> toJson() => _$LabelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Label &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.values, values) ||
                const DeepCollectionEquality().equals(other.values, values)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(values) ^
      runtimeType.hashCode;
}

extension $LabelExtension on Label {
  Label copyWith({String? id, String? name, List<Object>? values}) {
    return Label(
        id: id ?? this.id,
        name: name ?? this.name,
        values: values ?? this.values);
  }

  Label copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<List<Object>?>? values}) {
    return Label(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        values: (values != null ? values.value : this.values));
  }
}

String? cPEMessageStatusToJson(enums.CPEMessageStatus? cPEMessageStatus) {
  return enums.$CPEMessageStatusMap[cPEMessageStatus];
}

enums.CPEMessageStatus cPEMessageStatusFromJson(
  Object? cPEMessageStatus, [
  enums.CPEMessageStatus? defaultValue,
]) {
  if (cPEMessageStatus is String) {
    return enums.$CPEMessageStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cPEMessageStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CPEMessageStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CPEMessageStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CPEMessageStatus.swaggerGeneratedUnknown;
}

List<String> cPEMessageStatusListToJson(
    List<enums.CPEMessageStatus>? cPEMessageStatus) {
  if (cPEMessageStatus == null) {
    return [];
  }

  return cPEMessageStatus.map((e) => enums.$CPEMessageStatusMap[e]!).toList();
}

List<enums.CPEMessageStatus> cPEMessageStatusListFromJson(
  List? cPEMessageStatus, [
  List<enums.CPEMessageStatus>? defaultValue,
]) {
  if (cPEMessageStatus == null) {
    return defaultValue ?? [];
  }

  return cPEMessageStatus
      .map((e) => cPEMessageStatusFromJson(e.toString()))
      .toList();
}

List<enums.CPEMessageStatus>? cPEMessageStatusNullableListFromJson(
  List? cPEMessageStatus, [
  List<enums.CPEMessageStatus>? defaultValue,
]) {
  if (cPEMessageStatus == null) {
    return defaultValue;
  }

  return cPEMessageStatus
      .map((e) => cPEMessageStatusFromJson(e.toString()))
      .toList();
}

String? messageStatusToJson(enums.MessageStatus? messageStatus) {
  return enums.$MessageStatusMap[messageStatus];
}

enums.MessageStatus messageStatusFromJson(
  Object? messageStatus, [
  enums.MessageStatus? defaultValue,
]) {
  if (messageStatus is String) {
    return enums.$MessageStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == messageStatus.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.MessageStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MessageStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MessageStatus.swaggerGeneratedUnknown;
}

List<String> messageStatusListToJson(List<enums.MessageStatus>? messageStatus) {
  if (messageStatus == null) {
    return [];
  }

  return messageStatus.map((e) => enums.$MessageStatusMap[e]!).toList();
}

List<enums.MessageStatus> messageStatusListFromJson(
  List? messageStatus, [
  List<enums.MessageStatus>? defaultValue,
]) {
  if (messageStatus == null) {
    return defaultValue ?? [];
  }

  return messageStatus.map((e) => messageStatusFromJson(e.toString())).toList();
}

List<enums.MessageStatus>? messageStatusNullableListFromJson(
  List? messageStatus, [
  List<enums.MessageStatus>? defaultValue,
]) {
  if (messageStatus == null) {
    return defaultValue;
  }

  return messageStatus.map((e) => messageStatusFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
