// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_editorial_content_service.swagger.chopper.dart';
part 'liberty_editorial_content_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyEditorialContentService extends ChopperService {
  static LibertyEditorialContentService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyEditorialContentService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyEditorialContentService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://localhost:10010/v1');
    return _$LibertyEditorialContentService(newClient);
  }

  ///Get Content Component List
  ///@param type Type of the requested CMS component(s)
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param onlineFrom Filter: date-time,  check if component's OnlineFrom <= given value (defaults to now())
  ///@param onlineUntil Filter: date-time,  check if component's OnlineUntil >= given value (defaults to now()))
  ///@param lang Set of natural languages that are preferred as a response to the request.
  Future<chopper.Response<ComponentList>> componentsGet({
    String? type,
    int? offset,
    int? limit,
    String? onlineFrom,
    String? onlineUntil,
    required String? lang,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ComponentList, () => ComponentList.fromJsonFactory);

    return _componentsGet(
        type: type,
        offset: offset,
        limit: limit,
        onlineFrom: onlineFrom,
        onlineUntil: onlineUntil,
        lang: lang,
        cacheControl: cacheControl);
  }

  ///Get Content Component List
  ///@param type Type of the requested CMS component(s)
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param onlineFrom Filter: date-time,  check if component's OnlineFrom <= given value (defaults to now())
  ///@param onlineUntil Filter: date-time,  check if component's OnlineUntil >= given value (defaults to now()))
  ///@param lang Set of natural languages that are preferred as a response to the request.
  @Get(path: '/components')
  Future<chopper.Response<ComponentList>> _componentsGet({
    @Query('type') String? type,
    @Query('offset') int? offset,
    @Query('limit') int? limit,
    @Query('onlineFrom') String? onlineFrom,
    @Query('onlineUntil') String? onlineUntil,
    @Query('lang') required String? lang,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get Content Component
  ///@param id UUID of the requested CMS component
  Future<chopper.Response<Component>> componentsIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Component, () => Component.fromJsonFactory);

    return _componentsIdGet(id: id, cacheControl: cacheControl);
  }

  ///Get Content Component
  ///@param id UUID of the requested CMS component
  @Get(path: '/components/{id}')
  Future<chopper.Response<Component>> _componentsIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Submit Transaction
  ///@param Content-Length Size of the file in bytes
  ///@param Content-Type mime type of the transaction package
  ///@param TransactiondId ID of the transaction that is being published
  ///@param file The transation package to be published
  Future<chopper.Response> transactionsPost({
    String? contentLength,
    String? contentType,
    required String? transactiondId,
    required String? file,
    String? cacheControl,
  }) {
    return _transactionsPost(
        contentLength: contentLength,
        contentType: contentType,
        transactiondId: transactiondId,
        file: file,
        cacheControl: cacheControl);
  }

  ///Submit Transaction
  ///@param Content-Length Size of the file in bytes
  ///@param Content-Type mime type of the transaction package
  ///@param TransactiondId ID of the transaction that is being published
  ///@param file The transation package to be published
  @Post(path: '/transactions')
  Future<chopper.Response> _transactionsPost({
    @Header('Content-Length') String? contentLength,
    @Header('Content-Type') String? contentType,
    @Query('TransactiondId') required String? transactiondId,
    @Body() required String? file,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Download Media File
  ///@param If-None-Match Response have to be sent only if it doesn't have an ETag matching the given ones.
  Future<chopper.Response<List<String>>> uploadsGet({
    String? ifNoneMatch,
    String? cacheControl,
  }) {
    return _uploadsGet(ifNoneMatch: ifNoneMatch, cacheControl: cacheControl);
  }

  ///Download Media File
  ///@param If-None-Match Response have to be sent only if it doesn't have an ETag matching the given ones.
  @Get(path: '/uploads')
  Future<chopper.Response<List<String>>> _uploadsGet({
    @Header('If-None-Match') String? ifNoneMatch,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Component {
  Component({
    required this.id,
    required this.type,
    required this.version,
    this.alias,
    this.schemaVersion,
    required this.metadata,
    required this.properties,
  });

  factory Component.fromJson(Map<String, dynamic> json) =>
      _$ComponentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String version;
  @JsonKey(name: 'alias', includeIfNull: false, defaultValue: '')
  final String? alias;
  @JsonKey(name: 'schemaVersion', includeIfNull: false, defaultValue: '')
  final String? schemaVersion;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Component$Metadata metadata;
  @JsonKey(name: 'properties', includeIfNull: false)
  final Map<String, dynamic> properties;
  static const fromJsonFactory = _$ComponentFromJson;
  static const toJsonFactory = _$ComponentToJson;
  Map<String, dynamic> toJson() => _$ComponentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Component &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.alias, alias) ||
                const DeepCollectionEquality().equals(other.alias, alias)) &&
            (identical(other.schemaVersion, schemaVersion) ||
                const DeepCollectionEquality()
                    .equals(other.schemaVersion, schemaVersion)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.properties, properties) ||
                const DeepCollectionEquality()
                    .equals(other.properties, properties)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(alias) ^
      const DeepCollectionEquality().hash(schemaVersion) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(properties) ^
      runtimeType.hashCode;
}

extension $ComponentExtension on Component {
  Component copyWith(
      {String? id,
      String? type,
      String? version,
      String? alias,
      String? schemaVersion,
      Component$Metadata? metadata,
      Map<String, dynamic>? properties}) {
    return Component(
        id: id ?? this.id,
        type: type ?? this.type,
        version: version ?? this.version,
        alias: alias ?? this.alias,
        schemaVersion: schemaVersion ?? this.schemaVersion,
        metadata: metadata ?? this.metadata,
        properties: properties ?? this.properties);
  }

  Component copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? type,
      Wrapped<String>? version,
      Wrapped<String?>? alias,
      Wrapped<String?>? schemaVersion,
      Wrapped<Component$Metadata>? metadata,
      Wrapped<Map<String, dynamic>>? properties}) {
    return Component(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        version: (version != null ? version.value : this.version),
        alias: (alias != null ? alias.value : this.alias),
        schemaVersion:
            (schemaVersion != null ? schemaVersion.value : this.schemaVersion),
        metadata: (metadata != null ? metadata.value : this.metadata),
        properties: (properties != null ? properties.value : this.properties));
  }
}

@JsonSerializable(explicitToJson: true)
class ComponentList {
  ComponentList({
    required this.paging,
    required this.data,
  });

  factory ComponentList.fromJson(Map<String, dynamic> json) =>
      _$ComponentListFromJson(json);

  @JsonKey(name: 'paging', includeIfNull: false)
  final ComponentList$Paging paging;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <Component>[])
  final List<Component> data;
  static const fromJsonFactory = _$ComponentListFromJson;
  static const toJsonFactory = _$ComponentListToJson;
  Map<String, dynamic> toJson() => _$ComponentListToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ComponentList &&
            (identical(other.paging, paging) ||
                const DeepCollectionEquality().equals(other.paging, paging)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(paging) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $ComponentListExtension on ComponentList {
  ComponentList copyWith(
      {ComponentList$Paging? paging, List<Component>? data}) {
    return ComponentList(
        paging: paging ?? this.paging, data: data ?? this.data);
  }

  ComponentList copyWithWrapped(
      {Wrapped<ComponentList$Paging>? paging, Wrapped<List<Component>>? data}) {
    return ComponentList(
        paging: (paging != null ? paging.value : this.paging),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error error;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class Component$Metadata {
  Component$Metadata({
    this.createdOn,
    this.createdBy,
    this.modifiedOn,
    this.modifiedBy,
    this.onlineFrom,
    this.onlineUntil,
  });

  factory Component$Metadata.fromJson(Map<String, dynamic> json) =>
      _$Component$MetadataFromJson(json);

  @JsonKey(name: 'CreatedOn', includeIfNull: false)
  final DateTime? createdOn;
  @JsonKey(name: 'CreatedBy', includeIfNull: false, defaultValue: '')
  final String? createdBy;
  @JsonKey(name: 'ModifiedOn', includeIfNull: false)
  final DateTime? modifiedOn;
  @JsonKey(name: 'ModifiedBy', includeIfNull: false, defaultValue: '')
  final String? modifiedBy;
  @JsonKey(name: 'OnlineFrom', includeIfNull: false)
  final DateTime? onlineFrom;
  @JsonKey(name: 'OnlineUntil', includeIfNull: false)
  final DateTime? onlineUntil;
  static const fromJsonFactory = _$Component$MetadataFromJson;
  static const toJsonFactory = _$Component$MetadataToJson;
  Map<String, dynamic> toJson() => _$Component$MetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Component$Metadata &&
            (identical(other.createdOn, createdOn) ||
                const DeepCollectionEquality()
                    .equals(other.createdOn, createdOn)) &&
            (identical(other.createdBy, createdBy) ||
                const DeepCollectionEquality()
                    .equals(other.createdBy, createdBy)) &&
            (identical(other.modifiedOn, modifiedOn) ||
                const DeepCollectionEquality()
                    .equals(other.modifiedOn, modifiedOn)) &&
            (identical(other.modifiedBy, modifiedBy) ||
                const DeepCollectionEquality()
                    .equals(other.modifiedBy, modifiedBy)) &&
            (identical(other.onlineFrom, onlineFrom) ||
                const DeepCollectionEquality()
                    .equals(other.onlineFrom, onlineFrom)) &&
            (identical(other.onlineUntil, onlineUntil) ||
                const DeepCollectionEquality()
                    .equals(other.onlineUntil, onlineUntil)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(createdOn) ^
      const DeepCollectionEquality().hash(createdBy) ^
      const DeepCollectionEquality().hash(modifiedOn) ^
      const DeepCollectionEquality().hash(modifiedBy) ^
      const DeepCollectionEquality().hash(onlineFrom) ^
      const DeepCollectionEquality().hash(onlineUntil) ^
      runtimeType.hashCode;
}

extension $Component$MetadataExtension on Component$Metadata {
  Component$Metadata copyWith(
      {DateTime? createdOn,
      String? createdBy,
      DateTime? modifiedOn,
      String? modifiedBy,
      DateTime? onlineFrom,
      DateTime? onlineUntil}) {
    return Component$Metadata(
        createdOn: createdOn ?? this.createdOn,
        createdBy: createdBy ?? this.createdBy,
        modifiedOn: modifiedOn ?? this.modifiedOn,
        modifiedBy: modifiedBy ?? this.modifiedBy,
        onlineFrom: onlineFrom ?? this.onlineFrom,
        onlineUntil: onlineUntil ?? this.onlineUntil);
  }

  Component$Metadata copyWithWrapped(
      {Wrapped<DateTime?>? createdOn,
      Wrapped<String?>? createdBy,
      Wrapped<DateTime?>? modifiedOn,
      Wrapped<String?>? modifiedBy,
      Wrapped<DateTime?>? onlineFrom,
      Wrapped<DateTime?>? onlineUntil}) {
    return Component$Metadata(
        createdOn: (createdOn != null ? createdOn.value : this.createdOn),
        createdBy: (createdBy != null ? createdBy.value : this.createdBy),
        modifiedOn: (modifiedOn != null ? modifiedOn.value : this.modifiedOn),
        modifiedBy: (modifiedBy != null ? modifiedBy.value : this.modifiedBy),
        onlineFrom: (onlineFrom != null ? onlineFrom.value : this.onlineFrom),
        onlineUntil:
            (onlineUntil != null ? onlineUntil.value : this.onlineUntil));
  }
}

@JsonSerializable(explicitToJson: true)
class ComponentList$Paging {
  ComponentList$Paging({
    this.total,
    this.limit,
    this.offset,
  });

  factory ComponentList$Paging.fromJson(Map<String, dynamic> json) =>
      _$ComponentList$PagingFromJson(json);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(name: 'offset', includeIfNull: false)
  final int? offset;
  static const fromJsonFactory = _$ComponentList$PagingFromJson;
  static const toJsonFactory = _$ComponentList$PagingToJson;
  Map<String, dynamic> toJson() => _$ComponentList$PagingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ComponentList$Paging &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.offset, offset) ||
                const DeepCollectionEquality().equals(other.offset, offset)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(offset) ^
      runtimeType.hashCode;
}

extension $ComponentList$PagingExtension on ComponentList$Paging {
  ComponentList$Paging copyWith({int? total, int? limit, int? offset}) {
    return ComponentList$Paging(
        total: total ?? this.total,
        limit: limit ?? this.limit,
        offset: offset ?? this.offset);
  }

  ComponentList$Paging copyWithWrapped(
      {Wrapped<int?>? total, Wrapped<int?>? limit, Wrapped<int?>? offset}) {
    return ComponentList$Paging(
        total: (total != null ? total.value : this.total),
        limit: (limit != null ? limit.value : this.limit),
        offset: (offset != null ? offset.value : this.offset));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    required this.message,
    required this.details,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String details;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;
  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality().equals(other.details, details)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode, String? message, String? details}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        message: message ?? this.message,
        details: details ?? this.details);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<String>? message,
      Wrapped<String>? details}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
