// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_feed_composer_service.enums.swagger.dart' as enums;
export 'liberty_feed_composer_service.enums.swagger.dart';

part 'liberty_feed_composer_service.swagger.chopper.dart';
part 'liberty_feed_composer_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyFeedComposerService extends ChopperService {
  static LibertyFeedComposerService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyFeedComposerService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyFeedComposerService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyFeedComposerService(newClient);
  }

  ///Returns programs that the user might want to watch because the were either paused before being watched completely,
  ///or because there are more episodes available following the episode what was completely watched.
  ///In case of paused/finished episodes, the response will contain the most relevant episode.
  ///Returns TVOD titles that are no longer purchasable, but only if they are still entitled for the user.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  Future<chopper.Response<FeedComposerResponse>> continueWatchingGet({
    enums.ContinueWatchingGetMaxRes? maxRes,
    enums.ContinueWatchingGetEncoding? encoding,
    required int? count,
    String? xClaimsSet,
    required String? profileId,
    String? xEntitlementToken,
    String? xCus = 'X-Cus',
    String? xDev,
    required List<String>? filter,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _continueWatchingGet(
        maxRes: enums.$ContinueWatchingGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$ContinueWatchingGetEncodingMap[encoding]?.toString(),
        count: count,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        xEntitlementToken: xEntitlementToken,
        xCus: xCus,
        xDev: xDev,
        filter: filter,
        cacheControl: cacheControl);
  }

  ///Returns programs that the user might want to watch because the were either paused before being watched completely,
  ///or because there are more episodes available following the episode what was completely watched.
  ///In case of paused/finished episodes, the response will contain the most relevant episode.
  ///Returns TVOD titles that are no longer purchasable, but only if they are still entitled for the user.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  @Get(path: '/continue-watching')
  Future<chopper.Response<FeedComposerResponse>> _continueWatchingGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('x-Entitlement-Token') String? xEntitlementToken,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Query('filter') required List<String>? filter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Like Continue Watching, but only returns items that were not completely watched. In case of episodes, the
  ///individual episode is returned, not the show.
  ///Returns TVOD titles that are no longer purchasable, but only if they are still entitled for the user.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  Future<chopper.Response<FeedComposerResponse>> pausedItemsGet({
    enums.PausedItemsGetMaxRes? maxRes,
    enums.PausedItemsGetEncoding? encoding,
    required int? count,
    String? xClaimsSet,
    required String? profileId,
    String? xEntitlementToken,
    String? xCus = 'X-Cus',
    String? xDev,
    required List<String>? filter,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _pausedItemsGet(
        maxRes: enums.$PausedItemsGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$PausedItemsGetEncodingMap[encoding]?.toString(),
        count: count,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        xEntitlementToken: xEntitlementToken,
        xCus: xCus,
        xDev: xDev,
        filter: filter,
        cacheControl: cacheControl);
  }

  ///Like Continue Watching, but only returns items that were not completely watched. In case of episodes, the
  ///individual episode is returned, not the show.
  ///Returns TVOD titles that are no longer purchasable, but only if they are still entitled for the user.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  @Get(path: '/paused-items')
  Future<chopper.Response<FeedComposerResponse>> _pausedItemsGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('x-Entitlement-Token') String? xEntitlementToken,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Query('filter') required List<String>? filter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns items on the user's watch list.
  ///Removes TVOD programs that are no longer purchasable, except ones for which the user still has an active rental.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  Future<chopper.Response<FeedComposerResponse>> watchlistGet({
    enums.WatchlistGetMaxRes? maxRes,
    enums.WatchlistGetEncoding? encoding,
    required int? count,
    String? xClaimsSet,
    required String? profileId,
    String? xEntitlementToken,
    String? xCus = 'X-Cus',
    String? xDev,
    required List<String>? filter,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _watchlistGet(
        maxRes: enums.$WatchlistGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$WatchlistGetEncodingMap[encoding]?.toString(),
        count: count,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        xEntitlementToken: xEntitlementToken,
        xCus: xCus,
        xDev: xDev,
        filter: filter,
        cacheControl: cacheControl);
  }

  ///Returns items on the user's watch list.
  ///Removes TVOD programs that are no longer purchasable, except ones for which the user still has an active rental.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  @Get(path: '/watchlist')
  Future<chopper.Response<FeedComposerResponse>> _watchlistGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('x-Entitlement-Token') String? xEntitlementToken,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Query('filter') required List<String>? filter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the programs as set up in the editorial feed, that match the indicated filter
  ///Removes TVOD programs that are no longer purchasable, including ones that the user may still have an active rental.
  ///@param feedCrid The id of the editorial feed
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param filter Comma separated list of filters
  ///@param language The metadata language to use for sorting. Used and required when sorting either nameAZ, nameZA or editorial
  ///@param sorting The sorting option. Default is `editorial`, which means the default sorting set up by the editor.              This often is the order configured in the CMS, but can also be another default sorting defined on the feed rendering hints
  ///@param page The 0-based page number (using count as page size) to return. Default is 0.
  ///@param cityId City Id of the user
  Future<chopper.Response<FeedComposerResponseWithTotalCount>>
      editorialFeedFeedCridGet({
    required String? feedCrid,
    String? brandingProviderId,
    enums.EditorialFeedFeedCridGetMaxRes? maxRes,
    enums.EditorialFeedFeedCridGetEncoding? encoding,
    required int? count,
    List<String>? filter,
    String? language,
    enums.EditorialFeedFeedCridGetSorting? sorting,
    int? page,
    String? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseWithTotalCount,
        () => FeedComposerResponseWithTotalCount.fromJsonFactory);

    return _editorialFeedFeedCridGet(
        feedCrid: feedCrid,
        brandingProviderId: brandingProviderId,
        maxRes: enums.$EditorialFeedFeedCridGetMaxResMap[maxRes]?.toString(),
        encoding:
            enums.$EditorialFeedFeedCridGetEncodingMap[encoding]?.toString(),
        count: count,
        filter: filter,
        language: language,
        sorting: enums.$EditorialFeedFeedCridGetSortingMap[sorting]?.toString(),
        page: page,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Returns the programs as set up in the editorial feed, that match the indicated filter
  ///Removes TVOD programs that are no longer purchasable, including ones that the user may still have an active rental.
  ///@param feedCrid The id of the editorial feed
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param filter Comma separated list of filters
  ///@param language The metadata language to use for sorting. Used and required when sorting either nameAZ, nameZA or editorial
  ///@param sorting The sorting option. Default is `editorial`, which means the default sorting set up by the editor.              This often is the order configured in the CMS, but can also be another default sorting defined on the feed rendering hints
  ///@param page The 0-based page number (using count as page size) to return. Default is 0.
  ///@param cityId City Id of the user
  @Get(path: '/editorial-feed/{feedCrid}')
  Future<chopper.Response<FeedComposerResponseWithTotalCount>>
      _editorialFeedFeedCridGet({
    @Path('feedCrid') required String? feedCrid,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Query('filter') List<String>? filter,
    @Query('language') String? language,
    @Query('sorting') String? sorting,
    @Query('page') int? page,
    @Query('cityId') String? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns programs for which an active TVOD rental exists.
  ///In case a particular rental is for a season or show, that season or show is returned instead of individual entitled episodes.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  Future<chopper.Response<FeedComposerResponseForPurchasedItem>>
      purchasedItemsGet({
    enums.PurchasedItemsGetMaxRes? maxRes,
    enums.PurchasedItemsGetEncoding? encoding,
    required int? count,
    String? xEntitlementToken,
    String? xCus = 'X-Cus',
    String? xDev,
    List<String>? filter,
    String? brandingProviderId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseForPurchasedItem,
        () => FeedComposerResponseForPurchasedItem.fromJsonFactory);

    return _purchasedItemsGet(
        maxRes: enums.$PurchasedItemsGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$PurchasedItemsGetEncodingMap[encoding]?.toString(),
        count: count,
        xEntitlementToken: xEntitlementToken,
        xCus: xCus,
        xDev: xDev,
        filter: filter,
        brandingProviderId: brandingProviderId,
        cacheControl: cacheControl);
  }

  ///Returns programs for which an active TVOD rental exists.
  ///In case a particular rental is for a season or show, that season or show is returned instead of individual entitled episodes.
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-Entitlement-Token The entitlement token as obtained from the Purchase Service.  Used to get the entitlements and validate the customerId
  ///@param x-cus The customer Id. Used to validate the entitlement token.
  ///@param x-dev The device Id. Used to validate the entitlement token.
  ///@param filter Comma separated list of filters
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  @Get(path: '/purchased-items')
  Future<chopper.Response<FeedComposerResponseForPurchasedItem>>
      _purchasedItemsGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-Entitlement-Token') String? xEntitlementToken,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Query('filter') List<String>? filter,
    @Query('brandingProviderId') String? brandingProviderId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the programs on the requested top list.
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param topListId
  ///@param profileId profileId (not used for any personal data)
  ///@param cityId City Id of the user
  Future<chopper.Response<FeedComposerResponse>> topListTopListIdGet({
    String? brandingProviderId,
    enums.TopListTopListIdGetMaxRes? maxRes,
    enums.TopListTopListIdGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    required String? topListId,
    required String? profileId,
    String? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _topListTopListIdGet(
        brandingProviderId: brandingProviderId,
        maxRes: enums.$TopListTopListIdGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$TopListTopListIdGetEncodingMap[encoding]?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        topListId: topListId,
        profileId: profileId,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Returns the programs on the requested top list.
  ///@param brandingProviderId The (optional) id of the branding provider whose content should be considered exclusively
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param topListId
  ///@param profileId profileId (not used for any personal data)
  ///@param cityId City Id of the user
  @Get(path: '/top-list/{topListId}')
  Future<chopper.Response<FeedComposerResponse>> _topListTopListIdGet({
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Path('topListId') required String? topListId,
    @Query('profileId') required String? profileId,
    @Query('cityId') String? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns programs that are similar to the most recently watched VoD title (by the same profile), and are of the same genre.
  ///The profileId is only used to fetch the most recently watched VoD title; it is not used to personalize the list of suggestions.
  ///Rendering hint: RelatedToTitleForGenre
  ///RENG: GetRelatedContentRecommendation
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  Future<chopper.Response<FeedComposerResponseWithSeedTitleAndGenre>>
      moreLikeWatchedGenreGet({
    enums.MoreLikeWatchedGenreGetMaxRes? maxRes,
    enums.MoreLikeWatchedGenreGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseWithSeedTitleAndGenre,
        () => FeedComposerResponseWithSeedTitleAndGenre.fromJsonFactory);

    return _moreLikeWatchedGenreGet(
        maxRes: enums.$MoreLikeWatchedGenreGetMaxResMap[maxRes]?.toString(),
        encoding:
            enums.$MoreLikeWatchedGenreGetEncodingMap[encoding]?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Returns programs that are similar to the most recently watched VoD title (by the same profile), and are of the same genre.
  ///The profileId is only used to fetch the most recently watched VoD title; it is not used to personalize the list of suggestions.
  ///Rendering hint: RelatedToTitleForGenre
  ///RENG: GetRelatedContentRecommendation
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  @Get(path: '/more-like-watched-genre')
  Future<chopper.Response<FeedComposerResponseWithSeedTitleAndGenre>>
      _moreLikeWatchedGenreGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns programs that are similar to the most recently watched VoD title (by the same profile).
  ///The profileId is only used to fetch the most recently watched VoD title; it is not used to personalize the list of suggestions.
  ///The suggestions are only sourced from the indicated editorial feed
  ///Rendering hint: RelatedToTitleFrom
  ///RENG: GetRelatedContentRecommendation
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param feedCrid
  Future<chopper.Response<FeedComposerResponseWithSeedTitle>>
      moreLikeWatchedFromFeedFeedCridGet({
    enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes? maxRes,
    enums.MoreLikeWatchedFromFeedFeedCridGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    required String? feedCrid,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseWithSeedTitle,
        () => FeedComposerResponseWithSeedTitle.fromJsonFactory);

    return _moreLikeWatchedFromFeedFeedCridGet(
        maxRes: enums.$MoreLikeWatchedFromFeedFeedCridGetMaxResMap[maxRes]
            ?.toString(),
        encoding: enums.$MoreLikeWatchedFromFeedFeedCridGetEncodingMap[encoding]
            ?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        feedCrid: feedCrid,
        cacheControl: cacheControl);
  }

  ///Returns programs that are similar to the most recently watched VoD title (by the same profile).
  ///The profileId is only used to fetch the most recently watched VoD title; it is not used to personalize the list of suggestions.
  ///The suggestions are only sourced from the indicated editorial feed
  ///Rendering hint: RelatedToTitleFrom
  ///RENG: GetRelatedContentRecommendation
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param feedCrid
  @Get(path: '/more-like-watched-from-feed/{feedCrid}')
  Future<chopper.Response<FeedComposerResponseWithSeedTitle>>
      _moreLikeWatchedFromFeedFeedCridGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Path('feedCrid') required String? feedCrid,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns programs that are similar to the most recently watched VoD title (by the same profile).
  ///The profileId is only used to fetch the most recently watched VoD title; it is not used to personalize the list of suggestions.
  ///Rendering hint: RelatedToTitle
  ///RENG: GetRelatedContentRecommendation
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  Future<chopper.Response<FeedComposerResponseWithSeedTitle>>
      moreLikeWatchedGet({
    enums.MoreLikeWatchedGetMaxRes? maxRes,
    enums.MoreLikeWatchedGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseWithSeedTitle,
        () => FeedComposerResponseWithSeedTitle.fromJsonFactory);

    return _moreLikeWatchedGet(
        maxRes: enums.$MoreLikeWatchedGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$MoreLikeWatchedGetEncodingMap[encoding]?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Returns programs that are similar to the most recently watched VoD title (by the same profile).
  ///The profileId is only used to fetch the most recently watched VoD title; it is not used to personalize the list of suggestions.
  ///Rendering hint: RelatedToTitle
  ///RENG: GetRelatedContentRecommendation
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  @Get(path: '/more-like-watched')
  Future<chopper.Response<FeedComposerResponseWithSeedTitle>>
      _moreLikeWatchedGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns personal suggested programs that are of the same genre as the most recently watched VoD title.
  ///The results are sourced from the indicated feed or area (group/tree of feeds)
  ///Rendering hint: SuggestedForGenreFrom
  ///RENG: GetContextRecommendations with genre filter
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param areaCrid
  Future<chopper.Response<FeedComposerResponseWithSeedTitleAndGenre>>
      suggestedFromContentAreaByWatchedGenreAreaCridGet({
    enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes? maxRes,
    enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    required String? areaCrid,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseWithSeedTitleAndGenre,
        () => FeedComposerResponseWithSeedTitleAndGenre.fromJsonFactory);

    return _suggestedFromContentAreaByWatchedGenreAreaCridGet(
        maxRes: enums
            .$SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxResMap[maxRes]
            ?.toString(),
        encoding: enums
            .$SuggestedFromContentAreaByWatchedGenreAreaCridGetEncodingMap[
                encoding]
            ?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        areaCrid: areaCrid,
        cacheControl: cacheControl);
  }

  ///Returns personal suggested programs that are of the same genre as the most recently watched VoD title.
  ///The results are sourced from the indicated feed or area (group/tree of feeds)
  ///Rendering hint: SuggestedForGenreFrom
  ///RENG: GetContextRecommendations with genre filter
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param areaCrid
  @Get(path: '/suggested-from-content-area-by-watched-genre/{areaCrid}')
  Future<chopper.Response<FeedComposerResponseWithSeedTitleAndGenre>>
      _suggestedFromContentAreaByWatchedGenreAreaCridGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Path('areaCrid') required String? areaCrid,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns personal suggested programs.
  ///The results are sourced from the indicated feed or area (group/tree of feeds)
  ///Rendering hint: SuggestedFrom
  ///RENG: GetContextRecommendations
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param areaCrid
  Future<chopper.Response<FeedComposerResponse>>
      suggestedFromContentAreaAreaCridGet({
    enums.SuggestedFromContentAreaAreaCridGetMaxRes? maxRes,
    enums.SuggestedFromContentAreaAreaCridGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    required String? areaCrid,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _suggestedFromContentAreaAreaCridGet(
        maxRes: enums.$SuggestedFromContentAreaAreaCridGetMaxResMap[maxRes]
            ?.toString(),
        encoding: enums
            .$SuggestedFromContentAreaAreaCridGetEncodingMap[encoding]
            ?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        areaCrid: areaCrid,
        cacheControl: cacheControl);
  }

  ///Returns personal suggested programs.
  ///The results are sourced from the indicated feed or area (group/tree of feeds)
  ///Rendering hint: SuggestedFrom
  ///RENG: GetContextRecommendations
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  ///@param areaCrid
  @Get(path: '/suggested-from-content-area/{areaCrid}')
  Future<chopper.Response<FeedComposerResponse>>
      _suggestedFromContentAreaAreaCridGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Path('areaCrid') required String? areaCrid,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns personal recommended programs that are of the same genre as the most recently watched VoD title.
  ///Rendering hint: SuggestedForGenre
  ///RENG: GetPreferenceRecommendations with subGenre filter
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  Future<chopper.Response<FeedComposerResponseWithSeedTitleAndGenre>>
      userRecommendedByWatchedGenreGet({
    enums.UserRecommendedByWatchedGenreGetMaxRes? maxRes,
    enums.UserRecommendedByWatchedGenreGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(FeedComposerResponseWithSeedTitleAndGenre,
        () => FeedComposerResponseWithSeedTitleAndGenre.fromJsonFactory);

    return _userRecommendedByWatchedGenreGet(
        maxRes: enums.$UserRecommendedByWatchedGenreGetMaxResMap[maxRes]
            ?.toString(),
        encoding: enums.$UserRecommendedByWatchedGenreGetEncodingMap[encoding]
            ?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Returns personal recommended programs that are of the same genre as the most recently watched VoD title.
  ///Rendering hint: SuggestedForGenre
  ///RENG: GetPreferenceRecommendations with subGenre filter
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  @Get(path: '/user-recommended-by-watched-genre')
  Future<chopper.Response<FeedComposerResponseWithSeedTitleAndGenre>>
      _userRecommendedByWatchedGenreGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns personal recommended programs.
  ///Rendering hint: Suggested
  ///RENG: GetPreferenceRecommendations
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  Future<chopper.Response<FeedComposerResponse>> userRecommendedGet({
    enums.UserRecommendedGetMaxRes? maxRes,
    enums.UserRecommendedGetEncoding? encoding,
    required int? count,
    String? xRengClienttype,
    required bool? isSharedProfile,
    String? xClaimsSet,
    required String? profileId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        FeedComposerResponse, () => FeedComposerResponse.fromJsonFactory);

    return _userRecommendedGet(
        maxRes: enums.$UserRecommendedGetMaxResMap[maxRes]?.toString(),
        encoding: enums.$UserRecommendedGetEncodingMap[encoding]?.toString(),
        count: count,
        xRengClienttype: xRengClienttype,
        isSharedProfile: isSharedProfile,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Returns personal recommended programs.
  ///Rendering hint: Suggested
  ///RENG: GetPreferenceRecommendations
  ///@param maxRes The maximum resolution that the device or context supports. Content only available in higher resolutions will be filtered out
  ///@param encoding The only encoding that the device or context supports. If provided, content only available in different encoding profiles will be filtered out
  ///@param count The maximum number of items to return
  ///@param x-reng-clienttype The value to use towards RENG as the ClientType. If absent, a configured default will be used.
  ///@param isSharedProfile Indicate (for RENG) whether the profileId is the shared (main household) profileId
  ///@param x-claims-set The claims set generated by the gateway from the claims token as obtained from personalization service.  Used to validate that the profileId given, belongs to the customer making the request.
  ///@param profileId The end user profile Id
  @Get(path: '/user-recommended')
  Future<chopper.Response<FeedComposerResponse>> _userRecommendedGet({
    @Query('maxRes') String? maxRes,
    @Query('encoding') String? encoding,
    @Query('count') required int? count,
    @Header('x-reng-clienttype') String? xRengClienttype,
    @Query('isSharedProfile') required bool? isSharedProfile,
    @Header('x-claims-set') String? xClaimsSet,
    @Query('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Error {
  Error({
    this.error,
  });

  factory Error.fromJson(Map<String, dynamic> json) => _$ErrorFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final Error$Error? error;
  static const fromJsonFactory = _$ErrorFromJson;
  static const toJsonFactory = _$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorExtension on Error {
  Error copyWith({Error$Error? error}) {
    return Error(error: error ?? this.error);
  }

  Error copyWithWrapped({Wrapped<Error$Error?>? error}) {
    return Error(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class Program {
  Program({
    this.crid,
    this.type,
  });

  factory Program.fromJson(Map<String, dynamic> json) =>
      _$ProgramFromJson(json);

  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: programTypeToJson,
    fromJson: programTypeFromJson,
  )
  final enums.ProgramType? type;
  static const fromJsonFactory = _$ProgramFromJson;
  static const toJsonFactory = _$ProgramToJson;
  Map<String, dynamic> toJson() => _$ProgramToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Program &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ProgramExtension on Program {
  Program copyWith({String? crid, enums.ProgramType? type}) {
    return Program(crid: crid ?? this.crid, type: type ?? this.type);
  }

  Program copyWithWrapped(
      {Wrapped<String?>? crid, Wrapped<enums.ProgramType?>? type}) {
    return Program(
        crid: (crid != null ? crid.value : this.crid),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchasedProgram {
  PurchasedProgram({
    this.crid,
    this.productId,
    this.brandingProviderId,
    this.type,
  });

  factory PurchasedProgram.fromJson(Map<String, dynamic> json) =>
      _$PurchasedProgramFromJson(json);

  @JsonKey(name: 'crid', includeIfNull: false, defaultValue: '')
  final String? crid;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String? productId;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: purchasedProgramTypeToJson,
    fromJson: purchasedProgramTypeFromJson,
  )
  final enums.PurchasedProgramType? type;
  static const fromJsonFactory = _$PurchasedProgramFromJson;
  static const toJsonFactory = _$PurchasedProgramToJson;
  Map<String, dynamic> toJson() => _$PurchasedProgramToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchasedProgram &&
            (identical(other.crid, crid) ||
                const DeepCollectionEquality().equals(other.crid, crid)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(crid) ^
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $PurchasedProgramExtension on PurchasedProgram {
  PurchasedProgram copyWith(
      {String? crid,
      String? productId,
      String? brandingProviderId,
      enums.PurchasedProgramType? type}) {
    return PurchasedProgram(
        crid: crid ?? this.crid,
        productId: productId ?? this.productId,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        type: type ?? this.type);
  }

  PurchasedProgram copyWithWrapped(
      {Wrapped<String?>? crid,
      Wrapped<String?>? productId,
      Wrapped<String?>? brandingProviderId,
      Wrapped<enums.PurchasedProgramType?>? type}) {
    return PurchasedProgram(
        crid: (crid != null ? crid.value : this.crid),
        productId: (productId != null ? productId.value : this.productId),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponse {
  FeedComposerResponse({
    this.programs,
  });

  factory FeedComposerResponse.fromJson(Map<String, dynamic> json) =>
      _$FeedComposerResponseFromJson(json);

  @JsonKey(name: 'programs', includeIfNull: false, defaultValue: <Program>[])
  final List<Program>? programs;
  static const fromJsonFactory = _$FeedComposerResponseFromJson;
  static const toJsonFactory = _$FeedComposerResponseToJson;
  Map<String, dynamic> toJson() => _$FeedComposerResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponse &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(programs) ^ runtimeType.hashCode;
}

extension $FeedComposerResponseExtension on FeedComposerResponse {
  FeedComposerResponse copyWith({List<Program>? programs}) {
    return FeedComposerResponse(programs: programs ?? this.programs);
  }

  FeedComposerResponse copyWithWrapped({Wrapped<List<Program>?>? programs}) {
    return FeedComposerResponse(
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponseWithTotalCount {
  FeedComposerResponseWithTotalCount({
    this.totalCount,
    this.programs,
  });

  factory FeedComposerResponseWithTotalCount.fromJson(
          Map<String, dynamic> json) =>
      _$FeedComposerResponseWithTotalCountFromJson(json);

  @JsonKey(name: 'totalCount', includeIfNull: false)
  final int? totalCount;
  @JsonKey(name: 'programs', includeIfNull: false, defaultValue: <Program>[])
  final List<Program>? programs;
  static const fromJsonFactory = _$FeedComposerResponseWithTotalCountFromJson;
  static const toJsonFactory = _$FeedComposerResponseWithTotalCountToJson;
  Map<String, dynamic> toJson() =>
      _$FeedComposerResponseWithTotalCountToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponseWithTotalCount &&
            (identical(other.totalCount, totalCount) ||
                const DeepCollectionEquality()
                    .equals(other.totalCount, totalCount)) &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(totalCount) ^
      const DeepCollectionEquality().hash(programs) ^
      runtimeType.hashCode;
}

extension $FeedComposerResponseWithTotalCountExtension
    on FeedComposerResponseWithTotalCount {
  FeedComposerResponseWithTotalCount copyWith(
      {int? totalCount, List<Program>? programs}) {
    return FeedComposerResponseWithTotalCount(
        totalCount: totalCount ?? this.totalCount,
        programs: programs ?? this.programs);
  }

  FeedComposerResponseWithTotalCount copyWithWrapped(
      {Wrapped<int?>? totalCount, Wrapped<List<Program>?>? programs}) {
    return FeedComposerResponseWithTotalCount(
        totalCount: (totalCount != null ? totalCount.value : this.totalCount),
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponseForPurchasedItem {
  FeedComposerResponseForPurchasedItem({
    this.programs,
  });

  factory FeedComposerResponseForPurchasedItem.fromJson(
          Map<String, dynamic> json) =>
      _$FeedComposerResponseForPurchasedItemFromJson(json);

  @JsonKey(
      name: 'programs',
      includeIfNull: false,
      defaultValue: <PurchasedProgram>[])
  final List<PurchasedProgram>? programs;
  static const fromJsonFactory = _$FeedComposerResponseForPurchasedItemFromJson;
  static const toJsonFactory = _$FeedComposerResponseForPurchasedItemToJson;
  Map<String, dynamic> toJson() =>
      _$FeedComposerResponseForPurchasedItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponseForPurchasedItem &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(programs) ^ runtimeType.hashCode;
}

extension $FeedComposerResponseForPurchasedItemExtension
    on FeedComposerResponseForPurchasedItem {
  FeedComposerResponseForPurchasedItem copyWith(
      {List<PurchasedProgram>? programs}) {
    return FeedComposerResponseForPurchasedItem(
        programs: programs ?? this.programs);
  }

  FeedComposerResponseForPurchasedItem copyWithWrapped(
      {Wrapped<List<PurchasedProgram>?>? programs}) {
    return FeedComposerResponseForPurchasedItem(
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponseWithSeedTitleAndGenre {
  FeedComposerResponseWithSeedTitleAndGenre({
    this.seedContentGenreTermId,
    this.seedTitleCrid,
    this.programs,
  });

  factory FeedComposerResponseWithSeedTitleAndGenre.fromJson(
          Map<String, dynamic> json) =>
      _$FeedComposerResponseWithSeedTitleAndGenreFromJson(json);

  @JsonKey(
      name: 'seedContentGenreTermId', includeIfNull: false, defaultValue: '')
  final String? seedContentGenreTermId;
  @JsonKey(name: 'seedTitleCrid', includeIfNull: false, defaultValue: '')
  final String? seedTitleCrid;
  @JsonKey(name: 'programs', includeIfNull: false, defaultValue: <Program>[])
  final List<Program>? programs;
  static const fromJsonFactory =
      _$FeedComposerResponseWithSeedTitleAndGenreFromJson;
  static const toJsonFactory =
      _$FeedComposerResponseWithSeedTitleAndGenreToJson;
  Map<String, dynamic> toJson() =>
      _$FeedComposerResponseWithSeedTitleAndGenreToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponseWithSeedTitleAndGenre &&
            (identical(other.seedContentGenreTermId, seedContentGenreTermId) ||
                const DeepCollectionEquality().equals(
                    other.seedContentGenreTermId, seedContentGenreTermId)) &&
            (identical(other.seedTitleCrid, seedTitleCrid) ||
                const DeepCollectionEquality()
                    .equals(other.seedTitleCrid, seedTitleCrid)) &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seedContentGenreTermId) ^
      const DeepCollectionEquality().hash(seedTitleCrid) ^
      const DeepCollectionEquality().hash(programs) ^
      runtimeType.hashCode;
}

extension $FeedComposerResponseWithSeedTitleAndGenreExtension
    on FeedComposerResponseWithSeedTitleAndGenre {
  FeedComposerResponseWithSeedTitleAndGenre copyWith(
      {String? seedContentGenreTermId,
      String? seedTitleCrid,
      List<Program>? programs}) {
    return FeedComposerResponseWithSeedTitleAndGenre(
        seedContentGenreTermId:
            seedContentGenreTermId ?? this.seedContentGenreTermId,
        seedTitleCrid: seedTitleCrid ?? this.seedTitleCrid,
        programs: programs ?? this.programs);
  }

  FeedComposerResponseWithSeedTitleAndGenre copyWithWrapped(
      {Wrapped<String?>? seedContentGenreTermId,
      Wrapped<String?>? seedTitleCrid,
      Wrapped<List<Program>?>? programs}) {
    return FeedComposerResponseWithSeedTitleAndGenre(
        seedContentGenreTermId: (seedContentGenreTermId != null
            ? seedContentGenreTermId.value
            : this.seedContentGenreTermId),
        seedTitleCrid:
            (seedTitleCrid != null ? seedTitleCrid.value : this.seedTitleCrid),
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class FeedComposerResponseWithSeedTitle {
  FeedComposerResponseWithSeedTitle({
    this.seedTitleCrid,
    this.programs,
  });

  factory FeedComposerResponseWithSeedTitle.fromJson(
          Map<String, dynamic> json) =>
      _$FeedComposerResponseWithSeedTitleFromJson(json);

  @JsonKey(name: 'seedTitleCrid', includeIfNull: false, defaultValue: '')
  final String? seedTitleCrid;
  @JsonKey(name: 'programs', includeIfNull: false, defaultValue: <Program>[])
  final List<Program>? programs;
  static const fromJsonFactory = _$FeedComposerResponseWithSeedTitleFromJson;
  static const toJsonFactory = _$FeedComposerResponseWithSeedTitleToJson;
  Map<String, dynamic> toJson() =>
      _$FeedComposerResponseWithSeedTitleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FeedComposerResponseWithSeedTitle &&
            (identical(other.seedTitleCrid, seedTitleCrid) ||
                const DeepCollectionEquality()
                    .equals(other.seedTitleCrid, seedTitleCrid)) &&
            (identical(other.programs, programs) ||
                const DeepCollectionEquality()
                    .equals(other.programs, programs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seedTitleCrid) ^
      const DeepCollectionEquality().hash(programs) ^
      runtimeType.hashCode;
}

extension $FeedComposerResponseWithSeedTitleExtension
    on FeedComposerResponseWithSeedTitle {
  FeedComposerResponseWithSeedTitle copyWith(
      {String? seedTitleCrid, List<Program>? programs}) {
    return FeedComposerResponseWithSeedTitle(
        seedTitleCrid: seedTitleCrid ?? this.seedTitleCrid,
        programs: programs ?? this.programs);
  }

  FeedComposerResponseWithSeedTitle copyWithWrapped(
      {Wrapped<String?>? seedTitleCrid, Wrapped<List<Program>?>? programs}) {
    return FeedComposerResponseWithSeedTitle(
        seedTitleCrid:
            (seedTitleCrid != null ? seedTitleCrid.value : this.seedTitleCrid),
        programs: (programs != null ? programs.value : this.programs));
  }
}

@JsonSerializable(explicitToJson: true)
class Error$Error {
  Error$Error({
    this.httpStatusCode,
    this.statusCode,
    this.message,
    this.correlationId,
  });

  factory Error$Error.fromJson(Map<String, dynamic> json) =>
      _$Error$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int? httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$Error$ErrorFromJson;
  static const toJsonFactory = _$Error$ErrorToJson;
  Map<String, dynamic> toJson() => _$Error$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $Error$ErrorExtension on Error$Error {
  Error$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? correlationId}) {
    return Error$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        correlationId: correlationId ?? this.correlationId);
  }

  Error$Error copyWithWrapped(
      {Wrapped<int?>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String?>? message,
      Wrapped<String?>? correlationId}) {
    return Error$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? continueWatchingGetMaxResToJson(
    enums.ContinueWatchingGetMaxRes? continueWatchingGetMaxRes) {
  return enums.$ContinueWatchingGetMaxResMap[continueWatchingGetMaxRes];
}

enums.ContinueWatchingGetMaxRes continueWatchingGetMaxResFromJson(
  Object? continueWatchingGetMaxRes, [
  enums.ContinueWatchingGetMaxRes? defaultValue,
]) {
  if (continueWatchingGetMaxRes is String) {
    return enums.$ContinueWatchingGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                continueWatchingGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ContinueWatchingGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContinueWatchingGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContinueWatchingGetMaxRes.swaggerGeneratedUnknown;
}

List<String> continueWatchingGetMaxResListToJson(
    List<enums.ContinueWatchingGetMaxRes>? continueWatchingGetMaxRes) {
  if (continueWatchingGetMaxRes == null) {
    return [];
  }

  return continueWatchingGetMaxRes
      .map((e) => enums.$ContinueWatchingGetMaxResMap[e]!)
      .toList();
}

List<enums.ContinueWatchingGetMaxRes> continueWatchingGetMaxResListFromJson(
  List? continueWatchingGetMaxRes, [
  List<enums.ContinueWatchingGetMaxRes>? defaultValue,
]) {
  if (continueWatchingGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return continueWatchingGetMaxRes
      .map((e) => continueWatchingGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ContinueWatchingGetMaxRes>?
    continueWatchingGetMaxResNullableListFromJson(
  List? continueWatchingGetMaxRes, [
  List<enums.ContinueWatchingGetMaxRes>? defaultValue,
]) {
  if (continueWatchingGetMaxRes == null) {
    return defaultValue;
  }

  return continueWatchingGetMaxRes
      .map((e) => continueWatchingGetMaxResFromJson(e.toString()))
      .toList();
}

String? continueWatchingGetEncodingToJson(
    enums.ContinueWatchingGetEncoding? continueWatchingGetEncoding) {
  return enums.$ContinueWatchingGetEncodingMap[continueWatchingGetEncoding];
}

enums.ContinueWatchingGetEncoding continueWatchingGetEncodingFromJson(
  Object? continueWatchingGetEncoding, [
  enums.ContinueWatchingGetEncoding? defaultValue,
]) {
  if (continueWatchingGetEncoding is String) {
    return enums.$ContinueWatchingGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                continueWatchingGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ContinueWatchingGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContinueWatchingGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContinueWatchingGetEncoding.swaggerGeneratedUnknown;
}

List<String> continueWatchingGetEncodingListToJson(
    List<enums.ContinueWatchingGetEncoding>? continueWatchingGetEncoding) {
  if (continueWatchingGetEncoding == null) {
    return [];
  }

  return continueWatchingGetEncoding
      .map((e) => enums.$ContinueWatchingGetEncodingMap[e]!)
      .toList();
}

List<enums.ContinueWatchingGetEncoding> continueWatchingGetEncodingListFromJson(
  List? continueWatchingGetEncoding, [
  List<enums.ContinueWatchingGetEncoding>? defaultValue,
]) {
  if (continueWatchingGetEncoding == null) {
    return defaultValue ?? [];
  }

  return continueWatchingGetEncoding
      .map((e) => continueWatchingGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.ContinueWatchingGetEncoding>?
    continueWatchingGetEncodingNullableListFromJson(
  List? continueWatchingGetEncoding, [
  List<enums.ContinueWatchingGetEncoding>? defaultValue,
]) {
  if (continueWatchingGetEncoding == null) {
    return defaultValue;
  }

  return continueWatchingGetEncoding
      .map((e) => continueWatchingGetEncodingFromJson(e.toString()))
      .toList();
}

String? pausedItemsGetMaxResToJson(
    enums.PausedItemsGetMaxRes? pausedItemsGetMaxRes) {
  return enums.$PausedItemsGetMaxResMap[pausedItemsGetMaxRes];
}

enums.PausedItemsGetMaxRes pausedItemsGetMaxResFromJson(
  Object? pausedItemsGetMaxRes, [
  enums.PausedItemsGetMaxRes? defaultValue,
]) {
  if (pausedItemsGetMaxRes is String) {
    return enums.$PausedItemsGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                pausedItemsGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PausedItemsGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PausedItemsGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PausedItemsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> pausedItemsGetMaxResListToJson(
    List<enums.PausedItemsGetMaxRes>? pausedItemsGetMaxRes) {
  if (pausedItemsGetMaxRes == null) {
    return [];
  }

  return pausedItemsGetMaxRes
      .map((e) => enums.$PausedItemsGetMaxResMap[e]!)
      .toList();
}

List<enums.PausedItemsGetMaxRes> pausedItemsGetMaxResListFromJson(
  List? pausedItemsGetMaxRes, [
  List<enums.PausedItemsGetMaxRes>? defaultValue,
]) {
  if (pausedItemsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return pausedItemsGetMaxRes
      .map((e) => pausedItemsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.PausedItemsGetMaxRes>? pausedItemsGetMaxResNullableListFromJson(
  List? pausedItemsGetMaxRes, [
  List<enums.PausedItemsGetMaxRes>? defaultValue,
]) {
  if (pausedItemsGetMaxRes == null) {
    return defaultValue;
  }

  return pausedItemsGetMaxRes
      .map((e) => pausedItemsGetMaxResFromJson(e.toString()))
      .toList();
}

String? pausedItemsGetEncodingToJson(
    enums.PausedItemsGetEncoding? pausedItemsGetEncoding) {
  return enums.$PausedItemsGetEncodingMap[pausedItemsGetEncoding];
}

enums.PausedItemsGetEncoding pausedItemsGetEncodingFromJson(
  Object? pausedItemsGetEncoding, [
  enums.PausedItemsGetEncoding? defaultValue,
]) {
  if (pausedItemsGetEncoding is String) {
    return enums.$PausedItemsGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                pausedItemsGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PausedItemsGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PausedItemsGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PausedItemsGetEncoding.swaggerGeneratedUnknown;
}

List<String> pausedItemsGetEncodingListToJson(
    List<enums.PausedItemsGetEncoding>? pausedItemsGetEncoding) {
  if (pausedItemsGetEncoding == null) {
    return [];
  }

  return pausedItemsGetEncoding
      .map((e) => enums.$PausedItemsGetEncodingMap[e]!)
      .toList();
}

List<enums.PausedItemsGetEncoding> pausedItemsGetEncodingListFromJson(
  List? pausedItemsGetEncoding, [
  List<enums.PausedItemsGetEncoding>? defaultValue,
]) {
  if (pausedItemsGetEncoding == null) {
    return defaultValue ?? [];
  }

  return pausedItemsGetEncoding
      .map((e) => pausedItemsGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.PausedItemsGetEncoding>? pausedItemsGetEncodingNullableListFromJson(
  List? pausedItemsGetEncoding, [
  List<enums.PausedItemsGetEncoding>? defaultValue,
]) {
  if (pausedItemsGetEncoding == null) {
    return defaultValue;
  }

  return pausedItemsGetEncoding
      .map((e) => pausedItemsGetEncodingFromJson(e.toString()))
      .toList();
}

String? watchlistGetMaxResToJson(enums.WatchlistGetMaxRes? watchlistGetMaxRes) {
  return enums.$WatchlistGetMaxResMap[watchlistGetMaxRes];
}

enums.WatchlistGetMaxRes watchlistGetMaxResFromJson(
  Object? watchlistGetMaxRes, [
  enums.WatchlistGetMaxRes? defaultValue,
]) {
  if (watchlistGetMaxRes is String) {
    return enums.$WatchlistGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == watchlistGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.WatchlistGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$WatchlistGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.WatchlistGetMaxRes.swaggerGeneratedUnknown;
}

List<String> watchlistGetMaxResListToJson(
    List<enums.WatchlistGetMaxRes>? watchlistGetMaxRes) {
  if (watchlistGetMaxRes == null) {
    return [];
  }

  return watchlistGetMaxRes
      .map((e) => enums.$WatchlistGetMaxResMap[e]!)
      .toList();
}

List<enums.WatchlistGetMaxRes> watchlistGetMaxResListFromJson(
  List? watchlistGetMaxRes, [
  List<enums.WatchlistGetMaxRes>? defaultValue,
]) {
  if (watchlistGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return watchlistGetMaxRes
      .map((e) => watchlistGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistGetMaxRes>? watchlistGetMaxResNullableListFromJson(
  List? watchlistGetMaxRes, [
  List<enums.WatchlistGetMaxRes>? defaultValue,
]) {
  if (watchlistGetMaxRes == null) {
    return defaultValue;
  }

  return watchlistGetMaxRes
      .map((e) => watchlistGetMaxResFromJson(e.toString()))
      .toList();
}

String? watchlistGetEncodingToJson(
    enums.WatchlistGetEncoding? watchlistGetEncoding) {
  return enums.$WatchlistGetEncodingMap[watchlistGetEncoding];
}

enums.WatchlistGetEncoding watchlistGetEncodingFromJson(
  Object? watchlistGetEncoding, [
  enums.WatchlistGetEncoding? defaultValue,
]) {
  if (watchlistGetEncoding is String) {
    return enums.$WatchlistGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                watchlistGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.WatchlistGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$WatchlistGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.WatchlistGetEncoding.swaggerGeneratedUnknown;
}

List<String> watchlistGetEncodingListToJson(
    List<enums.WatchlistGetEncoding>? watchlistGetEncoding) {
  if (watchlistGetEncoding == null) {
    return [];
  }

  return watchlistGetEncoding
      .map((e) => enums.$WatchlistGetEncodingMap[e]!)
      .toList();
}

List<enums.WatchlistGetEncoding> watchlistGetEncodingListFromJson(
  List? watchlistGetEncoding, [
  List<enums.WatchlistGetEncoding>? defaultValue,
]) {
  if (watchlistGetEncoding == null) {
    return defaultValue ?? [];
  }

  return watchlistGetEncoding
      .map((e) => watchlistGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistGetEncoding>? watchlistGetEncodingNullableListFromJson(
  List? watchlistGetEncoding, [
  List<enums.WatchlistGetEncoding>? defaultValue,
]) {
  if (watchlistGetEncoding == null) {
    return defaultValue;
  }

  return watchlistGetEncoding
      .map((e) => watchlistGetEncodingFromJson(e.toString()))
      .toList();
}

String? editorialFeedFeedCridGetMaxResToJson(
    enums.EditorialFeedFeedCridGetMaxRes? editorialFeedFeedCridGetMaxRes) {
  return enums
      .$EditorialFeedFeedCridGetMaxResMap[editorialFeedFeedCridGetMaxRes];
}

enums.EditorialFeedFeedCridGetMaxRes editorialFeedFeedCridGetMaxResFromJson(
  Object? editorialFeedFeedCridGetMaxRes, [
  enums.EditorialFeedFeedCridGetMaxRes? defaultValue,
]) {
  if (editorialFeedFeedCridGetMaxRes is String) {
    return enums.$EditorialFeedFeedCridGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                editorialFeedFeedCridGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.EditorialFeedFeedCridGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EditorialFeedFeedCridGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EditorialFeedFeedCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> editorialFeedFeedCridGetMaxResListToJson(
    List<enums.EditorialFeedFeedCridGetMaxRes>?
        editorialFeedFeedCridGetMaxRes) {
  if (editorialFeedFeedCridGetMaxRes == null) {
    return [];
  }

  return editorialFeedFeedCridGetMaxRes
      .map((e) => enums.$EditorialFeedFeedCridGetMaxResMap[e]!)
      .toList();
}

List<enums.EditorialFeedFeedCridGetMaxRes>
    editorialFeedFeedCridGetMaxResListFromJson(
  List? editorialFeedFeedCridGetMaxRes, [
  List<enums.EditorialFeedFeedCridGetMaxRes>? defaultValue,
]) {
  if (editorialFeedFeedCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return editorialFeedFeedCridGetMaxRes
      .map((e) => editorialFeedFeedCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.EditorialFeedFeedCridGetMaxRes>?
    editorialFeedFeedCridGetMaxResNullableListFromJson(
  List? editorialFeedFeedCridGetMaxRes, [
  List<enums.EditorialFeedFeedCridGetMaxRes>? defaultValue,
]) {
  if (editorialFeedFeedCridGetMaxRes == null) {
    return defaultValue;
  }

  return editorialFeedFeedCridGetMaxRes
      .map((e) => editorialFeedFeedCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? editorialFeedFeedCridGetEncodingToJson(
    enums.EditorialFeedFeedCridGetEncoding? editorialFeedFeedCridGetEncoding) {
  return enums
      .$EditorialFeedFeedCridGetEncodingMap[editorialFeedFeedCridGetEncoding];
}

enums.EditorialFeedFeedCridGetEncoding editorialFeedFeedCridGetEncodingFromJson(
  Object? editorialFeedFeedCridGetEncoding, [
  enums.EditorialFeedFeedCridGetEncoding? defaultValue,
]) {
  if (editorialFeedFeedCridGetEncoding is String) {
    return enums.$EditorialFeedFeedCridGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                editorialFeedFeedCridGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.EditorialFeedFeedCridGetEncoding.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EditorialFeedFeedCridGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EditorialFeedFeedCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> editorialFeedFeedCridGetEncodingListToJson(
    List<enums.EditorialFeedFeedCridGetEncoding>?
        editorialFeedFeedCridGetEncoding) {
  if (editorialFeedFeedCridGetEncoding == null) {
    return [];
  }

  return editorialFeedFeedCridGetEncoding
      .map((e) => enums.$EditorialFeedFeedCridGetEncodingMap[e]!)
      .toList();
}

List<enums.EditorialFeedFeedCridGetEncoding>
    editorialFeedFeedCridGetEncodingListFromJson(
  List? editorialFeedFeedCridGetEncoding, [
  List<enums.EditorialFeedFeedCridGetEncoding>? defaultValue,
]) {
  if (editorialFeedFeedCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return editorialFeedFeedCridGetEncoding
      .map((e) => editorialFeedFeedCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.EditorialFeedFeedCridGetEncoding>?
    editorialFeedFeedCridGetEncodingNullableListFromJson(
  List? editorialFeedFeedCridGetEncoding, [
  List<enums.EditorialFeedFeedCridGetEncoding>? defaultValue,
]) {
  if (editorialFeedFeedCridGetEncoding == null) {
    return defaultValue;
  }

  return editorialFeedFeedCridGetEncoding
      .map((e) => editorialFeedFeedCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? editorialFeedFeedCridGetSortingToJson(
    enums.EditorialFeedFeedCridGetSorting? editorialFeedFeedCridGetSorting) {
  return enums
      .$EditorialFeedFeedCridGetSortingMap[editorialFeedFeedCridGetSorting];
}

enums.EditorialFeedFeedCridGetSorting editorialFeedFeedCridGetSortingFromJson(
  Object? editorialFeedFeedCridGetSorting, [
  enums.EditorialFeedFeedCridGetSorting? defaultValue,
]) {
  if (editorialFeedFeedCridGetSorting is String) {
    return enums.$EditorialFeedFeedCridGetSortingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                editorialFeedFeedCridGetSorting.toLowerCase(),
            orElse: () => const MapEntry(
                enums.EditorialFeedFeedCridGetSorting.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EditorialFeedFeedCridGetSortingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EditorialFeedFeedCridGetSorting.swaggerGeneratedUnknown;
}

List<String> editorialFeedFeedCridGetSortingListToJson(
    List<enums.EditorialFeedFeedCridGetSorting>?
        editorialFeedFeedCridGetSorting) {
  if (editorialFeedFeedCridGetSorting == null) {
    return [];
  }

  return editorialFeedFeedCridGetSorting
      .map((e) => enums.$EditorialFeedFeedCridGetSortingMap[e]!)
      .toList();
}

List<enums.EditorialFeedFeedCridGetSorting>
    editorialFeedFeedCridGetSortingListFromJson(
  List? editorialFeedFeedCridGetSorting, [
  List<enums.EditorialFeedFeedCridGetSorting>? defaultValue,
]) {
  if (editorialFeedFeedCridGetSorting == null) {
    return defaultValue ?? [];
  }

  return editorialFeedFeedCridGetSorting
      .map((e) => editorialFeedFeedCridGetSortingFromJson(e.toString()))
      .toList();
}

List<enums.EditorialFeedFeedCridGetSorting>?
    editorialFeedFeedCridGetSortingNullableListFromJson(
  List? editorialFeedFeedCridGetSorting, [
  List<enums.EditorialFeedFeedCridGetSorting>? defaultValue,
]) {
  if (editorialFeedFeedCridGetSorting == null) {
    return defaultValue;
  }

  return editorialFeedFeedCridGetSorting
      .map((e) => editorialFeedFeedCridGetSortingFromJson(e.toString()))
      .toList();
}

String? purchasedItemsGetMaxResToJson(
    enums.PurchasedItemsGetMaxRes? purchasedItemsGetMaxRes) {
  return enums.$PurchasedItemsGetMaxResMap[purchasedItemsGetMaxRes];
}

enums.PurchasedItemsGetMaxRes purchasedItemsGetMaxResFromJson(
  Object? purchasedItemsGetMaxRes, [
  enums.PurchasedItemsGetMaxRes? defaultValue,
]) {
  if (purchasedItemsGetMaxRes is String) {
    return enums.$PurchasedItemsGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                purchasedItemsGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PurchasedItemsGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PurchasedItemsGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PurchasedItemsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> purchasedItemsGetMaxResListToJson(
    List<enums.PurchasedItemsGetMaxRes>? purchasedItemsGetMaxRes) {
  if (purchasedItemsGetMaxRes == null) {
    return [];
  }

  return purchasedItemsGetMaxRes
      .map((e) => enums.$PurchasedItemsGetMaxResMap[e]!)
      .toList();
}

List<enums.PurchasedItemsGetMaxRes> purchasedItemsGetMaxResListFromJson(
  List? purchasedItemsGetMaxRes, [
  List<enums.PurchasedItemsGetMaxRes>? defaultValue,
]) {
  if (purchasedItemsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return purchasedItemsGetMaxRes
      .map((e) => purchasedItemsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.PurchasedItemsGetMaxRes>?
    purchasedItemsGetMaxResNullableListFromJson(
  List? purchasedItemsGetMaxRes, [
  List<enums.PurchasedItemsGetMaxRes>? defaultValue,
]) {
  if (purchasedItemsGetMaxRes == null) {
    return defaultValue;
  }

  return purchasedItemsGetMaxRes
      .map((e) => purchasedItemsGetMaxResFromJson(e.toString()))
      .toList();
}

String? purchasedItemsGetEncodingToJson(
    enums.PurchasedItemsGetEncoding? purchasedItemsGetEncoding) {
  return enums.$PurchasedItemsGetEncodingMap[purchasedItemsGetEncoding];
}

enums.PurchasedItemsGetEncoding purchasedItemsGetEncodingFromJson(
  Object? purchasedItemsGetEncoding, [
  enums.PurchasedItemsGetEncoding? defaultValue,
]) {
  if (purchasedItemsGetEncoding is String) {
    return enums.$PurchasedItemsGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                purchasedItemsGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PurchasedItemsGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PurchasedItemsGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PurchasedItemsGetEncoding.swaggerGeneratedUnknown;
}

List<String> purchasedItemsGetEncodingListToJson(
    List<enums.PurchasedItemsGetEncoding>? purchasedItemsGetEncoding) {
  if (purchasedItemsGetEncoding == null) {
    return [];
  }

  return purchasedItemsGetEncoding
      .map((e) => enums.$PurchasedItemsGetEncodingMap[e]!)
      .toList();
}

List<enums.PurchasedItemsGetEncoding> purchasedItemsGetEncodingListFromJson(
  List? purchasedItemsGetEncoding, [
  List<enums.PurchasedItemsGetEncoding>? defaultValue,
]) {
  if (purchasedItemsGetEncoding == null) {
    return defaultValue ?? [];
  }

  return purchasedItemsGetEncoding
      .map((e) => purchasedItemsGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.PurchasedItemsGetEncoding>?
    purchasedItemsGetEncodingNullableListFromJson(
  List? purchasedItemsGetEncoding, [
  List<enums.PurchasedItemsGetEncoding>? defaultValue,
]) {
  if (purchasedItemsGetEncoding == null) {
    return defaultValue;
  }

  return purchasedItemsGetEncoding
      .map((e) => purchasedItemsGetEncodingFromJson(e.toString()))
      .toList();
}

String? topListTopListIdGetMaxResToJson(
    enums.TopListTopListIdGetMaxRes? topListTopListIdGetMaxRes) {
  return enums.$TopListTopListIdGetMaxResMap[topListTopListIdGetMaxRes];
}

enums.TopListTopListIdGetMaxRes topListTopListIdGetMaxResFromJson(
  Object? topListTopListIdGetMaxRes, [
  enums.TopListTopListIdGetMaxRes? defaultValue,
]) {
  if (topListTopListIdGetMaxRes is String) {
    return enums.$TopListTopListIdGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                topListTopListIdGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.TopListTopListIdGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TopListTopListIdGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.TopListTopListIdGetMaxRes.swaggerGeneratedUnknown;
}

List<String> topListTopListIdGetMaxResListToJson(
    List<enums.TopListTopListIdGetMaxRes>? topListTopListIdGetMaxRes) {
  if (topListTopListIdGetMaxRes == null) {
    return [];
  }

  return topListTopListIdGetMaxRes
      .map((e) => enums.$TopListTopListIdGetMaxResMap[e]!)
      .toList();
}

List<enums.TopListTopListIdGetMaxRes> topListTopListIdGetMaxResListFromJson(
  List? topListTopListIdGetMaxRes, [
  List<enums.TopListTopListIdGetMaxRes>? defaultValue,
]) {
  if (topListTopListIdGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return topListTopListIdGetMaxRes
      .map((e) => topListTopListIdGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.TopListTopListIdGetMaxRes>?
    topListTopListIdGetMaxResNullableListFromJson(
  List? topListTopListIdGetMaxRes, [
  List<enums.TopListTopListIdGetMaxRes>? defaultValue,
]) {
  if (topListTopListIdGetMaxRes == null) {
    return defaultValue;
  }

  return topListTopListIdGetMaxRes
      .map((e) => topListTopListIdGetMaxResFromJson(e.toString()))
      .toList();
}

String? topListTopListIdGetEncodingToJson(
    enums.TopListTopListIdGetEncoding? topListTopListIdGetEncoding) {
  return enums.$TopListTopListIdGetEncodingMap[topListTopListIdGetEncoding];
}

enums.TopListTopListIdGetEncoding topListTopListIdGetEncodingFromJson(
  Object? topListTopListIdGetEncoding, [
  enums.TopListTopListIdGetEncoding? defaultValue,
]) {
  if (topListTopListIdGetEncoding is String) {
    return enums.$TopListTopListIdGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                topListTopListIdGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.TopListTopListIdGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TopListTopListIdGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.TopListTopListIdGetEncoding.swaggerGeneratedUnknown;
}

List<String> topListTopListIdGetEncodingListToJson(
    List<enums.TopListTopListIdGetEncoding>? topListTopListIdGetEncoding) {
  if (topListTopListIdGetEncoding == null) {
    return [];
  }

  return topListTopListIdGetEncoding
      .map((e) => enums.$TopListTopListIdGetEncodingMap[e]!)
      .toList();
}

List<enums.TopListTopListIdGetEncoding> topListTopListIdGetEncodingListFromJson(
  List? topListTopListIdGetEncoding, [
  List<enums.TopListTopListIdGetEncoding>? defaultValue,
]) {
  if (topListTopListIdGetEncoding == null) {
    return defaultValue ?? [];
  }

  return topListTopListIdGetEncoding
      .map((e) => topListTopListIdGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.TopListTopListIdGetEncoding>?
    topListTopListIdGetEncodingNullableListFromJson(
  List? topListTopListIdGetEncoding, [
  List<enums.TopListTopListIdGetEncoding>? defaultValue,
]) {
  if (topListTopListIdGetEncoding == null) {
    return defaultValue;
  }

  return topListTopListIdGetEncoding
      .map((e) => topListTopListIdGetEncodingFromJson(e.toString()))
      .toList();
}

String? moreLikeWatchedGenreGetMaxResToJson(
    enums.MoreLikeWatchedGenreGetMaxRes? moreLikeWatchedGenreGetMaxRes) {
  return enums.$MoreLikeWatchedGenreGetMaxResMap[moreLikeWatchedGenreGetMaxRes];
}

enums.MoreLikeWatchedGenreGetMaxRes moreLikeWatchedGenreGetMaxResFromJson(
  Object? moreLikeWatchedGenreGetMaxRes, [
  enums.MoreLikeWatchedGenreGetMaxRes? defaultValue,
]) {
  if (moreLikeWatchedGenreGetMaxRes is String) {
    return enums.$MoreLikeWatchedGenreGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeWatchedGenreGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeWatchedGenreGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeWatchedGenreGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeWatchedGenreGetMaxRes.swaggerGeneratedUnknown;
}

List<String> moreLikeWatchedGenreGetMaxResListToJson(
    List<enums.MoreLikeWatchedGenreGetMaxRes>? moreLikeWatchedGenreGetMaxRes) {
  if (moreLikeWatchedGenreGetMaxRes == null) {
    return [];
  }

  return moreLikeWatchedGenreGetMaxRes
      .map((e) => enums.$MoreLikeWatchedGenreGetMaxResMap[e]!)
      .toList();
}

List<enums.MoreLikeWatchedGenreGetMaxRes>
    moreLikeWatchedGenreGetMaxResListFromJson(
  List? moreLikeWatchedGenreGetMaxRes, [
  List<enums.MoreLikeWatchedGenreGetMaxRes>? defaultValue,
]) {
  if (moreLikeWatchedGenreGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return moreLikeWatchedGenreGetMaxRes
      .map((e) => moreLikeWatchedGenreGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeWatchedGenreGetMaxRes>?
    moreLikeWatchedGenreGetMaxResNullableListFromJson(
  List? moreLikeWatchedGenreGetMaxRes, [
  List<enums.MoreLikeWatchedGenreGetMaxRes>? defaultValue,
]) {
  if (moreLikeWatchedGenreGetMaxRes == null) {
    return defaultValue;
  }

  return moreLikeWatchedGenreGetMaxRes
      .map((e) => moreLikeWatchedGenreGetMaxResFromJson(e.toString()))
      .toList();
}

String? moreLikeWatchedGenreGetEncodingToJson(
    enums.MoreLikeWatchedGenreGetEncoding? moreLikeWatchedGenreGetEncoding) {
  return enums
      .$MoreLikeWatchedGenreGetEncodingMap[moreLikeWatchedGenreGetEncoding];
}

enums.MoreLikeWatchedGenreGetEncoding moreLikeWatchedGenreGetEncodingFromJson(
  Object? moreLikeWatchedGenreGetEncoding, [
  enums.MoreLikeWatchedGenreGetEncoding? defaultValue,
]) {
  if (moreLikeWatchedGenreGetEncoding is String) {
    return enums.$MoreLikeWatchedGenreGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeWatchedGenreGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeWatchedGenreGetEncoding.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeWatchedGenreGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeWatchedGenreGetEncoding.swaggerGeneratedUnknown;
}

List<String> moreLikeWatchedGenreGetEncodingListToJson(
    List<enums.MoreLikeWatchedGenreGetEncoding>?
        moreLikeWatchedGenreGetEncoding) {
  if (moreLikeWatchedGenreGetEncoding == null) {
    return [];
  }

  return moreLikeWatchedGenreGetEncoding
      .map((e) => enums.$MoreLikeWatchedGenreGetEncodingMap[e]!)
      .toList();
}

List<enums.MoreLikeWatchedGenreGetEncoding>
    moreLikeWatchedGenreGetEncodingListFromJson(
  List? moreLikeWatchedGenreGetEncoding, [
  List<enums.MoreLikeWatchedGenreGetEncoding>? defaultValue,
]) {
  if (moreLikeWatchedGenreGetEncoding == null) {
    return defaultValue ?? [];
  }

  return moreLikeWatchedGenreGetEncoding
      .map((e) => moreLikeWatchedGenreGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeWatchedGenreGetEncoding>?
    moreLikeWatchedGenreGetEncodingNullableListFromJson(
  List? moreLikeWatchedGenreGetEncoding, [
  List<enums.MoreLikeWatchedGenreGetEncoding>? defaultValue,
]) {
  if (moreLikeWatchedGenreGetEncoding == null) {
    return defaultValue;
  }

  return moreLikeWatchedGenreGetEncoding
      .map((e) => moreLikeWatchedGenreGetEncodingFromJson(e.toString()))
      .toList();
}

String? moreLikeWatchedFromFeedFeedCridGetMaxResToJson(
    enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes?
        moreLikeWatchedFromFeedFeedCridGetMaxRes) {
  return enums.$MoreLikeWatchedFromFeedFeedCridGetMaxResMap[
      moreLikeWatchedFromFeedFeedCridGetMaxRes];
}

enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes
    moreLikeWatchedFromFeedFeedCridGetMaxResFromJson(
  Object? moreLikeWatchedFromFeedFeedCridGetMaxRes, [
  enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes? defaultValue,
]) {
  if (moreLikeWatchedFromFeedFeedCridGetMaxRes is String) {
    return enums.$MoreLikeWatchedFromFeedFeedCridGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeWatchedFromFeedFeedCridGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeWatchedFromFeedFeedCridGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> moreLikeWatchedFromFeedFeedCridGetMaxResListToJson(
    List<enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes>?
        moreLikeWatchedFromFeedFeedCridGetMaxRes) {
  if (moreLikeWatchedFromFeedFeedCridGetMaxRes == null) {
    return [];
  }

  return moreLikeWatchedFromFeedFeedCridGetMaxRes
      .map((e) => enums.$MoreLikeWatchedFromFeedFeedCridGetMaxResMap[e]!)
      .toList();
}

List<enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes>
    moreLikeWatchedFromFeedFeedCridGetMaxResListFromJson(
  List? moreLikeWatchedFromFeedFeedCridGetMaxRes, [
  List<enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes>? defaultValue,
]) {
  if (moreLikeWatchedFromFeedFeedCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return moreLikeWatchedFromFeedFeedCridGetMaxRes
      .map(
          (e) => moreLikeWatchedFromFeedFeedCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes>?
    moreLikeWatchedFromFeedFeedCridGetMaxResNullableListFromJson(
  List? moreLikeWatchedFromFeedFeedCridGetMaxRes, [
  List<enums.MoreLikeWatchedFromFeedFeedCridGetMaxRes>? defaultValue,
]) {
  if (moreLikeWatchedFromFeedFeedCridGetMaxRes == null) {
    return defaultValue;
  }

  return moreLikeWatchedFromFeedFeedCridGetMaxRes
      .map(
          (e) => moreLikeWatchedFromFeedFeedCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? moreLikeWatchedFromFeedFeedCridGetEncodingToJson(
    enums.MoreLikeWatchedFromFeedFeedCridGetEncoding?
        moreLikeWatchedFromFeedFeedCridGetEncoding) {
  return enums.$MoreLikeWatchedFromFeedFeedCridGetEncodingMap[
      moreLikeWatchedFromFeedFeedCridGetEncoding];
}

enums.MoreLikeWatchedFromFeedFeedCridGetEncoding
    moreLikeWatchedFromFeedFeedCridGetEncodingFromJson(
  Object? moreLikeWatchedFromFeedFeedCridGetEncoding, [
  enums.MoreLikeWatchedFromFeedFeedCridGetEncoding? defaultValue,
]) {
  if (moreLikeWatchedFromFeedFeedCridGetEncoding is String) {
    return enums.$MoreLikeWatchedFromFeedFeedCridGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeWatchedFromFeedFeedCridGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeWatchedFromFeedFeedCridGetEncoding
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeWatchedFromFeedFeedCridGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeWatchedFromFeedFeedCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> moreLikeWatchedFromFeedFeedCridGetEncodingListToJson(
    List<enums.MoreLikeWatchedFromFeedFeedCridGetEncoding>?
        moreLikeWatchedFromFeedFeedCridGetEncoding) {
  if (moreLikeWatchedFromFeedFeedCridGetEncoding == null) {
    return [];
  }

  return moreLikeWatchedFromFeedFeedCridGetEncoding
      .map((e) => enums.$MoreLikeWatchedFromFeedFeedCridGetEncodingMap[e]!)
      .toList();
}

List<enums.MoreLikeWatchedFromFeedFeedCridGetEncoding>
    moreLikeWatchedFromFeedFeedCridGetEncodingListFromJson(
  List? moreLikeWatchedFromFeedFeedCridGetEncoding, [
  List<enums.MoreLikeWatchedFromFeedFeedCridGetEncoding>? defaultValue,
]) {
  if (moreLikeWatchedFromFeedFeedCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return moreLikeWatchedFromFeedFeedCridGetEncoding
      .map((e) =>
          moreLikeWatchedFromFeedFeedCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeWatchedFromFeedFeedCridGetEncoding>?
    moreLikeWatchedFromFeedFeedCridGetEncodingNullableListFromJson(
  List? moreLikeWatchedFromFeedFeedCridGetEncoding, [
  List<enums.MoreLikeWatchedFromFeedFeedCridGetEncoding>? defaultValue,
]) {
  if (moreLikeWatchedFromFeedFeedCridGetEncoding == null) {
    return defaultValue;
  }

  return moreLikeWatchedFromFeedFeedCridGetEncoding
      .map((e) =>
          moreLikeWatchedFromFeedFeedCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? moreLikeWatchedGetMaxResToJson(
    enums.MoreLikeWatchedGetMaxRes? moreLikeWatchedGetMaxRes) {
  return enums.$MoreLikeWatchedGetMaxResMap[moreLikeWatchedGetMaxRes];
}

enums.MoreLikeWatchedGetMaxRes moreLikeWatchedGetMaxResFromJson(
  Object? moreLikeWatchedGetMaxRes, [
  enums.MoreLikeWatchedGetMaxRes? defaultValue,
]) {
  if (moreLikeWatchedGetMaxRes is String) {
    return enums.$MoreLikeWatchedGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeWatchedGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeWatchedGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeWatchedGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeWatchedGetMaxRes.swaggerGeneratedUnknown;
}

List<String> moreLikeWatchedGetMaxResListToJson(
    List<enums.MoreLikeWatchedGetMaxRes>? moreLikeWatchedGetMaxRes) {
  if (moreLikeWatchedGetMaxRes == null) {
    return [];
  }

  return moreLikeWatchedGetMaxRes
      .map((e) => enums.$MoreLikeWatchedGetMaxResMap[e]!)
      .toList();
}

List<enums.MoreLikeWatchedGetMaxRes> moreLikeWatchedGetMaxResListFromJson(
  List? moreLikeWatchedGetMaxRes, [
  List<enums.MoreLikeWatchedGetMaxRes>? defaultValue,
]) {
  if (moreLikeWatchedGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return moreLikeWatchedGetMaxRes
      .map((e) => moreLikeWatchedGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeWatchedGetMaxRes>?
    moreLikeWatchedGetMaxResNullableListFromJson(
  List? moreLikeWatchedGetMaxRes, [
  List<enums.MoreLikeWatchedGetMaxRes>? defaultValue,
]) {
  if (moreLikeWatchedGetMaxRes == null) {
    return defaultValue;
  }

  return moreLikeWatchedGetMaxRes
      .map((e) => moreLikeWatchedGetMaxResFromJson(e.toString()))
      .toList();
}

String? moreLikeWatchedGetEncodingToJson(
    enums.MoreLikeWatchedGetEncoding? moreLikeWatchedGetEncoding) {
  return enums.$MoreLikeWatchedGetEncodingMap[moreLikeWatchedGetEncoding];
}

enums.MoreLikeWatchedGetEncoding moreLikeWatchedGetEncodingFromJson(
  Object? moreLikeWatchedGetEncoding, [
  enums.MoreLikeWatchedGetEncoding? defaultValue,
]) {
  if (moreLikeWatchedGetEncoding is String) {
    return enums.$MoreLikeWatchedGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeWatchedGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeWatchedGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeWatchedGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeWatchedGetEncoding.swaggerGeneratedUnknown;
}

List<String> moreLikeWatchedGetEncodingListToJson(
    List<enums.MoreLikeWatchedGetEncoding>? moreLikeWatchedGetEncoding) {
  if (moreLikeWatchedGetEncoding == null) {
    return [];
  }

  return moreLikeWatchedGetEncoding
      .map((e) => enums.$MoreLikeWatchedGetEncodingMap[e]!)
      .toList();
}

List<enums.MoreLikeWatchedGetEncoding> moreLikeWatchedGetEncodingListFromJson(
  List? moreLikeWatchedGetEncoding, [
  List<enums.MoreLikeWatchedGetEncoding>? defaultValue,
]) {
  if (moreLikeWatchedGetEncoding == null) {
    return defaultValue ?? [];
  }

  return moreLikeWatchedGetEncoding
      .map((e) => moreLikeWatchedGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeWatchedGetEncoding>?
    moreLikeWatchedGetEncodingNullableListFromJson(
  List? moreLikeWatchedGetEncoding, [
  List<enums.MoreLikeWatchedGetEncoding>? defaultValue,
]) {
  if (moreLikeWatchedGetEncoding == null) {
    return defaultValue;
  }

  return moreLikeWatchedGetEncoding
      .map((e) => moreLikeWatchedGetEncodingFromJson(e.toString()))
      .toList();
}

String? suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResToJson(
    enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes?
        suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes) {
  return enums.$SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxResMap[
      suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes];
}

enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
    suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResFromJson(
  Object? suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes, [
  enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes? defaultValue,
]) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes is String) {
    return enums
        .$SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums
          .$SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
          .swaggerGeneratedUnknown;
}

List<String> suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResListToJson(
    List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes>?
        suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes == null) {
    return [];
  }

  return suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
      .map((e) =>
          enums.$SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxResMap[e]!)
      .toList();
}

List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes>
    suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResListFromJson(
  List? suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes, [
  List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes>?
      defaultValue,
]) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
      .map((e) =>
          suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResFromJson(
              e.toString()))
      .toList();
}

List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes>?
    suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResNullableListFromJson(
  List? suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes, [
  List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes>?
      defaultValue,
]) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes == null) {
    return defaultValue;
  }

  return suggestedFromContentAreaByWatchedGenreAreaCridGetMaxRes
      .map((e) =>
          suggestedFromContentAreaByWatchedGenreAreaCridGetMaxResFromJson(
              e.toString()))
      .toList();
}

String? suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingToJson(
    enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding?
        suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding) {
  return enums.$SuggestedFromContentAreaByWatchedGenreAreaCridGetEncodingMap[
      suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding];
}

enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
    suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingFromJson(
  Object? suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding, [
  enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding? defaultValue,
]) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding is String) {
    return enums
        .$SuggestedFromContentAreaByWatchedGenreAreaCridGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums
          .$SuggestedFromContentAreaByWatchedGenreAreaCridGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
          .swaggerGeneratedUnknown;
}

List<String>
    suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingListToJson(
        List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding>?
            suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding == null) {
    return [];
  }

  return suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
      .map((e) => enums
          .$SuggestedFromContentAreaByWatchedGenreAreaCridGetEncodingMap[e]!)
      .toList();
}

List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding>
    suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingListFromJson(
  List? suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding, [
  List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding>?
      defaultValue,
]) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
      .map((e) =>
          suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingFromJson(
              e.toString()))
      .toList();
}

List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding>?
    suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingNullableListFromJson(
  List? suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding, [
  List<enums.SuggestedFromContentAreaByWatchedGenreAreaCridGetEncoding>?
      defaultValue,
]) {
  if (suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding == null) {
    return defaultValue;
  }

  return suggestedFromContentAreaByWatchedGenreAreaCridGetEncoding
      .map((e) =>
          suggestedFromContentAreaByWatchedGenreAreaCridGetEncodingFromJson(
              e.toString()))
      .toList();
}

String? suggestedFromContentAreaAreaCridGetMaxResToJson(
    enums.SuggestedFromContentAreaAreaCridGetMaxRes?
        suggestedFromContentAreaAreaCridGetMaxRes) {
  return enums.$SuggestedFromContentAreaAreaCridGetMaxResMap[
      suggestedFromContentAreaAreaCridGetMaxRes];
}

enums.SuggestedFromContentAreaAreaCridGetMaxRes
    suggestedFromContentAreaAreaCridGetMaxResFromJson(
  Object? suggestedFromContentAreaAreaCridGetMaxRes, [
  enums.SuggestedFromContentAreaAreaCridGetMaxRes? defaultValue,
]) {
  if (suggestedFromContentAreaAreaCridGetMaxRes is String) {
    return enums.$SuggestedFromContentAreaAreaCridGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                suggestedFromContentAreaAreaCridGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SuggestedFromContentAreaAreaCridGetMaxRes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SuggestedFromContentAreaAreaCridGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SuggestedFromContentAreaAreaCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> suggestedFromContentAreaAreaCridGetMaxResListToJson(
    List<enums.SuggestedFromContentAreaAreaCridGetMaxRes>?
        suggestedFromContentAreaAreaCridGetMaxRes) {
  if (suggestedFromContentAreaAreaCridGetMaxRes == null) {
    return [];
  }

  return suggestedFromContentAreaAreaCridGetMaxRes
      .map((e) => enums.$SuggestedFromContentAreaAreaCridGetMaxResMap[e]!)
      .toList();
}

List<enums.SuggestedFromContentAreaAreaCridGetMaxRes>
    suggestedFromContentAreaAreaCridGetMaxResListFromJson(
  List? suggestedFromContentAreaAreaCridGetMaxRes, [
  List<enums.SuggestedFromContentAreaAreaCridGetMaxRes>? defaultValue,
]) {
  if (suggestedFromContentAreaAreaCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return suggestedFromContentAreaAreaCridGetMaxRes
      .map((e) =>
          suggestedFromContentAreaAreaCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.SuggestedFromContentAreaAreaCridGetMaxRes>?
    suggestedFromContentAreaAreaCridGetMaxResNullableListFromJson(
  List? suggestedFromContentAreaAreaCridGetMaxRes, [
  List<enums.SuggestedFromContentAreaAreaCridGetMaxRes>? defaultValue,
]) {
  if (suggestedFromContentAreaAreaCridGetMaxRes == null) {
    return defaultValue;
  }

  return suggestedFromContentAreaAreaCridGetMaxRes
      .map((e) =>
          suggestedFromContentAreaAreaCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? suggestedFromContentAreaAreaCridGetEncodingToJson(
    enums.SuggestedFromContentAreaAreaCridGetEncoding?
        suggestedFromContentAreaAreaCridGetEncoding) {
  return enums.$SuggestedFromContentAreaAreaCridGetEncodingMap[
      suggestedFromContentAreaAreaCridGetEncoding];
}

enums.SuggestedFromContentAreaAreaCridGetEncoding
    suggestedFromContentAreaAreaCridGetEncodingFromJson(
  Object? suggestedFromContentAreaAreaCridGetEncoding, [
  enums.SuggestedFromContentAreaAreaCridGetEncoding? defaultValue,
]) {
  if (suggestedFromContentAreaAreaCridGetEncoding is String) {
    return enums.$SuggestedFromContentAreaAreaCridGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                suggestedFromContentAreaAreaCridGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SuggestedFromContentAreaAreaCridGetEncoding
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SuggestedFromContentAreaAreaCridGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SuggestedFromContentAreaAreaCridGetEncoding.swaggerGeneratedUnknown;
}

List<String> suggestedFromContentAreaAreaCridGetEncodingListToJson(
    List<enums.SuggestedFromContentAreaAreaCridGetEncoding>?
        suggestedFromContentAreaAreaCridGetEncoding) {
  if (suggestedFromContentAreaAreaCridGetEncoding == null) {
    return [];
  }

  return suggestedFromContentAreaAreaCridGetEncoding
      .map((e) => enums.$SuggestedFromContentAreaAreaCridGetEncodingMap[e]!)
      .toList();
}

List<enums.SuggestedFromContentAreaAreaCridGetEncoding>
    suggestedFromContentAreaAreaCridGetEncodingListFromJson(
  List? suggestedFromContentAreaAreaCridGetEncoding, [
  List<enums.SuggestedFromContentAreaAreaCridGetEncoding>? defaultValue,
]) {
  if (suggestedFromContentAreaAreaCridGetEncoding == null) {
    return defaultValue ?? [];
  }

  return suggestedFromContentAreaAreaCridGetEncoding
      .map((e) =>
          suggestedFromContentAreaAreaCridGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.SuggestedFromContentAreaAreaCridGetEncoding>?
    suggestedFromContentAreaAreaCridGetEncodingNullableListFromJson(
  List? suggestedFromContentAreaAreaCridGetEncoding, [
  List<enums.SuggestedFromContentAreaAreaCridGetEncoding>? defaultValue,
]) {
  if (suggestedFromContentAreaAreaCridGetEncoding == null) {
    return defaultValue;
  }

  return suggestedFromContentAreaAreaCridGetEncoding
      .map((e) =>
          suggestedFromContentAreaAreaCridGetEncodingFromJson(e.toString()))
      .toList();
}

String? userRecommendedByWatchedGenreGetMaxResToJson(
    enums.UserRecommendedByWatchedGenreGetMaxRes?
        userRecommendedByWatchedGenreGetMaxRes) {
  return enums.$UserRecommendedByWatchedGenreGetMaxResMap[
      userRecommendedByWatchedGenreGetMaxRes];
}

enums.UserRecommendedByWatchedGenreGetMaxRes
    userRecommendedByWatchedGenreGetMaxResFromJson(
  Object? userRecommendedByWatchedGenreGetMaxRes, [
  enums.UserRecommendedByWatchedGenreGetMaxRes? defaultValue,
]) {
  if (userRecommendedByWatchedGenreGetMaxRes is String) {
    return enums.$UserRecommendedByWatchedGenreGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                userRecommendedByWatchedGenreGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.UserRecommendedByWatchedGenreGetMaxRes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserRecommendedByWatchedGenreGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserRecommendedByWatchedGenreGetMaxRes.swaggerGeneratedUnknown;
}

List<String> userRecommendedByWatchedGenreGetMaxResListToJson(
    List<enums.UserRecommendedByWatchedGenreGetMaxRes>?
        userRecommendedByWatchedGenreGetMaxRes) {
  if (userRecommendedByWatchedGenreGetMaxRes == null) {
    return [];
  }

  return userRecommendedByWatchedGenreGetMaxRes
      .map((e) => enums.$UserRecommendedByWatchedGenreGetMaxResMap[e]!)
      .toList();
}

List<enums.UserRecommendedByWatchedGenreGetMaxRes>
    userRecommendedByWatchedGenreGetMaxResListFromJson(
  List? userRecommendedByWatchedGenreGetMaxRes, [
  List<enums.UserRecommendedByWatchedGenreGetMaxRes>? defaultValue,
]) {
  if (userRecommendedByWatchedGenreGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return userRecommendedByWatchedGenreGetMaxRes
      .map((e) => userRecommendedByWatchedGenreGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.UserRecommendedByWatchedGenreGetMaxRes>?
    userRecommendedByWatchedGenreGetMaxResNullableListFromJson(
  List? userRecommendedByWatchedGenreGetMaxRes, [
  List<enums.UserRecommendedByWatchedGenreGetMaxRes>? defaultValue,
]) {
  if (userRecommendedByWatchedGenreGetMaxRes == null) {
    return defaultValue;
  }

  return userRecommendedByWatchedGenreGetMaxRes
      .map((e) => userRecommendedByWatchedGenreGetMaxResFromJson(e.toString()))
      .toList();
}

String? userRecommendedByWatchedGenreGetEncodingToJson(
    enums.UserRecommendedByWatchedGenreGetEncoding?
        userRecommendedByWatchedGenreGetEncoding) {
  return enums.$UserRecommendedByWatchedGenreGetEncodingMap[
      userRecommendedByWatchedGenreGetEncoding];
}

enums.UserRecommendedByWatchedGenreGetEncoding
    userRecommendedByWatchedGenreGetEncodingFromJson(
  Object? userRecommendedByWatchedGenreGetEncoding, [
  enums.UserRecommendedByWatchedGenreGetEncoding? defaultValue,
]) {
  if (userRecommendedByWatchedGenreGetEncoding is String) {
    return enums.$UserRecommendedByWatchedGenreGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                userRecommendedByWatchedGenreGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.UserRecommendedByWatchedGenreGetEncoding
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserRecommendedByWatchedGenreGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserRecommendedByWatchedGenreGetEncoding.swaggerGeneratedUnknown;
}

List<String> userRecommendedByWatchedGenreGetEncodingListToJson(
    List<enums.UserRecommendedByWatchedGenreGetEncoding>?
        userRecommendedByWatchedGenreGetEncoding) {
  if (userRecommendedByWatchedGenreGetEncoding == null) {
    return [];
  }

  return userRecommendedByWatchedGenreGetEncoding
      .map((e) => enums.$UserRecommendedByWatchedGenreGetEncodingMap[e]!)
      .toList();
}

List<enums.UserRecommendedByWatchedGenreGetEncoding>
    userRecommendedByWatchedGenreGetEncodingListFromJson(
  List? userRecommendedByWatchedGenreGetEncoding, [
  List<enums.UserRecommendedByWatchedGenreGetEncoding>? defaultValue,
]) {
  if (userRecommendedByWatchedGenreGetEncoding == null) {
    return defaultValue ?? [];
  }

  return userRecommendedByWatchedGenreGetEncoding
      .map(
          (e) => userRecommendedByWatchedGenreGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.UserRecommendedByWatchedGenreGetEncoding>?
    userRecommendedByWatchedGenreGetEncodingNullableListFromJson(
  List? userRecommendedByWatchedGenreGetEncoding, [
  List<enums.UserRecommendedByWatchedGenreGetEncoding>? defaultValue,
]) {
  if (userRecommendedByWatchedGenreGetEncoding == null) {
    return defaultValue;
  }

  return userRecommendedByWatchedGenreGetEncoding
      .map(
          (e) => userRecommendedByWatchedGenreGetEncodingFromJson(e.toString()))
      .toList();
}

String? userRecommendedGetMaxResToJson(
    enums.UserRecommendedGetMaxRes? userRecommendedGetMaxRes) {
  return enums.$UserRecommendedGetMaxResMap[userRecommendedGetMaxRes];
}

enums.UserRecommendedGetMaxRes userRecommendedGetMaxResFromJson(
  Object? userRecommendedGetMaxRes, [
  enums.UserRecommendedGetMaxRes? defaultValue,
]) {
  if (userRecommendedGetMaxRes is String) {
    return enums.$UserRecommendedGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                userRecommendedGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.UserRecommendedGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserRecommendedGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserRecommendedGetMaxRes.swaggerGeneratedUnknown;
}

List<String> userRecommendedGetMaxResListToJson(
    List<enums.UserRecommendedGetMaxRes>? userRecommendedGetMaxRes) {
  if (userRecommendedGetMaxRes == null) {
    return [];
  }

  return userRecommendedGetMaxRes
      .map((e) => enums.$UserRecommendedGetMaxResMap[e]!)
      .toList();
}

List<enums.UserRecommendedGetMaxRes> userRecommendedGetMaxResListFromJson(
  List? userRecommendedGetMaxRes, [
  List<enums.UserRecommendedGetMaxRes>? defaultValue,
]) {
  if (userRecommendedGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return userRecommendedGetMaxRes
      .map((e) => userRecommendedGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.UserRecommendedGetMaxRes>?
    userRecommendedGetMaxResNullableListFromJson(
  List? userRecommendedGetMaxRes, [
  List<enums.UserRecommendedGetMaxRes>? defaultValue,
]) {
  if (userRecommendedGetMaxRes == null) {
    return defaultValue;
  }

  return userRecommendedGetMaxRes
      .map((e) => userRecommendedGetMaxResFromJson(e.toString()))
      .toList();
}

String? userRecommendedGetEncodingToJson(
    enums.UserRecommendedGetEncoding? userRecommendedGetEncoding) {
  return enums.$UserRecommendedGetEncodingMap[userRecommendedGetEncoding];
}

enums.UserRecommendedGetEncoding userRecommendedGetEncodingFromJson(
  Object? userRecommendedGetEncoding, [
  enums.UserRecommendedGetEncoding? defaultValue,
]) {
  if (userRecommendedGetEncoding is String) {
    return enums.$UserRecommendedGetEncodingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                userRecommendedGetEncoding.toLowerCase(),
            orElse: () => const MapEntry(
                enums.UserRecommendedGetEncoding.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserRecommendedGetEncodingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserRecommendedGetEncoding.swaggerGeneratedUnknown;
}

List<String> userRecommendedGetEncodingListToJson(
    List<enums.UserRecommendedGetEncoding>? userRecommendedGetEncoding) {
  if (userRecommendedGetEncoding == null) {
    return [];
  }

  return userRecommendedGetEncoding
      .map((e) => enums.$UserRecommendedGetEncodingMap[e]!)
      .toList();
}

List<enums.UserRecommendedGetEncoding> userRecommendedGetEncodingListFromJson(
  List? userRecommendedGetEncoding, [
  List<enums.UserRecommendedGetEncoding>? defaultValue,
]) {
  if (userRecommendedGetEncoding == null) {
    return defaultValue ?? [];
  }

  return userRecommendedGetEncoding
      .map((e) => userRecommendedGetEncodingFromJson(e.toString()))
      .toList();
}

List<enums.UserRecommendedGetEncoding>?
    userRecommendedGetEncodingNullableListFromJson(
  List? userRecommendedGetEncoding, [
  List<enums.UserRecommendedGetEncoding>? defaultValue,
]) {
  if (userRecommendedGetEncoding == null) {
    return defaultValue;
  }

  return userRecommendedGetEncoding
      .map((e) => userRecommendedGetEncodingFromJson(e.toString()))
      .toList();
}

String? programTypeToJson(enums.ProgramType? programType) {
  return enums.$ProgramTypeMap[programType];
}

enums.ProgramType programTypeFromJson(
  Object? programType, [
  enums.ProgramType? defaultValue,
]) {
  if (programType is String) {
    return enums.$ProgramTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == programType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ProgramType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProgramTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProgramType.swaggerGeneratedUnknown;
}

List<String> programTypeListToJson(List<enums.ProgramType>? programType) {
  if (programType == null) {
    return [];
  }

  return programType.map((e) => enums.$ProgramTypeMap[e]!).toList();
}

List<enums.ProgramType> programTypeListFromJson(
  List? programType, [
  List<enums.ProgramType>? defaultValue,
]) {
  if (programType == null) {
    return defaultValue ?? [];
  }

  return programType.map((e) => programTypeFromJson(e.toString())).toList();
}

List<enums.ProgramType>? programTypeNullableListFromJson(
  List? programType, [
  List<enums.ProgramType>? defaultValue,
]) {
  if (programType == null) {
    return defaultValue;
  }

  return programType.map((e) => programTypeFromJson(e.toString())).toList();
}

String? purchasedProgramTypeToJson(
    enums.PurchasedProgramType? purchasedProgramType) {
  return enums.$PurchasedProgramTypeMap[purchasedProgramType];
}

enums.PurchasedProgramType purchasedProgramTypeFromJson(
  Object? purchasedProgramType, [
  enums.PurchasedProgramType? defaultValue,
]) {
  if (purchasedProgramType is String) {
    return enums.$PurchasedProgramTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                purchasedProgramType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PurchasedProgramType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PurchasedProgramTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PurchasedProgramType.swaggerGeneratedUnknown;
}

List<String> purchasedProgramTypeListToJson(
    List<enums.PurchasedProgramType>? purchasedProgramType) {
  if (purchasedProgramType == null) {
    return [];
  }

  return purchasedProgramType
      .map((e) => enums.$PurchasedProgramTypeMap[e]!)
      .toList();
}

List<enums.PurchasedProgramType> purchasedProgramTypeListFromJson(
  List? purchasedProgramType, [
  List<enums.PurchasedProgramType>? defaultValue,
]) {
  if (purchasedProgramType == null) {
    return defaultValue ?? [];
  }

  return purchasedProgramType
      .map((e) => purchasedProgramTypeFromJson(e.toString()))
      .toList();
}

List<enums.PurchasedProgramType>? purchasedProgramTypeNullableListFromJson(
  List? purchasedProgramType, [
  List<enums.PurchasedProgramType>? defaultValue,
]) {
  if (purchasedProgramType == null) {
    return defaultValue;
  }

  return purchasedProgramType
      .map((e) => purchasedProgramTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
