// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_inspection_service.swagger.chopper.dart';
part 'liberty_inspection_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyInspectionService extends ChopperService {
  static LibertyInspectionService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyInspectionService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyInspectionService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyInspectionService(newClient);
  }

  ///Get CheckComponentDisableUpstreamComponent config
  Future<chopper.Response>
      v1ConfigsCheckComponentDisableUpstreamComponentConfigurationGet(
          {String? cacheControl}) {
    return _v1ConfigsCheckComponentDisableUpstreamComponentConfigurationGet(
        cacheControl: cacheControl);
  }

  ///Get CheckComponentDisableUpstreamComponent config
  @Get(path: '/v1/configs/checkComponentDisableUpstreamComponentConfiguration')
  Future<chopper.Response>
      _v1ConfigsCheckComponentDisableUpstreamComponentConfigurationGet(
          {@Header('Cache-Control') String? cacheControl});

  ///Method for retrieving the customer recordings.
  ///@param byDeviceId Device Id
  ///@param includeAdult Include adult flag
  ///@param startTime Used to filter the recording, to return only those which are on, or after the startTime
  ///@param endTime Used to filter the recording, to return only these which are before the endTime
  Future<chopper.Response<GetCustomerRecordingsResponseV1>>
      v1CustomerRecordingsGet({
    required String? byDeviceId,
    bool? includeAdult,
    String? startTime,
    String? endTime,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GetCustomerRecordingsResponseV1,
        () => GetCustomerRecordingsResponseV1.fromJsonFactory);

    return _v1CustomerRecordingsGet(
        byDeviceId: byDeviceId,
        includeAdult: includeAdult,
        startTime: startTime,
        endTime: endTime,
        cacheControl: cacheControl);
  }

  ///Method for retrieving the customer recordings.
  ///@param byDeviceId Device Id
  ///@param includeAdult Include adult flag
  ///@param startTime Used to filter the recording, to return only those which are on, or after the startTime
  ///@param endTime Used to filter the recording, to return only these which are before the endTime
  @Get(path: '/v1/customer/recordings')
  Future<chopper.Response<GetCustomerRecordingsResponseV1>>
      _v1CustomerRecordingsGet({
    @Query('byDeviceId') required String? byDeviceId,
    @Query('includeAdult') bool? includeAdult,
    @Query('startTime') String? startTime,
    @Query('endTime') String? endTime,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching historical recordings
  ///@param deviceId Device Id
  ///@param reports Report Filter
  Future<chopper.Response<HistoricalRecordingsResponse>>
      v1HistoricalRecordingsGet({
    required String? deviceId,
    required String? reports,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(HistoricalRecordingsResponse,
        () => HistoricalRecordingsResponse.fromJsonFactory);

    return _v1HistoricalRecordingsGet(
        deviceId: deviceId, reports: reports, cacheControl: cacheControl);
  }

  ///Method for fetching historical recordings
  ///@param deviceId Device Id
  ///@param reports Report Filter
  @Get(path: '/v1/historicalRecordings')
  Future<chopper.Response<HistoricalRecordingsResponse>>
      _v1HistoricalRecordingsGet({
    @Query('deviceId') required String? deviceId,
    @Query('reports') required String? reports,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching purchase history for a customer
  ///@param customerId Customer Id
  Future<chopper.Response<PurchaseHistoryResponse>>
      v1CustomerCustomerIdHistoryGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PurchaseHistoryResponse, () => PurchaseHistoryResponse.fromJsonFactory);

    return _v1CustomerCustomerIdHistoryGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Method for fetching purchase history for a customer
  ///@param customerId Customer Id
  @Get(path: '/v1/customer/{customerId}/history')
  Future<chopper.Response<PurchaseHistoryResponse>>
      _v1CustomerCustomerIdHistoryGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for remotely setting a channel on STB and RCU Key
  ///@param body
  Future<chopper.Response> v1ChangeChannelPost({
    ChangeChannelRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ChangeChannelRequest, () => ChangeChannelRequest.fromJsonFactory);

    return _v1ChangeChannelPost(body: body, cacheControl: cacheControl);
  }

  ///Method for remotely setting a channel on STB and RCU Key
  ///@param body
  @Post(path: '/v1/changeChannel')
  Future<chopper.Response> _v1ChangeChannelPost({
    @Body() ChangeChannelRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for for retrieving the list of customer data that operator would like to cross reference with the corresponding fields in IT (EDS) side.
  ///@param customerId customer Id
  ///@param countryId country Id
  Future<chopper.Response<GetCustomersResponse>> v1CustomersGet({
    required String? customerId,
    required String? countryId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GetCustomersResponse, () => GetCustomersResponse.fromJsonFactory);

    return _v1CustomersGet(
        customerId: customerId,
        countryId: countryId,
        cacheControl: cacheControl);
  }

  ///Method for for retrieving the list of customer data that operator would like to cross reference with the corresponding fields in IT (EDS) side.
  ///@param customerId customer Id
  ///@param countryId country Id
  @Get(path: '/v1/customers')
  Future<chopper.Response<GetCustomersResponse>> _v1CustomersGet({
    @Query('customerId') required String? customerId,
    @Query('countryId') required String? countryId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for collecting basic provisioning data from multiple microservices and external components.
  ///@param customerId customer Id
  ///@param countryId country Id
  Future<chopper.Response<CheckComponentsResponse>> v1CheckComponentsGet({
    required String? customerId,
    required String? countryId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CheckComponentsResponse, () => CheckComponentsResponse.fromJsonFactory);

    return _v1CheckComponentsGet(
        customerId: customerId,
        countryId: countryId,
        cacheControl: cacheControl);
  }

  ///Method for collecting basic provisioning data from multiple microservices and external components.
  ///@param customerId customer Id
  ///@param countryId country Id
  @Get(path: '/v1/checkComponents')
  Future<chopper.Response<CheckComponentsResponse>> _v1CheckComponentsGet({
    @Query('customerId') required String? customerId,
    @Query('countryId') required String? countryId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for retrieving the customer rentals.
  ///@param byDeviceId Device Id
  ///@param includeAdult Include Adult Flag
  Future<chopper.Response<GetCustomerRentalsResponse>> v1CustomerRentalsGet({
    required String? byDeviceId,
    bool? includeAdult,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GetCustomerRentalsResponse,
        () => GetCustomerRentalsResponse.fromJsonFactory);

    return _v1CustomerRentalsGet(
        byDeviceId: byDeviceId,
        includeAdult: includeAdult,
        cacheControl: cacheControl);
  }

  ///Method for retrieving the customer rentals.
  ///@param byDeviceId Device Id
  ///@param includeAdult Include Adult Flag
  @Get(path: '/v1/customer/rentals')
  Future<chopper.Response<GetCustomerRentalsResponse>> _v1CustomerRentalsGet({
    @Query('byDeviceId') required String? byDeviceId,
    @Query('includeAdult') bool? includeAdult,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching device status for a given device from message broker
  ///@param deviceId Device Id
  ///@param body
  Future<chopper.Response<GetDeviceStatusResponse>> v1DeviceStatusDeviceIdPost({
    required String? deviceId,
    GetDeviceStatusRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GetDeviceStatusRequest, () => GetDeviceStatusRequest.fromJsonFactory);
    generatedMapping.putIfAbsent(
        GetDeviceStatusResponse, () => GetDeviceStatusResponse.fromJsonFactory);

    return _v1DeviceStatusDeviceIdPost(
        deviceId: deviceId, body: body, cacheControl: cacheControl);
  }

  ///Method for fetching device status for a given device from message broker
  ///@param deviceId Device Id
  ///@param body
  @Post(path: '/v1/deviceStatus/{deviceId}')
  Future<chopper.Response<GetDeviceStatusResponse>>
      _v1DeviceStatusDeviceIdPost({
    @Path('deviceId') required String? deviceId,
    @Body() GetDeviceStatusRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for remotely sending a RCU Key press event to STB
  ///@param body
  Future<chopper.Response> v1RcuKeyPressPost({
    RCUKeyPressRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RCUKeyPressRequest, () => RCUKeyPressRequest.fromJsonFactory);

    return _v1RcuKeyPressPost(body: body, cacheControl: cacheControl);
  }

  ///Method for remotely sending a RCU Key press event to STB
  ///@param body
  @Post(path: '/v1/rcuKeyPress')
  Future<chopper.Response> _v1RcuKeyPressPost({
    @Body() RCUKeyPressRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for inspecting CPE credentials
  ///@param KeyId Key Id
  ///@param KeyType Key Type
  Future<chopper.Response<CpeCredentialResponse>> v1InspectCpeCredentialGet({
    required String? keyId,
    required String? keyType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CpeCredentialResponse, () => CpeCredentialResponse.fromJsonFactory);

    return _v1InspectCpeCredentialGet(
        keyId: keyId, keyType: keyType, cacheControl: cacheControl);
  }

  ///Method for inspecting CPE credentials
  ///@param KeyId Key Id
  ///@param KeyType Key Type
  @Get(path: '/v1/InspectCpeCredential')
  Future<chopper.Response<CpeCredentialResponse>> _v1InspectCpeCredentialGet({
    @Query('KeyId') required String? keyId,
    @Query('KeyType') required String? keyType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching RCU reports
  ///@param deviceId Device Id
  Future<chopper.Response<RcuReportResponse>> v1RcuReportGet({
    required String? deviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RcuReportResponse, () => RcuReportResponse.fromJsonFactory);

    return _v1RcuReportGet(deviceId: deviceId, cacheControl: cacheControl);
  }

  ///Method for fetching RCU reports
  ///@param deviceId Device Id
  @Get(path: '/v1/rcuReport')
  Future<chopper.Response<RcuReportResponse>> _v1RcuReportGet({
    @Query('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching customer facing error reports
  ///@param deviceId Device Id
  Future<chopper.Response<CustomerFacingErrorResponse>>
      v1CustomerFacingErrorsGet({
    required String? deviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(CustomerFacingErrorResponse,
        () => CustomerFacingErrorResponse.fromJsonFactory);

    return _v1CustomerFacingErrorsGet(
        deviceId: deviceId, cacheControl: cacheControl);
  }

  ///Method for fetching customer facing error reports
  ///@param deviceId Device Id
  @Get(path: '/v1/customerFacingErrors')
  Future<chopper.Response<CustomerFacingErrorResponse>>
      _v1CustomerFacingErrorsGet({
    @Query('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching purchased playouts
  ///@param deviceId Device Id
  ///@param productId Product Id
  Future<chopper.Response<CustomerFacingErrorResponse>> v1PurchasePlayoutGet({
    required String? deviceId,
    required String? productId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(CustomerFacingErrorResponse,
        () => CustomerFacingErrorResponse.fromJsonFactory);

    return _v1PurchasePlayoutGet(
        deviceId: deviceId, productId: productId, cacheControl: cacheControl);
  }

  ///Method for fetching purchased playouts
  ///@param deviceId Device Id
  ///@param productId Product Id
  @Get(path: '/v1/purchasePlayout')
  Future<chopper.Response<CustomerFacingErrorResponse>> _v1PurchasePlayoutGet({
    @Query('deviceId') required String? deviceId,
    @Query('productId') required String? productId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching purchase information
  ///@param deviceId Device Id
  Future<chopper.Response<PurchaseReportResponse>> v1PurchaseOverviewGet({
    required String? deviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PurchaseReportResponse, () => PurchaseReportResponse.fromJsonFactory);

    return _v1PurchaseOverviewGet(
        deviceId: deviceId, cacheControl: cacheControl);
  }

  ///Method for fetching purchase information
  ///@param deviceId Device Id
  @Get(path: '/v1/purchaseOverview')
  Future<chopper.Response<PurchaseReportResponse>> _v1PurchaseOverviewGet({
    @Query('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for fetching Watermark Metadata
  ///@param watermarkId Watermark Id
  ///@param timestamp Timestamp
  Future<chopper.Response<String>> v1GoWmIdGet({
    required int? watermarkId,
    String? timestamp,
    String? cacheControl,
  }) {
    return _v1GoWmIdGet(
        watermarkId: watermarkId,
        timestamp: timestamp,
        cacheControl: cacheControl);
  }

  ///Method for fetching Watermark Metadata
  ///@param watermarkId Watermark Id
  ///@param timestamp Timestamp
  @Get(path: '/v1/goWmId')
  Future<chopper.Response<String>> _v1GoWmIdGet({
    @Query('watermarkId') required int? watermarkId,
    @Query('timestamp') String? timestamp,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Method for retrieving the customer recordings.
  ///@param byDeviceId Device Id
  ///@param includeAdult Include adult flag
  ///@param startTime Used to filter the recording, to return only those which are on, or after the startTime
  ///@param endTime Used to filter the recording, to return only these which are before the endTime
  Future<chopper.Response<GetCustomerRecordingsResponseV2>>
      v2CustomerRecordingsGet({
    required String? byDeviceId,
    bool? includeAdult,
    String? startTime,
    String? endTime,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GetCustomerRecordingsResponseV2,
        () => GetCustomerRecordingsResponseV2.fromJsonFactory);

    return _v2CustomerRecordingsGet(
        byDeviceId: byDeviceId,
        includeAdult: includeAdult,
        startTime: startTime,
        endTime: endTime,
        cacheControl: cacheControl);
  }

  ///Method for retrieving the customer recordings.
  ///@param byDeviceId Device Id
  ///@param includeAdult Include adult flag
  ///@param startTime Used to filter the recording, to return only those which are on, or after the startTime
  ///@param endTime Used to filter the recording, to return only these which are before the endTime
  @Get(path: '/v2/customer/recordings')
  Future<chopper.Response<GetCustomerRecordingsResponseV2>>
      _v2CustomerRecordingsGet({
    @Query('byDeviceId') required String? byDeviceId,
    @Query('includeAdult') bool? includeAdult,
    @Query('startTime') String? startTime,
    @Query('endTime') String? endTime,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class CheckComponentDisableUpstreamComponentConfiguration {
  CheckComponentDisableUpstreamComponentConfiguration({
    required this.traxis,
    required this.vspp,
    required this.vrm,
    required this.personalizationService,
    required this.purchaseService,
    required this.recordingManagementService,
  });

  factory CheckComponentDisableUpstreamComponentConfiguration.fromJson(
          Map<String, dynamic> json) =>
      _$CheckComponentDisableUpstreamComponentConfigurationFromJson(json);

  @JsonKey(name: 'traxis', includeIfNull: false)
  final bool traxis;
  @JsonKey(name: 'vspp', includeIfNull: false)
  final bool vspp;
  @JsonKey(name: 'vrm', includeIfNull: false)
  final bool vrm;
  @JsonKey(name: 'personalizationService', includeIfNull: false)
  final bool personalizationService;
  @JsonKey(name: 'purchaseService', includeIfNull: false)
  final bool purchaseService;
  @JsonKey(name: 'recordingManagementService', includeIfNull: false)
  final bool recordingManagementService;
  static const fromJsonFactory =
      _$CheckComponentDisableUpstreamComponentConfigurationFromJson;
  static const toJsonFactory =
      _$CheckComponentDisableUpstreamComponentConfigurationToJson;
  Map<String, dynamic> toJson() =>
      _$CheckComponentDisableUpstreamComponentConfigurationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CheckComponentDisableUpstreamComponentConfiguration &&
            (identical(other.traxis, traxis) ||
                const DeepCollectionEquality().equals(other.traxis, traxis)) &&
            (identical(other.vspp, vspp) ||
                const DeepCollectionEquality().equals(other.vspp, vspp)) &&
            (identical(other.vrm, vrm) ||
                const DeepCollectionEquality().equals(other.vrm, vrm)) &&
            (identical(other.personalizationService, personalizationService) ||
                const DeepCollectionEquality().equals(
                    other.personalizationService, personalizationService)) &&
            (identical(other.purchaseService, purchaseService) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseService, purchaseService)) &&
            (identical(other.recordingManagementService,
                    recordingManagementService) ||
                const DeepCollectionEquality().equals(
                    other.recordingManagementService,
                    recordingManagementService)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(traxis) ^
      const DeepCollectionEquality().hash(vspp) ^
      const DeepCollectionEquality().hash(vrm) ^
      const DeepCollectionEquality().hash(personalizationService) ^
      const DeepCollectionEquality().hash(purchaseService) ^
      const DeepCollectionEquality().hash(recordingManagementService) ^
      runtimeType.hashCode;
}

extension $CheckComponentDisableUpstreamComponentConfigurationExtension
    on CheckComponentDisableUpstreamComponentConfiguration {
  CheckComponentDisableUpstreamComponentConfiguration copyWith(
      {bool? traxis,
      bool? vspp,
      bool? vrm,
      bool? personalizationService,
      bool? purchaseService,
      bool? recordingManagementService}) {
    return CheckComponentDisableUpstreamComponentConfiguration(
        traxis: traxis ?? this.traxis,
        vspp: vspp ?? this.vspp,
        vrm: vrm ?? this.vrm,
        personalizationService:
            personalizationService ?? this.personalizationService,
        purchaseService: purchaseService ?? this.purchaseService,
        recordingManagementService:
            recordingManagementService ?? this.recordingManagementService);
  }

  CheckComponentDisableUpstreamComponentConfiguration copyWithWrapped(
      {Wrapped<bool>? traxis,
      Wrapped<bool>? vspp,
      Wrapped<bool>? vrm,
      Wrapped<bool>? personalizationService,
      Wrapped<bool>? purchaseService,
      Wrapped<bool>? recordingManagementService}) {
    return CheckComponentDisableUpstreamComponentConfiguration(
        traxis: (traxis != null ? traxis.value : this.traxis),
        vspp: (vspp != null ? vspp.value : this.vspp),
        vrm: (vrm != null ? vrm.value : this.vrm),
        personalizationService: (personalizationService != null
            ? personalizationService.value
            : this.personalizationService),
        purchaseService: (purchaseService != null
            ? purchaseService.value
            : this.purchaseService),
        recordingManagementService: (recordingManagementService != null
            ? recordingManagementService.value
            : this.recordingManagementService));
  }
}

@JsonSerializable(explicitToJson: true)
class GetCustomerRecordingsResponseV1 {
  GetCustomerRecordingsResponseV1({
    this.recordingService,
    this.error,
  });

  factory GetCustomerRecordingsResponseV1.fromJson(Map<String, dynamic> json) =>
      _$GetCustomerRecordingsResponseV1FromJson(json);

  @JsonKey(name: 'recordingService', includeIfNull: false)
  final RecordingServiceResponseV1? recordingService;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$GetCustomerRecordingsResponseV1FromJson;
  static const toJsonFactory = _$GetCustomerRecordingsResponseV1ToJson;
  Map<String, dynamic> toJson() =>
      _$GetCustomerRecordingsResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetCustomerRecordingsResponseV1 &&
            (identical(other.recordingService, recordingService) ||
                const DeepCollectionEquality()
                    .equals(other.recordingService, recordingService)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordingService) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $GetCustomerRecordingsResponseV1Extension
    on GetCustomerRecordingsResponseV1 {
  GetCustomerRecordingsResponseV1 copyWith(
      {RecordingServiceResponseV1? recordingService, KrakenError? error}) {
    return GetCustomerRecordingsResponseV1(
        recordingService: recordingService ?? this.recordingService,
        error: error ?? this.error);
  }

  GetCustomerRecordingsResponseV1 copyWithWrapped(
      {Wrapped<RecordingServiceResponseV1?>? recordingService,
      Wrapped<KrakenError?>? error}) {
    return GetCustomerRecordingsResponseV1(
        recordingService: (recordingService != null
            ? recordingService.value
            : this.recordingService),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingResponseV1 {
  RecordingResponseV1({
    this.startTime,
    this.endTime,
    this.title,
    this.channelId,
    this.source,
    this.eventId,
    this.isAdult,
    this.expirationDate,
    this.recordingState,
    this.showId,
    this.cpeId,
  });

  factory RecordingResponseV1.fromJson(Map<String, dynamic> json) =>
      _$RecordingResponseV1FromJson(json);

  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'source', includeIfNull: false, defaultValue: '')
  final String? source;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'expirationDate', includeIfNull: false, defaultValue: '')
  final String? expirationDate;
  @JsonKey(name: 'recordingState', includeIfNull: false, defaultValue: '')
  final String? recordingState;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  static const fromJsonFactory = _$RecordingResponseV1FromJson;
  static const toJsonFactory = _$RecordingResponseV1ToJson;
  Map<String, dynamic> toJson() => _$RecordingResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingResponseV1 &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      runtimeType.hashCode;
}

extension $RecordingResponseV1Extension on RecordingResponseV1 {
  RecordingResponseV1 copyWith(
      {String? startTime,
      String? endTime,
      String? title,
      String? channelId,
      String? source,
      String? eventId,
      bool? isAdult,
      String? expirationDate,
      String? recordingState,
      String? showId,
      String? cpeId}) {
    return RecordingResponseV1(
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        title: title ?? this.title,
        channelId: channelId ?? this.channelId,
        source: source ?? this.source,
        eventId: eventId ?? this.eventId,
        isAdult: isAdult ?? this.isAdult,
        expirationDate: expirationDate ?? this.expirationDate,
        recordingState: recordingState ?? this.recordingState,
        showId: showId ?? this.showId,
        cpeId: cpeId ?? this.cpeId);
  }

  RecordingResponseV1 copyWithWrapped(
      {Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<String?>? title,
      Wrapped<String?>? channelId,
      Wrapped<String?>? source,
      Wrapped<String?>? eventId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? expirationDate,
      Wrapped<String?>? recordingState,
      Wrapped<String?>? showId,
      Wrapped<String?>? cpeId}) {
    return RecordingResponseV1(
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        title: (title != null ? title.value : this.title),
        channelId: (channelId != null ? channelId.value : this.channelId),
        source: (source != null ? source.value : this.source),
        eventId: (eventId != null ? eventId.value : this.eventId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        showId: (showId != null ? showId.value : this.showId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingServiceResponseV1 {
  RecordingServiceResponseV1({
    this.size,
    this.total,
    this.quota,
    this.occupied,
    this.isAdultContentAvailable,
    this.data,
    this.error,
  });

  factory RecordingServiceResponseV1.fromJson(Map<String, dynamic> json) =>
      _$RecordingServiceResponseV1FromJson(json);

  @JsonKey(name: 'size', includeIfNull: false)
  final int? size;
  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'quota', includeIfNull: false)
  final int? quota;
  @JsonKey(name: 'occupied', includeIfNull: false)
  final int? occupied;
  @JsonKey(name: 'isAdultContentAvailable', includeIfNull: false)
  final bool? isAdultContentAvailable;
  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <RecordingResponseV1>[])
  final List<RecordingResponseV1>? data;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$RecordingServiceResponseV1FromJson;
  static const toJsonFactory = _$RecordingServiceResponseV1ToJson;
  Map<String, dynamic> toJson() => _$RecordingServiceResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingServiceResponseV1 &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.occupied, occupied) ||
                const DeepCollectionEquality()
                    .equals(other.occupied, occupied)) &&
            (identical(
                    other.isAdultContentAvailable, isAdultContentAvailable) ||
                const DeepCollectionEquality().equals(
                    other.isAdultContentAvailable, isAdultContentAvailable)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(occupied) ^
      const DeepCollectionEquality().hash(isAdultContentAvailable) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $RecordingServiceResponseV1Extension on RecordingServiceResponseV1 {
  RecordingServiceResponseV1 copyWith(
      {int? size,
      int? total,
      int? quota,
      int? occupied,
      bool? isAdultContentAvailable,
      List<RecordingResponseV1>? data,
      KrakenError? error}) {
    return RecordingServiceResponseV1(
        size: size ?? this.size,
        total: total ?? this.total,
        quota: quota ?? this.quota,
        occupied: occupied ?? this.occupied,
        isAdultContentAvailable:
            isAdultContentAvailable ?? this.isAdultContentAvailable,
        data: data ?? this.data,
        error: error ?? this.error);
  }

  RecordingServiceResponseV1 copyWithWrapped(
      {Wrapped<int?>? size,
      Wrapped<int?>? total,
      Wrapped<int?>? quota,
      Wrapped<int?>? occupied,
      Wrapped<bool?>? isAdultContentAvailable,
      Wrapped<List<RecordingResponseV1>?>? data,
      Wrapped<KrakenError?>? error}) {
    return RecordingServiceResponseV1(
        size: (size != null ? size.value : this.size),
        total: (total != null ? total.value : this.total),
        quota: (quota != null ? quota.value : this.quota),
        occupied: (occupied != null ? occupied.value : this.occupied),
        isAdultContentAvailable: (isAdultContentAvailable != null
            ? isAdultContentAvailable.value
            : this.isAdultContentAvailable),
        data: (data != null ? data.value : this.data),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;
  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class BookingsReportResponse {
  BookingsReportResponse({
    this.targetDeviceType,
    this.title,
    this.channelName,
    this.source,
    this.eventId,
    this.isAdult,
    this.bookingType,
    this.originDeviceType,
    this.eventStartTime,
    this.eventEndTime,
    this.cpeId,
    this.seasonNumber,
    this.episodeNumber,
    this.showName,
    this.bookingTime,
  });

  factory BookingsReportResponse.fromJson(Map<String, dynamic> json) =>
      _$BookingsReportResponseFromJson(json);

  @JsonKey(name: 'targetDeviceType', includeIfNull: false, defaultValue: '')
  final String? targetDeviceType;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'source', includeIfNull: false, defaultValue: '')
  final String? source;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'bookingType', includeIfNull: false, defaultValue: '')
  final String? bookingType;
  @JsonKey(name: 'originDeviceType', includeIfNull: false, defaultValue: '')
  final String? originDeviceType;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime? eventStartTime;
  @JsonKey(name: 'eventEndTime', includeIfNull: false)
  final DateTime? eventEndTime;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final num? bookingTime;
  static const fromJsonFactory = _$BookingsReportResponseFromJson;
  static const toJsonFactory = _$BookingsReportResponseToJson;
  Map<String, dynamic> toJson() => _$BookingsReportResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BookingsReportResponse &&
            (identical(other.targetDeviceType, targetDeviceType) ||
                const DeepCollectionEquality()
                    .equals(other.targetDeviceType, targetDeviceType)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.bookingType, bookingType) ||
                const DeepCollectionEquality()
                    .equals(other.bookingType, bookingType)) &&
            (identical(other.originDeviceType, originDeviceType) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceType, originDeviceType)) &&
            (identical(other.eventStartTime, eventStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.eventEndTime, eventEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventEndTime, eventEndTime)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.bookingTime, bookingTime) ||
                const DeepCollectionEquality()
                    .equals(other.bookingTime, bookingTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(targetDeviceType) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(bookingType) ^
      const DeepCollectionEquality().hash(originDeviceType) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(eventEndTime) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      runtimeType.hashCode;
}

extension $BookingsReportResponseExtension on BookingsReportResponse {
  BookingsReportResponse copyWith(
      {String? targetDeviceType,
      String? title,
      String? channelName,
      String? source,
      String? eventId,
      bool? isAdult,
      String? bookingType,
      String? originDeviceType,
      DateTime? eventStartTime,
      DateTime? eventEndTime,
      String? cpeId,
      int? seasonNumber,
      int? episodeNumber,
      String? showName,
      num? bookingTime}) {
    return BookingsReportResponse(
        targetDeviceType: targetDeviceType ?? this.targetDeviceType,
        title: title ?? this.title,
        channelName: channelName ?? this.channelName,
        source: source ?? this.source,
        eventId: eventId ?? this.eventId,
        isAdult: isAdult ?? this.isAdult,
        bookingType: bookingType ?? this.bookingType,
        originDeviceType: originDeviceType ?? this.originDeviceType,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        eventEndTime: eventEndTime ?? this.eventEndTime,
        cpeId: cpeId ?? this.cpeId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        showName: showName ?? this.showName,
        bookingTime: bookingTime ?? this.bookingTime);
  }

  BookingsReportResponse copyWithWrapped(
      {Wrapped<String?>? targetDeviceType,
      Wrapped<String?>? title,
      Wrapped<String?>? channelName,
      Wrapped<String?>? source,
      Wrapped<String?>? eventId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? bookingType,
      Wrapped<String?>? originDeviceType,
      Wrapped<DateTime?>? eventStartTime,
      Wrapped<DateTime?>? eventEndTime,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? showName,
      Wrapped<num?>? bookingTime}) {
    return BookingsReportResponse(
        targetDeviceType: (targetDeviceType != null
            ? targetDeviceType.value
            : this.targetDeviceType),
        title: (title != null ? title.value : this.title),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        source: (source != null ? source.value : this.source),
        eventId: (eventId != null ? eventId.value : this.eventId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        bookingType:
            (bookingType != null ? bookingType.value : this.bookingType),
        originDeviceType: (originDeviceType != null
            ? originDeviceType.value
            : this.originDeviceType),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        eventEndTime:
            (eventEndTime != null ? eventEndTime.value : this.eventEndTime),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        showName: (showName != null ? showName.value : this.showName),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime));
  }
}

@JsonSerializable(explicitToJson: true)
class HistoricalRecordingsResponse {
  HistoricalRecordingsResponse({
    this.error,
    this.recordingActionReport,
    this.recordingReport,
    this.bookingsReport,
  });

  factory HistoricalRecordingsResponse.fromJson(Map<String, dynamic> json) =>
      _$HistoricalRecordingsResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  @JsonKey(
      name: 'recordingActionReport',
      includeIfNull: false,
      defaultValue: <RecordingActionReportResponse>[])
  final List<RecordingActionReportResponse>? recordingActionReport;
  @JsonKey(
      name: 'recordingReport',
      includeIfNull: false,
      defaultValue: <RecordingReportResponse>[])
  final List<RecordingReportResponse>? recordingReport;
  @JsonKey(
      name: 'bookingsReport',
      includeIfNull: false,
      defaultValue: <BookingsReportResponse>[])
  final List<BookingsReportResponse>? bookingsReport;
  static const fromJsonFactory = _$HistoricalRecordingsResponseFromJson;
  static const toJsonFactory = _$HistoricalRecordingsResponseToJson;
  Map<String, dynamic> toJson() => _$HistoricalRecordingsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is HistoricalRecordingsResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)) &&
            (identical(other.recordingActionReport, recordingActionReport) ||
                const DeepCollectionEquality().equals(
                    other.recordingActionReport, recordingActionReport)) &&
            (identical(other.recordingReport, recordingReport) ||
                const DeepCollectionEquality()
                    .equals(other.recordingReport, recordingReport)) &&
            (identical(other.bookingsReport, bookingsReport) ||
                const DeepCollectionEquality()
                    .equals(other.bookingsReport, bookingsReport)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^
      const DeepCollectionEquality().hash(recordingActionReport) ^
      const DeepCollectionEquality().hash(recordingReport) ^
      const DeepCollectionEquality().hash(bookingsReport) ^
      runtimeType.hashCode;
}

extension $HistoricalRecordingsResponseExtension
    on HistoricalRecordingsResponse {
  HistoricalRecordingsResponse copyWith(
      {KrakenError? error,
      List<RecordingActionReportResponse>? recordingActionReport,
      List<RecordingReportResponse>? recordingReport,
      List<BookingsReportResponse>? bookingsReport}) {
    return HistoricalRecordingsResponse(
        error: error ?? this.error,
        recordingActionReport:
            recordingActionReport ?? this.recordingActionReport,
        recordingReport: recordingReport ?? this.recordingReport,
        bookingsReport: bookingsReport ?? this.bookingsReport);
  }

  HistoricalRecordingsResponse copyWithWrapped(
      {Wrapped<KrakenError?>? error,
      Wrapped<List<RecordingActionReportResponse>?>? recordingActionReport,
      Wrapped<List<RecordingReportResponse>?>? recordingReport,
      Wrapped<List<BookingsReportResponse>?>? bookingsReport}) {
    return HistoricalRecordingsResponse(
        error: (error != null ? error.value : this.error),
        recordingActionReport: (recordingActionReport != null
            ? recordingActionReport.value
            : this.recordingActionReport),
        recordingReport: (recordingReport != null
            ? recordingReport.value
            : this.recordingReport),
        bookingsReport: (bookingsReport != null
            ? bookingsReport.value
            : this.bookingsReport));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingActionReportResponse {
  RecordingActionReportResponse({
    this.target,
    this.title,
    this.channelName,
    this.eventId,
    this.actionType,
    this.cpeId,
    this.reportDate,
  });

  factory RecordingActionReportResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingActionReportResponseFromJson(json);

  @JsonKey(name: 'target', includeIfNull: false, defaultValue: '')
  final String? target;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'actionType', includeIfNull: false, defaultValue: '')
  final String? actionType;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'reportDate', includeIfNull: false)
  final num? reportDate;
  static const fromJsonFactory = _$RecordingActionReportResponseFromJson;
  static const toJsonFactory = _$RecordingActionReportResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingActionReportResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingActionReportResponse &&
            (identical(other.target, target) ||
                const DeepCollectionEquality().equals(other.target, target)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.actionType, actionType) ||
                const DeepCollectionEquality()
                    .equals(other.actionType, actionType)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.reportDate, reportDate) ||
                const DeepCollectionEquality()
                    .equals(other.reportDate, reportDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(target) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(actionType) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(reportDate) ^
      runtimeType.hashCode;
}

extension $RecordingActionReportResponseExtension
    on RecordingActionReportResponse {
  RecordingActionReportResponse copyWith(
      {String? target,
      String? title,
      String? channelName,
      String? eventId,
      String? actionType,
      String? cpeId,
      num? reportDate}) {
    return RecordingActionReportResponse(
        target: target ?? this.target,
        title: title ?? this.title,
        channelName: channelName ?? this.channelName,
        eventId: eventId ?? this.eventId,
        actionType: actionType ?? this.actionType,
        cpeId: cpeId ?? this.cpeId,
        reportDate: reportDate ?? this.reportDate);
  }

  RecordingActionReportResponse copyWithWrapped(
      {Wrapped<String?>? target,
      Wrapped<String?>? title,
      Wrapped<String?>? channelName,
      Wrapped<String?>? eventId,
      Wrapped<String?>? actionType,
      Wrapped<String?>? cpeId,
      Wrapped<num?>? reportDate}) {
    return RecordingActionReportResponse(
        target: (target != null ? target.value : this.target),
        title: (title != null ? title.value : this.title),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        eventId: (eventId != null ? eventId.value : this.eventId),
        actionType: (actionType != null ? actionType.value : this.actionType),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        reportDate: (reportDate != null ? reportDate.value : this.reportDate));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingReportResponse {
  RecordingReportResponse({
    this.title,
    this.channelId,
    this.channelName,
    this.source,
    this.eventId,
    this.isAdult,
    this.reportType,
    this.originDeviceType,
    this.eventStartTime,
    this.eventEndTime,
    this.recDuration,
    this.recordingState,
    this.cpeId,
    this.recStartTime,
    this.recEndTime,
    this.failureReason,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.seasonNumber,
    this.episodeNumber,
    this.showName,
    this.bookingTime,
    this.reportDate,
  });

  factory RecordingReportResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingReportResponseFromJson(json);

  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'source', includeIfNull: false, defaultValue: '')
  final String? source;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'reportType', includeIfNull: false, defaultValue: '')
  final String? reportType;
  @JsonKey(name: 'originDeviceType', includeIfNull: false, defaultValue: '')
  final String? originDeviceType;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final num? eventStartTime;
  @JsonKey(name: 'eventEndTime', includeIfNull: false)
  final num? eventEndTime;
  @JsonKey(name: 'recDuration', includeIfNull: false)
  final num? recDuration;
  @JsonKey(name: 'recordingState', includeIfNull: false, defaultValue: '')
  final String? recordingState;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final num? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final num? recEndTime;
  @JsonKey(name: 'failureReason', includeIfNull: false, defaultValue: '')
  final String? failureReason;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final num? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final num? episodeNumber;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final num? bookingTime;
  @JsonKey(name: 'reportDate', includeIfNull: false)
  final num? reportDate;
  static const fromJsonFactory = _$RecordingReportResponseFromJson;
  static const toJsonFactory = _$RecordingReportResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingReportResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingReportResponse &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.reportType, reportType) ||
                const DeepCollectionEquality()
                    .equals(other.reportType, reportType)) &&
            (identical(other.originDeviceType, originDeviceType) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceType, originDeviceType)) &&
            (identical(other.eventStartTime, eventStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.eventEndTime, eventEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventEndTime, eventEndTime)) &&
            (identical(other.recDuration, recDuration) ||
                const DeepCollectionEquality()
                    .equals(other.recDuration, recDuration)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.bookingTime, bookingTime) ||
                const DeepCollectionEquality()
                    .equals(other.bookingTime, bookingTime)) &&
            (identical(other.reportDate, reportDate) ||
                const DeepCollectionEquality()
                    .equals(other.reportDate, reportDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(reportType) ^
      const DeepCollectionEquality().hash(originDeviceType) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(eventEndTime) ^
      const DeepCollectionEquality().hash(recDuration) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      const DeepCollectionEquality().hash(reportDate) ^
      runtimeType.hashCode;
}

extension $RecordingReportResponseExtension on RecordingReportResponse {
  RecordingReportResponse copyWith(
      {String? title,
      String? channelId,
      String? channelName,
      String? source,
      String? eventId,
      bool? isAdult,
      String? reportType,
      String? originDeviceType,
      num? eventStartTime,
      num? eventEndTime,
      num? recDuration,
      String? recordingState,
      String? cpeId,
      num? recStartTime,
      num? recEndTime,
      String? failureReason,
      int? prePaddingOffset,
      int? postPaddingOffset,
      num? seasonNumber,
      num? episodeNumber,
      String? showName,
      num? bookingTime,
      num? reportDate}) {
    return RecordingReportResponse(
        title: title ?? this.title,
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName,
        source: source ?? this.source,
        eventId: eventId ?? this.eventId,
        isAdult: isAdult ?? this.isAdult,
        reportType: reportType ?? this.reportType,
        originDeviceType: originDeviceType ?? this.originDeviceType,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        eventEndTime: eventEndTime ?? this.eventEndTime,
        recDuration: recDuration ?? this.recDuration,
        recordingState: recordingState ?? this.recordingState,
        cpeId: cpeId ?? this.cpeId,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        failureReason: failureReason ?? this.failureReason,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        showName: showName ?? this.showName,
        bookingTime: bookingTime ?? this.bookingTime,
        reportDate: reportDate ?? this.reportDate);
  }

  RecordingReportResponse copyWithWrapped(
      {Wrapped<String?>? title,
      Wrapped<String?>? channelId,
      Wrapped<String?>? channelName,
      Wrapped<String?>? source,
      Wrapped<String?>? eventId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? reportType,
      Wrapped<String?>? originDeviceType,
      Wrapped<num?>? eventStartTime,
      Wrapped<num?>? eventEndTime,
      Wrapped<num?>? recDuration,
      Wrapped<String?>? recordingState,
      Wrapped<String?>? cpeId,
      Wrapped<num?>? recStartTime,
      Wrapped<num?>? recEndTime,
      Wrapped<String?>? failureReason,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<num?>? seasonNumber,
      Wrapped<num?>? episodeNumber,
      Wrapped<String?>? showName,
      Wrapped<num?>? bookingTime,
      Wrapped<num?>? reportDate}) {
    return RecordingReportResponse(
        title: (title != null ? title.value : this.title),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        source: (source != null ? source.value : this.source),
        eventId: (eventId != null ? eventId.value : this.eventId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        reportType: (reportType != null ? reportType.value : this.reportType),
        originDeviceType: (originDeviceType != null
            ? originDeviceType.value
            : this.originDeviceType),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        eventEndTime:
            (eventEndTime != null ? eventEndTime.value : this.eventEndTime),
        recDuration:
            (recDuration != null ? recDuration.value : this.recDuration),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        showName: (showName != null ? showName.value : this.showName),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime),
        reportDate: (reportDate != null ? reportDate.value : this.reportDate));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseHistoryEntry {
  PurchaseHistoryEntry({
    this.entitlementEnd,
    this.purchaseDateTime,
    this.serialNumber,
    this.deviceId,
    this.smartCardId,
    this.productId,
    this.price,
  });

  factory PurchaseHistoryEntry.fromJson(Map<String, dynamic> json) =>
      _$PurchaseHistoryEntryFromJson(json);

  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'purchaseDateTime', includeIfNull: false, defaultValue: '')
  final String? purchaseDateTime;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String? productId;
  @JsonKey(name: 'price', includeIfNull: false)
  final double? price;
  static const fromJsonFactory = _$PurchaseHistoryEntryFromJson;
  static const toJsonFactory = _$PurchaseHistoryEntryToJson;
  Map<String, dynamic> toJson() => _$PurchaseHistoryEntryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseHistoryEntry &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.purchaseDateTime, purchaseDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseDateTime, purchaseDateTime)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(purchaseDateTime) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(price) ^
      runtimeType.hashCode;
}

extension $PurchaseHistoryEntryExtension on PurchaseHistoryEntry {
  PurchaseHistoryEntry copyWith(
      {String? entitlementEnd,
      String? purchaseDateTime,
      String? serialNumber,
      String? deviceId,
      String? smartCardId,
      String? productId,
      double? price}) {
    return PurchaseHistoryEntry(
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        purchaseDateTime: purchaseDateTime ?? this.purchaseDateTime,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        smartCardId: smartCardId ?? this.smartCardId,
        productId: productId ?? this.productId,
        price: price ?? this.price);
  }

  PurchaseHistoryEntry copyWithWrapped(
      {Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? purchaseDateTime,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? productId,
      Wrapped<double?>? price}) {
    return PurchaseHistoryEntry(
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        purchaseDateTime: (purchaseDateTime != null
            ? purchaseDateTime.value
            : this.purchaseDateTime),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        productId: (productId != null ? productId.value : this.productId),
        price: (price != null ? price.value : this.price));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseHistoryResponse {
  PurchaseHistoryResponse({
    this.purchaseHistory,
    this.error,
    this.customerId,
    this.budgetLimit,
    this.budgetLimitResetDay,
    this.isDeactivated,
    this.budgetUsed,
    this.lastResetDateTime,
  });

  factory PurchaseHistoryResponse.fromJson(Map<String, dynamic> json) =>
      _$PurchaseHistoryResponseFromJson(json);

  @JsonKey(
      name: 'purchaseHistory',
      includeIfNull: false,
      defaultValue: <PurchaseHistoryEntry>[])
  final List<PurchaseHistoryEntry>? purchaseHistory;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'budgetLimit', includeIfNull: false)
  final double? budgetLimit;
  @JsonKey(name: 'budgetLimitResetDay', includeIfNull: false)
  final int? budgetLimitResetDay;
  @JsonKey(name: 'isDeactivated', includeIfNull: false)
  final bool? isDeactivated;
  @JsonKey(name: 'budgetUsed', includeIfNull: false)
  final double? budgetUsed;
  @JsonKey(name: 'lastResetDateTime', includeIfNull: false, defaultValue: '')
  final String? lastResetDateTime;
  static const fromJsonFactory = _$PurchaseHistoryResponseFromJson;
  static const toJsonFactory = _$PurchaseHistoryResponseToJson;
  Map<String, dynamic> toJson() => _$PurchaseHistoryResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseHistoryResponse &&
            (identical(other.purchaseHistory, purchaseHistory) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseHistory, purchaseHistory)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.budgetLimit, budgetLimit) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimit, budgetLimit)) &&
            (identical(other.budgetLimitResetDay, budgetLimitResetDay) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimitResetDay, budgetLimitResetDay)) &&
            (identical(other.isDeactivated, isDeactivated) ||
                const DeepCollectionEquality()
                    .equals(other.isDeactivated, isDeactivated)) &&
            (identical(other.budgetUsed, budgetUsed) ||
                const DeepCollectionEquality()
                    .equals(other.budgetUsed, budgetUsed)) &&
            (identical(other.lastResetDateTime, lastResetDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastResetDateTime, lastResetDateTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(purchaseHistory) ^
      const DeepCollectionEquality().hash(error) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(budgetLimit) ^
      const DeepCollectionEquality().hash(budgetLimitResetDay) ^
      const DeepCollectionEquality().hash(isDeactivated) ^
      const DeepCollectionEquality().hash(budgetUsed) ^
      const DeepCollectionEquality().hash(lastResetDateTime) ^
      runtimeType.hashCode;
}

extension $PurchaseHistoryResponseExtension on PurchaseHistoryResponse {
  PurchaseHistoryResponse copyWith(
      {List<PurchaseHistoryEntry>? purchaseHistory,
      KrakenError? error,
      String? customerId,
      double? budgetLimit,
      int? budgetLimitResetDay,
      bool? isDeactivated,
      double? budgetUsed,
      String? lastResetDateTime}) {
    return PurchaseHistoryResponse(
        purchaseHistory: purchaseHistory ?? this.purchaseHistory,
        error: error ?? this.error,
        customerId: customerId ?? this.customerId,
        budgetLimit: budgetLimit ?? this.budgetLimit,
        budgetLimitResetDay: budgetLimitResetDay ?? this.budgetLimitResetDay,
        isDeactivated: isDeactivated ?? this.isDeactivated,
        budgetUsed: budgetUsed ?? this.budgetUsed,
        lastResetDateTime: lastResetDateTime ?? this.lastResetDateTime);
  }

  PurchaseHistoryResponse copyWithWrapped(
      {Wrapped<List<PurchaseHistoryEntry>?>? purchaseHistory,
      Wrapped<KrakenError?>? error,
      Wrapped<String?>? customerId,
      Wrapped<double?>? budgetLimit,
      Wrapped<int?>? budgetLimitResetDay,
      Wrapped<bool?>? isDeactivated,
      Wrapped<double?>? budgetUsed,
      Wrapped<String?>? lastResetDateTime}) {
    return PurchaseHistoryResponse(
        purchaseHistory: (purchaseHistory != null
            ? purchaseHistory.value
            : this.purchaseHistory),
        error: (error != null ? error.value : this.error),
        customerId: (customerId != null ? customerId.value : this.customerId),
        budgetLimit:
            (budgetLimit != null ? budgetLimit.value : this.budgetLimit),
        budgetLimitResetDay: (budgetLimitResetDay != null
            ? budgetLimitResetDay.value
            : this.budgetLimitResetDay),
        isDeactivated:
            (isDeactivated != null ? isDeactivated.value : this.isDeactivated),
        budgetUsed: (budgetUsed != null ? budgetUsed.value : this.budgetUsed),
        lastResetDateTime: (lastResetDateTime != null
            ? lastResetDateTime.value
            : this.lastResetDateTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ChangeChannelRequest {
  ChangeChannelRequest({
    this.id,
    this.deviceId,
    this.logicalChannelNumber,
    this.friendlyDeviceName,
  });

  factory ChangeChannelRequest.fromJson(Map<String, dynamic> json) =>
      _$ChangeChannelRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'logicalChannelNumber', includeIfNull: false)
  final int? logicalChannelNumber;
  @JsonKey(name: 'friendlyDeviceName', includeIfNull: false, defaultValue: '')
  final String? friendlyDeviceName;
  static const fromJsonFactory = _$ChangeChannelRequestFromJson;
  static const toJsonFactory = _$ChangeChannelRequestToJson;
  Map<String, dynamic> toJson() => _$ChangeChannelRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChangeChannelRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.logicalChannelNumber, logicalChannelNumber) ||
                const DeepCollectionEquality().equals(
                    other.logicalChannelNumber, logicalChannelNumber)) &&
            (identical(other.friendlyDeviceName, friendlyDeviceName) ||
                const DeepCollectionEquality()
                    .equals(other.friendlyDeviceName, friendlyDeviceName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(logicalChannelNumber) ^
      const DeepCollectionEquality().hash(friendlyDeviceName) ^
      runtimeType.hashCode;
}

extension $ChangeChannelRequestExtension on ChangeChannelRequest {
  ChangeChannelRequest copyWith(
      {String? id,
      String? deviceId,
      int? logicalChannelNumber,
      String? friendlyDeviceName}) {
    return ChangeChannelRequest(
        id: id ?? this.id,
        deviceId: deviceId ?? this.deviceId,
        logicalChannelNumber: logicalChannelNumber ?? this.logicalChannelNumber,
        friendlyDeviceName: friendlyDeviceName ?? this.friendlyDeviceName);
  }

  ChangeChannelRequest copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? deviceId,
      Wrapped<int?>? logicalChannelNumber,
      Wrapped<String?>? friendlyDeviceName}) {
    return ChangeChannelRequest(
        id: (id != null ? id.value : this.id),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        logicalChannelNumber: (logicalChannelNumber != null
            ? logicalChannelNumber.value
            : this.logicalChannelNumber),
        friendlyDeviceName: (friendlyDeviceName != null
            ? friendlyDeviceName.value
            : this.friendlyDeviceName));
  }
}

@JsonSerializable(explicitToJson: true)
class Device {
  Device({
    this.smartCardID,
    this.serialNumber,
    this.deviceType,
    this.platformType,
    this.extSerialNumber,
  });

  factory Device.fromJson(Map<String, dynamic> json) => _$DeviceFromJson(json);

  @JsonKey(name: 'smartCardID', includeIfNull: false, defaultValue: '')
  final String? smartCardID;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'extSerialNumber', includeIfNull: false, defaultValue: '')
  final String? extSerialNumber;
  static const fromJsonFactory = _$DeviceFromJson;
  static const toJsonFactory = _$DeviceToJson;
  Map<String, dynamic> toJson() => _$DeviceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Device &&
            (identical(other.smartCardID, smartCardID) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardID, smartCardID)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.extSerialNumber, extSerialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.extSerialNumber, extSerialNumber)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(smartCardID) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(extSerialNumber) ^
      runtimeType.hashCode;
}

extension $DeviceExtension on Device {
  Device copyWith(
      {String? smartCardID,
      String? serialNumber,
      String? deviceType,
      String? platformType,
      String? extSerialNumber}) {
    return Device(
        smartCardID: smartCardID ?? this.smartCardID,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceType: deviceType ?? this.deviceType,
        platformType: platformType ?? this.platformType,
        extSerialNumber: extSerialNumber ?? this.extSerialNumber);
  }

  Device copyWithWrapped(
      {Wrapped<String?>? smartCardID,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceType,
      Wrapped<String?>? platformType,
      Wrapped<String?>? extSerialNumber}) {
    return Device(
        smartCardID:
            (smartCardID != null ? smartCardID.value : this.smartCardID),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        extSerialNumber: (extSerialNumber != null
            ? extSerialNumber.value
            : this.extSerialNumber));
  }
}

@JsonSerializable(explicitToJson: true)
class Entitlement {
  Entitlement({
    this.entitlementID,
    this.entitlementStartDate,
    this.entitlementEndDate,
    this.casIndicator,
  });

  factory Entitlement.fromJson(Map<String, dynamic> json) =>
      _$EntitlementFromJson(json);

  @JsonKey(name: 'entitlementID', includeIfNull: false, defaultValue: '')
  final String? entitlementID;
  @JsonKey(name: 'entitlementStartDate', includeIfNull: false, defaultValue: '')
  final String? entitlementStartDate;
  @JsonKey(name: 'entitlementEndDate', includeIfNull: false, defaultValue: '')
  final String? entitlementEndDate;
  @JsonKey(name: 'casIndicator', includeIfNull: false)
  final int? casIndicator;
  static const fromJsonFactory = _$EntitlementFromJson;
  static const toJsonFactory = _$EntitlementToJson;
  Map<String, dynamic> toJson() => _$EntitlementToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Entitlement &&
            (identical(other.entitlementID, entitlementID) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementID, entitlementID)) &&
            (identical(other.entitlementStartDate, entitlementStartDate) ||
                const DeepCollectionEquality().equals(
                    other.entitlementStartDate, entitlementStartDate)) &&
            (identical(other.entitlementEndDate, entitlementEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEndDate, entitlementEndDate)) &&
            (identical(other.casIndicator, casIndicator) ||
                const DeepCollectionEquality()
                    .equals(other.casIndicator, casIndicator)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlementID) ^
      const DeepCollectionEquality().hash(entitlementStartDate) ^
      const DeepCollectionEquality().hash(entitlementEndDate) ^
      const DeepCollectionEquality().hash(casIndicator) ^
      runtimeType.hashCode;
}

extension $EntitlementExtension on Entitlement {
  Entitlement copyWith(
      {String? entitlementID,
      String? entitlementStartDate,
      String? entitlementEndDate,
      int? casIndicator}) {
    return Entitlement(
        entitlementID: entitlementID ?? this.entitlementID,
        entitlementStartDate: entitlementStartDate ?? this.entitlementStartDate,
        entitlementEndDate: entitlementEndDate ?? this.entitlementEndDate,
        casIndicator: casIndicator ?? this.casIndicator);
  }

  Entitlement copyWithWrapped(
      {Wrapped<String?>? entitlementID,
      Wrapped<String?>? entitlementStartDate,
      Wrapped<String?>? entitlementEndDate,
      Wrapped<int?>? casIndicator}) {
    return Entitlement(
        entitlementID:
            (entitlementID != null ? entitlementID.value : this.entitlementID),
        entitlementStartDate: (entitlementStartDate != null
            ? entitlementStartDate.value
            : this.entitlementStartDate),
        entitlementEndDate: (entitlementEndDate != null
            ? entitlementEndDate.value
            : this.entitlementEndDate),
        casIndicator:
            (casIndicator != null ? casIndicator.value : this.casIndicator));
  }
}

@JsonSerializable(explicitToJson: true)
class GetCustomersResponse {
  GetCustomersResponse({
    this.personalizationServiceResponse,
    this.purchaseServiceResponse,
  });

  factory GetCustomersResponse.fromJson(Map<String, dynamic> json) =>
      _$GetCustomersResponseFromJson(json);

  @JsonKey(name: 'personalizationServiceResponse', includeIfNull: false)
  final PersonalizationServiceResponseForGetCustomers?
      personalizationServiceResponse;
  @JsonKey(name: 'purchaseServiceResponse', includeIfNull: false)
  final PurchaseServiceResponseForGetCustomers? purchaseServiceResponse;
  static const fromJsonFactory = _$GetCustomersResponseFromJson;
  static const toJsonFactory = _$GetCustomersResponseToJson;
  Map<String, dynamic> toJson() => _$GetCustomersResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetCustomersResponse &&
            (identical(other.personalizationServiceResponse,
                    personalizationServiceResponse) ||
                const DeepCollectionEquality().equals(
                    other.personalizationServiceResponse,
                    personalizationServiceResponse)) &&
            (identical(
                    other.purchaseServiceResponse, purchaseServiceResponse) ||
                const DeepCollectionEquality().equals(
                    other.purchaseServiceResponse, purchaseServiceResponse)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(personalizationServiceResponse) ^
      const DeepCollectionEquality().hash(purchaseServiceResponse) ^
      runtimeType.hashCode;
}

extension $GetCustomersResponseExtension on GetCustomersResponse {
  GetCustomersResponse copyWith(
      {PersonalizationServiceResponseForGetCustomers?
          personalizationServiceResponse,
      PurchaseServiceResponseForGetCustomers? purchaseServiceResponse}) {
    return GetCustomersResponse(
        personalizationServiceResponse: personalizationServiceResponse ??
            this.personalizationServiceResponse,
        purchaseServiceResponse:
            purchaseServiceResponse ?? this.purchaseServiceResponse);
  }

  GetCustomersResponse copyWithWrapped(
      {Wrapped<PersonalizationServiceResponseForGetCustomers?>?
          personalizationServiceResponse,
      Wrapped<PurchaseServiceResponseForGetCustomers?>?
          purchaseServiceResponse}) {
    return GetCustomersResponse(
        personalizationServiceResponse: (personalizationServiceResponse != null
            ? personalizationServiceResponse.value
            : this.personalizationServiceResponse),
        purchaseServiceResponse: (purchaseServiceResponse != null
            ? purchaseServiceResponse.value
            : this.purchaseServiceResponse));
  }
}

@JsonSerializable(explicitToJson: true)
class PersonalizationServiceResponseForGetCustomers {
  PersonalizationServiceResponseForGetCustomers({
    this.customerId,
    this.assignedDevices,
    this.cityId,
    this.countryId,
    this.customerStatus,
    this.error,
  });

  factory PersonalizationServiceResponseForGetCustomers.fromJson(
          Map<String, dynamic> json) =>
      _$PersonalizationServiceResponseForGetCustomersFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'assignedDevices', includeIfNull: false, defaultValue: <Device>[])
  final List<Device>? assignedDevices;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'customerStatus', includeIfNull: false, defaultValue: '')
  final String? customerStatus;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory =
      _$PersonalizationServiceResponseForGetCustomersFromJson;
  static const toJsonFactory =
      _$PersonalizationServiceResponseForGetCustomersToJson;
  Map<String, dynamic> toJson() =>
      _$PersonalizationServiceResponseForGetCustomersToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PersonalizationServiceResponseForGetCustomers &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $PersonalizationServiceResponseForGetCustomersExtension
    on PersonalizationServiceResponseForGetCustomers {
  PersonalizationServiceResponseForGetCustomers copyWith(
      {String? customerId,
      List<Device>? assignedDevices,
      int? cityId,
      String? countryId,
      String? customerStatus,
      KrakenError? error}) {
    return PersonalizationServiceResponseForGetCustomers(
        customerId: customerId ?? this.customerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        cityId: cityId ?? this.cityId,
        countryId: countryId ?? this.countryId,
        customerStatus: customerStatus ?? this.customerStatus,
        error: error ?? this.error);
  }

  PersonalizationServiceResponseForGetCustomers copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<List<Device>?>? assignedDevices,
      Wrapped<int?>? cityId,
      Wrapped<String?>? countryId,
      Wrapped<String?>? customerStatus,
      Wrapped<KrakenError?>? error}) {
    return PersonalizationServiceResponseForGetCustomers(
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        cityId: (cityId != null ? cityId.value : this.cityId),
        countryId: (countryId != null ? countryId.value : this.countryId),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseServiceResponseForGetCustomers {
  PurchaseServiceResponseForGetCustomers({
    this.entitlements,
    this.error,
  });

  factory PurchaseServiceResponseForGetCustomers.fromJson(
          Map<String, dynamic> json) =>
      _$PurchaseServiceResponseForGetCustomersFromJson(json);

  @JsonKey(
      name: 'entitlements', includeIfNull: false, defaultValue: <Entitlement>[])
  final List<Entitlement>? entitlements;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory =
      _$PurchaseServiceResponseForGetCustomersFromJson;
  static const toJsonFactory = _$PurchaseServiceResponseForGetCustomersToJson;
  Map<String, dynamic> toJson() =>
      _$PurchaseServiceResponseForGetCustomersToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseServiceResponseForGetCustomers &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlements) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $PurchaseServiceResponseForGetCustomersExtension
    on PurchaseServiceResponseForGetCustomers {
  PurchaseServiceResponseForGetCustomers copyWith(
      {List<Entitlement>? entitlements, KrakenError? error}) {
    return PurchaseServiceResponseForGetCustomers(
        entitlements: entitlements ?? this.entitlements,
        error: error ?? this.error);
  }

  PurchaseServiceResponseForGetCustomers copyWithWrapped(
      {Wrapped<List<Entitlement>?>? entitlements,
      Wrapped<KrakenError?>? error}) {
    return PurchaseServiceResponseForGetCustomers(
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class CheckComponentsResponse {
  CheckComponentsResponse({
    this.traxis,
    this.vrm,
    this.personalizationService,
    this.purchaseService,
    this.recordingManagementService,
    this.vspp,
  });

  factory CheckComponentsResponse.fromJson(Map<String, dynamic> json) =>
      _$CheckComponentsResponseFromJson(json);

  @JsonKey(name: 'traxis', includeIfNull: false)
  final TraxisResponse? traxis;
  @JsonKey(name: 'vrm', includeIfNull: false)
  final VrmResponse? vrm;
  @JsonKey(name: 'personalizationService', includeIfNull: false)
  final PersonalizationServiceResponseForCheckComponents?
      personalizationService;
  @JsonKey(name: 'purchaseService', includeIfNull: false)
  final PurchaseServiceResponseForCheckComponents? purchaseService;
  @JsonKey(name: 'recordingManagementService', includeIfNull: false)
  final RecordingManagementServiceResponse? recordingManagementService;
  @JsonKey(name: 'vspp', includeIfNull: false)
  final VsppResponse? vspp;
  static const fromJsonFactory = _$CheckComponentsResponseFromJson;
  static const toJsonFactory = _$CheckComponentsResponseToJson;
  Map<String, dynamic> toJson() => _$CheckComponentsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CheckComponentsResponse &&
            (identical(other.traxis, traxis) ||
                const DeepCollectionEquality().equals(other.traxis, traxis)) &&
            (identical(other.vrm, vrm) ||
                const DeepCollectionEquality().equals(other.vrm, vrm)) &&
            (identical(other.personalizationService, personalizationService) ||
                const DeepCollectionEquality().equals(
                    other.personalizationService, personalizationService)) &&
            (identical(other.purchaseService, purchaseService) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseService, purchaseService)) &&
            (identical(other.recordingManagementService,
                    recordingManagementService) ||
                const DeepCollectionEquality().equals(
                    other.recordingManagementService,
                    recordingManagementService)) &&
            (identical(other.vspp, vspp) ||
                const DeepCollectionEquality().equals(other.vspp, vspp)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(traxis) ^
      const DeepCollectionEquality().hash(vrm) ^
      const DeepCollectionEquality().hash(personalizationService) ^
      const DeepCollectionEquality().hash(purchaseService) ^
      const DeepCollectionEquality().hash(recordingManagementService) ^
      const DeepCollectionEquality().hash(vspp) ^
      runtimeType.hashCode;
}

extension $CheckComponentsResponseExtension on CheckComponentsResponse {
  CheckComponentsResponse copyWith(
      {TraxisResponse? traxis,
      VrmResponse? vrm,
      PersonalizationServiceResponseForCheckComponents? personalizationService,
      PurchaseServiceResponseForCheckComponents? purchaseService,
      RecordingManagementServiceResponse? recordingManagementService,
      VsppResponse? vspp}) {
    return CheckComponentsResponse(
        traxis: traxis ?? this.traxis,
        vrm: vrm ?? this.vrm,
        personalizationService:
            personalizationService ?? this.personalizationService,
        purchaseService: purchaseService ?? this.purchaseService,
        recordingManagementService:
            recordingManagementService ?? this.recordingManagementService,
        vspp: vspp ?? this.vspp);
  }

  CheckComponentsResponse copyWithWrapped(
      {Wrapped<TraxisResponse?>? traxis,
      Wrapped<VrmResponse?>? vrm,
      Wrapped<PersonalizationServiceResponseForCheckComponents?>?
          personalizationService,
      Wrapped<PurchaseServiceResponseForCheckComponents?>? purchaseService,
      Wrapped<RecordingManagementServiceResponse?>? recordingManagementService,
      Wrapped<VsppResponse?>? vspp}) {
    return CheckComponentsResponse(
        traxis: (traxis != null ? traxis.value : this.traxis),
        vrm: (vrm != null ? vrm.value : this.vrm),
        personalizationService: (personalizationService != null
            ? personalizationService.value
            : this.personalizationService),
        purchaseService: (purchaseService != null
            ? purchaseService.value
            : this.purchaseService),
        recordingManagementService: (recordingManagementService != null
            ? recordingManagementService.value
            : this.recordingManagementService),
        vspp: (vspp != null ? vspp.value : this.vspp));
  }
}

@JsonSerializable(explicitToJson: true)
class PersonalizationServiceResponseForCheckComponents {
  PersonalizationServiceResponseForCheckComponents({
    this.isSuspended,
    this.status,
    this.customerId,
    this.advancedAdvertisingMode,
    this.assignedDevices,
    this.cityId,
    this.countryId,
    this.error,
  });

  factory PersonalizationServiceResponseForCheckComponents.fromJson(
          Map<String, dynamic> json) =>
      _$PersonalizationServiceResponseForCheckComponentsFromJson(json);

  @JsonKey(name: 'isSuspended', includeIfNull: false)
  final bool? isSuspended;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  @JsonKey(
      name: 'assignedDevices', includeIfNull: false, defaultValue: <Device>[])
  final List<Device>? assignedDevices;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory =
      _$PersonalizationServiceResponseForCheckComponentsFromJson;
  static const toJsonFactory =
      _$PersonalizationServiceResponseForCheckComponentsToJson;
  Map<String, dynamic> toJson() =>
      _$PersonalizationServiceResponseForCheckComponentsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PersonalizationServiceResponseForCheckComponents &&
            (identical(other.isSuspended, isSuspended) ||
                const DeepCollectionEquality()
                    .equals(other.isSuspended, isSuspended)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isSuspended) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $PersonalizationServiceResponseForCheckComponentsExtension
    on PersonalizationServiceResponseForCheckComponents {
  PersonalizationServiceResponseForCheckComponents copyWith(
      {bool? isSuspended,
      String? status,
      String? customerId,
      String? advancedAdvertisingMode,
      List<Device>? assignedDevices,
      int? cityId,
      String? countryId,
      KrakenError? error}) {
    return PersonalizationServiceResponseForCheckComponents(
        isSuspended: isSuspended ?? this.isSuspended,
        status: status ?? this.status,
        customerId: customerId ?? this.customerId,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        cityId: cityId ?? this.cityId,
        countryId: countryId ?? this.countryId,
        error: error ?? this.error);
  }

  PersonalizationServiceResponseForCheckComponents copyWithWrapped(
      {Wrapped<bool?>? isSuspended,
      Wrapped<String?>? status,
      Wrapped<String?>? customerId,
      Wrapped<String?>? advancedAdvertisingMode,
      Wrapped<List<Device>?>? assignedDevices,
      Wrapped<int?>? cityId,
      Wrapped<String?>? countryId,
      Wrapped<KrakenError?>? error}) {
    return PersonalizationServiceResponseForCheckComponents(
        isSuspended:
            (isSuspended != null ? isSuspended.value : this.isSuspended),
        status: (status != null ? status.value : this.status),
        customerId: (customerId != null ? customerId.value : this.customerId),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        cityId: (cityId != null ? cityId.value : this.cityId),
        countryId: (countryId != null ? countryId.value : this.countryId),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseServiceResponseForCheckComponents {
  PurchaseServiceResponseForCheckComponents({
    this.isSuspended,
    this.budgetResetDayOfMonth,
    this.status,
    this.customerId,
    this.budgetLimit,
    this.assignedDevices,
    this.entitlements,
    this.error,
  });

  factory PurchaseServiceResponseForCheckComponents.fromJson(
          Map<String, dynamic> json) =>
      _$PurchaseServiceResponseForCheckComponentsFromJson(json);

  @JsonKey(name: 'isSuspended', includeIfNull: false)
  final bool? isSuspended;
  @JsonKey(name: 'budgetResetDayOfMonth', includeIfNull: false)
  final int? budgetResetDayOfMonth;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'budgetLimit', includeIfNull: false)
  final int? budgetLimit;
  @JsonKey(
      name: 'assignedDevices', includeIfNull: false, defaultValue: <Device>[])
  final List<Device>? assignedDevices;
  @JsonKey(
      name: 'entitlements', includeIfNull: false, defaultValue: <Entitlement>[])
  final List<Entitlement>? entitlements;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory =
      _$PurchaseServiceResponseForCheckComponentsFromJson;
  static const toJsonFactory =
      _$PurchaseServiceResponseForCheckComponentsToJson;
  Map<String, dynamic> toJson() =>
      _$PurchaseServiceResponseForCheckComponentsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseServiceResponseForCheckComponents &&
            (identical(other.isSuspended, isSuspended) ||
                const DeepCollectionEquality()
                    .equals(other.isSuspended, isSuspended)) &&
            (identical(other.budgetResetDayOfMonth, budgetResetDayOfMonth) ||
                const DeepCollectionEquality().equals(
                    other.budgetResetDayOfMonth, budgetResetDayOfMonth)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.budgetLimit, budgetLimit) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimit, budgetLimit)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isSuspended) ^
      const DeepCollectionEquality().hash(budgetResetDayOfMonth) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(budgetLimit) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(entitlements) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $PurchaseServiceResponseForCheckComponentsExtension
    on PurchaseServiceResponseForCheckComponents {
  PurchaseServiceResponseForCheckComponents copyWith(
      {bool? isSuspended,
      int? budgetResetDayOfMonth,
      String? status,
      String? customerId,
      int? budgetLimit,
      List<Device>? assignedDevices,
      List<Entitlement>? entitlements,
      KrakenError? error}) {
    return PurchaseServiceResponseForCheckComponents(
        isSuspended: isSuspended ?? this.isSuspended,
        budgetResetDayOfMonth:
            budgetResetDayOfMonth ?? this.budgetResetDayOfMonth,
        status: status ?? this.status,
        customerId: customerId ?? this.customerId,
        budgetLimit: budgetLimit ?? this.budgetLimit,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        entitlements: entitlements ?? this.entitlements,
        error: error ?? this.error);
  }

  PurchaseServiceResponseForCheckComponents copyWithWrapped(
      {Wrapped<bool?>? isSuspended,
      Wrapped<int?>? budgetResetDayOfMonth,
      Wrapped<String?>? status,
      Wrapped<String?>? customerId,
      Wrapped<int?>? budgetLimit,
      Wrapped<List<Device>?>? assignedDevices,
      Wrapped<List<Entitlement>?>? entitlements,
      Wrapped<KrakenError?>? error}) {
    return PurchaseServiceResponseForCheckComponents(
        isSuspended:
            (isSuspended != null ? isSuspended.value : this.isSuspended),
        budgetResetDayOfMonth: (budgetResetDayOfMonth != null
            ? budgetResetDayOfMonth.value
            : this.budgetResetDayOfMonth),
        status: (status != null ? status.value : this.status),
        customerId: (customerId != null ? customerId.value : this.customerId),
        budgetLimit:
            (budgetLimit != null ? budgetLimit.value : this.budgetLimit),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingManagementServiceResponse {
  RecordingManagementServiceResponse({
    this.id,
    this.status,
    this.quota,
    this.active,
    this.suspended,
    this.occupied,
    this.error,
  });

  factory RecordingManagementServiceResponse.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingManagementServiceResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'quota', includeIfNull: false)
  final int? quota;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  @JsonKey(name: 'suspended', includeIfNull: false)
  final bool? suspended;
  @JsonKey(name: 'occupied', includeIfNull: false)
  final int? occupied;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$RecordingManagementServiceResponseFromJson;
  static const toJsonFactory = _$RecordingManagementServiceResponseToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingManagementServiceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingManagementServiceResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.suspended, suspended) ||
                const DeepCollectionEquality()
                    .equals(other.suspended, suspended)) &&
            (identical(other.occupied, occupied) ||
                const DeepCollectionEquality()
                    .equals(other.occupied, occupied)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(suspended) ^
      const DeepCollectionEquality().hash(occupied) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $RecordingManagementServiceResponseExtension
    on RecordingManagementServiceResponse {
  RecordingManagementServiceResponse copyWith(
      {String? id,
      String? status,
      int? quota,
      bool? active,
      bool? suspended,
      int? occupied,
      KrakenError? error}) {
    return RecordingManagementServiceResponse(
        id: id ?? this.id,
        status: status ?? this.status,
        quota: quota ?? this.quota,
        active: active ?? this.active,
        suspended: suspended ?? this.suspended,
        occupied: occupied ?? this.occupied,
        error: error ?? this.error);
  }

  RecordingManagementServiceResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? status,
      Wrapped<int?>? quota,
      Wrapped<bool?>? active,
      Wrapped<bool?>? suspended,
      Wrapped<int?>? occupied,
      Wrapped<KrakenError?>? error}) {
    return RecordingManagementServiceResponse(
        id: (id != null ? id.value : this.id),
        status: (status != null ? status.value : this.status),
        quota: (quota != null ? quota.value : this.quota),
        active: (active != null ? active.value : this.active),
        suspended: (suspended != null ? suspended.value : this.suspended),
        occupied: (occupied != null ? occupied.value : this.occupied),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class TraxisResponse {
  TraxisResponse({
    this.isSuspended,
    this.status,
    this.customerId,
    this.error,
  });

  factory TraxisResponse.fromJson(Map<String, dynamic> json) =>
      _$TraxisResponseFromJson(json);

  @JsonKey(name: 'isSuspended', includeIfNull: false)
  final bool? isSuspended;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$TraxisResponseFromJson;
  static const toJsonFactory = _$TraxisResponseToJson;
  Map<String, dynamic> toJson() => _$TraxisResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TraxisResponse &&
            (identical(other.isSuspended, isSuspended) ||
                const DeepCollectionEquality()
                    .equals(other.isSuspended, isSuspended)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(isSuspended) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $TraxisResponseExtension on TraxisResponse {
  TraxisResponse copyWith(
      {bool? isSuspended,
      String? status,
      String? customerId,
      KrakenError? error}) {
    return TraxisResponse(
        isSuspended: isSuspended ?? this.isSuspended,
        status: status ?? this.status,
        customerId: customerId ?? this.customerId,
        error: error ?? this.error);
  }

  TraxisResponse copyWithWrapped(
      {Wrapped<bool?>? isSuspended,
      Wrapped<String?>? status,
      Wrapped<String?>? customerId,
      Wrapped<KrakenError?>? error}) {
    return TraxisResponse(
        isSuspended:
            (isSuspended != null ? isSuspended.value : this.isSuspended),
        status: (status != null ? status.value : this.status),
        customerId: (customerId != null ? customerId.value : this.customerId),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class VrmResponse {
  VrmResponse({
    this.status,
    this.customerId,
    this.quota,
    this.quotaType,
    this.disabled,
    this.error,
  });

  factory VrmResponse.fromJson(Map<String, dynamic> json) =>
      _$VrmResponseFromJson(json);

  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'quota', includeIfNull: false)
  final int? quota;
  @JsonKey(name: 'quotaType', includeIfNull: false, defaultValue: '')
  final String? quotaType;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool? disabled;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$VrmResponseFromJson;
  static const toJsonFactory = _$VrmResponseToJson;
  Map<String, dynamic> toJson() => _$VrmResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VrmResponse &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.quotaType, quotaType) ||
                const DeepCollectionEquality()
                    .equals(other.quotaType, quotaType)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(quotaType) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $VrmResponseExtension on VrmResponse {
  VrmResponse copyWith(
      {String? status,
      String? customerId,
      int? quota,
      String? quotaType,
      bool? disabled,
      KrakenError? error}) {
    return VrmResponse(
        status: status ?? this.status,
        customerId: customerId ?? this.customerId,
        quota: quota ?? this.quota,
        quotaType: quotaType ?? this.quotaType,
        disabled: disabled ?? this.disabled,
        error: error ?? this.error);
  }

  VrmResponse copyWithWrapped(
      {Wrapped<String?>? status,
      Wrapped<String?>? customerId,
      Wrapped<int?>? quota,
      Wrapped<String?>? quotaType,
      Wrapped<bool?>? disabled,
      Wrapped<KrakenError?>? error}) {
    return VrmResponse(
        status: (status != null ? status.value : this.status),
        customerId: (customerId != null ? customerId.value : this.customerId),
        quota: (quota != null ? quota.value : this.quota),
        quotaType: (quotaType != null ? quotaType.value : this.quotaType),
        disabled: (disabled != null ? disabled.value : this.disabled),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class VsppResponse {
  VsppResponse({
    this.status,
    this.customerId,
    this.quota,
    this.quotaType,
    this.cityId,
    this.error,
  });

  factory VsppResponse.fromJson(Map<String, dynamic> json) =>
      _$VsppResponseFromJson(json);

  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'quota', includeIfNull: false)
  final num? quota;
  @JsonKey(name: 'quotaType', includeIfNull: false, defaultValue: '')
  final String? quotaType;
  @JsonKey(name: 'cityId', includeIfNull: false, defaultValue: '')
  final String? cityId;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$VsppResponseFromJson;
  static const toJsonFactory = _$VsppResponseToJson;
  Map<String, dynamic> toJson() => _$VsppResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VsppResponse &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.quotaType, quotaType) ||
                const DeepCollectionEquality()
                    .equals(other.quotaType, quotaType)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(quotaType) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $VsppResponseExtension on VsppResponse {
  VsppResponse copyWith(
      {String? status,
      String? customerId,
      num? quota,
      String? quotaType,
      String? cityId,
      KrakenError? error}) {
    return VsppResponse(
        status: status ?? this.status,
        customerId: customerId ?? this.customerId,
        quota: quota ?? this.quota,
        quotaType: quotaType ?? this.quotaType,
        cityId: cityId ?? this.cityId,
        error: error ?? this.error);
  }

  VsppResponse copyWithWrapped(
      {Wrapped<String?>? status,
      Wrapped<String?>? customerId,
      Wrapped<num?>? quota,
      Wrapped<String?>? quotaType,
      Wrapped<String?>? cityId,
      Wrapped<KrakenError?>? error}) {
    return VsppResponse(
        status: (status != null ? status.value : this.status),
        customerId: (customerId != null ? customerId.value : this.customerId),
        quota: (quota != null ? quota.value : this.quota),
        quotaType: (quotaType != null ? quotaType.value : this.quotaType),
        cityId: (cityId != null ? cityId.value : this.cityId),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class GetCustomerRentalsResponse {
  GetCustomerRentalsResponse({
    this.purchaseService,
    this.error,
  });

  factory GetCustomerRentalsResponse.fromJson(Map<String, dynamic> json) =>
      _$GetCustomerRentalsResponseFromJson(json);

  @JsonKey(name: 'purchaseService', includeIfNull: false)
  final PurchaseServiceResponseForGetCustomer? purchaseService;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$GetCustomerRentalsResponseFromJson;
  static const toJsonFactory = _$GetCustomerRentalsResponseToJson;
  Map<String, dynamic> toJson() => _$GetCustomerRentalsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetCustomerRentalsResponse &&
            (identical(other.purchaseService, purchaseService) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseService, purchaseService)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(purchaseService) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $GetCustomerRentalsResponseExtension on GetCustomerRentalsResponse {
  GetCustomerRentalsResponse copyWith(
      {PurchaseServiceResponseForGetCustomer? purchaseService,
      KrakenError? error}) {
    return GetCustomerRentalsResponse(
        purchaseService: purchaseService ?? this.purchaseService,
        error: error ?? this.error);
  }

  GetCustomerRentalsResponse copyWithWrapped(
      {Wrapped<PurchaseServiceResponseForGetCustomer?>? purchaseService,
      Wrapped<KrakenError?>? error}) {
    return GetCustomerRentalsResponse(
        purchaseService: (purchaseService != null
            ? purchaseService.value
            : this.purchaseService),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseServiceResponseForGetCustomer {
  PurchaseServiceResponseForGetCustomer({
    this.rentals,
    this.error,
  });

  factory PurchaseServiceResponseForGetCustomer.fromJson(
          Map<String, dynamic> json) =>
      _$PurchaseServiceResponseForGetCustomerFromJson(json);

  @JsonKey(name: 'rentals', includeIfNull: false, defaultValue: <Rental>[])
  final List<Rental>? rentals;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory =
      _$PurchaseServiceResponseForGetCustomerFromJson;
  static const toJsonFactory = _$PurchaseServiceResponseForGetCustomerToJson;
  Map<String, dynamic> toJson() =>
      _$PurchaseServiceResponseForGetCustomerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseServiceResponseForGetCustomer &&
            (identical(other.rentals, rentals) ||
                const DeepCollectionEquality()
                    .equals(other.rentals, rentals)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rentals) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $PurchaseServiceResponseForGetCustomerExtension
    on PurchaseServiceResponseForGetCustomer {
  PurchaseServiceResponseForGetCustomer copyWith(
      {List<Rental>? rentals, KrakenError? error}) {
    return PurchaseServiceResponseForGetCustomer(
        rentals: rentals ?? this.rentals, error: error ?? this.error);
  }

  PurchaseServiceResponseForGetCustomer copyWithWrapped(
      {Wrapped<List<Rental>?>? rentals, Wrapped<KrakenError?>? error}) {
    return PurchaseServiceResponseForGetCustomer(
        rentals: (rentals != null ? rentals.value : this.rentals),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class Rental {
  Rental({
    this.purchaseDate,
    this.maxRes,
    this.languages,
    this.id,
    this.title,
    this.expiryDate,
    this.isAdult,
    this.price,
  });

  factory Rental.fromJson(Map<String, dynamic> json) => _$RentalFromJson(json);

  @JsonKey(name: 'purchaseDate', includeIfNull: false, defaultValue: '')
  final String? purchaseDate;
  @JsonKey(name: 'maxRes', includeIfNull: false, defaultValue: '')
  final String? maxRes;
  @JsonKey(name: 'languages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? languages;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'expiryDate', includeIfNull: false, defaultValue: '')
  final String? expiryDate;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  static const fromJsonFactory = _$RentalFromJson;
  static const toJsonFactory = _$RentalToJson;
  Map<String, dynamic> toJson() => _$RentalToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Rental &&
            (identical(other.purchaseDate, purchaseDate) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseDate, purchaseDate)) &&
            (identical(other.maxRes, maxRes) ||
                const DeepCollectionEquality().equals(other.maxRes, maxRes)) &&
            (identical(other.languages, languages) ||
                const DeepCollectionEquality()
                    .equals(other.languages, languages)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.expiryDate, expiryDate) ||
                const DeepCollectionEquality()
                    .equals(other.expiryDate, expiryDate)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(purchaseDate) ^
      const DeepCollectionEquality().hash(maxRes) ^
      const DeepCollectionEquality().hash(languages) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(expiryDate) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(price) ^
      runtimeType.hashCode;
}

extension $RentalExtension on Rental {
  Rental copyWith(
      {String? purchaseDate,
      String? maxRes,
      List<String>? languages,
      String? id,
      String? title,
      String? expiryDate,
      bool? isAdult,
      String? price}) {
    return Rental(
        purchaseDate: purchaseDate ?? this.purchaseDate,
        maxRes: maxRes ?? this.maxRes,
        languages: languages ?? this.languages,
        id: id ?? this.id,
        title: title ?? this.title,
        expiryDate: expiryDate ?? this.expiryDate,
        isAdult: isAdult ?? this.isAdult,
        price: price ?? this.price);
  }

  Rental copyWithWrapped(
      {Wrapped<String?>? purchaseDate,
      Wrapped<String?>? maxRes,
      Wrapped<List<String>?>? languages,
      Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? expiryDate,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? price}) {
    return Rental(
        purchaseDate:
            (purchaseDate != null ? purchaseDate.value : this.purchaseDate),
        maxRes: (maxRes != null ? maxRes.value : this.maxRes),
        languages: (languages != null ? languages.value : this.languages),
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        expiryDate: (expiryDate != null ? expiryDate.value : this.expiryDate),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        price: (price != null ? price.value : this.price));
  }
}

@JsonSerializable(explicitToJson: true)
class GetDeviceStatusResponse {
  GetDeviceStatusResponse({
    this.version,
    this.id,
    this.source,
    this.status,
    this.messageType,
  });

  factory GetDeviceStatusResponse.fromJson(Map<String, dynamic> json) =>
      _$GetDeviceStatusResponseFromJson(json);

  @JsonKey(name: 'version', includeIfNull: false)
  final int? version;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'source', includeIfNull: false, defaultValue: '')
  final String? source;
  @JsonKey(name: 'status', includeIfNull: false)
  final Map<String, dynamic>? status;
  @JsonKey(name: 'messageType', includeIfNull: false, defaultValue: '')
  final String? messageType;
  static const fromJsonFactory = _$GetDeviceStatusResponseFromJson;
  static const toJsonFactory = _$GetDeviceStatusResponseToJson;
  Map<String, dynamic> toJson() => _$GetDeviceStatusResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetDeviceStatusResponse &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.messageType, messageType) ||
                const DeepCollectionEquality()
                    .equals(other.messageType, messageType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(messageType) ^
      runtimeType.hashCode;
}

extension $GetDeviceStatusResponseExtension on GetDeviceStatusResponse {
  GetDeviceStatusResponse copyWith(
      {int? version,
      String? id,
      String? source,
      Map<String, dynamic>? status,
      String? messageType}) {
    return GetDeviceStatusResponse(
        version: version ?? this.version,
        id: id ?? this.id,
        source: source ?? this.source,
        status: status ?? this.status,
        messageType: messageType ?? this.messageType);
  }

  GetDeviceStatusResponse copyWithWrapped(
      {Wrapped<int?>? version,
      Wrapped<String?>? id,
      Wrapped<String?>? source,
      Wrapped<Map<String, dynamic>?>? status,
      Wrapped<String?>? messageType}) {
    return GetDeviceStatusResponse(
        version: (version != null ? version.value : this.version),
        id: (id != null ? id.value : this.id),
        source: (source != null ? source.value : this.source),
        status: (status != null ? status.value : this.status),
        messageType:
            (messageType != null ? messageType.value : this.messageType));
  }
}

@JsonSerializable(explicitToJson: true)
class GetDeviceStatusRequest {
  GetDeviceStatusRequest({
    this.id,
    this.request,
    this.messageType,
  });

  factory GetDeviceStatusRequest.fromJson(Map<String, dynamic> json) =>
      _$GetDeviceStatusRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'request', includeIfNull: false, defaultValue: <String>[])
  final List<String>? request;
  @JsonKey(name: 'messageType', includeIfNull: false, defaultValue: '')
  final String? messageType;
  static const fromJsonFactory = _$GetDeviceStatusRequestFromJson;
  static const toJsonFactory = _$GetDeviceStatusRequestToJson;
  Map<String, dynamic> toJson() => _$GetDeviceStatusRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetDeviceStatusRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.request, request) ||
                const DeepCollectionEquality()
                    .equals(other.request, request)) &&
            (identical(other.messageType, messageType) ||
                const DeepCollectionEquality()
                    .equals(other.messageType, messageType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(request) ^
      const DeepCollectionEquality().hash(messageType) ^
      runtimeType.hashCode;
}

extension $GetDeviceStatusRequestExtension on GetDeviceStatusRequest {
  GetDeviceStatusRequest copyWith(
      {String? id, List<String>? request, String? messageType}) {
    return GetDeviceStatusRequest(
        id: id ?? this.id,
        request: request ?? this.request,
        messageType: messageType ?? this.messageType);
  }

  GetDeviceStatusRequest copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<List<String>?>? request,
      Wrapped<String?>? messageType}) {
    return GetDeviceStatusRequest(
        id: (id != null ? id.value : this.id),
        request: (request != null ? request.value : this.request),
        messageType:
            (messageType != null ? messageType.value : this.messageType));
  }
}

@JsonSerializable(explicitToJson: true)
class RCUKeyPressRequest {
  RCUKeyPressRequest({
    this.eventType,
    this.id,
    this.deviceId,
    this.friendlyDeviceName,
    this.w3cKey,
  });

  factory RCUKeyPressRequest.fromJson(Map<String, dynamic> json) =>
      _$RCUKeyPressRequestFromJson(json);

  @JsonKey(name: 'eventType', includeIfNull: false, defaultValue: '')
  final String? eventType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'friendlyDeviceName', includeIfNull: false, defaultValue: '')
  final String? friendlyDeviceName;
  @JsonKey(name: 'w3cKey', includeIfNull: false, defaultValue: '')
  final String? w3cKey;
  static const fromJsonFactory = _$RCUKeyPressRequestFromJson;
  static const toJsonFactory = _$RCUKeyPressRequestToJson;
  Map<String, dynamic> toJson() => _$RCUKeyPressRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RCUKeyPressRequest &&
            (identical(other.eventType, eventType) ||
                const DeepCollectionEquality()
                    .equals(other.eventType, eventType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.friendlyDeviceName, friendlyDeviceName) ||
                const DeepCollectionEquality()
                    .equals(other.friendlyDeviceName, friendlyDeviceName)) &&
            (identical(other.w3cKey, w3cKey) ||
                const DeepCollectionEquality().equals(other.w3cKey, w3cKey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(friendlyDeviceName) ^
      const DeepCollectionEquality().hash(w3cKey) ^
      runtimeType.hashCode;
}

extension $RCUKeyPressRequestExtension on RCUKeyPressRequest {
  RCUKeyPressRequest copyWith(
      {String? eventType,
      String? id,
      String? deviceId,
      String? friendlyDeviceName,
      String? w3cKey}) {
    return RCUKeyPressRequest(
        eventType: eventType ?? this.eventType,
        id: id ?? this.id,
        deviceId: deviceId ?? this.deviceId,
        friendlyDeviceName: friendlyDeviceName ?? this.friendlyDeviceName,
        w3cKey: w3cKey ?? this.w3cKey);
  }

  RCUKeyPressRequest copyWithWrapped(
      {Wrapped<String?>? eventType,
      Wrapped<String?>? id,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? friendlyDeviceName,
      Wrapped<String?>? w3cKey}) {
    return RCUKeyPressRequest(
        eventType: (eventType != null ? eventType.value : this.eventType),
        id: (id != null ? id.value : this.id),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        friendlyDeviceName: (friendlyDeviceName != null
            ? friendlyDeviceName.value
            : this.friendlyDeviceName),
        w3cKey: (w3cKey != null ? w3cKey.value : this.w3cKey));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeCredentialResponse {
  CpeCredentialResponse({
    this.error,
    this.extSerialNumber,
    this.pairingDateTime,
  });

  factory CpeCredentialResponse.fromJson(Map<String, dynamic> json) =>
      _$CpeCredentialResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  @JsonKey(name: 'extSerialNumber', includeIfNull: false, defaultValue: '')
  final String? extSerialNumber;
  @JsonKey(name: 'pairingDateTime', includeIfNull: false, defaultValue: '')
  final String? pairingDateTime;
  static const fromJsonFactory = _$CpeCredentialResponseFromJson;
  static const toJsonFactory = _$CpeCredentialResponseToJson;
  Map<String, dynamic> toJson() => _$CpeCredentialResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeCredentialResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)) &&
            (identical(other.extSerialNumber, extSerialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.extSerialNumber, extSerialNumber)) &&
            (identical(other.pairingDateTime, pairingDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.pairingDateTime, pairingDateTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^
      const DeepCollectionEquality().hash(extSerialNumber) ^
      const DeepCollectionEquality().hash(pairingDateTime) ^
      runtimeType.hashCode;
}

extension $CpeCredentialResponseExtension on CpeCredentialResponse {
  CpeCredentialResponse copyWith(
      {KrakenError? error, String? extSerialNumber, String? pairingDateTime}) {
    return CpeCredentialResponse(
        error: error ?? this.error,
        extSerialNumber: extSerialNumber ?? this.extSerialNumber,
        pairingDateTime: pairingDateTime ?? this.pairingDateTime);
  }

  CpeCredentialResponse copyWithWrapped(
      {Wrapped<KrakenError?>? error,
      Wrapped<String?>? extSerialNumber,
      Wrapped<String?>? pairingDateTime}) {
    return CpeCredentialResponse(
        error: (error != null ? error.value : this.error),
        extSerialNumber: (extSerialNumber != null
            ? extSerialNumber.value
            : this.extSerialNumber),
        pairingDateTime: (pairingDateTime != null
            ? pairingDateTime.value
            : this.pairingDateTime));
  }
}

@JsonSerializable(explicitToJson: true)
class RcuReportEntry {
  RcuReportEntry({
    this.vendor,
    this.dateTime,
    this.userString,
    this.rcuType,
    this.appStackVersion,
    this.rfStackVersion,
    this.cpeId,
  });

  factory RcuReportEntry.fromJson(Map<String, dynamic> json) =>
      _$RcuReportEntryFromJson(json);

  @JsonKey(name: 'vendor', includeIfNull: false, defaultValue: '')
  final String? vendor;
  @JsonKey(name: 'dateTime', includeIfNull: false)
  final num? dateTime;
  @JsonKey(name: 'userString', includeIfNull: false, defaultValue: '')
  final String? userString;
  @JsonKey(name: 'rcuType', includeIfNull: false, defaultValue: '')
  final String? rcuType;
  @JsonKey(name: 'appStackVersion', includeIfNull: false, defaultValue: '')
  final String? appStackVersion;
  @JsonKey(name: 'rfStackVersion', includeIfNull: false, defaultValue: '')
  final String? rfStackVersion;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  static const fromJsonFactory = _$RcuReportEntryFromJson;
  static const toJsonFactory = _$RcuReportEntryToJson;
  Map<String, dynamic> toJson() => _$RcuReportEntryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RcuReportEntry &&
            (identical(other.vendor, vendor) ||
                const DeepCollectionEquality().equals(other.vendor, vendor)) &&
            (identical(other.dateTime, dateTime) ||
                const DeepCollectionEquality()
                    .equals(other.dateTime, dateTime)) &&
            (identical(other.userString, userString) ||
                const DeepCollectionEquality()
                    .equals(other.userString, userString)) &&
            (identical(other.rcuType, rcuType) ||
                const DeepCollectionEquality()
                    .equals(other.rcuType, rcuType)) &&
            (identical(other.appStackVersion, appStackVersion) ||
                const DeepCollectionEquality()
                    .equals(other.appStackVersion, appStackVersion)) &&
            (identical(other.rfStackVersion, rfStackVersion) ||
                const DeepCollectionEquality()
                    .equals(other.rfStackVersion, rfStackVersion)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(vendor) ^
      const DeepCollectionEquality().hash(dateTime) ^
      const DeepCollectionEquality().hash(userString) ^
      const DeepCollectionEquality().hash(rcuType) ^
      const DeepCollectionEquality().hash(appStackVersion) ^
      const DeepCollectionEquality().hash(rfStackVersion) ^
      const DeepCollectionEquality().hash(cpeId) ^
      runtimeType.hashCode;
}

extension $RcuReportEntryExtension on RcuReportEntry {
  RcuReportEntry copyWith(
      {String? vendor,
      num? dateTime,
      String? userString,
      String? rcuType,
      String? appStackVersion,
      String? rfStackVersion,
      String? cpeId}) {
    return RcuReportEntry(
        vendor: vendor ?? this.vendor,
        dateTime: dateTime ?? this.dateTime,
        userString: userString ?? this.userString,
        rcuType: rcuType ?? this.rcuType,
        appStackVersion: appStackVersion ?? this.appStackVersion,
        rfStackVersion: rfStackVersion ?? this.rfStackVersion,
        cpeId: cpeId ?? this.cpeId);
  }

  RcuReportEntry copyWithWrapped(
      {Wrapped<String?>? vendor,
      Wrapped<num?>? dateTime,
      Wrapped<String?>? userString,
      Wrapped<String?>? rcuType,
      Wrapped<String?>? appStackVersion,
      Wrapped<String?>? rfStackVersion,
      Wrapped<String?>? cpeId}) {
    return RcuReportEntry(
        vendor: (vendor != null ? vendor.value : this.vendor),
        dateTime: (dateTime != null ? dateTime.value : this.dateTime),
        userString: (userString != null ? userString.value : this.userString),
        rcuType: (rcuType != null ? rcuType.value : this.rcuType),
        appStackVersion: (appStackVersion != null
            ? appStackVersion.value
            : this.appStackVersion),
        rfStackVersion: (rfStackVersion != null
            ? rfStackVersion.value
            : this.rfStackVersion),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId));
  }
}

@JsonSerializable(explicitToJson: true)
class RcuReportResponse {
  RcuReportResponse({
    this.error,
    this.rCUReport,
  });

  factory RcuReportResponse.fromJson(Map<String, dynamic> json) =>
      _$RcuReportResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  @JsonKey(
      name: 'RCUReport', includeIfNull: false, defaultValue: <RcuReportEntry>[])
  final List<RcuReportEntry>? rCUReport;
  static const fromJsonFactory = _$RcuReportResponseFromJson;
  static const toJsonFactory = _$RcuReportResponseToJson;
  Map<String, dynamic> toJson() => _$RcuReportResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RcuReportResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)) &&
            (identical(other.rCUReport, rCUReport) ||
                const DeepCollectionEquality()
                    .equals(other.rCUReport, rCUReport)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^
      const DeepCollectionEquality().hash(rCUReport) ^
      runtimeType.hashCode;
}

extension $RcuReportResponseExtension on RcuReportResponse {
  RcuReportResponse copyWith(
      {KrakenError? error, List<RcuReportEntry>? rCUReport}) {
    return RcuReportResponse(
        error: error ?? this.error, rCUReport: rCUReport ?? this.rCUReport);
  }

  RcuReportResponse copyWithWrapped(
      {Wrapped<KrakenError?>? error,
      Wrapped<List<RcuReportEntry>?>? rCUReport}) {
    return RcuReportResponse(
        error: (error != null ? error.value : this.error),
        rCUReport: (rCUReport != null ? rCUReport.value : this.rCUReport));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerFacingErrorEntry {
  CustomerFacingErrorEntry({
    this.dateTime,
    this.errorCode,
  });

  factory CustomerFacingErrorEntry.fromJson(Map<String, dynamic> json) =>
      _$CustomerFacingErrorEntryFromJson(json);

  @JsonKey(name: 'dateTime', includeIfNull: false)
  final num? dateTime;
  @JsonKey(name: 'errorCode', includeIfNull: false, defaultValue: '')
  final String? errorCode;
  static const fromJsonFactory = _$CustomerFacingErrorEntryFromJson;
  static const toJsonFactory = _$CustomerFacingErrorEntryToJson;
  Map<String, dynamic> toJson() => _$CustomerFacingErrorEntryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerFacingErrorEntry &&
            (identical(other.dateTime, dateTime) ||
                const DeepCollectionEquality()
                    .equals(other.dateTime, dateTime)) &&
            (identical(other.errorCode, errorCode) ||
                const DeepCollectionEquality()
                    .equals(other.errorCode, errorCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(dateTime) ^
      const DeepCollectionEquality().hash(errorCode) ^
      runtimeType.hashCode;
}

extension $CustomerFacingErrorEntryExtension on CustomerFacingErrorEntry {
  CustomerFacingErrorEntry copyWith({num? dateTime, String? errorCode}) {
    return CustomerFacingErrorEntry(
        dateTime: dateTime ?? this.dateTime,
        errorCode: errorCode ?? this.errorCode);
  }

  CustomerFacingErrorEntry copyWithWrapped(
      {Wrapped<num?>? dateTime, Wrapped<String?>? errorCode}) {
    return CustomerFacingErrorEntry(
        dateTime: (dateTime != null ? dateTime.value : this.dateTime),
        errorCode: (errorCode != null ? errorCode.value : this.errorCode));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerFacingErrorResponse {
  CustomerFacingErrorResponse({
    this.error,
    this.customerFacingErrors,
  });

  factory CustomerFacingErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$CustomerFacingErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  @JsonKey(
      name: 'customerFacingErrors',
      includeIfNull: false,
      defaultValue: <CustomerFacingErrorEntry>[])
  final List<CustomerFacingErrorEntry>? customerFacingErrors;
  static const fromJsonFactory = _$CustomerFacingErrorResponseFromJson;
  static const toJsonFactory = _$CustomerFacingErrorResponseToJson;
  Map<String, dynamic> toJson() => _$CustomerFacingErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerFacingErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)) &&
            (identical(other.customerFacingErrors, customerFacingErrors) ||
                const DeepCollectionEquality()
                    .equals(other.customerFacingErrors, customerFacingErrors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^
      const DeepCollectionEquality().hash(customerFacingErrors) ^
      runtimeType.hashCode;
}

extension $CustomerFacingErrorResponseExtension on CustomerFacingErrorResponse {
  CustomerFacingErrorResponse copyWith(
      {KrakenError? error,
      List<CustomerFacingErrorEntry>? customerFacingErrors}) {
    return CustomerFacingErrorResponse(
        error: error ?? this.error,
        customerFacingErrors:
            customerFacingErrors ?? this.customerFacingErrors);
  }

  CustomerFacingErrorResponse copyWithWrapped(
      {Wrapped<KrakenError?>? error,
      Wrapped<List<CustomerFacingErrorEntry>?>? customerFacingErrors}) {
    return CustomerFacingErrorResponse(
        error: (error != null ? error.value : this.error),
        customerFacingErrors: (customerFacingErrors != null
            ? customerFacingErrors.value
            : this.customerFacingErrors));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseReport {
  PurchaseReport({
    this.eventType,
    this.customerId,
    this.deviceId,
    this.reportDate,
    this.productId,
    this.eventInfo,
    this.price,
    this.productType,
    this.transactionId,
    this.productTitle,
    this.rentalPeriod,
    this.assetTitle,
  });

  factory PurchaseReport.fromJson(Map<String, dynamic> json) =>
      _$PurchaseReportFromJson(json);

  @JsonKey(name: 'eventType', includeIfNull: false, defaultValue: '')
  final String? eventType;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'reportDate', includeIfNull: false)
  final num? reportDate;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String? productId;
  @JsonKey(name: 'eventInfo', includeIfNull: false, defaultValue: '')
  final String? eventInfo;
  @JsonKey(name: 'price', includeIfNull: false, defaultValue: '')
  final String? price;
  @JsonKey(name: 'productType', includeIfNull: false, defaultValue: '')
  final String? productType;
  @JsonKey(name: 'transactionId', includeIfNull: false, defaultValue: '')
  final String? transactionId;
  @JsonKey(name: 'productTitle', includeIfNull: false, defaultValue: '')
  final String? productTitle;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'assetTitle', includeIfNull: false, defaultValue: <String>[])
  final List<String>? assetTitle;
  static const fromJsonFactory = _$PurchaseReportFromJson;
  static const toJsonFactory = _$PurchaseReportToJson;
  Map<String, dynamic> toJson() => _$PurchaseReportToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseReport &&
            (identical(other.eventType, eventType) ||
                const DeepCollectionEquality()
                    .equals(other.eventType, eventType)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.reportDate, reportDate) ||
                const DeepCollectionEquality()
                    .equals(other.reportDate, reportDate)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.eventInfo, eventInfo) ||
                const DeepCollectionEquality()
                    .equals(other.eventInfo, eventInfo)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.productType, productType) ||
                const DeepCollectionEquality()
                    .equals(other.productType, productType)) &&
            (identical(other.transactionId, transactionId) ||
                const DeepCollectionEquality()
                    .equals(other.transactionId, transactionId)) &&
            (identical(other.productTitle, productTitle) ||
                const DeepCollectionEquality()
                    .equals(other.productTitle, productTitle)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.assetTitle, assetTitle) ||
                const DeepCollectionEquality()
                    .equals(other.assetTitle, assetTitle)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventType) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(reportDate) ^
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(eventInfo) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(transactionId) ^
      const DeepCollectionEquality().hash(productTitle) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(assetTitle) ^
      runtimeType.hashCode;
}

extension $PurchaseReportExtension on PurchaseReport {
  PurchaseReport copyWith(
      {String? eventType,
      String? customerId,
      String? deviceId,
      num? reportDate,
      String? productId,
      String? eventInfo,
      String? price,
      String? productType,
      String? transactionId,
      String? productTitle,
      String? rentalPeriod,
      List<String>? assetTitle}) {
    return PurchaseReport(
        eventType: eventType ?? this.eventType,
        customerId: customerId ?? this.customerId,
        deviceId: deviceId ?? this.deviceId,
        reportDate: reportDate ?? this.reportDate,
        productId: productId ?? this.productId,
        eventInfo: eventInfo ?? this.eventInfo,
        price: price ?? this.price,
        productType: productType ?? this.productType,
        transactionId: transactionId ?? this.transactionId,
        productTitle: productTitle ?? this.productTitle,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        assetTitle: assetTitle ?? this.assetTitle);
  }

  PurchaseReport copyWithWrapped(
      {Wrapped<String?>? eventType,
      Wrapped<String?>? customerId,
      Wrapped<String?>? deviceId,
      Wrapped<num?>? reportDate,
      Wrapped<String?>? productId,
      Wrapped<String?>? eventInfo,
      Wrapped<String?>? price,
      Wrapped<String?>? productType,
      Wrapped<String?>? transactionId,
      Wrapped<String?>? productTitle,
      Wrapped<String?>? rentalPeriod,
      Wrapped<List<String>?>? assetTitle}) {
    return PurchaseReport(
        eventType: (eventType != null ? eventType.value : this.eventType),
        customerId: (customerId != null ? customerId.value : this.customerId),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        reportDate: (reportDate != null ? reportDate.value : this.reportDate),
        productId: (productId != null ? productId.value : this.productId),
        eventInfo: (eventInfo != null ? eventInfo.value : this.eventInfo),
        price: (price != null ? price.value : this.price),
        productType:
            (productType != null ? productType.value : this.productType),
        transactionId:
            (transactionId != null ? transactionId.value : this.transactionId),
        productTitle:
            (productTitle != null ? productTitle.value : this.productTitle),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        assetTitle: (assetTitle != null ? assetTitle.value : this.assetTitle));
  }
}

@JsonSerializable(explicitToJson: true)
class PurchaseReportResponse {
  PurchaseReportResponse({
    required this.purchaseReport,
  });

  factory PurchaseReportResponse.fromJson(Map<String, dynamic> json) =>
      _$PurchaseReportResponseFromJson(json);

  @JsonKey(
      name: 'purchaseReport',
      includeIfNull: false,
      defaultValue: <PurchaseReport>[])
  final List<PurchaseReport> purchaseReport;
  static const fromJsonFactory = _$PurchaseReportResponseFromJson;
  static const toJsonFactory = _$PurchaseReportResponseToJson;
  Map<String, dynamic> toJson() => _$PurchaseReportResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PurchaseReportResponse &&
            (identical(other.purchaseReport, purchaseReport) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseReport, purchaseReport)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(purchaseReport) ^
      runtimeType.hashCode;
}

extension $PurchaseReportResponseExtension on PurchaseReportResponse {
  PurchaseReportResponse copyWith({List<PurchaseReport>? purchaseReport}) {
    return PurchaseReportResponse(
        purchaseReport: purchaseReport ?? this.purchaseReport);
  }

  PurchaseReportResponse copyWithWrapped(
      {Wrapped<List<PurchaseReport>>? purchaseReport}) {
    return PurchaseReportResponse(
        purchaseReport: (purchaseReport != null
            ? purchaseReport.value
            : this.purchaseReport));
  }
}

@JsonSerializable(explicitToJson: true)
class GetCustomerRecordingsResponseV2 {
  GetCustomerRecordingsResponseV2({
    this.recordingService,
    this.error,
  });

  factory GetCustomerRecordingsResponseV2.fromJson(Map<String, dynamic> json) =>
      _$GetCustomerRecordingsResponseV2FromJson(json);

  @JsonKey(name: 'recordingService', includeIfNull: false)
  final RecordingServiceResponseV2? recordingService;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$GetCustomerRecordingsResponseV2FromJson;
  static const toJsonFactory = _$GetCustomerRecordingsResponseV2ToJson;
  Map<String, dynamic> toJson() =>
      _$GetCustomerRecordingsResponseV2ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetCustomerRecordingsResponseV2 &&
            (identical(other.recordingService, recordingService) ||
                const DeepCollectionEquality()
                    .equals(other.recordingService, recordingService)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordingService) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $GetCustomerRecordingsResponseV2Extension
    on GetCustomerRecordingsResponseV2 {
  GetCustomerRecordingsResponseV2 copyWith(
      {RecordingServiceResponseV2? recordingService, KrakenError? error}) {
    return GetCustomerRecordingsResponseV2(
        recordingService: recordingService ?? this.recordingService,
        error: error ?? this.error);
  }

  GetCustomerRecordingsResponseV2 copyWithWrapped(
      {Wrapped<RecordingServiceResponseV2?>? recordingService,
      Wrapped<KrakenError?>? error}) {
    return GetCustomerRecordingsResponseV2(
        recordingService: (recordingService != null
            ? recordingService.value
            : this.recordingService),
        error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingResponseV2 {
  RecordingResponseV2({
    this.startTime,
    this.endTime,
    this.id,
    this.title,
    this.channelId,
    this.source,
    this.eventId,
    this.isAdult,
    this.expirationDate,
    this.recordingState,
    this.showId,
    this.cpeId,
    this.recStartTime,
    this.recEndTime,
    this.originDeviceId,
    this.failureReason,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.seasonNumber,
    this.episodeNumber,
    this.seasonName,
    this.showName,
    this.bookingTime,
  });

  factory RecordingResponseV2.fromJson(Map<String, dynamic> json) =>
      _$RecordingResponseV2FromJson(json);

  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'source', includeIfNull: false, defaultValue: '')
  final String? source;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'expirationDate', includeIfNull: false, defaultValue: '')
  final String? expirationDate;
  @JsonKey(name: 'recordingState', includeIfNull: false, defaultValue: '')
  final String? recordingState;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'recStartTime', includeIfNull: false, defaultValue: '')
  final String? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false, defaultValue: '')
  final String? recEndTime;
  @JsonKey(name: 'originDeviceId', includeIfNull: false, defaultValue: '')
  final String? originDeviceId;
  @JsonKey(name: 'failureReason', includeIfNull: false, defaultValue: '')
  final String? failureReason;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'bookingTime', includeIfNull: false, defaultValue: '')
  final String? bookingTime;
  static const fromJsonFactory = _$RecordingResponseV2FromJson;
  static const toJsonFactory = _$RecordingResponseV2ToJson;
  Map<String, dynamic> toJson() => _$RecordingResponseV2ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingResponseV2 &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.originDeviceId, originDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceId, originDeviceId)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality()
                    .equals(other.showName, showName)) &&
            (identical(other.bookingTime, bookingTime) ||
                const DeepCollectionEquality()
                    .equals(other.bookingTime, bookingTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(originDeviceId) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      runtimeType.hashCode;
}

extension $RecordingResponseV2Extension on RecordingResponseV2 {
  RecordingResponseV2 copyWith(
      {String? startTime,
      String? endTime,
      String? id,
      String? title,
      String? channelId,
      String? source,
      String? eventId,
      bool? isAdult,
      String? expirationDate,
      String? recordingState,
      String? showId,
      String? cpeId,
      String? recStartTime,
      String? recEndTime,
      String? originDeviceId,
      String? failureReason,
      int? prePaddingOffset,
      int? postPaddingOffset,
      int? seasonNumber,
      int? episodeNumber,
      String? seasonName,
      String? showName,
      String? bookingTime}) {
    return RecordingResponseV2(
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        id: id ?? this.id,
        title: title ?? this.title,
        channelId: channelId ?? this.channelId,
        source: source ?? this.source,
        eventId: eventId ?? this.eventId,
        isAdult: isAdult ?? this.isAdult,
        expirationDate: expirationDate ?? this.expirationDate,
        recordingState: recordingState ?? this.recordingState,
        showId: showId ?? this.showId,
        cpeId: cpeId ?? this.cpeId,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        originDeviceId: originDeviceId ?? this.originDeviceId,
        failureReason: failureReason ?? this.failureReason,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonName: seasonName ?? this.seasonName,
        showName: showName ?? this.showName,
        bookingTime: bookingTime ?? this.bookingTime);
  }

  RecordingResponseV2 copyWithWrapped(
      {Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? channelId,
      Wrapped<String?>? source,
      Wrapped<String?>? eventId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? expirationDate,
      Wrapped<String?>? recordingState,
      Wrapped<String?>? showId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? recStartTime,
      Wrapped<String?>? recEndTime,
      Wrapped<String?>? originDeviceId,
      Wrapped<String?>? failureReason,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? seasonName,
      Wrapped<String?>? showName,
      Wrapped<String?>? bookingTime}) {
    return RecordingResponseV2(
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        channelId: (channelId != null ? channelId.value : this.channelId),
        source: (source != null ? source.value : this.source),
        eventId: (eventId != null ? eventId.value : this.eventId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        showId: (showId != null ? showId.value : this.showId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        originDeviceId: (originDeviceId != null
            ? originDeviceId.value
            : this.originDeviceId),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        showName: (showName != null ? showName.value : this.showName),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingServiceResponseV2 {
  RecordingServiceResponseV2({
    this.size,
    this.total,
    this.quota,
    this.occupied,
    this.isAdultContentAvailable,
    this.data,
    this.error,
  });

  factory RecordingServiceResponseV2.fromJson(Map<String, dynamic> json) =>
      _$RecordingServiceResponseV2FromJson(json);

  @JsonKey(name: 'size', includeIfNull: false)
  final int? size;
  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'quota', includeIfNull: false)
  final int? quota;
  @JsonKey(name: 'occupied', includeIfNull: false)
  final int? occupied;
  @JsonKey(name: 'isAdultContentAvailable', includeIfNull: false)
  final bool? isAdultContentAvailable;
  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <RecordingResponseV2>[])
  final List<RecordingResponseV2>? data;
  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$RecordingServiceResponseV2FromJson;
  static const toJsonFactory = _$RecordingServiceResponseV2ToJson;
  Map<String, dynamic> toJson() => _$RecordingServiceResponseV2ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingServiceResponseV2 &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.occupied, occupied) ||
                const DeepCollectionEquality()
                    .equals(other.occupied, occupied)) &&
            (identical(
                    other.isAdultContentAvailable, isAdultContentAvailable) ||
                const DeepCollectionEquality().equals(
                    other.isAdultContentAvailable, isAdultContentAvailable)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(occupied) ^
      const DeepCollectionEquality().hash(isAdultContentAvailable) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(error) ^
      runtimeType.hashCode;
}

extension $RecordingServiceResponseV2Extension on RecordingServiceResponseV2 {
  RecordingServiceResponseV2 copyWith(
      {int? size,
      int? total,
      int? quota,
      int? occupied,
      bool? isAdultContentAvailable,
      List<RecordingResponseV2>? data,
      KrakenError? error}) {
    return RecordingServiceResponseV2(
        size: size ?? this.size,
        total: total ?? this.total,
        quota: quota ?? this.quota,
        occupied: occupied ?? this.occupied,
        isAdultContentAvailable:
            isAdultContentAvailable ?? this.isAdultContentAvailable,
        data: data ?? this.data,
        error: error ?? this.error);
  }

  RecordingServiceResponseV2 copyWithWrapped(
      {Wrapped<int?>? size,
      Wrapped<int?>? total,
      Wrapped<int?>? quota,
      Wrapped<int?>? occupied,
      Wrapped<bool?>? isAdultContentAvailable,
      Wrapped<List<RecordingResponseV2>?>? data,
      Wrapped<KrakenError?>? error}) {
    return RecordingServiceResponseV2(
        size: (size != null ? size.value : this.size),
        total: (total != null ? total.value : this.total),
        quota: (quota != null ? quota.value : this.quota),
        occupied: (occupied != null ? occupied.value : this.occupied),
        isAdultContentAvailable: (isAdultContentAvailable != null
            ? isAdultContentAvailable.value
            : this.isAdultContentAvailable),
        data: (data != null ? data.value : this.data),
        error: (error != null ? error.value : this.error));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
