// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_key_wrapping_service.swagger.chopper.dart';
part 'liberty_key_wrapping_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyKeyWrappingService extends ChopperService {
  static LibertyKeyWrappingService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyKeyWrappingService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyKeyWrappingService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyKeyWrappingService(newClient);
  }

  ///Shows the caches
  Future<chopper.Response<String>> cachesGet({String? cacheControl}) {
    return _cachesGet(cacheControl: cacheControl);
  }

  ///Shows the caches
  @Get(path: '/caches')
  Future<chopper.Response<String>> _cachesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Shows the specified cache
  ///@param cacheName The cache name
  ///@param filter filter on key
  ///@param maxResults the maximum number of results
  Future<chopper.Response<String>> cachesCacheNameGet({
    required String? cacheName,
    String? filter,
    int? maxResults,
    String? cacheControl,
  }) {
    return _cachesCacheNameGet(
        cacheName: cacheName,
        filter: filter,
        maxResults: maxResults,
        cacheControl: cacheControl);
  }

  ///Shows the specified cache
  ///@param cacheName The cache name
  ///@param filter filter on key
  ///@param maxResults the maximum number of results
  @Get(path: '/caches/{cacheName}')
  Future<chopper.Response<String>> _cachesCacheNameGet({
    @Path('cacheName') required String? cacheName,
    @Query('filter') String? filter,
    @Query('maxResults') int? maxResults,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Clears all the items
  ///@param cacheName The cache name
  Future<chopper.Response<String>> cachesCacheNameClearAllPost({
    required String? cacheName,
    String? cacheControl,
  }) {
    return _cachesCacheNameClearAllPost(
        cacheName: cacheName, cacheControl: cacheControl);
  }

  ///Clears all the items
  ///@param cacheName The cache name
  @Post(
    path: '/caches/{cacheName}/clearAll',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _cachesCacheNameClearAllPost({
    @Path('cacheName') required String? cacheName,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Removes the item from the cache
  ///@param cacheName The cache name
  ///@param body The url encoded key
  Future<chopper.Response<String>> cachesCacheNameClearItemPost({
    required String? cacheName,
    required String? body,
    String? cacheControl,
  }) {
    return _cachesCacheNameClearItemPost(
        cacheName: cacheName, body: body, cacheControl: cacheControl);
  }

  ///Removes the item from the cache
  ///@param cacheName The cache name
  ///@param body The url encoded key
  @Post(path: '/caches/{cacheName}/clearItem')
  Future<chopper.Response<String>> _cachesCacheNameClearItemPost({
    @Path('cacheName') required String? cacheName,
    @Body() required String? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves the item from the cache
  ///@param cacheName The cache name
  ///@param key The key
  Future<chopper.Response<String>> cachesCacheNameViewItemPost({
    required String? cacheName,
    required String? key,
    String? cacheControl,
  }) {
    return _cachesCacheNameViewItemPost(
        cacheName: cacheName, key: key, cacheControl: cacheControl);
  }

  ///Retrieves the item from the cache
  ///@param cacheName The cache name
  ///@param key The key
  @Post(
    path: '/caches/{cacheName}/viewItem',
    optionalBody: true,
  )
  Future<chopper.Response<String>> _cachesCacheNameViewItemPost({
    @Path('cacheName') required String? cacheName,
    @Field('key') required String? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///get clear and encrypted key and signalization for content encryption
  ///@param body
  ///@param X-Cus
  Future<chopper.Response<KeyAndSignalizationResponse>>
      getKeyAndSignalizationPost({
    PostGetKeyAndSignalizationRequest? body,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PostGetKeyAndSignalizationRequest,
        () => PostGetKeyAndSignalizationRequest.fromJsonFactory);
    generatedMapping.putIfAbsent(KeyAndSignalizationResponse,
        () => KeyAndSignalizationResponse.fromJsonFactory);

    return _getKeyAndSignalizationPost(
        body: body, xCus: xCus, cacheControl: cacheControl);
  }

  ///get clear and encrypted key and signalization for content encryption
  ///@param body
  ///@param X-Cus
  @Post(path: '/getKeyAndSignalization')
  Future<chopper.Response<KeyAndSignalizationResponse>>
      _getKeyAndSignalizationPost({
    @Body() PostGetKeyAndSignalizationRequest? body,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class EncryptedContentKey {
  EncryptedContentKey({
    this.procin3,
    this.procin4,
  });

  factory EncryptedContentKey.fromJson(Map<String, dynamic> json) =>
      _$EncryptedContentKeyFromJson(json);

  @JsonKey(name: 'procin3', includeIfNull: false, defaultValue: '')
  final String? procin3;
  @JsonKey(name: 'procin4', includeIfNull: false, defaultValue: '')
  final String? procin4;
  static const fromJsonFactory = _$EncryptedContentKeyFromJson;
  static const toJsonFactory = _$EncryptedContentKeyToJson;
  Map<String, dynamic> toJson() => _$EncryptedContentKeyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EncryptedContentKey &&
            (identical(other.procin3, procin3) ||
                const DeepCollectionEquality()
                    .equals(other.procin3, procin3)) &&
            (identical(other.procin4, procin4) ||
                const DeepCollectionEquality().equals(other.procin4, procin4)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(procin3) ^
      const DeepCollectionEquality().hash(procin4) ^
      runtimeType.hashCode;
}

extension $EncryptedContentKeyExtension on EncryptedContentKey {
  EncryptedContentKey copyWith({String? procin3, String? procin4}) {
    return EncryptedContentKey(
        procin3: procin3 ?? this.procin3, procin4: procin4 ?? this.procin4);
  }

  EncryptedContentKey copyWithWrapped(
      {Wrapped<String?>? procin3, Wrapped<String?>? procin4}) {
    return EncryptedContentKey(
        procin3: (procin3 != null ? procin3.value : this.procin3),
        procin4: (procin4 != null ? procin4.value : this.procin4));
  }
}

@JsonSerializable(explicitToJson: true)
class Fairplay {
  Fairplay({
    this.iv,
    this.hlsextxkey,
  });

  factory Fairplay.fromJson(Map<String, dynamic> json) =>
      _$FairplayFromJson(json);

  @JsonKey(name: 'IV', includeIfNull: false, defaultValue: '')
  final String? iv;
  @JsonKey(name: 'HLS_EXT-X-KEY', includeIfNull: false, defaultValue: '')
  final String? hlsextxkey;
  static const fromJsonFactory = _$FairplayFromJson;
  static const toJsonFactory = _$FairplayToJson;
  Map<String, dynamic> toJson() => _$FairplayToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Fairplay &&
            (identical(other.iv, iv) ||
                const DeepCollectionEquality().equals(other.iv, iv)) &&
            (identical(other.hlsextxkey, hlsextxkey) ||
                const DeepCollectionEquality()
                    .equals(other.hlsextxkey, hlsextxkey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(iv) ^
      const DeepCollectionEquality().hash(hlsextxkey) ^
      runtimeType.hashCode;
}

extension $FairplayExtension on Fairplay {
  Fairplay copyWith({String? iv, String? hlsextxkey}) {
    return Fairplay(
        iv: iv ?? this.iv, hlsextxkey: hlsextxkey ?? this.hlsextxkey);
  }

  Fairplay copyWithWrapped(
      {Wrapped<String?>? iv, Wrapped<String?>? hlsextxkey}) {
    return Fairplay(
        iv: (iv != null ? iv.value : this.iv),
        hlsextxkey: (hlsextxkey != null ? hlsextxkey.value : this.hlsextxkey));
  }
}

@JsonSerializable(explicitToJson: true)
class KeyAndSignalizationResponse {
  KeyAndSignalizationResponse({
    this.signalization,
    this.clearContentKey,
    this.encryptedContentKey,
  });

  factory KeyAndSignalizationResponse.fromJson(Map<String, dynamic> json) =>
      _$KeyAndSignalizationResponseFromJson(json);

  @JsonKey(name: 'signalization', includeIfNull: false)
  final SignalizationRoot? signalization;
  @JsonKey(name: 'clearContentKey', includeIfNull: false, defaultValue: '')
  final String? clearContentKey;
  @JsonKey(name: 'encryptedContentKey', includeIfNull: false)
  final EncryptedContentKey? encryptedContentKey;
  static const fromJsonFactory = _$KeyAndSignalizationResponseFromJson;
  static const toJsonFactory = _$KeyAndSignalizationResponseToJson;
  Map<String, dynamic> toJson() => _$KeyAndSignalizationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KeyAndSignalizationResponse &&
            (identical(other.signalization, signalization) ||
                const DeepCollectionEquality()
                    .equals(other.signalization, signalization)) &&
            (identical(other.clearContentKey, clearContentKey) ||
                const DeepCollectionEquality()
                    .equals(other.clearContentKey, clearContentKey)) &&
            (identical(other.encryptedContentKey, encryptedContentKey) ||
                const DeepCollectionEquality()
                    .equals(other.encryptedContentKey, encryptedContentKey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(signalization) ^
      const DeepCollectionEquality().hash(clearContentKey) ^
      const DeepCollectionEquality().hash(encryptedContentKey) ^
      runtimeType.hashCode;
}

extension $KeyAndSignalizationResponseExtension on KeyAndSignalizationResponse {
  KeyAndSignalizationResponse copyWith(
      {SignalizationRoot? signalization,
      String? clearContentKey,
      EncryptedContentKey? encryptedContentKey}) {
    return KeyAndSignalizationResponse(
        signalization: signalization ?? this.signalization,
        clearContentKey: clearContentKey ?? this.clearContentKey,
        encryptedContentKey: encryptedContentKey ?? this.encryptedContentKey);
  }

  KeyAndSignalizationResponse copyWithWrapped(
      {Wrapped<SignalizationRoot?>? signalization,
      Wrapped<String?>? clearContentKey,
      Wrapped<EncryptedContentKey?>? encryptedContentKey}) {
    return KeyAndSignalizationResponse(
        signalization:
            (signalization != null ? signalization.value : this.signalization),
        clearContentKey: (clearContentKey != null
            ? clearContentKey.value
            : this.clearContentKey),
        encryptedContentKey: (encryptedContentKey != null
            ? encryptedContentKey.value
            : this.encryptedContentKey));
  }
}

@JsonSerializable(explicitToJson: true)
class Playready {
  Playready({
    this.iv,
    this.pssh,
  });

  factory Playready.fromJson(Map<String, dynamic> json) =>
      _$PlayreadyFromJson(json);

  @JsonKey(name: 'IV', includeIfNull: false, defaultValue: '')
  final String? iv;
  @JsonKey(name: 'PSSH', includeIfNull: false, defaultValue: '')
  final String? pssh;
  static const fromJsonFactory = _$PlayreadyFromJson;
  static const toJsonFactory = _$PlayreadyToJson;
  Map<String, dynamic> toJson() => _$PlayreadyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Playready &&
            (identical(other.iv, iv) ||
                const DeepCollectionEquality().equals(other.iv, iv)) &&
            (identical(other.pssh, pssh) ||
                const DeepCollectionEquality().equals(other.pssh, pssh)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(iv) ^
      const DeepCollectionEquality().hash(pssh) ^
      runtimeType.hashCode;
}

extension $PlayreadyExtension on Playready {
  Playready copyWith({String? iv, String? pssh}) {
    return Playready(iv: iv ?? this.iv, pssh: pssh ?? this.pssh);
  }

  Playready copyWithWrapped({Wrapped<String?>? iv, Wrapped<String?>? pssh}) {
    return Playready(
        iv: (iv != null ? iv.value : this.iv),
        pssh: (pssh != null ? pssh.value : this.pssh));
  }
}

@JsonSerializable(explicitToJson: true)
class SignalizationRoot {
  SignalizationRoot({
    this.fairplay,
    this.playready,
    this.widevine,
  });

  factory SignalizationRoot.fromJson(Map<String, dynamic> json) =>
      _$SignalizationRootFromJson(json);

  @JsonKey(name: 'fairplay', includeIfNull: false)
  final Fairplay? fairplay;
  @JsonKey(name: 'playready', includeIfNull: false)
  final Playready? playready;
  @JsonKey(name: 'widevine', includeIfNull: false)
  final Widevine? widevine;
  static const fromJsonFactory = _$SignalizationRootFromJson;
  static const toJsonFactory = _$SignalizationRootToJson;
  Map<String, dynamic> toJson() => _$SignalizationRootToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SignalizationRoot &&
            (identical(other.fairplay, fairplay) ||
                const DeepCollectionEquality()
                    .equals(other.fairplay, fairplay)) &&
            (identical(other.playready, playready) ||
                const DeepCollectionEquality()
                    .equals(other.playready, playready)) &&
            (identical(other.widevine, widevine) ||
                const DeepCollectionEquality()
                    .equals(other.widevine, widevine)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(fairplay) ^
      const DeepCollectionEquality().hash(playready) ^
      const DeepCollectionEquality().hash(widevine) ^
      runtimeType.hashCode;
}

extension $SignalizationRootExtension on SignalizationRoot {
  SignalizationRoot copyWith(
      {Fairplay? fairplay, Playready? playready, Widevine? widevine}) {
    return SignalizationRoot(
        fairplay: fairplay ?? this.fairplay,
        playready: playready ?? this.playready,
        widevine: widevine ?? this.widevine);
  }

  SignalizationRoot copyWithWrapped(
      {Wrapped<Fairplay?>? fairplay,
      Wrapped<Playready?>? playready,
      Wrapped<Widevine?>? widevine}) {
    return SignalizationRoot(
        fairplay: (fairplay != null ? fairplay.value : this.fairplay),
        playready: (playready != null ? playready.value : this.playready),
        widevine: (widevine != null ? widevine.value : this.widevine));
  }
}

@JsonSerializable(explicitToJson: true)
class Widevine {
  Widevine({
    this.iv,
    this.pssh,
  });

  factory Widevine.fromJson(Map<String, dynamic> json) =>
      _$WidevineFromJson(json);

  @JsonKey(name: 'IV', includeIfNull: false, defaultValue: '')
  final String? iv;
  @JsonKey(name: 'PSSH', includeIfNull: false, defaultValue: '')
  final String? pssh;
  static const fromJsonFactory = _$WidevineFromJson;
  static const toJsonFactory = _$WidevineToJson;
  Map<String, dynamic> toJson() => _$WidevineToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Widevine &&
            (identical(other.iv, iv) ||
                const DeepCollectionEquality().equals(other.iv, iv)) &&
            (identical(other.pssh, pssh) ||
                const DeepCollectionEquality().equals(other.pssh, pssh)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(iv) ^
      const DeepCollectionEquality().hash(pssh) ^
      runtimeType.hashCode;
}

extension $WidevineExtension on Widevine {
  Widevine copyWith({String? iv, String? pssh}) {
    return Widevine(iv: iv ?? this.iv, pssh: pssh ?? this.pssh);
  }

  Widevine copyWithWrapped({Wrapped<String?>? iv, Wrapped<String?>? pssh}) {
    return Widevine(
        iv: (iv != null ? iv.value : this.iv),
        pssh: (pssh != null ? pssh.value : this.pssh));
  }
}

@JsonSerializable(explicitToJson: true)
class PostGetKeyAndSignalizationRequest {
  PostGetKeyAndSignalizationRequest({
    required this.customerId,
    required this.cpeId,
    required this.contentId,
  });

  factory PostGetKeyAndSignalizationRequest.fromJson(
          Map<String, dynamic> json) =>
      _$PostGetKeyAndSignalizationRequestFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String cpeId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  static const fromJsonFactory = _$PostGetKeyAndSignalizationRequestFromJson;
  static const toJsonFactory = _$PostGetKeyAndSignalizationRequestToJson;
  Map<String, dynamic> toJson() =>
      _$PostGetKeyAndSignalizationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostGetKeyAndSignalizationRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(contentId) ^
      runtimeType.hashCode;
}

extension $PostGetKeyAndSignalizationRequestExtension
    on PostGetKeyAndSignalizationRequest {
  PostGetKeyAndSignalizationRequest copyWith(
      {String? customerId, String? cpeId, String? contentId}) {
    return PostGetKeyAndSignalizationRequest(
        customerId: customerId ?? this.customerId,
        cpeId: cpeId ?? this.cpeId,
        contentId: contentId ?? this.contentId);
  }

  PostGetKeyAndSignalizationRequest copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<String>? cpeId,
      Wrapped<String>? contentId}) {
    return PostGetKeyAndSignalizationRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        contentId: (contentId != null ? contentId.value : this.contentId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
