// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_linear_service.swagger.chopper.dart';
part 'liberty_linear_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyLinearService extends ChopperService {
  static LibertyLinearService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyLinearService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyLinearService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyLinearService(newClient);
  }

  ///Get IMDB rating for CRID,IMI in path
  ///@param crid,imi CRID,IMI for which IMDB rating needs to be returned
  Future<chopper.Response<Ratings>> v1RatingsCridImiGet({
    required String? cridImi,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Ratings, () => Ratings.fromJsonFactory);

    return _v1RatingsCridImiGet(cridImi: cridImi, cacheControl: cacheControl);
  }

  ///Get IMDB rating for CRID,IMI in path
  ///@param crid,imi CRID,IMI for which IMDB rating needs to be returned
  @Get(path: '/v1/ratings/{crid,imi}')
  Future<chopper.Response<Ratings>> _v1RatingsCridImiGet({
    @Path('crid,imi') required String? cridImi,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Ratings {
  Ratings({
    this.imdbRating,
  });

  factory Ratings.fromJson(Map<String, dynamic> json) =>
      _$RatingsFromJson(json);

  @JsonKey(name: 'imdbRating', includeIfNull: false, defaultValue: '')
  final String? imdbRating;
  static const fromJsonFactory = _$RatingsFromJson;
  static const toJsonFactory = _$RatingsToJson;
  Map<String, dynamic> toJson() => _$RatingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Ratings &&
            (identical(other.imdbRating, imdbRating) ||
                const DeepCollectionEquality()
                    .equals(other.imdbRating, imdbRating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(imdbRating) ^ runtimeType.hashCode;
}

extension $RatingsExtension on Ratings {
  Ratings copyWith({String? imdbRating}) {
    return Ratings(imdbRating: imdbRating ?? this.imdbRating);
  }

  Ratings copyWithWrapped({Wrapped<String?>? imdbRating}) {
    return Ratings(
        imdbRating: (imdbRating != null ? imdbRating.value : this.imdbRating));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorList {
  ErrorList({
    this.errors,
  });

  factory ErrorList.fromJson(Map<String, dynamic> json) =>
      _$ErrorListFromJson(json);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? errors;
  static const fromJsonFactory = _$ErrorListFromJson;
  static const toJsonFactory = _$ErrorListToJson;
  Map<String, dynamic> toJson() => _$ErrorListToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorList &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ErrorListExtension on ErrorList {
  ErrorList copyWith({List<String>? errors}) {
    return ErrorList(errors: errors ?? this.errors);
  }

  ErrorList copyWithWrapped({Wrapped<List<String>?>? errors}) {
    return ErrorList(errors: (errors != null ? errors.value : this.errors));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
