import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_omv_notification_service.swagger.chopper.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyOmvNotificationService extends ChopperService {
  static LibertyOmvNotificationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyOmvNotificationService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyOmvNotificationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://localhost:8080');
    return _$LibertyOmvNotificationService(newClient);
  }

  ///Publishes notification to a MQTT topic
  ///@param cpeId CPE ID
  ///@param action action can be either notify or notifyAsync
  ///@param application this is the payload that is published to a topic on MQTT
  Future<chopper.Response>
      omwnotificationV1CallhomeserviceDeviceCpeIdActionSyncProfilePost({
    required String? cpeId,
    required String? action,
    required String? application,
    String? cacheControl,
  }) {
    return _omwnotificationV1CallhomeserviceDeviceCpeIdActionSyncProfilePost(
        cpeId: cpeId,
        action: action,
        application: application,
        cacheControl: cacheControl);
  }

  ///Publishes notification to a MQTT topic
  ///@param cpeId CPE ID
  ///@param action action can be either notify or notifyAsync
  ///@param application this is the payload that is published to a topic on MQTT
  @Post(
    path:
        '/omwnotification/v1/callhomeservice/device/{cpeId}/{action}/syncProfile',
    optionalBody: true,
  )
  Future<chopper.Response>
      _omwnotificationV1CallhomeserviceDeviceCpeIdActionSyncProfilePost({
    @Path('cpeId') required String? cpeId,
    @Path('action') required String? action,
    @Path('application') required String? application,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Publishes notification to a MQTT topic
  ///@param cpeId CPE ID
  ///@param action action can be either notify or notifyAsync
  ///@param application this becomes part of the payload that is published to a topic on MQTT
  ///@param payload this is data part of the payload that is published to a topic on MQTT
  Future<chopper.Response>
      omwnotificationV1CallhomeserviceDeviceCpeIdActionCnrPost({
    required String? cpeId,
    required String? action,
    required String? application,
    required String? payload,
    String? cacheControl,
  }) {
    return _omwnotificationV1CallhomeserviceDeviceCpeIdActionCnrPost(
        cpeId: cpeId,
        action: action,
        application: application,
        payload: payload,
        cacheControl: cacheControl);
  }

  ///Publishes notification to a MQTT topic
  ///@param cpeId CPE ID
  ///@param action action can be either notify or notifyAsync
  ///@param application this becomes part of the payload that is published to a topic on MQTT
  ///@param payload this is data part of the payload that is published to a topic on MQTT
  @Post(path: '/omwnotification/v1/callhomeservice/device/{cpeId}/{action}/cnr')
  Future<chopper.Response>
      _omwnotificationV1CallhomeserviceDeviceCpeIdActionCnrPost({
    @Path('cpeId') required String? cpeId,
    @Path('action') required String? action,
    @Path('application') required String? application,
    @Body() required String? payload,
    @Header('Cache-Control') String? cacheControl,
  });
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
