// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_qr_code_service.enums.swagger.dart' as enums;
export 'liberty_qr_code_service.enums.swagger.dart';

part 'liberty_qr_code_service.swagger.chopper.dart';
part 'liberty_qr_code_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyQrCodeService extends ChopperService {
  static LibertyQrCodeService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyQrCodeService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyQrCodeService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyQrCodeService(newClient);
  }

  ///
  Future<chopper.Response<QrCodesResponse>> qrcodesPost({
    String? cacheControl,
    required QrCodesRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        QrCodesResponse, () => QrCodesResponse.fromJsonFactory);

    return _qrcodesPost(cacheControl: cacheControl, body: body);
  }

  ///
  @Post(path: '/qrcodes')
  Future<chopper.Response<QrCodesResponse>> _qrcodesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodesRequest? body,
  });

  ///
  ///@param tinyUrlCode returns a QR Code object with image in base64 and the authorization url
  Future<chopper.Response> qrcodesTinyurlTinyUrlCodeGet({
    required String? tinyUrlCode,
    String? cacheControl,
  }) {
    return _qrcodesTinyurlTinyUrlCodeGet(
        tinyUrlCode: tinyUrlCode, cacheControl: cacheControl);
  }

  ///
  ///@param tinyUrlCode returns a QR Code object with image in base64 and the authorization url
  @Get(path: '/qrcodes/tinyurl/{tinyUrlCode}')
  Future<chopper.Response> _qrcodesTinyurlTinyUrlCodeGet({
    @Path('tinyUrlCode') required String? tinyUrlCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param state
  ///@param status Status of qrcode
  Future<chopper.Response> qrcodesStateGet({
    required String? state,
    required enums.CheckStatus? status,
    String? cacheControl,
  }) {
    return _qrcodesStateGet(
        state: state,
        status: enums.$CheckStatusMap[status]?.toString(),
        cacheControl: cacheControl);
  }

  ///
  ///@param state
  ///@param status Status of qrcode
  @Get(path: '/qrcodes/{state}')
  Future<chopper.Response> _qrcodesStateGet({
    @Path('state') required String? state,
    @Query('status') required String? status,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  Future<chopper.Response> qrcodesConfirmationPost({
    String? cacheControl,
    required QrCodeConfirmationRequest? body,
  }) {
    return _qrcodesConfirmationPost(cacheControl: cacheControl, body: body);
  }

  ///
  @Post(path: '/qrcodes/confirmation')
  Future<chopper.Response> _qrcodesConfirmationPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QrCodeConfirmationRequest? body,
  });

  ///
  ///@param state
  ///@param code
  Future<chopper.Response> qrcodesConfirmationGet({
    required String? state,
    required String? code,
    String? cacheControl,
  }) {
    return _qrcodesConfirmationGet(
        state: state, code: code, cacheControl: cacheControl);
  }

  ///
  ///@param state
  ///@param code
  @Get(path: '/qrcodes/confirmation')
  Future<chopper.Response> _qrcodesConfirmationGet({
    @Query('state') required String? state,
    @Query('code') required String? code,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class QrCodes {
  QrCodes({
    required this.state,
    this.validityToken,
    this.status,
    this.authorizationCode,
  });

  factory QrCodes.fromJson(Map<String, dynamic> json) =>
      _$QrCodesFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(name: 'validityToken', includeIfNull: false, defaultValue: '')
  final String? validityToken;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status? status;
  @JsonKey(name: 'authorizationCode', includeIfNull: false, defaultValue: '')
  final String? authorizationCode;
  static const fromJsonFactory = _$QrCodesFromJson;
  static const toJsonFactory = _$QrCodesToJson;
  Map<String, dynamic> toJson() => _$QrCodesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodes &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.validityToken, validityToken) ||
                const DeepCollectionEquality()
                    .equals(other.validityToken, validityToken)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.authorizationCode, authorizationCode) ||
                const DeepCollectionEquality()
                    .equals(other.authorizationCode, authorizationCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(validityToken) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(authorizationCode) ^
      runtimeType.hashCode;
}

extension $QrCodesExtension on QrCodes {
  QrCodes copyWith(
      {String? state,
      String? validityToken,
      enums.Status? status,
      String? authorizationCode}) {
    return QrCodes(
        state: state ?? this.state,
        validityToken: validityToken ?? this.validityToken,
        status: status ?? this.status,
        authorizationCode: authorizationCode ?? this.authorizationCode);
  }

  QrCodes copyWithWrapped(
      {Wrapped<String>? state,
      Wrapped<String?>? validityToken,
      Wrapped<enums.Status?>? status,
      Wrapped<String?>? authorizationCode}) {
    return QrCodes(
        state: (state != null ? state.value : this.state),
        validityToken:
            (validityToken != null ? validityToken.value : this.validityToken),
        status: (status != null ? status.value : this.status),
        authorizationCode: (authorizationCode != null
            ? authorizationCode.value
            : this.authorizationCode));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesRequest {
  QrCodesRequest({
    required this.screenSize,
  });

  factory QrCodesRequest.fromJson(Map<String, dynamic> json) =>
      _$QrCodesRequestFromJson(json);

  @JsonKey(name: 'screenSize', includeIfNull: false, defaultValue: '')
  final String screenSize;
  static const fromJsonFactory = _$QrCodesRequestFromJson;
  static const toJsonFactory = _$QrCodesRequestToJson;
  Map<String, dynamic> toJson() => _$QrCodesRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesRequest &&
            (identical(other.screenSize, screenSize) ||
                const DeepCollectionEquality()
                    .equals(other.screenSize, screenSize)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(screenSize) ^ runtimeType.hashCode;
}

extension $QrCodesRequestExtension on QrCodesRequest {
  QrCodesRequest copyWith({String? screenSize}) {
    return QrCodesRequest(screenSize: screenSize ?? this.screenSize);
  }

  QrCodesRequest copyWithWrapped({Wrapped<String>? screenSize}) {
    return QrCodesRequest(
        screenSize: (screenSize != null ? screenSize.value : this.screenSize));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesConfirmationResponse {
  QrCodesConfirmationResponse({
    this.state,
    this.status,
    this.confirmationCode,
  });

  factory QrCodesConfirmationResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesConfirmationResponseFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: statusToJson,
    fromJson: statusFromJson,
  )
  final enums.Status? status;
  @JsonKey(name: 'confirmationCode', includeIfNull: false, defaultValue: '')
  final String? confirmationCode;
  static const fromJsonFactory = _$QrCodesConfirmationResponseFromJson;
  static const toJsonFactory = _$QrCodesConfirmationResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesConfirmationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesConfirmationResponse &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.confirmationCode, confirmationCode) ||
                const DeepCollectionEquality()
                    .equals(other.confirmationCode, confirmationCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(confirmationCode) ^
      runtimeType.hashCode;
}

extension $QrCodesConfirmationResponseExtension on QrCodesConfirmationResponse {
  QrCodesConfirmationResponse copyWith(
      {String? state, enums.Status? status, String? confirmationCode}) {
    return QrCodesConfirmationResponse(
        state: state ?? this.state,
        status: status ?? this.status,
        confirmationCode: confirmationCode ?? this.confirmationCode);
  }

  QrCodesConfirmationResponse copyWithWrapped(
      {Wrapped<String?>? state,
      Wrapped<enums.Status?>? status,
      Wrapped<String?>? confirmationCode}) {
    return QrCodesConfirmationResponse(
        state: (state != null ? state.value : this.state),
        status: (status != null ? status.value : this.status),
        confirmationCode: (confirmationCode != null
            ? confirmationCode.value
            : this.confirmationCode));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodesResponse {
  QrCodesResponse({
    this.state,
    this.expiry,
    this.counterExpiresInSeconds,
    this.qrCode,
    this.tinyUrl,
  });

  factory QrCodesResponse.fromJson(Map<String, dynamic> json) =>
      _$QrCodesResponseFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String? state;
  @JsonKey(name: 'expiry', includeIfNull: false)
  final DateTime? expiry;
  @JsonKey(name: 'counterExpiresInSeconds', includeIfNull: false)
  final double? counterExpiresInSeconds;
  @JsonKey(name: 'qrCode', includeIfNull: false, defaultValue: '')
  final String? qrCode;
  @JsonKey(name: 'tinyUrl', includeIfNull: false, defaultValue: '')
  final String? tinyUrl;
  static const fromJsonFactory = _$QrCodesResponseFromJson;
  static const toJsonFactory = _$QrCodesResponseToJson;
  Map<String, dynamic> toJson() => _$QrCodesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodesResponse &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.expiry, expiry) ||
                const DeepCollectionEquality().equals(other.expiry, expiry)) &&
            (identical(
                    other.counterExpiresInSeconds, counterExpiresInSeconds) ||
                const DeepCollectionEquality().equals(
                    other.counterExpiresInSeconds, counterExpiresInSeconds)) &&
            (identical(other.qrCode, qrCode) ||
                const DeepCollectionEquality().equals(other.qrCode, qrCode)) &&
            (identical(other.tinyUrl, tinyUrl) ||
                const DeepCollectionEquality().equals(other.tinyUrl, tinyUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(expiry) ^
      const DeepCollectionEquality().hash(counterExpiresInSeconds) ^
      const DeepCollectionEquality().hash(qrCode) ^
      const DeepCollectionEquality().hash(tinyUrl) ^
      runtimeType.hashCode;
}

extension $QrCodesResponseExtension on QrCodesResponse {
  QrCodesResponse copyWith(
      {String? state,
      DateTime? expiry,
      double? counterExpiresInSeconds,
      String? qrCode,
      String? tinyUrl}) {
    return QrCodesResponse(
        state: state ?? this.state,
        expiry: expiry ?? this.expiry,
        counterExpiresInSeconds:
            counterExpiresInSeconds ?? this.counterExpiresInSeconds,
        qrCode: qrCode ?? this.qrCode,
        tinyUrl: tinyUrl ?? this.tinyUrl);
  }

  QrCodesResponse copyWithWrapped(
      {Wrapped<String?>? state,
      Wrapped<DateTime?>? expiry,
      Wrapped<double?>? counterExpiresInSeconds,
      Wrapped<String?>? qrCode,
      Wrapped<String?>? tinyUrl}) {
    return QrCodesResponse(
        state: (state != null ? state.value : this.state),
        expiry: (expiry != null ? expiry.value : this.expiry),
        counterExpiresInSeconds: (counterExpiresInSeconds != null
            ? counterExpiresInSeconds.value
            : this.counterExpiresInSeconds),
        qrCode: (qrCode != null ? qrCode.value : this.qrCode),
        tinyUrl: (tinyUrl != null ? tinyUrl.value : this.tinyUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class QrCodeConfirmationRequest {
  QrCodeConfirmationRequest({
    required this.state,
    required this.confirmationCode,
  });

  factory QrCodeConfirmationRequest.fromJson(Map<String, dynamic> json) =>
      _$QrCodeConfirmationRequestFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(name: 'confirmationCode', includeIfNull: false, defaultValue: '')
  final String confirmationCode;
  static const fromJsonFactory = _$QrCodeConfirmationRequestFromJson;
  static const toJsonFactory = _$QrCodeConfirmationRequestToJson;
  Map<String, dynamic> toJson() => _$QrCodeConfirmationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QrCodeConfirmationRequest &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.confirmationCode, confirmationCode) ||
                const DeepCollectionEquality()
                    .equals(other.confirmationCode, confirmationCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(confirmationCode) ^
      runtimeType.hashCode;
}

extension $QrCodeConfirmationRequestExtension on QrCodeConfirmationRequest {
  QrCodeConfirmationRequest copyWith(
      {String? state, String? confirmationCode}) {
    return QrCodeConfirmationRequest(
        state: state ?? this.state,
        confirmationCode: confirmationCode ?? this.confirmationCode);
  }

  QrCodeConfirmationRequest copyWithWrapped(
      {Wrapped<String>? state, Wrapped<String>? confirmationCode}) {
    return QrCodeConfirmationRequest(
        state: (state != null ? state.value : this.state),
        confirmationCode: (confirmationCode != null
            ? confirmationCode.value
            : this.confirmationCode));
  }
}

String? statusToJson(enums.Status? status) {
  return enums.$StatusMap[status];
}

enums.Status statusFromJson(
  Object? status, [
  enums.Status? defaultValue,
]) {
  if (status is String) {
    return enums.$StatusMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == status.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.Status.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$StatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.Status.swaggerGeneratedUnknown;
}

List<String> statusListToJson(List<enums.Status>? status) {
  if (status == null) {
    return [];
  }

  return status.map((e) => enums.$StatusMap[e]!).toList();
}

List<enums.Status> statusListFromJson(
  List? status, [
  List<enums.Status>? defaultValue,
]) {
  if (status == null) {
    return defaultValue ?? [];
  }

  return status.map((e) => statusFromJson(e.toString())).toList();
}

List<enums.Status>? statusNullableListFromJson(
  List? status, [
  List<enums.Status>? defaultValue,
]) {
  if (status == null) {
    return defaultValue;
  }

  return status.map((e) => statusFromJson(e.toString())).toList();
}

String? checkStatusToJson(enums.CheckStatus? checkStatus) {
  return enums.$CheckStatusMap[checkStatus];
}

enums.CheckStatus checkStatusFromJson(
  Object? checkStatus, [
  enums.CheckStatus? defaultValue,
]) {
  if (checkStatus is String) {
    return enums.$CheckStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == checkStatus.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.CheckStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CheckStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CheckStatus.swaggerGeneratedUnknown;
}

List<String> checkStatusListToJson(List<enums.CheckStatus>? checkStatus) {
  if (checkStatus == null) {
    return [];
  }

  return checkStatus.map((e) => enums.$CheckStatusMap[e]!).toList();
}

List<enums.CheckStatus> checkStatusListFromJson(
  List? checkStatus, [
  List<enums.CheckStatus>? defaultValue,
]) {
  if (checkStatus == null) {
    return defaultValue ?? [];
  }

  return checkStatus.map((e) => checkStatusFromJson(e.toString())).toList();
}

List<enums.CheckStatus>? checkStatusNullableListFromJson(
  List? checkStatus, [
  List<enums.CheckStatus>? defaultValue,
]) {
  if (checkStatus == null) {
    return defaultValue;
  }

  return checkStatus.map((e) => checkStatusFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
