// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_replay_catalog_service.enums.swagger.dart' as enums;
export 'liberty_replay_catalog_service.enums.swagger.dart';

part 'liberty_replay_catalog_service.swagger.chopper.dart';
part 'liberty_replay_catalog_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyReplayCatalogService extends ChopperService {
  static LibertyReplayCatalogService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyReplayCatalogService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyReplayCatalogService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyReplayCatalogService(newClient);
  }

  ///
  ///@param programId
  ///@param type
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param channelId Filters results by **channel**. Use **/networks** or **/channels** API to get valid values. Can't be used together with **providerId** parameter.
  ///@param providerId Filters results by **provider (network)**. Use **/networks** API to get valid values. Can't be used together with **channelId** parameter.
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param genreId Filters results by genre. Use **/genres** API to list available ones.
  ///@param X-Claims-Set Encrypted customer context data
  Future<chopper.Response<MostRelevantInstanceResponse>>
      mostrelevantinstanceGet({
    required String? programId,
    required enums.MostrelevantinstanceGetType? type,
    required String? language,
    String? cityId,
    String? channelId,
    String? providerId,
    String? dayStart,
    enums.MostrelevantinstanceGetMaxRes? maxRes,
    String? profileId,
    String? genreId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(MostRelevantInstanceResponse,
        () => MostRelevantInstanceResponse.fromJsonFactory);

    return _mostrelevantinstanceGet(
        programId: programId,
        type: enums.$MostrelevantinstanceGetTypeMap[type]?.toString(),
        language: language,
        cityId: cityId,
        channelId: channelId,
        providerId: providerId,
        dayStart: dayStart,
        maxRes: enums.$MostrelevantinstanceGetMaxResMap[maxRes]?.toString(),
        profileId: profileId,
        genreId: genreId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///
  ///@param programId
  ///@param type
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param channelId Filters results by **channel**. Use **/networks** or **/channels** API to get valid values. Can't be used together with **providerId** parameter.
  ///@param providerId Filters results by **provider (network)**. Use **/networks** API to get valid values. Can't be used together with **channelId** parameter.
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param genreId Filters results by genre. Use **/genres** API to list available ones.
  ///@param X-Claims-Set Encrypted customer context data
  @Get(path: '/mostrelevantinstance')
  Future<chopper.Response<MostRelevantInstanceResponse>>
      _mostrelevantinstanceGet({
    @Query('programId') required String? programId,
    @Query('type') required String? type,
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('channelId') String? channelId,
    @Query('providerId') String? providerId,
    @Query('dayStart') String? dayStart,
    @Query('maxRes') String? maxRes,
    @Query('profileId') String? profileId,
    @Query('genreId') String? genreId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param customerId
  ///@param entitled Set to true to **only** get the channels customer is entitled to
  ///@param x-cus ID of the customer
  ///@param x-dev ID of CPE the request is coming from
  ///@param x-entitlements-token Token that contains encrypted customer's entitlement data
  Future<chopper.Response<ReplayChannelResponse>> channelsGet({
    required String? language,
    String? cityId,
    enums.ChannelsGetMaxRes? maxRes,
    String? customerId,
    bool? entitled,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayChannelResponse, () => ReplayChannelResponse.fromJsonFactory);

    return _channelsGet(
        language: language,
        cityId: cityId,
        maxRes: enums.$ChannelsGetMaxResMap[maxRes]?.toString(),
        customerId: customerId,
        entitled: entitled,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param customerId
  ///@param entitled Set to true to **only** get the channels customer is entitled to
  ///@param x-cus ID of the customer
  ///@param x-dev ID of CPE the request is coming from
  ///@param x-entitlements-token Token that contains encrypted customer's entitlement data
  @Get(path: '/channels')
  Future<chopper.Response<ReplayChannelResponse>> _channelsGet({
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('maxRes') String? maxRes,
    @Query('customerId') String? customerId,
    @Query('entitled') bool? entitled,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param customerId
  ///@param entitled Set to true to **only** get the networks customer is entitled to
  ///@param x-cus ID of the customer
  ///@param x-dev ID of CPE the request is coming from
  ///@param x-entitlements-token Token that contains encrypted customer's entitlement data
  Future<chopper.Response<ReplayNetworksResponse>> networksGet({
    required String? language,
    String? cityId,
    enums.NetworksGetMaxRes? maxRes,
    String? customerId,
    bool? entitled,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayNetworksResponse, () => ReplayNetworksResponse.fromJsonFactory);

    return _networksGet(
        language: language,
        cityId: cityId,
        maxRes: enums.$NetworksGetMaxResMap[maxRes]?.toString(),
        customerId: customerId,
        entitled: entitled,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param customerId
  ///@param entitled Set to true to **only** get the networks customer is entitled to
  ///@param x-cus ID of the customer
  ///@param x-dev ID of CPE the request is coming from
  ///@param x-entitlements-token Token that contains encrypted customer's entitlement data
  @Get(path: '/networks')
  Future<chopper.Response<ReplayNetworksResponse>> _networksGet({
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('maxRes') String? maxRes,
    @Query('customerId') String? customerId,
    @Query('entitled') bool? entitled,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param channelId Filters programs by channel
  ///@param providerId Filters programs by network (provider)
  ///@param page
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight. Can not be used together with **start** parameter.    **NOTE**: This parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param start Filters results by date/time: starting from provided value until now. Can not be used together with **dayStart** parameter.
  ///@param sort Results sorting criteria. **NOTE**: **dayStart** parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param genreId Filters programs by genre. Use **/genres** API to list available ones.
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response<ReplayProgramsResponse>> programsGet({
    String? channelId,
    String? providerId,
    int? page,
    String? dayStart,
    String? start,
    enums.ProgramsGetSort? sort,
    String? profileId,
    required String? language,
    String? cityId,
    enums.ProgramsGetMaxRes? maxRes,
    String? genreId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayProgramsResponse, () => ReplayProgramsResponse.fromJsonFactory);

    return _programsGet(
        channelId: channelId,
        providerId: providerId,
        page: page,
        dayStart: dayStart,
        start: start,
        sort: enums.$ProgramsGetSortMap[sort]?.toString(),
        profileId: profileId,
        language: language,
        cityId: cityId,
        maxRes: enums.$ProgramsGetMaxResMap[maxRes]?.toString(),
        genreId: genreId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///
  ///@param channelId Filters programs by channel
  ///@param providerId Filters programs by network (provider)
  ///@param page
  ///@param dayStart Filters results by date/time: starting from provided value until next midnight. Can not be used together with **start** parameter.    **NOTE**: This parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param start Filters results by date/time: starting from provided value until now. Can not be used together with **dayStart** parameter.
  ///@param sort Results sorting criteria. **NOTE**: **dayStart** parameter affects sorting by popularity behavior, see details in API's description above.
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  ///@param genreId Filters programs by genre. Use **/genres** API to list available ones.
  ///@param X-Claims-Set Encoded customer information
  @Get(path: '/programs')
  Future<chopper.Response<ReplayProgramsResponse>> _programsGet({
    @Query('channelId') String? channelId,
    @Query('providerId') String? providerId,
    @Query('page') int? page,
    @Query('dayStart') String? dayStart,
    @Query('start') String? start,
    @Query('sort') String? sort,
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('maxRes') String? maxRes,
    @Query('genreId') String? genreId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  Future<chopper.Response<ReplayProgramsResponse>> programsContextualMenuGet({
    String? profileId,
    required String? language,
    String? cityId,
    enums.ProgramsContextualMenuGetMaxRes? maxRes,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayProgramsResponse, () => ReplayProgramsResponse.fromJsonFactory);

    return _programsContextualMenuGet(
        profileId: profileId,
        language: language,
        cityId: cityId,
        maxRes: enums.$ProgramsContextualMenuGetMaxResMap[maxRes]?.toString(),
        cacheControl: cacheControl);
  }

  ///
  ///@param profileId ID of customer's personal profile. Specify it to get bookmarks along with results.
  ///@param language
  ///@param cityId ID of the region CPE is located at. If not specified, default value configured for requested language will be used.
  ///@param maxRes Filters results by video resolution. Use the highest resolution supported by CPE for this parameter.
  @Get(path: '/programs/contextualMenu')
  Future<chopper.Response<ReplayProgramsResponse>> _programsContextualMenuGet({
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('cityId') String? cityId,
    @Query('maxRes') String? maxRes,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param language
  Future<chopper.Response<GenresResponse>> genresGet({
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GenresResponse, () => GenresResponse.fromJsonFactory);

    return _genresGet(language: language, cacheControl: cacheControl);
  }

  ///
  ///@param language
  @Get(path: '/genres')
  Future<chopper.Response<GenresResponse>> _genresGet({
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class MostRelevantInstanceResponse {
  MostRelevantInstanceResponse({
    required this.mostRelevantInstances,
    this.bookmarkedInstance,
  });

  factory MostRelevantInstanceResponse.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantInstanceResponseFromJson(json);

  @JsonKey(
      name: 'mostRelevantInstances',
      includeIfNull: false,
      defaultValue: <InstanceOfProgram>[])
  final List<InstanceOfProgram> mostRelevantInstances;
  @JsonKey(name: 'bookmarkedInstance', includeIfNull: false)
  final Bookmark? bookmarkedInstance;
  static const fromJsonFactory = _$MostRelevantInstanceResponseFromJson;
  static const toJsonFactory = _$MostRelevantInstanceResponseToJson;
  Map<String, dynamic> toJson() => _$MostRelevantInstanceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantInstanceResponse &&
            (identical(other.mostRelevantInstances, mostRelevantInstances) ||
                const DeepCollectionEquality().equals(
                    other.mostRelevantInstances, mostRelevantInstances)) &&
            (identical(other.bookmarkedInstance, bookmarkedInstance) ||
                const DeepCollectionEquality()
                    .equals(other.bookmarkedInstance, bookmarkedInstance)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mostRelevantInstances) ^
      const DeepCollectionEquality().hash(bookmarkedInstance) ^
      runtimeType.hashCode;
}

extension $MostRelevantInstanceResponseExtension
    on MostRelevantInstanceResponse {
  MostRelevantInstanceResponse copyWith(
      {List<InstanceOfProgram>? mostRelevantInstances,
      Bookmark? bookmarkedInstance}) {
    return MostRelevantInstanceResponse(
        mostRelevantInstances:
            mostRelevantInstances ?? this.mostRelevantInstances,
        bookmarkedInstance: bookmarkedInstance ?? this.bookmarkedInstance);
  }

  MostRelevantInstanceResponse copyWithWrapped(
      {Wrapped<List<InstanceOfProgram>>? mostRelevantInstances,
      Wrapped<Bookmark?>? bookmarkedInstance}) {
    return MostRelevantInstanceResponse(
        mostRelevantInstances: (mostRelevantInstances != null
            ? mostRelevantInstances.value
            : this.mostRelevantInstances),
        bookmarkedInstance: (bookmarkedInstance != null
            ? bookmarkedInstance.value
            : this.bookmarkedInstance));
  }
}

@JsonSerializable(explicitToJson: true)
class GenresResponse {
  GenresResponse({
    required this.genres,
  });

  factory GenresResponse.fromJson(Map<String, dynamic> json) =>
      _$GenresResponseFromJson(json);

  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <Genre>[])
  final List<Genre> genres;
  static const fromJsonFactory = _$GenresResponseFromJson;
  static const toJsonFactory = _$GenresResponseToJson;
  Map<String, dynamic> toJson() => _$GenresResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenresResponse &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(genres) ^ runtimeType.hashCode;
}

extension $GenresResponseExtension on GenresResponse {
  GenresResponse copyWith({List<Genre>? genres}) {
    return GenresResponse(genres: genres ?? this.genres);
  }

  GenresResponse copyWithWrapped({Wrapped<List<Genre>>? genres}) {
    return GenresResponse(
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    required this.genreId,
    required this.name,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  @JsonKey(name: 'genreId', includeIfNull: false, defaultValue: '')
  final String genreId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$GenreFromJson;
  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.genreId, genreId) ||
                const DeepCollectionEquality()
                    .equals(other.genreId, genreId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(genreId) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith({String? genreId, String? name}) {
    return Genre(genreId: genreId ?? this.genreId, name: name ?? this.name);
  }

  Genre copyWithWrapped({Wrapped<String>? genreId, Wrapped<String>? name}) {
    return Genre(
        genreId: (genreId != null ? genreId.value : this.genreId),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class InstanceOfProgram {
  InstanceOfProgram({
    required this.eventId,
    required this.channelId,
    required this.eventStartTime,
    required this.isAdult,
    required this.replayContainsAdult,
    required this.replayMinAge,
  });

  factory InstanceOfProgram.fromJson(Map<String, dynamic> json) =>
      _$InstanceOfProgramFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime eventStartTime;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int replayMinAge;
  static const fromJsonFactory = _$InstanceOfProgramFromJson;
  static const toJsonFactory = _$InstanceOfProgramToJson;
  Map<String, dynamic> toJson() => _$InstanceOfProgramToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InstanceOfProgram &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventStartTime, eventStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      runtimeType.hashCode;
}

extension $InstanceOfProgramExtension on InstanceOfProgram {
  InstanceOfProgram copyWith(
      {String? eventId,
      String? channelId,
      DateTime? eventStartTime,
      bool? isAdult,
      bool? replayContainsAdult,
      int? replayMinAge}) {
    return InstanceOfProgram(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        isAdult: isAdult ?? this.isAdult,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge);
  }

  InstanceOfProgram copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<DateTime>? eventStartTime,
      Wrapped<bool>? isAdult,
      Wrapped<bool>? replayContainsAdult,
      Wrapped<int>? replayMinAge}) {
    return InstanceOfProgram(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge));
  }
}

@JsonSerializable(explicitToJson: true)
class Bookmark {
  Bookmark({
    required this.position,
    required this.duration,
    this.eventId,
  });

  factory Bookmark.fromJson(Map<String, dynamic> json) =>
      _$BookmarkFromJson(json);

  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  static const fromJsonFactory = _$BookmarkFromJson;
  static const toJsonFactory = _$BookmarkToJson;
  Map<String, dynamic> toJson() => _$BookmarkToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Bookmark &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality().equals(other.eventId, eventId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(eventId) ^
      runtimeType.hashCode;
}

extension $BookmarkExtension on Bookmark {
  Bookmark copyWith({int? position, int? duration, String? eventId}) {
    return Bookmark(
        position: position ?? this.position,
        duration: duration ?? this.duration,
        eventId: eventId ?? this.eventId);
  }

  Bookmark copyWithWrapped(
      {Wrapped<int>? position,
      Wrapped<int>? duration,
      Wrapped<String?>? eventId}) {
    return Bookmark(
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration),
        eventId: (eventId != null ? eventId.value : this.eventId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayChannelResponse {
  ReplayChannelResponse({
    required this.replayChannels,
  });

  factory ReplayChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayChannelResponseFromJson(json);

  @JsonKey(
      name: 'replayChannels',
      includeIfNull: false,
      defaultValue: <ReplayChannel>[])
  final List<ReplayChannel> replayChannels;
  static const fromJsonFactory = _$ReplayChannelResponseFromJson;
  static const toJsonFactory = _$ReplayChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayChannelResponse &&
            (identical(other.replayChannels, replayChannels) ||
                const DeepCollectionEquality()
                    .equals(other.replayChannels, replayChannels)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayChannels) ^
      runtimeType.hashCode;
}

extension $ReplayChannelResponseExtension on ReplayChannelResponse {
  ReplayChannelResponse copyWith({List<ReplayChannel>? replayChannels}) {
    return ReplayChannelResponse(
        replayChannels: replayChannels ?? this.replayChannels);
  }

  ReplayChannelResponse copyWithWrapped(
      {Wrapped<List<ReplayChannel>>? replayChannels}) {
    return ReplayChannelResponse(
        replayChannels: (replayChannels != null
            ? replayChannels.value
            : this.replayChannels));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayNetworksResponse {
  ReplayNetworksResponse({
    required this.replayNetworks,
  });

  factory ReplayNetworksResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayNetworksResponseFromJson(json);

  @JsonKey(
      name: 'replayNetworks',
      includeIfNull: false,
      defaultValue: <ReplayNetwork>[])
  final List<ReplayNetwork> replayNetworks;
  static const fromJsonFactory = _$ReplayNetworksResponseFromJson;
  static const toJsonFactory = _$ReplayNetworksResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayNetworksResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayNetworksResponse &&
            (identical(other.replayNetworks, replayNetworks) ||
                const DeepCollectionEquality()
                    .equals(other.replayNetworks, replayNetworks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayNetworks) ^
      runtimeType.hashCode;
}

extension $ReplayNetworksResponseExtension on ReplayNetworksResponse {
  ReplayNetworksResponse copyWith({List<ReplayNetwork>? replayNetworks}) {
    return ReplayNetworksResponse(
        replayNetworks: replayNetworks ?? this.replayNetworks);
  }

  ReplayNetworksResponse copyWithWrapped(
      {Wrapped<List<ReplayNetwork>>? replayNetworks}) {
    return ReplayNetworksResponse(
        replayNetworks: (replayNetworks != null
            ? replayNetworks.value
            : this.replayNetworks));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayChannel {
  ReplayChannel({
    required this.id,
    required this.name,
    required this.replayDays,
    this.backgroundImage,
    this.logo,
  });

  factory ReplayChannel.fromJson(Map<String, dynamic> json) =>
      _$ReplayChannelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'replayDays', includeIfNull: false)
  final int replayDays;
  @JsonKey(name: 'backgroundImage', includeIfNull: false, defaultValue: '')
  final String? backgroundImage;
  @JsonKey(name: 'logo', includeIfNull: false, defaultValue: '')
  final String? logo;
  static const fromJsonFactory = _$ReplayChannelFromJson;
  static const toJsonFactory = _$ReplayChannelToJson;
  Map<String, dynamic> toJson() => _$ReplayChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayChannel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.replayDays, replayDays) ||
                const DeepCollectionEquality()
                    .equals(other.replayDays, replayDays)) &&
            (identical(other.backgroundImage, backgroundImage) ||
                const DeepCollectionEquality()
                    .equals(other.backgroundImage, backgroundImage)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(replayDays) ^
      const DeepCollectionEquality().hash(backgroundImage) ^
      const DeepCollectionEquality().hash(logo) ^
      runtimeType.hashCode;
}

extension $ReplayChannelExtension on ReplayChannel {
  ReplayChannel copyWith(
      {String? id,
      String? name,
      int? replayDays,
      String? backgroundImage,
      String? logo}) {
    return ReplayChannel(
        id: id ?? this.id,
        name: name ?? this.name,
        replayDays: replayDays ?? this.replayDays,
        backgroundImage: backgroundImage ?? this.backgroundImage,
        logo: logo ?? this.logo);
  }

  ReplayChannel copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<int>? replayDays,
      Wrapped<String?>? backgroundImage,
      Wrapped<String?>? logo}) {
    return ReplayChannel(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        replayDays: (replayDays != null ? replayDays.value : this.replayDays),
        backgroundImage: (backgroundImage != null
            ? backgroundImage.value
            : this.backgroundImage),
        logo: (logo != null ? logo.value : this.logo));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayNetwork {
  ReplayNetwork({
    required this.id,
    required this.name,
    required this.replayDays,
    this.backgroundImage,
    this.logo,
    this.dualBrandingLogo,
    required this.type,
  });

  factory ReplayNetwork.fromJson(Map<String, dynamic> json) =>
      _$ReplayNetworkFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'replayDays', includeIfNull: false)
  final int replayDays;
  @JsonKey(name: 'backgroundImage', includeIfNull: false, defaultValue: '')
  final String? backgroundImage;
  @JsonKey(name: 'logo', includeIfNull: false, defaultValue: '')
  final String? logo;
  @JsonKey(name: 'dualBrandingLogo', includeIfNull: false, defaultValue: '')
  final String? dualBrandingLogo;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: replayNetworkTypeToJson,
    fromJson: replayNetworkTypeFromJson,
  )
  final enums.ReplayNetworkType type;
  static const fromJsonFactory = _$ReplayNetworkFromJson;
  static const toJsonFactory = _$ReplayNetworkToJson;
  Map<String, dynamic> toJson() => _$ReplayNetworkToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayNetwork &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.replayDays, replayDays) ||
                const DeepCollectionEquality()
                    .equals(other.replayDays, replayDays)) &&
            (identical(other.backgroundImage, backgroundImage) ||
                const DeepCollectionEquality()
                    .equals(other.backgroundImage, backgroundImage)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)) &&
            (identical(other.dualBrandingLogo, dualBrandingLogo) ||
                const DeepCollectionEquality()
                    .equals(other.dualBrandingLogo, dualBrandingLogo)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(replayDays) ^
      const DeepCollectionEquality().hash(backgroundImage) ^
      const DeepCollectionEquality().hash(logo) ^
      const DeepCollectionEquality().hash(dualBrandingLogo) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ReplayNetworkExtension on ReplayNetwork {
  ReplayNetwork copyWith(
      {String? id,
      String? name,
      int? replayDays,
      String? backgroundImage,
      String? logo,
      String? dualBrandingLogo,
      enums.ReplayNetworkType? type}) {
    return ReplayNetwork(
        id: id ?? this.id,
        name: name ?? this.name,
        replayDays: replayDays ?? this.replayDays,
        backgroundImage: backgroundImage ?? this.backgroundImage,
        logo: logo ?? this.logo,
        dualBrandingLogo: dualBrandingLogo ?? this.dualBrandingLogo,
        type: type ?? this.type);
  }

  ReplayNetwork copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<int>? replayDays,
      Wrapped<String?>? backgroundImage,
      Wrapped<String?>? logo,
      Wrapped<String?>? dualBrandingLogo,
      Wrapped<enums.ReplayNetworkType>? type}) {
    return ReplayNetwork(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        replayDays: (replayDays != null ? replayDays.value : this.replayDays),
        backgroundImage: (backgroundImage != null
            ? backgroundImage.value
            : this.backgroundImage),
        logo: (logo != null ? logo.value : this.logo),
        dualBrandingLogo: (dualBrandingLogo != null
            ? dualBrandingLogo.value
            : this.dualBrandingLogo),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgramsResponse {
  ReplayProgramsResponse({
    this.promotion,
    this.aspots,
    required this.replayPrograms,
    required this.page,
    required this.isLastPage,
  });

  factory ReplayProgramsResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayProgramsResponseFromJson(json);

  @JsonKey(name: 'promotion', includeIfNull: false)
  final ReplayProgramsResponse$Promotion? promotion;
  @JsonKey(name: 'aspots', includeIfNull: false, defaultValue: <ReplayAspot>[])
  final List<ReplayAspot>? aspots;
  @JsonKey(
      name: 'replayPrograms',
      includeIfNull: false,
      defaultValue: <ReplayProgram>[])
  final List<ReplayProgram> replayPrograms;
  @JsonKey(name: 'page', includeIfNull: false)
  final int page;
  @JsonKey(name: 'isLastPage', includeIfNull: false)
  final bool isLastPage;
  static const fromJsonFactory = _$ReplayProgramsResponseFromJson;
  static const toJsonFactory = _$ReplayProgramsResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayProgramsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgramsResponse &&
            (identical(other.promotion, promotion) ||
                const DeepCollectionEquality()
                    .equals(other.promotion, promotion)) &&
            (identical(other.aspots, aspots) ||
                const DeepCollectionEquality().equals(other.aspots, aspots)) &&
            (identical(other.replayPrograms, replayPrograms) ||
                const DeepCollectionEquality()
                    .equals(other.replayPrograms, replayPrograms)) &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)) &&
            (identical(other.isLastPage, isLastPage) ||
                const DeepCollectionEquality()
                    .equals(other.isLastPage, isLastPage)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(promotion) ^
      const DeepCollectionEquality().hash(aspots) ^
      const DeepCollectionEquality().hash(replayPrograms) ^
      const DeepCollectionEquality().hash(page) ^
      const DeepCollectionEquality().hash(isLastPage) ^
      runtimeType.hashCode;
}

extension $ReplayProgramsResponseExtension on ReplayProgramsResponse {
  ReplayProgramsResponse copyWith(
      {ReplayProgramsResponse$Promotion? promotion,
      List<ReplayAspot>? aspots,
      List<ReplayProgram>? replayPrograms,
      int? page,
      bool? isLastPage}) {
    return ReplayProgramsResponse(
        promotion: promotion ?? this.promotion,
        aspots: aspots ?? this.aspots,
        replayPrograms: replayPrograms ?? this.replayPrograms,
        page: page ?? this.page,
        isLastPage: isLastPage ?? this.isLastPage);
  }

  ReplayProgramsResponse copyWithWrapped(
      {Wrapped<ReplayProgramsResponse$Promotion?>? promotion,
      Wrapped<List<ReplayAspot>?>? aspots,
      Wrapped<List<ReplayProgram>>? replayPrograms,
      Wrapped<int>? page,
      Wrapped<bool>? isLastPage}) {
    return ReplayProgramsResponse(
        promotion: (promotion != null ? promotion.value : this.promotion),
        aspots: (aspots != null ? aspots.value : this.aspots),
        replayPrograms: (replayPrograms != null
            ? replayPrograms.value
            : this.replayPrograms),
        page: (page != null ? page.value : this.page),
        isLastPage: (isLastPage != null ? isLastPage.value : this.isLastPage));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgram {
  ReplayProgram({
    required this.id,
    required this.name,
    required this.type,
    required this.channelId,
    this.providerId,
    required this.isAdult,
    this.image,
    this.bookmark,
    this.episodeNumber,
    this.seasonNumber,
  });

  factory ReplayProgram.fromJson(Map<String, dynamic> json) =>
      _$ReplayProgramFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: replayProgramTypeToJson,
    fromJson: replayProgramTypeFromJson,
  )
  final enums.ReplayProgramType type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final Bookmark? bookmark;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  static const fromJsonFactory = _$ReplayProgramFromJson;
  static const toJsonFactory = _$ReplayProgramToJson;
  Map<String, dynamic> toJson() => _$ReplayProgramToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgram &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.providerId, providerId) ||
                const DeepCollectionEquality()
                    .equals(other.providerId, providerId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      runtimeType.hashCode;
}

extension $ReplayProgramExtension on ReplayProgram {
  ReplayProgram copyWith(
      {String? id,
      String? name,
      enums.ReplayProgramType? type,
      String? channelId,
      String? providerId,
      bool? isAdult,
      String? image,
      Bookmark? bookmark,
      int? episodeNumber,
      int? seasonNumber}) {
    return ReplayProgram(
        id: id ?? this.id,
        name: name ?? this.name,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        providerId: providerId ?? this.providerId,
        isAdult: isAdult ?? this.isAdult,
        image: image ?? this.image,
        bookmark: bookmark ?? this.bookmark,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber);
  }

  ReplayProgram copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<enums.ReplayProgramType>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? providerId,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? image,
      Wrapped<Bookmark?>? bookmark,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber}) {
    return ReplayProgram(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        providerId: (providerId != null ? providerId.value : this.providerId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        image: (image != null ? image.value : this.image),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayAspot {
  ReplayAspot({
    required this.synopsis,
    required this.background,
    required this.treatment,
    required this.program,
  });

  factory ReplayAspot.fromJson(Map<String, dynamic> json) =>
      _$ReplayAspotFromJson(json);

  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String synopsis;
  @JsonKey(name: 'background', includeIfNull: false, defaultValue: '')
  final String background;
  @JsonKey(name: 'treatment', includeIfNull: false, defaultValue: '')
  final String treatment;
  @JsonKey(name: 'program', includeIfNull: false)
  final ReplayProgramWithInstances program;
  static const fromJsonFactory = _$ReplayAspotFromJson;
  static const toJsonFactory = _$ReplayAspotToJson;
  Map<String, dynamic> toJson() => _$ReplayAspotToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayAspot &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.background, background) ||
                const DeepCollectionEquality()
                    .equals(other.background, background)) &&
            (identical(other.treatment, treatment) ||
                const DeepCollectionEquality()
                    .equals(other.treatment, treatment)) &&
            (identical(other.program, program) ||
                const DeepCollectionEquality().equals(other.program, program)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(background) ^
      const DeepCollectionEquality().hash(treatment) ^
      const DeepCollectionEquality().hash(program) ^
      runtimeType.hashCode;
}

extension $ReplayAspotExtension on ReplayAspot {
  ReplayAspot copyWith(
      {String? synopsis,
      String? background,
      String? treatment,
      ReplayProgramWithInstances? program}) {
    return ReplayAspot(
        synopsis: synopsis ?? this.synopsis,
        background: background ?? this.background,
        treatment: treatment ?? this.treatment,
        program: program ?? this.program);
  }

  ReplayAspot copyWithWrapped(
      {Wrapped<String>? synopsis,
      Wrapped<String>? background,
      Wrapped<String>? treatment,
      Wrapped<ReplayProgramWithInstances>? program}) {
    return ReplayAspot(
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        background: (background != null ? background.value : this.background),
        treatment: (treatment != null ? treatment.value : this.treatment),
        program: (program != null ? program.value : this.program));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgramWithInstances {
  ReplayProgramWithInstances({
    required this.mostRelevantInstances,
    this.bookmarkedInstance,
    required this.id,
    required this.name,
    required this.type,
    required this.channelId,
    this.providerId,
    required this.isAdult,
    this.image,
    this.bookmark,
    this.episodeNumber,
    this.seasonNumber,
  });

  factory ReplayProgramWithInstances.fromJson(Map<String, dynamic> json) =>
      _$ReplayProgramWithInstancesFromJson(json);

  @JsonKey(
      name: 'mostRelevantInstances',
      includeIfNull: false,
      defaultValue: <InstanceOfProgram>[])
  final List<InstanceOfProgram> mostRelevantInstances;
  @JsonKey(name: 'bookmarkedInstance', includeIfNull: false)
  final Bookmark? bookmarkedInstance;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: replayProgramWithInstancesTypeToJson,
    fromJson: replayProgramWithInstancesTypeFromJson,
  )
  final enums.ReplayProgramWithInstancesType type;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final Bookmark? bookmark;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  static const fromJsonFactory = _$ReplayProgramWithInstancesFromJson;
  static const toJsonFactory = _$ReplayProgramWithInstancesToJson;
  Map<String, dynamic> toJson() => _$ReplayProgramWithInstancesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgramWithInstances &&
            (identical(other.mostRelevantInstances, mostRelevantInstances) ||
                const DeepCollectionEquality().equals(
                    other.mostRelevantInstances, mostRelevantInstances)) &&
            (identical(other.bookmarkedInstance, bookmarkedInstance) ||
                const DeepCollectionEquality()
                    .equals(other.bookmarkedInstance, bookmarkedInstance)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.providerId, providerId) ||
                const DeepCollectionEquality()
                    .equals(other.providerId, providerId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mostRelevantInstances) ^
      const DeepCollectionEquality().hash(bookmarkedInstance) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      runtimeType.hashCode;
}

extension $ReplayProgramWithInstancesExtension on ReplayProgramWithInstances {
  ReplayProgramWithInstances copyWith(
      {List<InstanceOfProgram>? mostRelevantInstances,
      Bookmark? bookmarkedInstance,
      String? id,
      String? name,
      enums.ReplayProgramWithInstancesType? type,
      String? channelId,
      String? providerId,
      bool? isAdult,
      String? image,
      Bookmark? bookmark,
      int? episodeNumber,
      int? seasonNumber}) {
    return ReplayProgramWithInstances(
        mostRelevantInstances:
            mostRelevantInstances ?? this.mostRelevantInstances,
        bookmarkedInstance: bookmarkedInstance ?? this.bookmarkedInstance,
        id: id ?? this.id,
        name: name ?? this.name,
        type: type ?? this.type,
        channelId: channelId ?? this.channelId,
        providerId: providerId ?? this.providerId,
        isAdult: isAdult ?? this.isAdult,
        image: image ?? this.image,
        bookmark: bookmark ?? this.bookmark,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber);
  }

  ReplayProgramWithInstances copyWithWrapped(
      {Wrapped<List<InstanceOfProgram>>? mostRelevantInstances,
      Wrapped<Bookmark?>? bookmarkedInstance,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<enums.ReplayProgramWithInstancesType>? type,
      Wrapped<String>? channelId,
      Wrapped<String?>? providerId,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? image,
      Wrapped<Bookmark?>? bookmark,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber}) {
    return ReplayProgramWithInstances(
        mostRelevantInstances: (mostRelevantInstances != null
            ? mostRelevantInstances.value
            : this.mostRelevantInstances),
        bookmarkedInstance: (bookmarkedInstance != null
            ? bookmarkedInstance.value
            : this.bookmarkedInstance),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        channelId: (channelId != null ? channelId.value : this.channelId),
        providerId: (providerId != null ? providerId.value : this.providerId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        image: (image != null ? image.value : this.image),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.errors,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({List<String>? errors}) {
    return ErrorResponse(errors: errors ?? this.errors);
  }

  ErrorResponse copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ErrorResponse(errors: (errors != null ? errors.value : this.errors));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProgramsResponse$Promotion {
  ReplayProgramsResponse$Promotion({
    required this.replayPrograms,
    required this.name,
  });

  factory ReplayProgramsResponse$Promotion.fromJson(
          Map<String, dynamic> json) =>
      _$ReplayProgramsResponse$PromotionFromJson(json);

  @JsonKey(
      name: 'replayPrograms',
      includeIfNull: false,
      defaultValue: <ReplayProgram>[])
  final List<ReplayProgram> replayPrograms;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$ReplayProgramsResponse$PromotionFromJson;
  static const toJsonFactory = _$ReplayProgramsResponse$PromotionToJson;
  Map<String, dynamic> toJson() =>
      _$ReplayProgramsResponse$PromotionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProgramsResponse$Promotion &&
            (identical(other.replayPrograms, replayPrograms) ||
                const DeepCollectionEquality()
                    .equals(other.replayPrograms, replayPrograms)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayPrograms) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $ReplayProgramsResponse$PromotionExtension
    on ReplayProgramsResponse$Promotion {
  ReplayProgramsResponse$Promotion copyWith(
      {List<ReplayProgram>? replayPrograms, String? name}) {
    return ReplayProgramsResponse$Promotion(
        replayPrograms: replayPrograms ?? this.replayPrograms,
        name: name ?? this.name);
  }

  ReplayProgramsResponse$Promotion copyWithWrapped(
      {Wrapped<List<ReplayProgram>>? replayPrograms, Wrapped<String>? name}) {
    return ReplayProgramsResponse$Promotion(
        replayPrograms: (replayPrograms != null
            ? replayPrograms.value
            : this.replayPrograms),
        name: (name != null ? name.value : this.name));
  }
}

String? mostrelevantinstanceGetTypeToJson(
    enums.MostrelevantinstanceGetType? mostrelevantinstanceGetType) {
  return enums.$MostrelevantinstanceGetTypeMap[mostrelevantinstanceGetType];
}

enums.MostrelevantinstanceGetType mostrelevantinstanceGetTypeFromJson(
  Object? mostrelevantinstanceGetType, [
  enums.MostrelevantinstanceGetType? defaultValue,
]) {
  if (mostrelevantinstanceGetType is String) {
    return enums.$MostrelevantinstanceGetTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                mostrelevantinstanceGetType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MostrelevantinstanceGetType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MostrelevantinstanceGetTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MostrelevantinstanceGetType.swaggerGeneratedUnknown;
}

List<String> mostrelevantinstanceGetTypeListToJson(
    List<enums.MostrelevantinstanceGetType>? mostrelevantinstanceGetType) {
  if (mostrelevantinstanceGetType == null) {
    return [];
  }

  return mostrelevantinstanceGetType
      .map((e) => enums.$MostrelevantinstanceGetTypeMap[e]!)
      .toList();
}

List<enums.MostrelevantinstanceGetType> mostrelevantinstanceGetTypeListFromJson(
  List? mostrelevantinstanceGetType, [
  List<enums.MostrelevantinstanceGetType>? defaultValue,
]) {
  if (mostrelevantinstanceGetType == null) {
    return defaultValue ?? [];
  }

  return mostrelevantinstanceGetType
      .map((e) => mostrelevantinstanceGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.MostrelevantinstanceGetType>?
    mostrelevantinstanceGetTypeNullableListFromJson(
  List? mostrelevantinstanceGetType, [
  List<enums.MostrelevantinstanceGetType>? defaultValue,
]) {
  if (mostrelevantinstanceGetType == null) {
    return defaultValue;
  }

  return mostrelevantinstanceGetType
      .map((e) => mostrelevantinstanceGetTypeFromJson(e.toString()))
      .toList();
}

String? mostrelevantinstanceGetMaxResToJson(
    enums.MostrelevantinstanceGetMaxRes? mostrelevantinstanceGetMaxRes) {
  return enums.$MostrelevantinstanceGetMaxResMap[mostrelevantinstanceGetMaxRes];
}

enums.MostrelevantinstanceGetMaxRes mostrelevantinstanceGetMaxResFromJson(
  Object? mostrelevantinstanceGetMaxRes, [
  enums.MostrelevantinstanceGetMaxRes? defaultValue,
]) {
  if (mostrelevantinstanceGetMaxRes is String) {
    return enums.$MostrelevantinstanceGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                mostrelevantinstanceGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MostrelevantinstanceGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MostrelevantinstanceGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MostrelevantinstanceGetMaxRes.swaggerGeneratedUnknown;
}

List<String> mostrelevantinstanceGetMaxResListToJson(
    List<enums.MostrelevantinstanceGetMaxRes>? mostrelevantinstanceGetMaxRes) {
  if (mostrelevantinstanceGetMaxRes == null) {
    return [];
  }

  return mostrelevantinstanceGetMaxRes
      .map((e) => enums.$MostrelevantinstanceGetMaxResMap[e]!)
      .toList();
}

List<enums.MostrelevantinstanceGetMaxRes>
    mostrelevantinstanceGetMaxResListFromJson(
  List? mostrelevantinstanceGetMaxRes, [
  List<enums.MostrelevantinstanceGetMaxRes>? defaultValue,
]) {
  if (mostrelevantinstanceGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return mostrelevantinstanceGetMaxRes
      .map((e) => mostrelevantinstanceGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.MostrelevantinstanceGetMaxRes>?
    mostrelevantinstanceGetMaxResNullableListFromJson(
  List? mostrelevantinstanceGetMaxRes, [
  List<enums.MostrelevantinstanceGetMaxRes>? defaultValue,
]) {
  if (mostrelevantinstanceGetMaxRes == null) {
    return defaultValue;
  }

  return mostrelevantinstanceGetMaxRes
      .map((e) => mostrelevantinstanceGetMaxResFromJson(e.toString()))
      .toList();
}

String? channelsGetMaxResToJson(enums.ChannelsGetMaxRes? channelsGetMaxRes) {
  return enums.$ChannelsGetMaxResMap[channelsGetMaxRes];
}

enums.ChannelsGetMaxRes channelsGetMaxResFromJson(
  Object? channelsGetMaxRes, [
  enums.ChannelsGetMaxRes? defaultValue,
]) {
  if (channelsGetMaxRes is String) {
    return enums.$ChannelsGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == channelsGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelsGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelsGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> channelsGetMaxResListToJson(
    List<enums.ChannelsGetMaxRes>? channelsGetMaxRes) {
  if (channelsGetMaxRes == null) {
    return [];
  }

  return channelsGetMaxRes.map((e) => enums.$ChannelsGetMaxResMap[e]!).toList();
}

List<enums.ChannelsGetMaxRes> channelsGetMaxResListFromJson(
  List? channelsGetMaxRes, [
  List<enums.ChannelsGetMaxRes>? defaultValue,
]) {
  if (channelsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return channelsGetMaxRes
      .map((e) => channelsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ChannelsGetMaxRes>? channelsGetMaxResNullableListFromJson(
  List? channelsGetMaxRes, [
  List<enums.ChannelsGetMaxRes>? defaultValue,
]) {
  if (channelsGetMaxRes == null) {
    return defaultValue;
  }

  return channelsGetMaxRes
      .map((e) => channelsGetMaxResFromJson(e.toString()))
      .toList();
}

String? networksGetMaxResToJson(enums.NetworksGetMaxRes? networksGetMaxRes) {
  return enums.$NetworksGetMaxResMap[networksGetMaxRes];
}

enums.NetworksGetMaxRes networksGetMaxResFromJson(
  Object? networksGetMaxRes, [
  enums.NetworksGetMaxRes? defaultValue,
]) {
  if (networksGetMaxRes is String) {
    return enums.$NetworksGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == networksGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.NetworksGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$NetworksGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.NetworksGetMaxRes.swaggerGeneratedUnknown;
}

List<String> networksGetMaxResListToJson(
    List<enums.NetworksGetMaxRes>? networksGetMaxRes) {
  if (networksGetMaxRes == null) {
    return [];
  }

  return networksGetMaxRes.map((e) => enums.$NetworksGetMaxResMap[e]!).toList();
}

List<enums.NetworksGetMaxRes> networksGetMaxResListFromJson(
  List? networksGetMaxRes, [
  List<enums.NetworksGetMaxRes>? defaultValue,
]) {
  if (networksGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return networksGetMaxRes
      .map((e) => networksGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.NetworksGetMaxRes>? networksGetMaxResNullableListFromJson(
  List? networksGetMaxRes, [
  List<enums.NetworksGetMaxRes>? defaultValue,
]) {
  if (networksGetMaxRes == null) {
    return defaultValue;
  }

  return networksGetMaxRes
      .map((e) => networksGetMaxResFromJson(e.toString()))
      .toList();
}

String? programsGetSortToJson(enums.ProgramsGetSort? programsGetSort) {
  return enums.$ProgramsGetSortMap[programsGetSort];
}

enums.ProgramsGetSort programsGetSortFromJson(
  Object? programsGetSort, [
  enums.ProgramsGetSort? defaultValue,
]) {
  if (programsGetSort is String) {
    return enums.$ProgramsGetSortMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == programsGetSort.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProgramsGetSort.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProgramsGetSortMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProgramsGetSort.swaggerGeneratedUnknown;
}

List<String> programsGetSortListToJson(
    List<enums.ProgramsGetSort>? programsGetSort) {
  if (programsGetSort == null) {
    return [];
  }

  return programsGetSort.map((e) => enums.$ProgramsGetSortMap[e]!).toList();
}

List<enums.ProgramsGetSort> programsGetSortListFromJson(
  List? programsGetSort, [
  List<enums.ProgramsGetSort>? defaultValue,
]) {
  if (programsGetSort == null) {
    return defaultValue ?? [];
  }

  return programsGetSort
      .map((e) => programsGetSortFromJson(e.toString()))
      .toList();
}

List<enums.ProgramsGetSort>? programsGetSortNullableListFromJson(
  List? programsGetSort, [
  List<enums.ProgramsGetSort>? defaultValue,
]) {
  if (programsGetSort == null) {
    return defaultValue;
  }

  return programsGetSort
      .map((e) => programsGetSortFromJson(e.toString()))
      .toList();
}

String? programsGetMaxResToJson(enums.ProgramsGetMaxRes? programsGetMaxRes) {
  return enums.$ProgramsGetMaxResMap[programsGetMaxRes];
}

enums.ProgramsGetMaxRes programsGetMaxResFromJson(
  Object? programsGetMaxRes, [
  enums.ProgramsGetMaxRes? defaultValue,
]) {
  if (programsGetMaxRes is String) {
    return enums.$ProgramsGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == programsGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProgramsGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProgramsGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProgramsGetMaxRes.swaggerGeneratedUnknown;
}

List<String> programsGetMaxResListToJson(
    List<enums.ProgramsGetMaxRes>? programsGetMaxRes) {
  if (programsGetMaxRes == null) {
    return [];
  }

  return programsGetMaxRes.map((e) => enums.$ProgramsGetMaxResMap[e]!).toList();
}

List<enums.ProgramsGetMaxRes> programsGetMaxResListFromJson(
  List? programsGetMaxRes, [
  List<enums.ProgramsGetMaxRes>? defaultValue,
]) {
  if (programsGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return programsGetMaxRes
      .map((e) => programsGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ProgramsGetMaxRes>? programsGetMaxResNullableListFromJson(
  List? programsGetMaxRes, [
  List<enums.ProgramsGetMaxRes>? defaultValue,
]) {
  if (programsGetMaxRes == null) {
    return defaultValue;
  }

  return programsGetMaxRes
      .map((e) => programsGetMaxResFromJson(e.toString()))
      .toList();
}

String? programsContextualMenuGetMaxResToJson(
    enums.ProgramsContextualMenuGetMaxRes? programsContextualMenuGetMaxRes) {
  return enums
      .$ProgramsContextualMenuGetMaxResMap[programsContextualMenuGetMaxRes];
}

enums.ProgramsContextualMenuGetMaxRes programsContextualMenuGetMaxResFromJson(
  Object? programsContextualMenuGetMaxRes, [
  enums.ProgramsContextualMenuGetMaxRes? defaultValue,
]) {
  if (programsContextualMenuGetMaxRes is String) {
    return enums.$ProgramsContextualMenuGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                programsContextualMenuGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProgramsContextualMenuGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProgramsContextualMenuGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProgramsContextualMenuGetMaxRes.swaggerGeneratedUnknown;
}

List<String> programsContextualMenuGetMaxResListToJson(
    List<enums.ProgramsContextualMenuGetMaxRes>?
        programsContextualMenuGetMaxRes) {
  if (programsContextualMenuGetMaxRes == null) {
    return [];
  }

  return programsContextualMenuGetMaxRes
      .map((e) => enums.$ProgramsContextualMenuGetMaxResMap[e]!)
      .toList();
}

List<enums.ProgramsContextualMenuGetMaxRes>
    programsContextualMenuGetMaxResListFromJson(
  List? programsContextualMenuGetMaxRes, [
  List<enums.ProgramsContextualMenuGetMaxRes>? defaultValue,
]) {
  if (programsContextualMenuGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return programsContextualMenuGetMaxRes
      .map((e) => programsContextualMenuGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.ProgramsContextualMenuGetMaxRes>?
    programsContextualMenuGetMaxResNullableListFromJson(
  List? programsContextualMenuGetMaxRes, [
  List<enums.ProgramsContextualMenuGetMaxRes>? defaultValue,
]) {
  if (programsContextualMenuGetMaxRes == null) {
    return defaultValue;
  }

  return programsContextualMenuGetMaxRes
      .map((e) => programsContextualMenuGetMaxResFromJson(e.toString()))
      .toList();
}

String? replayNetworkTypeToJson(enums.ReplayNetworkType? replayNetworkType) {
  return enums.$ReplayNetworkTypeMap[replayNetworkType];
}

enums.ReplayNetworkType replayNetworkTypeFromJson(
  Object? replayNetworkType, [
  enums.ReplayNetworkType? defaultValue,
]) {
  if (replayNetworkType is String) {
    return enums.$ReplayNetworkTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == replayNetworkType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReplayNetworkType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReplayNetworkTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReplayNetworkType.swaggerGeneratedUnknown;
}

List<String> replayNetworkTypeListToJson(
    List<enums.ReplayNetworkType>? replayNetworkType) {
  if (replayNetworkType == null) {
    return [];
  }

  return replayNetworkType.map((e) => enums.$ReplayNetworkTypeMap[e]!).toList();
}

List<enums.ReplayNetworkType> replayNetworkTypeListFromJson(
  List? replayNetworkType, [
  List<enums.ReplayNetworkType>? defaultValue,
]) {
  if (replayNetworkType == null) {
    return defaultValue ?? [];
  }

  return replayNetworkType
      .map((e) => replayNetworkTypeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayNetworkType>? replayNetworkTypeNullableListFromJson(
  List? replayNetworkType, [
  List<enums.ReplayNetworkType>? defaultValue,
]) {
  if (replayNetworkType == null) {
    return defaultValue;
  }

  return replayNetworkType
      .map((e) => replayNetworkTypeFromJson(e.toString()))
      .toList();
}

String? replayProgramTypeToJson(enums.ReplayProgramType? replayProgramType) {
  return enums.$ReplayProgramTypeMap[replayProgramType];
}

enums.ReplayProgramType replayProgramTypeFromJson(
  Object? replayProgramType, [
  enums.ReplayProgramType? defaultValue,
]) {
  if (replayProgramType is String) {
    return enums.$ReplayProgramTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == replayProgramType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReplayProgramType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReplayProgramTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReplayProgramType.swaggerGeneratedUnknown;
}

List<String> replayProgramTypeListToJson(
    List<enums.ReplayProgramType>? replayProgramType) {
  if (replayProgramType == null) {
    return [];
  }

  return replayProgramType.map((e) => enums.$ReplayProgramTypeMap[e]!).toList();
}

List<enums.ReplayProgramType> replayProgramTypeListFromJson(
  List? replayProgramType, [
  List<enums.ReplayProgramType>? defaultValue,
]) {
  if (replayProgramType == null) {
    return defaultValue ?? [];
  }

  return replayProgramType
      .map((e) => replayProgramTypeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayProgramType>? replayProgramTypeNullableListFromJson(
  List? replayProgramType, [
  List<enums.ReplayProgramType>? defaultValue,
]) {
  if (replayProgramType == null) {
    return defaultValue;
  }

  return replayProgramType
      .map((e) => replayProgramTypeFromJson(e.toString()))
      .toList();
}

String? replayProgramWithInstancesTypeToJson(
    enums.ReplayProgramWithInstancesType? replayProgramWithInstancesType) {
  return enums
      .$ReplayProgramWithInstancesTypeMap[replayProgramWithInstancesType];
}

enums.ReplayProgramWithInstancesType replayProgramWithInstancesTypeFromJson(
  Object? replayProgramWithInstancesType, [
  enums.ReplayProgramWithInstancesType? defaultValue,
]) {
  if (replayProgramWithInstancesType is String) {
    return enums.$ReplayProgramWithInstancesTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                replayProgramWithInstancesType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReplayProgramWithInstancesType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReplayProgramWithInstancesTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReplayProgramWithInstancesType.swaggerGeneratedUnknown;
}

List<String> replayProgramWithInstancesTypeListToJson(
    List<enums.ReplayProgramWithInstancesType>?
        replayProgramWithInstancesType) {
  if (replayProgramWithInstancesType == null) {
    return [];
  }

  return replayProgramWithInstancesType
      .map((e) => enums.$ReplayProgramWithInstancesTypeMap[e]!)
      .toList();
}

List<enums.ReplayProgramWithInstancesType>
    replayProgramWithInstancesTypeListFromJson(
  List? replayProgramWithInstancesType, [
  List<enums.ReplayProgramWithInstancesType>? defaultValue,
]) {
  if (replayProgramWithInstancesType == null) {
    return defaultValue ?? [];
  }

  return replayProgramWithInstancesType
      .map((e) => replayProgramWithInstancesTypeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayProgramWithInstancesType>?
    replayProgramWithInstancesTypeNullableListFromJson(
  List? replayProgramWithInstancesType, [
  List<enums.ReplayProgramWithInstancesType>? defaultValue,
]) {
  if (replayProgramWithInstancesType == null) {
    return defaultValue;
  }

  return replayProgramWithInstancesType
      .map((e) => replayProgramWithInstancesTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
