// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_right_registration_service.enums.swagger.dart' as enums;
export 'liberty_right_registration_service.enums.swagger.dart';

part 'liberty_right_registration_service.swagger.chopper.dart';
part 'liberty_right_registration_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyRightRegistrationService extends ChopperService {
  static LibertyRightRegistrationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyRightRegistrationService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyRightRegistrationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyRightRegistrationService(newClient);
  }

  ///Register an event
  ///@param registerEventParams
  Future<chopper.Response> eventsRegisterPost({
    required RegisterEventParams? registerEventParams,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RegisterEventParams, () => RegisterEventParams.fromJsonFactory);

    return _eventsRegisterPost(
        registerEventParams: registerEventParams, cacheControl: cacheControl);
  }

  ///Register an event
  ///@param registerEventParams
  @Post(path: '/events/register')
  Future<chopper.Response> _eventsRegisterPost({
    @Body() required RegisterEventParams? registerEventParams,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Unregister an event
  ///@param unregisterEventParams
  Future<chopper.Response> eventsUnregisterPost({
    required UnregisterEventParams? unregisterEventParams,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UnregisterEventParams, () => UnregisterEventParams.fromJsonFactory);

    return _eventsUnregisterPost(
        unregisterEventParams: unregisterEventParams,
        cacheControl: cacheControl);
  }

  ///Unregister an event
  ///@param unregisterEventParams
  @Post(path: '/events/unregister')
  Future<chopper.Response> _eventsUnregisterPost({
    @Body() required UnregisterEventParams? unregisterEventParams,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get registrations of an event
  ///@param eventId
  Future<chopper.Response<List<EventRegistration>>>
      eventsEventIdRegistrationsGet({
    required String? eventId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EventRegistration, () => EventRegistration.fromJsonFactory);

    return _eventsEventIdRegistrationsGet(
        eventId: eventId, cacheControl: cacheControl);
  }

  ///Get registrations of an event
  ///@param eventId
  @Get(path: '/events/{eventId}/registrations')
  Future<chopper.Response<List<EventRegistration>>>
      _eventsEventIdRegistrationsGet({
    @Path('eventId') required String? eventId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Schedules event full ingest for registrations and deregistrations. Only one task can be run in same time.
  Future<chopper.Response> tasksRunEventFullIngestPost({String? cacheControl}) {
    return _tasksRunEventFullIngestPost(cacheControl: cacheControl);
  }

  ///Schedules event full ingest for registrations and deregistrations. Only one task can be run in same time.
  @Post(
    path: '/tasks/run-event-full-ingest',
    optionalBody: true,
  )
  Future<chopper.Response> _tasksRunEventFullIngestPost(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class RegisterEventParams {
  RegisterEventParams({
    required this.eventId,
    required this.contentType,
  });

  factory RegisterEventParams.fromJson(Map<String, dynamic> json) =>
      _$RegisterEventParamsFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeParamToJson,
    fromJson: contentTypeParamFromJson,
  )
  final enums.ContentTypeParam contentType;
  static const fromJsonFactory = _$RegisterEventParamsFromJson;
  static const toJsonFactory = _$RegisterEventParamsToJson;
  Map<String, dynamic> toJson() => _$RegisterEventParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RegisterEventParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      runtimeType.hashCode;
}

extension $RegisterEventParamsExtension on RegisterEventParams {
  RegisterEventParams copyWith(
      {String? eventId, enums.ContentTypeParam? contentType}) {
    return RegisterEventParams(
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType);
  }

  RegisterEventParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<enums.ContentTypeParam>? contentType}) {
    return RegisterEventParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType));
  }
}

@JsonSerializable(explicitToJson: true)
class UnregisterEventParams {
  UnregisterEventParams({
    required this.eventId,
    required this.contentType,
  });

  factory UnregisterEventParams.fromJson(Map<String, dynamic> json) =>
      _$UnregisterEventParamsFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeParamToJson,
    fromJson: contentTypeParamFromJson,
  )
  final enums.ContentTypeParam contentType;
  static const fromJsonFactory = _$UnregisterEventParamsFromJson;
  static const toJsonFactory = _$UnregisterEventParamsToJson;
  Map<String, dynamic> toJson() => _$UnregisterEventParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UnregisterEventParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      runtimeType.hashCode;
}

extension $UnregisterEventParamsExtension on UnregisterEventParams {
  UnregisterEventParams copyWith(
      {String? eventId, enums.ContentTypeParam? contentType}) {
    return UnregisterEventParams(
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType);
  }

  UnregisterEventParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<enums.ContentTypeParam>? contentType}) {
    return UnregisterEventParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType));
  }
}

@JsonSerializable(explicitToJson: true)
class EventRegistration {
  EventRegistration({
    required this.eventId,
    required this.contentType,
    this.createDate,
    this.status,
    this.registrationDate,
    this.lastFailureReason,
    this.lastFailureDate,
    this.isReferenced,
    this.resolution,
    this.contentProvider,
  });

  factory EventRegistration.fromJson(Map<String, dynamic> json) =>
      _$EventRegistrationFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: contentTypeToJson,
    fromJson: contentTypeFromJson,
  )
  final enums.ContentType contentType;
  @JsonKey(name: 'createDate', includeIfNull: false)
  final DateTime? createDate;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: registrationStatusToJson,
    fromJson: registrationStatusFromJson,
  )
  final enums.RegistrationStatus? status;
  @JsonKey(name: 'registrationDate', includeIfNull: false)
  final DateTime? registrationDate;
  @JsonKey(name: 'lastFailureReason', includeIfNull: false, defaultValue: '')
  final String? lastFailureReason;
  @JsonKey(name: 'lastFailureDate', includeIfNull: false)
  final DateTime? lastFailureDate;
  @JsonKey(name: 'isReferenced', includeIfNull: false)
  final bool? isReferenced;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'contentProvider', includeIfNull: false, defaultValue: '')
  final String? contentProvider;
  static const fromJsonFactory = _$EventRegistrationFromJson;
  static const toJsonFactory = _$EventRegistrationToJson;
  Map<String, dynamic> toJson() => _$EventRegistrationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventRegistration &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.createDate, createDate) ||
                const DeepCollectionEquality()
                    .equals(other.createDate, createDate)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.registrationDate, registrationDate) ||
                const DeepCollectionEquality()
                    .equals(other.registrationDate, registrationDate)) &&
            (identical(other.lastFailureReason, lastFailureReason) ||
                const DeepCollectionEquality()
                    .equals(other.lastFailureReason, lastFailureReason)) &&
            (identical(other.lastFailureDate, lastFailureDate) ||
                const DeepCollectionEquality()
                    .equals(other.lastFailureDate, lastFailureDate)) &&
            (identical(other.isReferenced, isReferenced) ||
                const DeepCollectionEquality()
                    .equals(other.isReferenced, isReferenced)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.contentProvider, contentProvider) ||
                const DeepCollectionEquality()
                    .equals(other.contentProvider, contentProvider)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(createDate) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(registrationDate) ^
      const DeepCollectionEquality().hash(lastFailureReason) ^
      const DeepCollectionEquality().hash(lastFailureDate) ^
      const DeepCollectionEquality().hash(isReferenced) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(contentProvider) ^
      runtimeType.hashCode;
}

extension $EventRegistrationExtension on EventRegistration {
  EventRegistration copyWith(
      {String? eventId,
      enums.ContentType? contentType,
      DateTime? createDate,
      enums.RegistrationStatus? status,
      DateTime? registrationDate,
      String? lastFailureReason,
      DateTime? lastFailureDate,
      bool? isReferenced,
      String? resolution,
      String? contentProvider}) {
    return EventRegistration(
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType,
        createDate: createDate ?? this.createDate,
        status: status ?? this.status,
        registrationDate: registrationDate ?? this.registrationDate,
        lastFailureReason: lastFailureReason ?? this.lastFailureReason,
        lastFailureDate: lastFailureDate ?? this.lastFailureDate,
        isReferenced: isReferenced ?? this.isReferenced,
        resolution: resolution ?? this.resolution,
        contentProvider: contentProvider ?? this.contentProvider);
  }

  EventRegistration copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<enums.ContentType>? contentType,
      Wrapped<DateTime?>? createDate,
      Wrapped<enums.RegistrationStatus?>? status,
      Wrapped<DateTime?>? registrationDate,
      Wrapped<String?>? lastFailureReason,
      Wrapped<DateTime?>? lastFailureDate,
      Wrapped<bool?>? isReferenced,
      Wrapped<String?>? resolution,
      Wrapped<String?>? contentProvider}) {
    return EventRegistration(
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        createDate: (createDate != null ? createDate.value : this.createDate),
        status: (status != null ? status.value : this.status),
        registrationDate: (registrationDate != null
            ? registrationDate.value
            : this.registrationDate),
        lastFailureReason: (lastFailureReason != null
            ? lastFailureReason.value
            : this.lastFailureReason),
        lastFailureDate: (lastFailureDate != null
            ? lastFailureDate.value
            : this.lastFailureDate),
        isReferenced:
            (isReferenced != null ? isReferenced.value : this.isReferenced),
        resolution: (resolution != null ? resolution.value : this.resolution),
        contentProvider: (contentProvider != null
            ? contentProvider.value
            : this.contentProvider));
  }
}

String? contentTypeParamToJson(enums.ContentTypeParam? contentTypeParam) {
  return enums.$ContentTypeParamMap[contentTypeParam];
}

enums.ContentTypeParam contentTypeParamFromJson(
  Object? contentTypeParam, [
  enums.ContentTypeParam? defaultValue,
]) {
  if (contentTypeParam is String) {
    return enums.$ContentTypeParamMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == contentTypeParam.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ContentTypeParam.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContentTypeParamMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContentTypeParam.swaggerGeneratedUnknown;
}

List<String> contentTypeParamListToJson(
    List<enums.ContentTypeParam>? contentTypeParam) {
  if (contentTypeParam == null) {
    return [];
  }

  return contentTypeParam.map((e) => enums.$ContentTypeParamMap[e]!).toList();
}

List<enums.ContentTypeParam> contentTypeParamListFromJson(
  List? contentTypeParam, [
  List<enums.ContentTypeParam>? defaultValue,
]) {
  if (contentTypeParam == null) {
    return defaultValue ?? [];
  }

  return contentTypeParam
      .map((e) => contentTypeParamFromJson(e.toString()))
      .toList();
}

List<enums.ContentTypeParam>? contentTypeParamNullableListFromJson(
  List? contentTypeParam, [
  List<enums.ContentTypeParam>? defaultValue,
]) {
  if (contentTypeParam == null) {
    return defaultValue;
  }

  return contentTypeParam
      .map((e) => contentTypeParamFromJson(e.toString()))
      .toList();
}

String? contentTypeToJson(enums.ContentType? contentType) {
  return enums.$ContentTypeMap[contentType];
}

enums.ContentType contentTypeFromJson(
  Object? contentType, [
  enums.ContentType? defaultValue,
]) {
  if (contentType is String) {
    return enums.$ContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == contentType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ContentType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ContentType.swaggerGeneratedUnknown;
}

List<String> contentTypeListToJson(List<enums.ContentType>? contentType) {
  if (contentType == null) {
    return [];
  }

  return contentType.map((e) => enums.$ContentTypeMap[e]!).toList();
}

List<enums.ContentType> contentTypeListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue ?? [];
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

List<enums.ContentType>? contentTypeNullableListFromJson(
  List? contentType, [
  List<enums.ContentType>? defaultValue,
]) {
  if (contentType == null) {
    return defaultValue;
  }

  return contentType.map((e) => contentTypeFromJson(e.toString())).toList();
}

String? registrationStatusToJson(enums.RegistrationStatus? registrationStatus) {
  return enums.$RegistrationStatusMap[registrationStatus];
}

enums.RegistrationStatus registrationStatusFromJson(
  Object? registrationStatus, [
  enums.RegistrationStatus? defaultValue,
]) {
  if (registrationStatus is String) {
    return enums.$RegistrationStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == registrationStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.RegistrationStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RegistrationStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RegistrationStatus.swaggerGeneratedUnknown;
}

List<String> registrationStatusListToJson(
    List<enums.RegistrationStatus>? registrationStatus) {
  if (registrationStatus == null) {
    return [];
  }

  return registrationStatus
      .map((e) => enums.$RegistrationStatusMap[e]!)
      .toList();
}

List<enums.RegistrationStatus> registrationStatusListFromJson(
  List? registrationStatus, [
  List<enums.RegistrationStatus>? defaultValue,
]) {
  if (registrationStatus == null) {
    return defaultValue ?? [];
  }

  return registrationStatus
      .map((e) => registrationStatusFromJson(e.toString()))
      .toList();
}

List<enums.RegistrationStatus>? registrationStatusNullableListFromJson(
  List? registrationStatus, [
  List<enums.RegistrationStatus>? defaultValue,
]) {
  if (registrationStatus == null) {
    return defaultValue;
  }

  return registrationStatus
      .map((e) => registrationStatusFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
