// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_simple_search_service.enums.swagger.dart' as enums;
export 'liberty_simple_search_service.enums.swagger.dart';

part 'liberty_simple_search_service.swagger.chopper.dart';
part 'liberty_simple_search_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertySimpleSearchService extends ChopperService {
  static LibertySimpleSearchService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertySimpleSearchService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertySimpleSearchService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertySimpleSearchService(newClient);
  }

  ///Handles Simple Search
  ///@param
  ///@param
  ///@param
  ///@param body Simple Search Request Body
  Future<chopper.Response<RecommendationsResponse>> searchPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required SimpleSearchRequestBody? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimpleSearchRequestBody, () => SimpleSearchRequestBody.fromJsonFactory);
    generatedMapping.putIfAbsent(
        RecommendationsResponse, () => RecommendationsResponse.fromJsonFactory);

    return _searchPost(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        body: body,
        cacheControl: cacheControl);
  }

  ///Handles Simple Search
  ///@param
  ///@param
  ///@param
  ///@param body Simple Search Request Body
  @Post(path: '/search')
  Future<chopper.Response<RecommendationsResponse>> _searchPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Body() required SimpleSearchRequestBody? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Handles Learn Actions
  ///@param
  ///@param
  ///@param body Learn Action Request Body
  Future<chopper.Response> learnActionPost({
    String? xDev,
    String? xCus = 'X-Cus',
    required LearnActionRequestBody? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LearnActionRequestBody, () => LearnActionRequestBody.fromJsonFactory);

    return _learnActionPost(
        xDev: xDev, xCus: xCus, body: body, cacheControl: cacheControl);
  }

  ///Handles Learn Actions
  ///@param
  ///@param
  ///@param body Learn Action Request Body
  @Post(path: '/learn-action')
  Future<chopper.Response> _learnActionPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Body() required LearnActionRequestBody? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Handles More-Like-This based on titles
  ///@param body More-like-this Request Body
  Future<chopper.Response<RecommendationsResponse>> moreLikeThisPost({
    required MoreLikeThisRequestBody? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisRequestBody, () => MoreLikeThisRequestBody.fromJsonFactory);
    generatedMapping.putIfAbsent(
        RecommendationsResponse, () => RecommendationsResponse.fromJsonFactory);

    return _moreLikeThisPost(body: body, cacheControl: cacheControl);
  }

  ///Handles More-Like-This based on titles
  ///@param body More-like-this Request Body
  @Post(path: '/more-like-this')
  Future<chopper.Response<RecommendationsResponse>> _moreLikeThisPost({
    @Body() required MoreLikeThisRequestBody? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Handles TopSearchList based on learn action 'Click on Search'
  ///@param body Top Search List Request Body
  Future<chopper.Response<RecommendationsResponse>> topSearchListPost({
    required TopSearchListRequestBody? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TopSearchListRequestBody,
        () => TopSearchListRequestBody.fromJsonFactory);
    generatedMapping.putIfAbsent(
        RecommendationsResponse, () => RecommendationsResponse.fromJsonFactory);

    return _topSearchListPost(body: body, cacheControl: cacheControl);
  }

  ///Handles TopSearchList based on learn action 'Click on Search'
  ///@param body Top Search List Request Body
  @Post(path: '/top-search-list')
  Future<chopper.Response<RecommendationsResponse>> _topSearchListPost({
    @Body() required TopSearchListRequestBody? body,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class SimpleSearchRequestBody {
  SimpleSearchRequestBody({
    required this.clientType,
    required this.searchTerm,
    required this.language,
    required this.startResults,
    required this.maxResults,
    required this.contentSources,
    this.filterTimeWindowStart,
    this.filterTimeWindowEnd,
  });

  factory SimpleSearchRequestBody.fromJson(Map<String, dynamic> json) =>
      _$SimpleSearchRequestBodyFromJson(json);

  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(name: 'searchTerm', includeIfNull: false, defaultValue: '')
  final String searchTerm;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String language;
  @JsonKey(name: 'startResults', includeIfNull: false)
  final int startResults;
  @JsonKey(name: 'maxResults', includeIfNull: false)
  final int maxResults;
  @JsonKey(
      name: 'contentSources', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> contentSources;
  @JsonKey(name: 'filterTimeWindowStart', includeIfNull: false)
  final num? filterTimeWindowStart;
  @JsonKey(name: 'filterTimeWindowEnd', includeIfNull: false)
  final num? filterTimeWindowEnd;
  static const fromJsonFactory = _$SimpleSearchRequestBodyFromJson;
  static const toJsonFactory = _$SimpleSearchRequestBodyToJson;
  Map<String, dynamic> toJson() => _$SimpleSearchRequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleSearchRequestBody &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(other.searchTerm, searchTerm) ||
                const DeepCollectionEquality()
                    .equals(other.searchTerm, searchTerm)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.startResults, startResults) ||
                const DeepCollectionEquality()
                    .equals(other.startResults, startResults)) &&
            (identical(other.maxResults, maxResults) ||
                const DeepCollectionEquality()
                    .equals(other.maxResults, maxResults)) &&
            (identical(other.contentSources, contentSources) ||
                const DeepCollectionEquality()
                    .equals(other.contentSources, contentSources)) &&
            (identical(other.filterTimeWindowStart, filterTimeWindowStart) ||
                const DeepCollectionEquality().equals(
                    other.filterTimeWindowStart, filterTimeWindowStart)) &&
            (identical(other.filterTimeWindowEnd, filterTimeWindowEnd) ||
                const DeepCollectionEquality()
                    .equals(other.filterTimeWindowEnd, filterTimeWindowEnd)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(searchTerm) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(startResults) ^
      const DeepCollectionEquality().hash(maxResults) ^
      const DeepCollectionEquality().hash(contentSources) ^
      const DeepCollectionEquality().hash(filterTimeWindowStart) ^
      const DeepCollectionEquality().hash(filterTimeWindowEnd) ^
      runtimeType.hashCode;
}

extension $SimpleSearchRequestBodyExtension on SimpleSearchRequestBody {
  SimpleSearchRequestBody copyWith(
      {String? clientType,
      String? searchTerm,
      String? language,
      int? startResults,
      int? maxResults,
      List<Object>? contentSources,
      num? filterTimeWindowStart,
      num? filterTimeWindowEnd}) {
    return SimpleSearchRequestBody(
        clientType: clientType ?? this.clientType,
        searchTerm: searchTerm ?? this.searchTerm,
        language: language ?? this.language,
        startResults: startResults ?? this.startResults,
        maxResults: maxResults ?? this.maxResults,
        contentSources: contentSources ?? this.contentSources,
        filterTimeWindowStart:
            filterTimeWindowStart ?? this.filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd ?? this.filterTimeWindowEnd);
  }

  SimpleSearchRequestBody copyWithWrapped(
      {Wrapped<String>? clientType,
      Wrapped<String>? searchTerm,
      Wrapped<String>? language,
      Wrapped<int>? startResults,
      Wrapped<int>? maxResults,
      Wrapped<List<Object>>? contentSources,
      Wrapped<num?>? filterTimeWindowStart,
      Wrapped<num?>? filterTimeWindowEnd}) {
    return SimpleSearchRequestBody(
        clientType: (clientType != null ? clientType.value : this.clientType),
        searchTerm: (searchTerm != null ? searchTerm.value : this.searchTerm),
        language: (language != null ? language.value : this.language),
        startResults:
            (startResults != null ? startResults.value : this.startResults),
        maxResults: (maxResults != null ? maxResults.value : this.maxResults),
        contentSources: (contentSources != null
            ? contentSources.value
            : this.contentSources),
        filterTimeWindowStart: (filterTimeWindowStart != null
            ? filterTimeWindowStart.value
            : this.filterTimeWindowStart),
        filterTimeWindowEnd: (filterTimeWindowEnd != null
            ? filterTimeWindowEnd.value
            : this.filterTimeWindowEnd));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisRequestBody {
  MoreLikeThisRequestBody({
    required this.clientType,
    required this.resourceContentSourceId,
    required this.resourceId,
    required this.language,
    required this.maxResults,
    required this.contentSources,
  });

  factory MoreLikeThisRequestBody.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisRequestBodyFromJson(json);

  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(
      name: 'resourceContentSourceId', includeIfNull: false, defaultValue: '')
  final String resourceContentSourceId;
  @JsonKey(name: 'resourceId', includeIfNull: false, defaultValue: '')
  final String resourceId;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String language;
  @JsonKey(name: 'maxResults', includeIfNull: false)
  final int maxResults;
  @JsonKey(
      name: 'contentSources', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> contentSources;
  static const fromJsonFactory = _$MoreLikeThisRequestBodyFromJson;
  static const toJsonFactory = _$MoreLikeThisRequestBodyToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisRequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MoreLikeThisRequestBody &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(
                    other.resourceContentSourceId, resourceContentSourceId) ||
                const DeepCollectionEquality().equals(
                    other.resourceContentSourceId, resourceContentSourceId)) &&
            (identical(other.resourceId, resourceId) ||
                const DeepCollectionEquality()
                    .equals(other.resourceId, resourceId)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.maxResults, maxResults) ||
                const DeepCollectionEquality()
                    .equals(other.maxResults, maxResults)) &&
            (identical(other.contentSources, contentSources) ||
                const DeepCollectionEquality()
                    .equals(other.contentSources, contentSources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(resourceContentSourceId) ^
      const DeepCollectionEquality().hash(resourceId) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(maxResults) ^
      const DeepCollectionEquality().hash(contentSources) ^
      runtimeType.hashCode;
}

extension $MoreLikeThisRequestBodyExtension on MoreLikeThisRequestBody {
  MoreLikeThisRequestBody copyWith(
      {String? clientType,
      String? resourceContentSourceId,
      String? resourceId,
      String? language,
      int? maxResults,
      List<Object>? contentSources}) {
    return MoreLikeThisRequestBody(
        clientType: clientType ?? this.clientType,
        resourceContentSourceId:
            resourceContentSourceId ?? this.resourceContentSourceId,
        resourceId: resourceId ?? this.resourceId,
        language: language ?? this.language,
        maxResults: maxResults ?? this.maxResults,
        contentSources: contentSources ?? this.contentSources);
  }

  MoreLikeThisRequestBody copyWithWrapped(
      {Wrapped<String>? clientType,
      Wrapped<String>? resourceContentSourceId,
      Wrapped<String>? resourceId,
      Wrapped<String>? language,
      Wrapped<int>? maxResults,
      Wrapped<List<Object>>? contentSources}) {
    return MoreLikeThisRequestBody(
        clientType: (clientType != null ? clientType.value : this.clientType),
        resourceContentSourceId: (resourceContentSourceId != null
            ? resourceContentSourceId.value
            : this.resourceContentSourceId),
        resourceId: (resourceId != null ? resourceId.value : this.resourceId),
        language: (language != null ? language.value : this.language),
        maxResults: (maxResults != null ? maxResults.value : this.maxResults),
        contentSources: (contentSources != null
            ? contentSources.value
            : this.contentSources));
  }
}

@JsonSerializable(explicitToJson: true)
class TopSearchListRequestBody {
  TopSearchListRequestBody({
    required this.clientType,
    required this.language,
    required this.maxResults,
    required this.contentSources,
  });

  factory TopSearchListRequestBody.fromJson(Map<String, dynamic> json) =>
      _$TopSearchListRequestBodyFromJson(json);

  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String language;
  @JsonKey(name: 'maxResults', includeIfNull: false)
  final int maxResults;
  @JsonKey(
      name: 'contentSources', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> contentSources;
  static const fromJsonFactory = _$TopSearchListRequestBodyFromJson;
  static const toJsonFactory = _$TopSearchListRequestBodyToJson;
  Map<String, dynamic> toJson() => _$TopSearchListRequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopSearchListRequestBody &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)) &&
            (identical(other.maxResults, maxResults) ||
                const DeepCollectionEquality()
                    .equals(other.maxResults, maxResults)) &&
            (identical(other.contentSources, contentSources) ||
                const DeepCollectionEquality()
                    .equals(other.contentSources, contentSources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(language) ^
      const DeepCollectionEquality().hash(maxResults) ^
      const DeepCollectionEquality().hash(contentSources) ^
      runtimeType.hashCode;
}

extension $TopSearchListRequestBodyExtension on TopSearchListRequestBody {
  TopSearchListRequestBody copyWith(
      {String? clientType,
      String? language,
      int? maxResults,
      List<Object>? contentSources}) {
    return TopSearchListRequestBody(
        clientType: clientType ?? this.clientType,
        language: language ?? this.language,
        maxResults: maxResults ?? this.maxResults,
        contentSources: contentSources ?? this.contentSources);
  }

  TopSearchListRequestBody copyWithWrapped(
      {Wrapped<String>? clientType,
      Wrapped<String>? language,
      Wrapped<int>? maxResults,
      Wrapped<List<Object>>? contentSources}) {
    return TopSearchListRequestBody(
        clientType: (clientType != null ? clientType.value : this.clientType),
        language: (language != null ? language.value : this.language),
        maxResults: (maxResults != null ? maxResults.value : this.maxResults),
        contentSources: (contentSources != null
            ? contentSources.value
            : this.contentSources));
  }
}

@JsonSerializable(explicitToJson: true)
class RecommendationsResponse {
  RecommendationsResponse({
    required this.recommendations,
  });

  factory RecommendationsResponse.fromJson(Map<String, dynamic> json) =>
      _$RecommendationsResponseFromJson(json);

  @JsonKey(
      name: 'recommendations',
      includeIfNull: false,
      defaultValue: <Recommendation>[])
  final List<Recommendation> recommendations;
  static const fromJsonFactory = _$RecommendationsResponseFromJson;
  static const toJsonFactory = _$RecommendationsResponseToJson;
  Map<String, dynamic> toJson() => _$RecommendationsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecommendationsResponse &&
            (identical(other.recommendations, recommendations) ||
                const DeepCollectionEquality()
                    .equals(other.recommendations, recommendations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recommendations) ^
      runtimeType.hashCode;
}

extension $RecommendationsResponseExtension on RecommendationsResponse {
  RecommendationsResponse copyWith({List<Recommendation>? recommendations}) {
    return RecommendationsResponse(
        recommendations: recommendations ?? this.recommendations);
  }

  RecommendationsResponse copyWithWrapped(
      {Wrapped<List<Recommendation>>? recommendations}) {
    return RecommendationsResponse(
        recommendations: (recommendations != null
            ? recommendations.value
            : this.recommendations));
  }
}

@JsonSerializable(explicitToJson: true)
class Recommendation {
  Recommendation({
    required this.contentSourceId,
    required this.contentItemId,
    required this.contentLocationId,
    this.seriesId,
    this.collapseSeries,
    this.collapseInstance,
  });

  factory Recommendation.fromJson(Map<String, dynamic> json) =>
      _$RecommendationFromJson(json);

  @JsonKey(name: 'contentSourceId', includeIfNull: false, defaultValue: '')
  final String contentSourceId;
  @JsonKey(name: 'contentItemId', includeIfNull: false, defaultValue: '')
  final String contentItemId;
  @JsonKey(name: 'contentLocationId', includeIfNull: false, defaultValue: '')
  final String contentLocationId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'collapseSeries', includeIfNull: false, defaultValue: '')
  final String? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false, defaultValue: '')
  final String? collapseInstance;
  static const fromJsonFactory = _$RecommendationFromJson;
  static const toJsonFactory = _$RecommendationToJson;
  Map<String, dynamic> toJson() => _$RecommendationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Recommendation &&
            (identical(other.contentSourceId, contentSourceId) ||
                const DeepCollectionEquality()
                    .equals(other.contentSourceId, contentSourceId)) &&
            (identical(other.contentItemId, contentItemId) ||
                const DeepCollectionEquality()
                    .equals(other.contentItemId, contentItemId)) &&
            (identical(other.contentLocationId, contentLocationId) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocationId, contentLocationId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSourceId) ^
      const DeepCollectionEquality().hash(contentItemId) ^
      const DeepCollectionEquality().hash(contentLocationId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      runtimeType.hashCode;
}

extension $RecommendationExtension on Recommendation {
  Recommendation copyWith(
      {String? contentSourceId,
      String? contentItemId,
      String? contentLocationId,
      String? seriesId,
      String? collapseSeries,
      String? collapseInstance}) {
    return Recommendation(
        contentSourceId: contentSourceId ?? this.contentSourceId,
        contentItemId: contentItemId ?? this.contentItemId,
        contentLocationId: contentLocationId ?? this.contentLocationId,
        seriesId: seriesId ?? this.seriesId,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance);
  }

  Recommendation copyWithWrapped(
      {Wrapped<String>? contentSourceId,
      Wrapped<String>? contentItemId,
      Wrapped<String>? contentLocationId,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? collapseSeries,
      Wrapped<String?>? collapseInstance}) {
    return Recommendation(
        contentSourceId: (contentSourceId != null
            ? contentSourceId.value
            : this.contentSourceId),
        contentItemId:
            (contentItemId != null ? contentItemId.value : this.contentItemId),
        contentLocationId: (contentLocationId != null
            ? contentLocationId.value
            : this.contentLocationId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance));
  }
}

@JsonSerializable(explicitToJson: true)
class LearnActionRequestBody {
  LearnActionRequestBody({
    required this.clientType,
    this.contentSourceId,
    this.actionId,
    this.contentItemId,
    this.contentItemInstanceId,
    this.profileId,
  });

  factory LearnActionRequestBody.fromJson(Map<String, dynamic> json) =>
      _$LearnActionRequestBodyFromJson(json);

  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(name: 'contentSourceId', includeIfNull: false, defaultValue: '')
  final String? contentSourceId;
  @JsonKey(name: 'actionId', includeIfNull: false)
  final int? actionId;
  @JsonKey(name: 'contentItemId', includeIfNull: false, defaultValue: '')
  final String? contentItemId;
  @JsonKey(
      name: 'contentItemInstanceId', includeIfNull: false, defaultValue: '')
  final String? contentItemInstanceId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  static const fromJsonFactory = _$LearnActionRequestBodyFromJson;
  static const toJsonFactory = _$LearnActionRequestBodyToJson;
  Map<String, dynamic> toJson() => _$LearnActionRequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LearnActionRequestBody &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(other.contentSourceId, contentSourceId) ||
                const DeepCollectionEquality()
                    .equals(other.contentSourceId, contentSourceId)) &&
            (identical(other.actionId, actionId) ||
                const DeepCollectionEquality()
                    .equals(other.actionId, actionId)) &&
            (identical(other.contentItemId, contentItemId) ||
                const DeepCollectionEquality()
                    .equals(other.contentItemId, contentItemId)) &&
            (identical(other.contentItemInstanceId, contentItemInstanceId) ||
                const DeepCollectionEquality().equals(
                    other.contentItemInstanceId, contentItemInstanceId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(contentSourceId) ^
      const DeepCollectionEquality().hash(actionId) ^
      const DeepCollectionEquality().hash(contentItemId) ^
      const DeepCollectionEquality().hash(contentItemInstanceId) ^
      const DeepCollectionEquality().hash(profileId) ^
      runtimeType.hashCode;
}

extension $LearnActionRequestBodyExtension on LearnActionRequestBody {
  LearnActionRequestBody copyWith(
      {String? clientType,
      String? contentSourceId,
      int? actionId,
      String? contentItemId,
      String? contentItemInstanceId,
      String? profileId}) {
    return LearnActionRequestBody(
        clientType: clientType ?? this.clientType,
        contentSourceId: contentSourceId ?? this.contentSourceId,
        actionId: actionId ?? this.actionId,
        contentItemId: contentItemId ?? this.contentItemId,
        contentItemInstanceId:
            contentItemInstanceId ?? this.contentItemInstanceId,
        profileId: profileId ?? this.profileId);
  }

  LearnActionRequestBody copyWithWrapped(
      {Wrapped<String>? clientType,
      Wrapped<String?>? contentSourceId,
      Wrapped<int?>? actionId,
      Wrapped<String?>? contentItemId,
      Wrapped<String?>? contentItemInstanceId,
      Wrapped<String?>? profileId}) {
    return LearnActionRequestBody(
        clientType: (clientType != null ? clientType.value : this.clientType),
        contentSourceId: (contentSourceId != null
            ? contentSourceId.value
            : this.contentSourceId),
        actionId: (actionId != null ? actionId.value : this.actionId),
        contentItemId:
            (contentItemId != null ? contentItemId.value : this.contentItemId),
        contentItemInstanceId: (contentItemInstanceId != null
            ? contentItemInstanceId.value
            : this.contentItemInstanceId),
        profileId: (profileId != null ? profileId.value : this.profileId));
  }
}

String? simpleSearchRequestBodyContentSourcesToJson(
    enums.SimpleSearchRequestBodyContentSources?
        simpleSearchRequestBodyContentSources) {
  return enums.$SimpleSearchRequestBodyContentSourcesMap[
      simpleSearchRequestBodyContentSources];
}

enums.SimpleSearchRequestBodyContentSources
    simpleSearchRequestBodyContentSourcesFromJson(
  Object? simpleSearchRequestBodyContentSources, [
  enums.SimpleSearchRequestBodyContentSources? defaultValue,
]) {
  if (simpleSearchRequestBodyContentSources is String) {
    return enums.$SimpleSearchRequestBodyContentSourcesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                simpleSearchRequestBodyContentSources.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SimpleSearchRequestBodyContentSources
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SimpleSearchRequestBodyContentSourcesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SimpleSearchRequestBodyContentSources.swaggerGeneratedUnknown;
}

List<String> simpleSearchRequestBodyContentSourcesListToJson(
    List<enums.SimpleSearchRequestBodyContentSources>?
        simpleSearchRequestBodyContentSources) {
  if (simpleSearchRequestBodyContentSources == null) {
    return [];
  }

  return simpleSearchRequestBodyContentSources
      .map((e) => enums.$SimpleSearchRequestBodyContentSourcesMap[e]!)
      .toList();
}

List<enums.SimpleSearchRequestBodyContentSources>
    simpleSearchRequestBodyContentSourcesListFromJson(
  List? simpleSearchRequestBodyContentSources, [
  List<enums.SimpleSearchRequestBodyContentSources>? defaultValue,
]) {
  if (simpleSearchRequestBodyContentSources == null) {
    return defaultValue ?? [];
  }

  return simpleSearchRequestBodyContentSources
      .map((e) => simpleSearchRequestBodyContentSourcesFromJson(e.toString()))
      .toList();
}

List<enums.SimpleSearchRequestBodyContentSources>?
    simpleSearchRequestBodyContentSourcesNullableListFromJson(
  List? simpleSearchRequestBodyContentSources, [
  List<enums.SimpleSearchRequestBodyContentSources>? defaultValue,
]) {
  if (simpleSearchRequestBodyContentSources == null) {
    return defaultValue;
  }

  return simpleSearchRequestBodyContentSources
      .map((e) => simpleSearchRequestBodyContentSourcesFromJson(e.toString()))
      .toList();
}

String? moreLikeThisRequestBodyContentSourcesToJson(
    enums.MoreLikeThisRequestBodyContentSources?
        moreLikeThisRequestBodyContentSources) {
  return enums.$MoreLikeThisRequestBodyContentSourcesMap[
      moreLikeThisRequestBodyContentSources];
}

enums.MoreLikeThisRequestBodyContentSources
    moreLikeThisRequestBodyContentSourcesFromJson(
  Object? moreLikeThisRequestBodyContentSources, [
  enums.MoreLikeThisRequestBodyContentSources? defaultValue,
]) {
  if (moreLikeThisRequestBodyContentSources is String) {
    return enums.$MoreLikeThisRequestBodyContentSourcesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                moreLikeThisRequestBodyContentSources.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MoreLikeThisRequestBodyContentSources
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MoreLikeThisRequestBodyContentSourcesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MoreLikeThisRequestBodyContentSources.swaggerGeneratedUnknown;
}

List<String> moreLikeThisRequestBodyContentSourcesListToJson(
    List<enums.MoreLikeThisRequestBodyContentSources>?
        moreLikeThisRequestBodyContentSources) {
  if (moreLikeThisRequestBodyContentSources == null) {
    return [];
  }

  return moreLikeThisRequestBodyContentSources
      .map((e) => enums.$MoreLikeThisRequestBodyContentSourcesMap[e]!)
      .toList();
}

List<enums.MoreLikeThisRequestBodyContentSources>
    moreLikeThisRequestBodyContentSourcesListFromJson(
  List? moreLikeThisRequestBodyContentSources, [
  List<enums.MoreLikeThisRequestBodyContentSources>? defaultValue,
]) {
  if (moreLikeThisRequestBodyContentSources == null) {
    return defaultValue ?? [];
  }

  return moreLikeThisRequestBodyContentSources
      .map((e) => moreLikeThisRequestBodyContentSourcesFromJson(e.toString()))
      .toList();
}

List<enums.MoreLikeThisRequestBodyContentSources>?
    moreLikeThisRequestBodyContentSourcesNullableListFromJson(
  List? moreLikeThisRequestBodyContentSources, [
  List<enums.MoreLikeThisRequestBodyContentSources>? defaultValue,
]) {
  if (moreLikeThisRequestBodyContentSources == null) {
    return defaultValue;
  }

  return moreLikeThisRequestBodyContentSources
      .map((e) => moreLikeThisRequestBodyContentSourcesFromJson(e.toString()))
      .toList();
}

String? topSearchListRequestBodyContentSourcesToJson(
    enums.TopSearchListRequestBodyContentSources?
        topSearchListRequestBodyContentSources) {
  return enums.$TopSearchListRequestBodyContentSourcesMap[
      topSearchListRequestBodyContentSources];
}

enums.TopSearchListRequestBodyContentSources
    topSearchListRequestBodyContentSourcesFromJson(
  Object? topSearchListRequestBodyContentSources, [
  enums.TopSearchListRequestBodyContentSources? defaultValue,
]) {
  if (topSearchListRequestBodyContentSources is String) {
    return enums.$TopSearchListRequestBodyContentSourcesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                topSearchListRequestBodyContentSources.toLowerCase(),
            orElse: () => const MapEntry(
                enums.TopSearchListRequestBodyContentSources
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TopSearchListRequestBodyContentSourcesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.TopSearchListRequestBodyContentSources.swaggerGeneratedUnknown;
}

List<String> topSearchListRequestBodyContentSourcesListToJson(
    List<enums.TopSearchListRequestBodyContentSources>?
        topSearchListRequestBodyContentSources) {
  if (topSearchListRequestBodyContentSources == null) {
    return [];
  }

  return topSearchListRequestBodyContentSources
      .map((e) => enums.$TopSearchListRequestBodyContentSourcesMap[e]!)
      .toList();
}

List<enums.TopSearchListRequestBodyContentSources>
    topSearchListRequestBodyContentSourcesListFromJson(
  List? topSearchListRequestBodyContentSources, [
  List<enums.TopSearchListRequestBodyContentSources>? defaultValue,
]) {
  if (topSearchListRequestBodyContentSources == null) {
    return defaultValue ?? [];
  }

  return topSearchListRequestBodyContentSources
      .map((e) => topSearchListRequestBodyContentSourcesFromJson(e.toString()))
      .toList();
}

List<enums.TopSearchListRequestBodyContentSources>?
    topSearchListRequestBodyContentSourcesNullableListFromJson(
  List? topSearchListRequestBodyContentSources, [
  List<enums.TopSearchListRequestBodyContentSources>? defaultValue,
]) {
  if (topSearchListRequestBodyContentSources == null) {
    return defaultValue;
  }

  return topSearchListRequestBodyContentSources
      .map((e) => topSearchListRequestBodyContentSourcesFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
