import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_thumbnails_service.swagger.chopper.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyThumbnailsService extends ChopperService {
  static LibertyThumbnailsService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyThumbnailsService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyThumbnailsService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyThumbnailsService(newClient);
  }

  ///Uploads thumbnails files
  ///@param assetId Content reference identifier
  ///@param files Thumbnail files
  Future<chopper.Response> assetsAssetIdThumbnailsPost({
    required String? assetId,
    required List<String>? files,
    String? cacheControl,
  }) {
    return _assetsAssetIdThumbnailsPost(
        assetId: assetId, files: files, cacheControl: cacheControl);
  }

  ///Uploads thumbnails files
  ///@param assetId Content reference identifier
  ///@param files Thumbnail files
  @Post(
    path: '/assets/{assetId}/thumbnails',
    optionalBody: true,
  )
  Future<chopper.Response> _assetsAssetIdThumbnailsPost({
    @Path('assetId') required String? assetId,
    @Field('files') required List<String>? files,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Cleanup thumbnails files
  ///@param assetId Content reference identifier
  Future<chopper.Response> assetsAssetIdThumbnailsDelete({
    required String? assetId,
    String? cacheControl,
  }) {
    return _assetsAssetIdThumbnailsDelete(
        assetId: assetId, cacheControl: cacheControl);
  }

  ///Cleanup thumbnails files
  ///@param assetId Content reference identifier
  @Delete(path: '/assets/{assetId}/thumbnails')
  Future<chopper.Response> _assetsAssetIdThumbnailsDelete({
    @Path('assetId') required String? assetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Assetize content from rolling buffer
  ///@param body
  Future<chopper.Response> assetsAssetizePost({
    String? body,
    String? cacheControl,
  }) {
    return _assetsAssetizePost(body: body, cacheControl: cacheControl);
  }

  ///Assetize content from rolling buffer
  ///@param body
  @Post(path: '/assets/assetize')
  Future<chopper.Response> _assetsAssetizePost({
    @Body() String? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get binary file
  ///@param assetId Content reference identifier
  ///@param binFileName Binary file name
  ///@param Range Requested binary data range
  Future<chopper.Response> assetsAssetIdBinFileNameGet({
    required String? assetId,
    required String? binFileName,
    String? range,
    String? cacheControl,
  }) {
    return _assetsAssetIdBinFileNameGet(
        assetId: assetId,
        binFileName: binFileName,
        range: range,
        cacheControl: cacheControl);
  }

  ///Get binary file
  ///@param assetId Content reference identifier
  ///@param binFileName Binary file name
  ///@param Range Requested binary data range
  @Get(path: '/assets/{assetId}/{binFileName}')
  Future<chopper.Response> _assetsAssetIdBinFileNameGet({
    @Path('assetId') required String? assetId,
    @Path('binFileName') required String? binFileName,
    @Header('Range') String? range,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get or create WebVTT file
  ///@param assetId Content reference identifier
  ///@param start-offset Start offset (in seconds)
  ///@param end-offset End offset (in seconds)
  ///@param X-Original-URI
  Future<chopper.Response> assetsAssetIdGet({
    required String? assetId,
    String? startOffset,
    String? endOffset,
    String? xOriginalURI,
    String? cacheControl,
  }) {
    return _assetsAssetIdGet(
        assetId: assetId,
        startOffset: startOffset,
        endOffset: endOffset,
        xOriginalURI: xOriginalURI,
        cacheControl: cacheControl);
  }

  ///Get or create WebVTT file
  ///@param assetId Content reference identifier
  ///@param start-offset Start offset (in seconds)
  ///@param end-offset End offset (in seconds)
  ///@param X-Original-URI
  @Get(path: '/assets/{assetId}')
  Future<chopper.Response> _assetsAssetIdGet({
    @Path('assetId') required String? assetId,
    @Query('start-offset') String? startOffset,
    @Query('end-offset') String? endOffset,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  Future<chopper.Response> channelsChannelIdBinFileNameGet({
    required String? channelId,
    required String? binFileName,
    String? cacheControl,
  }) {
    return _channelsChannelIdBinFileNameGet(
        channelId: channelId,
        binFileName: binFileName,
        cacheControl: cacheControl);
  }

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  @Get(path: '/channels/{channelId}/{binFileName}')
  Future<chopper.Response> _channelsChannelIdBinFileNameGet({
    @Path('channelId') required String? channelId,
    @Path('binFileName') required String? binFileName,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  Future<chopper.Response> channelsChannelIdBinFileNameHead({
    required String? channelId,
    required String? binFileName,
    String? cacheControl,
  }) {
    return _channelsChannelIdBinFileNameHead(
        channelId: channelId,
        binFileName: binFileName,
        cacheControl: cacheControl);
  }

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  @Head(path: '/channels/{channelId}/{binFileName}')
  Future<chopper.Response> _channelsChannelIdBinFileNameHead({
    @Path('channelId') required String? channelId,
    @Path('binFileName') required String? binFileName,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get WebVTT file
  ///@param channelId Channel identifier
  ///@param start Start time
  ///@param end End time
  ///@param X-Original-URI
  Future<chopper.Response> channelsChannelIdGet({
    required String? channelId,
    required String? start,
    required String? end,
    String? xOriginalURI,
    String? cacheControl,
  }) {
    return _channelsChannelIdGet(
        channelId: channelId,
        start: start,
        end: end,
        xOriginalURI: xOriginalURI,
        cacheControl: cacheControl);
  }

  ///Get WebVTT file
  ///@param channelId Channel identifier
  ///@param start Start time
  ///@param end End time
  ///@param X-Original-URI
  @Get(path: '/channels/{channelId}')
  Future<chopper.Response> _channelsChannelIdGet({
    @Path('channelId') required String? channelId,
    @Query('start') required String? start,
    @Query('end') required String? end,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get image file
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  Future<chopper.Response> channelsChannelIdYearMonthDayHourMinuteSecondGet({
    required String? channelId,
    required int? year,
    required int? month,
    required int? day,
    required int? hour,
    required int? minute,
    required int? second,
    String? cacheControl,
  }) {
    return _channelsChannelIdYearMonthDayHourMinuteSecondGet(
        channelId: channelId,
        year: year,
        month: month,
        day: day,
        hour: hour,
        minute: minute,
        second: second,
        cacheControl: cacheControl);
  }

  ///Get image file
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  @Get(
      path:
          '/channels/{channelId}/{year}/{month}/{day}/{hour}/{minute}/{second}')
  Future<chopper.Response> _channelsChannelIdYearMonthDayHourMinuteSecondGet({
    @Path('channelId') required String? channelId,
    @Path('year') required int? year,
    @Path('month') required int? month,
    @Path('day') required int? day,
    @Path('hour') required int? hour,
    @Path('minute') required int? minute,
    @Path('second') required int? second,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns a screengrab image located at the path on the unassetized screengrab storage
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  Future<chopper.Response>
      screengrabsChannelsChannelIdYearMonthDayHourMinuteSecondGet({
    required String? channelId,
    required int? year,
    required int? month,
    required int? day,
    required int? hour,
    required int? minute,
    required int? second,
    String? cacheControl,
  }) {
    return _screengrabsChannelsChannelIdYearMonthDayHourMinuteSecondGet(
        channelId: channelId,
        year: year,
        month: month,
        day: day,
        hour: hour,
        minute: minute,
        second: second,
        cacheControl: cacheControl);
  }

  ///Returns a screengrab image located at the path on the unassetized screengrab storage
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  @Get(
      path:
          '/screengrabs/channels/{channelId}/{year}/{month}/{day}/{hour}/{minute}/{second}')
  Future<chopper.Response>
      _screengrabsChannelsChannelIdYearMonthDayHourMinuteSecondGet({
    @Path('channelId') required String? channelId,
    @Path('year') required int? year,
    @Path('month') required int? month,
    @Path('day') required int? day,
    @Path('hour') required int? hour,
    @Path('minute') required int? minute,
    @Path('second') required int? second,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get metadata for screensgrabs of some asset
  ///@param assetId Asset id
  Future<chopper.Response> screengrabsAssetIdMetadataGet({
    required String? assetId,
    String? cacheControl,
  }) {
    return _screengrabsAssetIdMetadataGet(
        assetId: assetId, cacheControl: cacheControl);
  }

  ///Get metadata for screensgrabs of some asset
  ///@param assetId Asset id
  @Get(path: '/screengrabs/{assetId}/metadata')
  Future<chopper.Response> _screengrabsAssetIdMetadataGet({
    @Path('assetId') required String? assetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns a screengrab image located at the path on the assetized screengrab storage
  ///@param assetId Screengrab assetId
  ///@param fileName Screengrab fileName
  Future<chopper.Response> screengrabsAssetIdFileNameGet({
    required String? assetId,
    required String? fileName,
    String? cacheControl,
  }) {
    return _screengrabsAssetIdFileNameGet(
        assetId: assetId, fileName: fileName, cacheControl: cacheControl);
  }

  ///Returns a screengrab image located at the path on the assetized screengrab storage
  ///@param assetId Screengrab assetId
  ///@param fileName Screengrab fileName
  @Get(path: '/screengrabs/{assetId}/{fileName}')
  Future<chopper.Response> _screengrabsAssetIdFileNameGet({
    @Path('assetId') required String? assetId,
    @Path('fileName') required String? fileName,
    @Header('Cache-Control') String? cacheControl,
  });
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
