// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'liberty_watchlist_service.enums.swagger.dart' as enums;
export 'liberty_watchlist_service.enums.swagger.dart';

part 'liberty_watchlist_service.swagger.chopper.dart';
part 'liberty_watchlist_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyWatchlistService extends ChopperService {
  static LibertyWatchlistService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyWatchlistService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyWatchlistService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyWatchlistService(newClient);
  }

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  Future<chopper.Response<WatchlistEntryResponseBase>>
      v1WatchlistsIdEntriesEntryIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xClaimsSet,
    required String? id,
    required String? entryId,
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(WatchlistEntryResponseBase,
        () => WatchlistEntryResponseBase.fromJsonFactory);

    return _v1WatchlistsIdEntriesEntryIdGet(
        xDev: xDev,
        xCus: xCus,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        xClaimsSet: xClaimsSet,
        id: id,
        entryId: entryId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  @Get(path: '/v1/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response<WatchlistEntryResponseBase>>
      _v1WatchlistsIdEntriesEntryIdGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Path('entryId') required String? entryId,
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v1WatchlistsIdEntriesEntryIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required String? entryId,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdEntriesEntryIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        entryId: entryId,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v1/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response> _v1WatchlistsIdEntriesEntryIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Path('entryId') required String? entryId,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param body Watchlist entry
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v1WatchlistsIdEntriesPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    bool? sharedProfile,
    WatchlistEntryRequest? body,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistEntryRequest, () => WatchlistEntryRequest.fromJsonFactory);

    return _v1WatchlistsIdEntriesPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        sharedProfile: sharedProfile,
        body: body,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl);
  }

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param body Watchlist entry
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Post(path: '/v1/watchlists/{id}/entries')
  Future<chopper.Response> _v1WatchlistsIdEntriesPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('sharedProfile') bool? sharedProfile,
    @Body() WatchlistEntryRequest? body,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v1WatchlistsIdEntriesDelete({
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required bool? expired,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdEntriesDelete(
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        expired: expired,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v1/watchlists/{id}/entries')
  Future<chopper.Response> _v1WatchlistsIdEntriesDelete({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('expired') required bool? expired,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  Future<chopper.Response<WatchlistEntryResponseBase>>
      v2WatchlistsIdEntriesEntryIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xClaimsSet,
    required String? id,
    required String? entryId,
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(WatchlistEntryResponseBase,
        () => WatchlistEntryResponseBase.fromJsonFactory);

    return _v2WatchlistsIdEntriesEntryIdGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        xClaimsSet: xClaimsSet,
        id: id,
        entryId: entryId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Retrieves response metadata for entry from watchlist
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param language The language option
  @Get(path: '/v2/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response<WatchlistEntryResponseBase>>
      _v2WatchlistsIdEntriesEntryIdGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Path('entryId') required String? entryId,
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v2WatchlistsIdEntriesEntryIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required String? entryId,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdEntriesEntryIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        entryId: entryId,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist entry from a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param entryId The entry Id
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v2/watchlists/{id}/entries/{entryId}')
  Future<chopper.Response> _v2WatchlistsIdEntriesEntryIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Path('entryId') required String? entryId,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param body Watchlist entry
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response> v2WatchlistsIdEntriesPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? id,
    bool? sharedProfile,
    WatchlistEntryRequest? body,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistEntryRequest, () => WatchlistEntryRequest.fromJsonFactory);

    return _v2WatchlistsIdEntriesPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        sharedProfile: sharedProfile,
        body: body,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl);
  }

  ///Add a watchlist entry to a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param sharedProfile Is shared profile
  ///@param body Watchlist entry
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Post(path: '/v2/watchlists/{id}/entries')
  Future<chopper.Response> _v2WatchlistsIdEntriesPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('sharedProfile') bool? sharedProfile,
    @Body() WatchlistEntryRequest? body,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  Future<chopper.Response> v2WatchlistsIdEntriesDelete({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required bool? expired,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdEntriesDelete(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        expired: expired,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Removes all the entries that are expired or removed from metadata provider for a watchlist
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information
  ///@param id The watchlist Id
  ///@param expired Expired indicator
  ///@param sharedProfile Is shared profile
  @Delete(path: '/v2/watchlists/{id}/entries')
  Future<chopper.Response> _v2WatchlistsIdEntriesDelete({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('expired') required bool? expired,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param md metadata filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  Future<chopper.Response<WatchlistResponse>> v1WatchlistsProfileProfileIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xClaimsSet,
    required String? profileId,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? md,
    String? type,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdGet(
        xDev: xDev,
        xCus: xCus,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        md: md,
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param md metadata filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  @Get(path: '/v1/watchlists/profile/{profileId}')
  Future<chopper.Response<WatchlistResponse>> _v1WatchlistsProfileProfileIdGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('md') String? md,
    @Query('type') String? type,
    @Query('startResults') int? startResults,
    @Query('maxResults') int? maxResults,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  Future<chopper.Response> v1WatchlistsProfileProfileIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    String? cacheControl,
  }) {
    return _v1WatchlistsProfileProfileIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  @Delete(path: '/v1/watchlists/profile/{profileId}')
  Future<chopper.Response> _v1WatchlistsProfileProfileIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v1WatchlistsProfileProfileIdNameNameAssetIdGet({
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdNameNameAssetIdGet(
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        name: name,
        id: id,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  @Get(path: '/v1/watchlists/profile/{profileId}/name/{name}/asset/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v1WatchlistsProfileProfileIdNameNameAssetIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v1WatchlistsProfileProfileIdNameNameSeriesIdGet({
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdNameNameSeriesIdGet(
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        name: name,
        id: id,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  @Get(path: '/v1/watchlists/profile/{profileId}/name/{name}/series/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v1WatchlistsProfileProfileIdNameNameSeriesIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  Future<chopper.Response<GridResponse>> v1WatchlistsProfileProfileIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v1WatchlistsProfileProfileIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  @Get(path: '/v1/watchlists/profile/{profileId}/grid')
  Future<chopper.Response<GridResponse>> _v1WatchlistsProfileProfileIdGridGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('feed') String? feed,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  Future<chopper.Response> v2WatchlistsProfileProfileIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    String? cacheControl,
  }) {
    return _v2WatchlistsProfileProfileIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist from a given profile in database
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  @Delete(path: '/v2/watchlists/profile/{profileId}')
  Future<chopper.Response> _v2WatchlistsProfileProfileIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v2WatchlistsProfileProfileIdNameNameAssetIdGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdNameNameAssetIdGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        name: name,
        id: id,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and asset id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Asset Id
  @Get(path: '/v2/watchlists/profile/{profileId}/name/{name}/asset/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v2WatchlistsProfileProfileIdNameNameAssetIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      v2WatchlistsProfileProfileIdNameNameSeriesIdGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimpleWatchlistEntryResponseBase,
        () => SimpleWatchlistEntryResponseBase.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdNameNameSeriesIdGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        name: name,
        id: id,
        cacheControl: cacheControl);
  }

  ///Retrieves entry based on profile id, watchlist name and series id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The profile Id
  ///@param name Watchlist name
  ///@param id Show Id
  @Get(path: '/v2/watchlists/profile/{profileId}/name/{name}/series/{id}')
  Future<chopper.Response<SimpleWatchlistEntryResponseBase>>
      _v2WatchlistsProfileProfileIdNameNameSeriesIdGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  Future<chopper.Response<GridResponse>> v2WatchlistsProfileProfileIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  @Get(path: '/v2/watchlists/profile/{profileId}/grid')
  Future<chopper.Response<GridResponse>> _v2WatchlistsProfileProfileIdGridGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('feed') String? feed,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  Future<chopper.Response<WatchlistResponse>>
      v2WatchlistsProfileProfileIdSimpleGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? profileId,
    String? type,
    int? startResults,
    int? maxResults,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdSimpleGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  @Get(path: '/v2/watchlists/profile/{profileId}/simple')
  Future<chopper.Response<WatchlistResponse>>
      _v2WatchlistsProfileProfileIdSimpleGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Query('type') String? type,
    @Query('startResults') int? startResults,
    @Query('maxResults') int? maxResults,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  Future<chopper.Response<WatchlistResponse>>
      v2WatchlistsProfileProfileIdExtendedGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xClaimsSet,
    required String? profileId,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? type,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v2WatchlistsProfileProfileIdExtendedGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xEntitlementsToken: xEntitlementsToken,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        type: type,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param profileId The Profile Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param type metadata filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  @Get(path: '/v2/watchlists/profile/{profileId}/extended')
  Future<chopper.Response<WatchlistResponse>>
      _v2WatchlistsProfileProfileIdExtendedGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('profileId') required String? profileId,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('type') String? type,
    @Query('startResults') int? startResults,
    @Query('maxResults') int? maxResults,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist Id by profile Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response<WatchlistId>> v1WatchlistsGet({
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? byProfileId,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v1WatchlistsGet(
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        byProfileId: byProfileId,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist Id by profile Id
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Get(path: '/v1/watchlists')
  Future<chopper.Response<WatchlistId>> _v1WatchlistsGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Query('byProfileId') required String? byProfileId,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param body Watchlist
  Future<chopper.Response<WatchlistId>> v1WatchlistsPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    WatchlistRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistRequest, () => WatchlistRequest.fromJsonFactory);
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v1WatchlistsPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        body: body,
        cacheControl: cacheControl);
  }

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param body Watchlist
  @Post(path: '/v1/watchlists')
  Future<chopper.Response<WatchlistId>> _v1WatchlistsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Body() WatchlistRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  Future<chopper.Response<WatchlistResponse>> v1WatchlistsIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v1WatchlistsIdGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  @Get(path: '/v1/watchlists/{id}')
  Future<chopper.Response<WatchlistResponse>> _v1WatchlistsIdGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('startResults') int? startResults,
    @Query('maxResults') int? maxResults,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  ///@param body Watchlist
  Future<chopper.Response> v1WatchlistsIdPut({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    WatchlistRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistRequest, () => WatchlistRequest.fromJsonFactory);

    return _v1WatchlistsIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        body: body,
        cacheControl: cacheControl);
  }

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  ///@param body Watchlist
  @Put(path: '/v1/watchlists/{id}')
  Future<chopper.Response> _v1WatchlistsIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Body() WatchlistRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  Future<chopper.Response> v1WatchlistsIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xVia,
    String? xClaimsSet,
    bool? sharedProfile,
    required String? id,
    String? cacheControl,
  }) {
    return _v1WatchlistsIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        sharedProfile: sharedProfile,
        id: id,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  @Delete(path: '/v1/watchlists/{id}')
  Future<chopper.Response> _v1WatchlistsIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Query('sharedProfile') bool? sharedProfile,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  Future<chopper.Response<GridResponse>> v1WatchlistsIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v1WatchlistsIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  @Get(path: '/v1/watchlists/{id}/grid')
  Future<chopper.Response<GridResponse>> _v1WatchlistsIdGridGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('feed') String? feed,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist Id by profile Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  Future<chopper.Response<WatchlistId>> v2WatchlistsGet({
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? byProfileId,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v2WatchlistsGet(
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        byProfileId: byProfileId,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist Id by profile Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param byProfileId The profile Id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  @Get(path: '/v2/watchlists')
  Future<chopper.Response<WatchlistId>> _v2WatchlistsGet({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Query('byProfileId') required String? byProfileId,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param body Watchlist
  Future<chopper.Response<WatchlistId>> v2WatchlistsPost({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    WatchlistRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistRequest, () => WatchlistRequest.fromJsonFactory);
    generatedMapping.putIfAbsent(
        WatchlistId, () => WatchlistId.fromJsonFactory);

    return _v2WatchlistsPost(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        body: body,
        cacheControl: cacheControl);
  }

  ///Create watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param body Watchlist
  @Post(path: '/v2/watchlists')
  Future<chopper.Response<WatchlistId>> _v2WatchlistsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Body() WatchlistRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  Future<chopper.Response<WatchlistResponse>> v2WatchlistsIdGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    int? startResults,
    int? maxResults,
    bool? sharedProfile,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistResponse, () => WatchlistResponse.fromJsonFactory);

    return _v2WatchlistsIdGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        startResults: startResults,
        maxResults: maxResults,
        sharedProfile: sharedProfile,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param startResults page offset start index
  ///@param maxResults page offset end index
  ///@param sharedProfile Is shared profile
  @Get(path: '/v2/watchlists/{id}')
  Future<chopper.Response<WatchlistResponse>> _v2WatchlistsIdGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('startResults') int? startResults,
    @Query('maxResults') int? maxResults,
    @Query('sharedProfile') bool? sharedProfile,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  ///@param body Watchlist
  Future<chopper.Response> v2WatchlistsIdPut({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    required String? id,
    String? xOriginalURI,
    String? xOriginalForwardedProto,
    WatchlistRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatchlistRequest, () => WatchlistRequest.fromJsonFactory);

    return _v2WatchlistsIdPut(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        xOriginalURI: xOriginalURI,
        xOriginalForwardedProto: xOriginalForwardedProto,
        body: body,
        cacheControl: cacheControl);
  }

  ///Update watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id
  ///@param X-Original-URI
  ///@param X-Original-Forwarded-Proto
  ///@param body Watchlist
  @Put(path: '/v2/watchlists/{id}')
  Future<chopper.Response> _v2WatchlistsIdPut({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('X-Original-Forwarded-Proto') String? xOriginalForwardedProto,
    @Body() WatchlistRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  Future<chopper.Response> v2WatchlistsIdDelete({
    String? xDev,
    String? xGoDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xVia,
    String? xClaimsSet,
    bool? sharedProfile,
    required String? id,
    String? cacheControl,
  }) {
    return _v2WatchlistsIdDelete(
        xDev: xDev,
        xGoDev: xGoDev,
        xCus: xCus,
        xProfile: xProfile,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        sharedProfile: sharedProfile,
        id: id,
        cacheControl: cacheControl);
  }

  ///Delete a watchlist
  ///@param X-Dev The device Id
  ///@param X-Go-Dev The Horizon GO device ID
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param sharedProfile Is shared profile
  ///@param id
  @Delete(path: '/v2/watchlists/{id}')
  Future<chopper.Response> _v2WatchlistsIdDelete({
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Query('sharedProfile') bool? sharedProfile,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  Future<chopper.Response<GridResponse>> v2WatchlistsIdGridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xProfile,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xVia,
    String? xClaimsSet,
    required String? id,
    required String? sort,
    required String? order,
    bool? smart,
    required String? language,
    String? genreFilter,
    String? statusFilter,
    String? feed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GridResponse, () => GridResponse.fromJsonFactory);

    return _v2WatchlistsIdGridGet(
        xDev: xDev,
        xCus: xCus,
        xProfile: xProfile,
        xEntitlementsToken: xEntitlementsToken,
        xVia: xVia,
        xClaimsSet: xClaimsSet,
        id: id,
        sort: sort,
        order: order,
        smart: smart,
        language: language,
        genreFilter: genreFilter,
        statusFilter: statusFilter,
        feed: feed,
        cacheControl: cacheControl);
  }

  ///Retrieves watchlist with response metadata for entries
  ///@param X-Dev The device Id
  ///@param X-Cus The customer Id
  ///@param X-Profile Profile ID for authentication
  ///@param x-entitlements-token Entitlement Token
  ///@param X-Via Token to identify sender. Example: obo-ingress-horizonauth
  ///@param X-Claims-Set Encoded customer information. Should come with X-Via
  ///@param id The watchlist Id
  ///@param sort The sort option
  ///@param order The order option
  ///@param smart Option to smart sort
  ///@param language The language option
  ///@param genreFilter Genre filter option
  ///@param statusFilter status filter option
  ///@param feed feed filter option
  @Get(path: '/v2/watchlists/{id}/grid')
  Future<chopper.Response<GridResponse>> _v2WatchlistsIdGridGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Profile') String? xProfile,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-Via') String? xVia,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Path('id') required String? id,
    @Query('sort') required String? sort,
    @Query('order') required String? order,
    @Query('smart') bool? smart,
    @Query('language') required String? language,
    @Query('genreFilter') String? genreFilter,
    @Query('statusFilter') String? statusFilter,
    @Query('feed') String? feed,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class EstContent {
  EstContent({
    this.videoHost,
    this.videoUrl,
    this.id,
  });

  factory EstContent.fromJson(Map<String, dynamic> json) =>
      _$EstContentFromJson(json);

  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String? videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String? videoUrl;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$EstContentFromJson;
  static const toJsonFactory = _$EstContentToJson;
  Map<String, dynamic> toJson() => _$EstContentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstContent &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $EstContentExtension on EstContent {
  EstContent copyWith({String? videoHost, String? videoUrl, String? id}) {
    return EstContent(
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        id: id ?? this.id);
  }

  EstContent copyWithWrapped(
      {Wrapped<String?>? videoHost,
      Wrapped<String?>? videoUrl,
      Wrapped<String?>? id}) {
    return EstContent(
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    this.scheme,
    this.title,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  @JsonKey(name: 'scheme', includeIfNull: false, defaultValue: '')
  final String? scheme;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  static const fromJsonFactory = _$GenreFromJson;
  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.scheme, scheme) ||
                const DeepCollectionEquality().equals(other.scheme, scheme)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(scheme) ^
      const DeepCollectionEquality().hash(title) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith({String? scheme, String? title}) {
    return Genre(scheme: scheme ?? this.scheme, title: title ?? this.title);
  }

  Genre copyWithWrapped({Wrapped<String?>? scheme, Wrapped<String?>? title}) {
    return Genre(
        scheme: (scheme != null ? scheme.value : this.scheme),
        title: (title != null ? title.value : this.title));
  }
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    this.image,
    this.type,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  static const fromJsonFactory = _$ImageFromJson;
  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({String? image, String? type}) {
    return Image(image: image ?? this.image, type: type ?? this.type);
  }

  Image copyWithWrapped({Wrapped<String?>? image, Wrapped<String?>? type}) {
    return Image(
        image: (image != null ? image.value : this.image),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistEntryResponseBase {
  WatchlistEntryResponseBase({
    this.replayAvailable,
    this.ageRating,
    this.year,
    this.duration,
    this.id,
    this.type,
    this.description,
    this.title,
    this.isBoxset,
    this.seasonNumber,
    this.listPrice,
    this.added,
    this.mostRelevantEpisode,
    this.titleId,
    this.channelId,
    this.seriesId,
    this.isExpired,
    this.viewState,
    this.isAdult,
    this.episodeNumber,
    this.expirationDate,
    this.isRemoved,
    this.isReplay,
    this.earliestBroadcastStartTime,
    this.eventStartTime,
    this.longDescription,
    this.categories,
    this.isHD,
    this.isGoPlayable,
    this.cast,
    this.directors,
    this.images,
    this.providerId,
    this.sortTitle,
    this.groupParentalRating,
    this.viewedState,
    this.bookmark,
    this.currency,
    this.minPriceDisplay,
    this.priceDisplay,
    this.entitlementState,
    this.entitlementEnd,
    this.productType,
    this.listingId,
    this.imdbRating,
    this.yearOfProductionStart,
    this.yearOfProductionEnd,
    this.hasMultipleProducts,
    this.containsAdult,
    this.instances,
  });

  factory WatchlistEntryResponseBase.fromJson(Map<String, dynamic> json) =>
      _$WatchlistEntryResponseBaseFromJson(json);

  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'year', includeIfNull: false, defaultValue: '')
  final String? year;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: watchlistEntryResponseBaseTypeToJson,
    fromJson: watchlistEntryResponseBaseTypeFromJson,
  )
  final enums.WatchlistEntryResponseBaseType? type;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'listPrice', includeIfNull: false, defaultValue: '')
  final String? listPrice;
  @JsonKey(name: 'added', includeIfNull: false)
  final DateTime? added;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false, defaultValue: '')
  final String? mostRelevantEpisode;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String? titleId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'isExpired', includeIfNull: false)
  final bool? isExpired;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'isRemoved', includeIfNull: false)
  final bool? isRemoved;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'earliestBroadcastStartTime', includeIfNull: false)
  final DateTime? earliestBroadcastStartTime;
  @JsonKey(name: 'eventStartTime', includeIfNull: false)
  final DateTime? eventStartTime;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'categories', includeIfNull: false, defaultValue: <Genre>[])
  final List<Genre>? categories;
  @JsonKey(name: 'isHD', includeIfNull: false)
  final bool? isHD;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'cast', includeIfNull: false, defaultValue: <String>[])
  final List<String>? cast;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image>? images;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'sortTitle', includeIfNull: false, defaultValue: '')
  final String? sortTitle;
  @JsonKey(name: 'groupParentalRating', includeIfNull: false, defaultValue: '')
  final String? groupParentalRating;
  @JsonKey(name: 'viewedState', includeIfNull: false, defaultValue: '')
  final String? viewedState;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(
    name: 'entitlementState',
    includeIfNull: false,
    toJson: watchlistEntryResponseBaseEntitlementStateToJson,
    fromJson: watchlistEntryResponseBaseEntitlementStateFromJson,
  )
  final enums.WatchlistEntryResponseBaseEntitlementState? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime? entitlementEnd;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: watchlistEntryResponseBaseProductTypeToJson,
    fromJson: watchlistEntryResponseBaseProductTypeFromJson,
  )
  final enums.WatchlistEntryResponseBaseProductType? productType;
  @JsonKey(name: 'listingId', includeIfNull: false, defaultValue: '')
  final String? listingId;
  @JsonKey(name: 'imdbRating', includeIfNull: false, defaultValue: '')
  final String? imdbRating;
  @JsonKey(name: 'yearOfProductionStart', includeIfNull: false)
  final int? yearOfProductionStart;
  @JsonKey(name: 'yearOfProductionEnd', includeIfNull: false)
  final int? yearOfProductionEnd;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(
      name: 'instances', includeIfNull: false, defaultValue: <EstContent>[])
  final List<EstContent>? instances;
  static const fromJsonFactory = _$WatchlistEntryResponseBaseFromJson;
  static const toJsonFactory = _$WatchlistEntryResponseBaseToJson;
  Map<String, dynamic> toJson() => _$WatchlistEntryResponseBaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistEntryResponseBase &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.year, year) ||
                const DeepCollectionEquality().equals(other.year, year)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.listPrice, listPrice) ||
                const DeepCollectionEquality()
                    .equals(other.listPrice, listPrice)) &&
            (identical(other.added, added) ||
                const DeepCollectionEquality().equals(other.added, added)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.isExpired, isExpired) ||
                const DeepCollectionEquality()
                    .equals(other.isExpired, isExpired)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.isRemoved, isRemoved) ||
                const DeepCollectionEquality()
                    .equals(other.isRemoved, isRemoved)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.earliestBroadcastStartTime, earliestBroadcastStartTime) ||
                const DeepCollectionEquality().equals(
                    other.earliestBroadcastStartTime, earliestBroadcastStartTime)) &&
            (identical(other.eventStartTime, eventStartTime) || const DeepCollectionEquality().equals(other.eventStartTime, eventStartTime)) &&
            (identical(other.longDescription, longDescription) || const DeepCollectionEquality().equals(other.longDescription, longDescription)) &&
            (identical(other.categories, categories) || const DeepCollectionEquality().equals(other.categories, categories)) &&
            (identical(other.isHD, isHD) || const DeepCollectionEquality().equals(other.isHD, isHD)) &&
            (identical(other.isGoPlayable, isGoPlayable) || const DeepCollectionEquality().equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.cast, cast) || const DeepCollectionEquality().equals(other.cast, cast)) &&
            (identical(other.directors, directors) || const DeepCollectionEquality().equals(other.directors, directors)) &&
            (identical(other.images, images) || const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)) &&
            (identical(other.sortTitle, sortTitle) || const DeepCollectionEquality().equals(other.sortTitle, sortTitle)) &&
            (identical(other.groupParentalRating, groupParentalRating) || const DeepCollectionEquality().equals(other.groupParentalRating, groupParentalRating)) &&
            (identical(other.viewedState, viewedState) || const DeepCollectionEquality().equals(other.viewedState, viewedState)) &&
            (identical(other.bookmark, bookmark) || const DeepCollectionEquality().equals(other.bookmark, bookmark)) &&
            (identical(other.currency, currency) || const DeepCollectionEquality().equals(other.currency, currency)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) || const DeepCollectionEquality().equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.priceDisplay, priceDisplay) || const DeepCollectionEquality().equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.entitlementState, entitlementState) || const DeepCollectionEquality().equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) || const DeepCollectionEquality().equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.listingId, listingId) || const DeepCollectionEquality().equals(other.listingId, listingId)) &&
            (identical(other.imdbRating, imdbRating) || const DeepCollectionEquality().equals(other.imdbRating, imdbRating)) &&
            (identical(other.yearOfProductionStart, yearOfProductionStart) || const DeepCollectionEquality().equals(other.yearOfProductionStart, yearOfProductionStart)) &&
            (identical(other.yearOfProductionEnd, yearOfProductionEnd) || const DeepCollectionEquality().equals(other.yearOfProductionEnd, yearOfProductionEnd)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) || const DeepCollectionEquality().equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.containsAdult, containsAdult) || const DeepCollectionEquality().equals(other.containsAdult, containsAdult)) &&
            (identical(other.instances, instances) || const DeepCollectionEquality().equals(other.instances, instances)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(year) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(listPrice) ^
      const DeepCollectionEquality().hash(added) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(isExpired) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(isRemoved) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(earliestBroadcastStartTime) ^
      const DeepCollectionEquality().hash(eventStartTime) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(categories) ^
      const DeepCollectionEquality().hash(isHD) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(cast) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(sortTitle) ^
      const DeepCollectionEquality().hash(groupParentalRating) ^
      const DeepCollectionEquality().hash(viewedState) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(listingId) ^
      const DeepCollectionEquality().hash(imdbRating) ^
      const DeepCollectionEquality().hash(yearOfProductionStart) ^
      const DeepCollectionEquality().hash(yearOfProductionEnd) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(instances) ^
      runtimeType.hashCode;
}

extension $WatchlistEntryResponseBaseExtension on WatchlistEntryResponseBase {
  WatchlistEntryResponseBase copyWith(
      {bool? replayAvailable,
      int? ageRating,
      String? year,
      int? duration,
      String? id,
      enums.WatchlistEntryResponseBaseType? type,
      String? description,
      String? title,
      bool? isBoxset,
      int? seasonNumber,
      String? listPrice,
      DateTime? added,
      String? mostRelevantEpisode,
      String? titleId,
      String? channelId,
      String? seriesId,
      bool? isExpired,
      String? viewState,
      bool? isAdult,
      int? episodeNumber,
      DateTime? expirationDate,
      bool? isRemoved,
      bool? isReplay,
      DateTime? earliestBroadcastStartTime,
      DateTime? eventStartTime,
      String? longDescription,
      List<Genre>? categories,
      bool? isHD,
      bool? isGoPlayable,
      List<String>? cast,
      List<String>? directors,
      List<Image>? images,
      String? providerId,
      String? sortTitle,
      String? groupParentalRating,
      String? viewedState,
      int? bookmark,
      String? currency,
      String? minPriceDisplay,
      String? priceDisplay,
      enums.WatchlistEntryResponseBaseEntitlementState? entitlementState,
      DateTime? entitlementEnd,
      enums.WatchlistEntryResponseBaseProductType? productType,
      String? listingId,
      String? imdbRating,
      int? yearOfProductionStart,
      int? yearOfProductionEnd,
      bool? hasMultipleProducts,
      bool? containsAdult,
      List<EstContent>? instances}) {
    return WatchlistEntryResponseBase(
        replayAvailable: replayAvailable ?? this.replayAvailable,
        ageRating: ageRating ?? this.ageRating,
        year: year ?? this.year,
        duration: duration ?? this.duration,
        id: id ?? this.id,
        type: type ?? this.type,
        description: description ?? this.description,
        title: title ?? this.title,
        isBoxset: isBoxset ?? this.isBoxset,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        listPrice: listPrice ?? this.listPrice,
        added: added ?? this.added,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        titleId: titleId ?? this.titleId,
        channelId: channelId ?? this.channelId,
        seriesId: seriesId ?? this.seriesId,
        isExpired: isExpired ?? this.isExpired,
        viewState: viewState ?? this.viewState,
        isAdult: isAdult ?? this.isAdult,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        expirationDate: expirationDate ?? this.expirationDate,
        isRemoved: isRemoved ?? this.isRemoved,
        isReplay: isReplay ?? this.isReplay,
        earliestBroadcastStartTime:
            earliestBroadcastStartTime ?? this.earliestBroadcastStartTime,
        eventStartTime: eventStartTime ?? this.eventStartTime,
        longDescription: longDescription ?? this.longDescription,
        categories: categories ?? this.categories,
        isHD: isHD ?? this.isHD,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        cast: cast ?? this.cast,
        directors: directors ?? this.directors,
        images: images ?? this.images,
        providerId: providerId ?? this.providerId,
        sortTitle: sortTitle ?? this.sortTitle,
        groupParentalRating: groupParentalRating ?? this.groupParentalRating,
        viewedState: viewedState ?? this.viewedState,
        bookmark: bookmark ?? this.bookmark,
        currency: currency ?? this.currency,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        productType: productType ?? this.productType,
        listingId: listingId ?? this.listingId,
        imdbRating: imdbRating ?? this.imdbRating,
        yearOfProductionStart:
            yearOfProductionStart ?? this.yearOfProductionStart,
        yearOfProductionEnd: yearOfProductionEnd ?? this.yearOfProductionEnd,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        containsAdult: containsAdult ?? this.containsAdult,
        instances: instances ?? this.instances);
  }

  WatchlistEntryResponseBase copyWithWrapped(
      {Wrapped<bool?>? replayAvailable,
      Wrapped<int?>? ageRating,
      Wrapped<String?>? year,
      Wrapped<int?>? duration,
      Wrapped<String?>? id,
      Wrapped<enums.WatchlistEntryResponseBaseType?>? type,
      Wrapped<String?>? description,
      Wrapped<String?>? title,
      Wrapped<bool?>? isBoxset,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? listPrice,
      Wrapped<DateTime?>? added,
      Wrapped<String?>? mostRelevantEpisode,
      Wrapped<String?>? titleId,
      Wrapped<String?>? channelId,
      Wrapped<String?>? seriesId,
      Wrapped<bool?>? isExpired,
      Wrapped<String?>? viewState,
      Wrapped<bool?>? isAdult,
      Wrapped<int?>? episodeNumber,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<bool?>? isRemoved,
      Wrapped<bool?>? isReplay,
      Wrapped<DateTime?>? earliestBroadcastStartTime,
      Wrapped<DateTime?>? eventStartTime,
      Wrapped<String?>? longDescription,
      Wrapped<List<Genre>?>? categories,
      Wrapped<bool?>? isHD,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<List<String>?>? cast,
      Wrapped<List<String>?>? directors,
      Wrapped<List<Image>?>? images,
      Wrapped<String?>? providerId,
      Wrapped<String?>? sortTitle,
      Wrapped<String?>? groupParentalRating,
      Wrapped<String?>? viewedState,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? currency,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? priceDisplay,
      Wrapped<enums.WatchlistEntryResponseBaseEntitlementState?>?
          entitlementState,
      Wrapped<DateTime?>? entitlementEnd,
      Wrapped<enums.WatchlistEntryResponseBaseProductType?>? productType,
      Wrapped<String?>? listingId,
      Wrapped<String?>? imdbRating,
      Wrapped<int?>? yearOfProductionStart,
      Wrapped<int?>? yearOfProductionEnd,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<bool?>? containsAdult,
      Wrapped<List<EstContent>?>? instances}) {
    return WatchlistEntryResponseBase(
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        year: (year != null ? year.value : this.year),
        duration: (duration != null ? duration.value : this.duration),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        description:
            (description != null ? description.value : this.description),
        title: (title != null ? title.value : this.title),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        listPrice: (listPrice != null ? listPrice.value : this.listPrice),
        added: (added != null ? added.value : this.added),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        titleId: (titleId != null ? titleId.value : this.titleId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        isExpired: (isExpired != null ? isExpired.value : this.isExpired),
        viewState: (viewState != null ? viewState.value : this.viewState),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        isRemoved: (isRemoved != null ? isRemoved.value : this.isRemoved),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        earliestBroadcastStartTime: (earliestBroadcastStartTime != null
            ? earliestBroadcastStartTime.value
            : this.earliestBroadcastStartTime),
        eventStartTime: (eventStartTime != null
            ? eventStartTime.value
            : this.eventStartTime),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        categories: (categories != null ? categories.value : this.categories),
        isHD: (isHD != null ? isHD.value : this.isHD),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        cast: (cast != null ? cast.value : this.cast),
        directors: (directors != null ? directors.value : this.directors),
        images: (images != null ? images.value : this.images),
        providerId: (providerId != null ? providerId.value : this.providerId),
        sortTitle: (sortTitle != null ? sortTitle.value : this.sortTitle),
        groupParentalRating: (groupParentalRating != null
            ? groupParentalRating.value
            : this.groupParentalRating),
        viewedState:
            (viewedState != null ? viewedState.value : this.viewedState),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        currency: (currency != null ? currency.value : this.currency),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        productType:
            (productType != null ? productType.value : this.productType),
        listingId: (listingId != null ? listingId.value : this.listingId),
        imdbRating: (imdbRating != null ? imdbRating.value : this.imdbRating),
        yearOfProductionStart: (yearOfProductionStart != null
            ? yearOfProductionStart.value
            : this.yearOfProductionStart),
        yearOfProductionEnd: (yearOfProductionEnd != null
            ? yearOfProductionEnd.value
            : this.yearOfProductionEnd),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        instances: (instances != null ? instances.value : this.instances));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistEntryRequest {
  WatchlistEntryRequest({
    this.id,
    this.type,
    this.title,
    this.showId,
    this.watchlistId,
    this.serviceId,
    this.reminderSet,
    this.remindBefore,
  });

  factory WatchlistEntryRequest.fromJson(Map<String, dynamic> json) =>
      _$WatchlistEntryRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: watchlistEntryRequestTypeToJson,
    fromJson: watchlistEntryRequestTypeFromJson,
  )
  final enums.WatchlistEntryRequestType? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'serviceId', includeIfNull: false, defaultValue: '')
  final String? serviceId;
  @JsonKey(name: 'reminderSet', includeIfNull: false)
  final bool? reminderSet;
  @JsonKey(name: 'remindBefore', includeIfNull: false)
  final int? remindBefore;
  static const fromJsonFactory = _$WatchlistEntryRequestFromJson;
  static const toJsonFactory = _$WatchlistEntryRequestToJson;
  Map<String, dynamic> toJson() => _$WatchlistEntryRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistEntryRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.reminderSet, reminderSet) ||
                const DeepCollectionEquality()
                    .equals(other.reminderSet, reminderSet)) &&
            (identical(other.remindBefore, remindBefore) ||
                const DeepCollectionEquality()
                    .equals(other.remindBefore, remindBefore)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(reminderSet) ^
      const DeepCollectionEquality().hash(remindBefore) ^
      runtimeType.hashCode;
}

extension $WatchlistEntryRequestExtension on WatchlistEntryRequest {
  WatchlistEntryRequest copyWith(
      {String? id,
      enums.WatchlistEntryRequestType? type,
      String? title,
      String? showId,
      String? watchlistId,
      String? serviceId,
      bool? reminderSet,
      int? remindBefore}) {
    return WatchlistEntryRequest(
        id: id ?? this.id,
        type: type ?? this.type,
        title: title ?? this.title,
        showId: showId ?? this.showId,
        watchlistId: watchlistId ?? this.watchlistId,
        serviceId: serviceId ?? this.serviceId,
        reminderSet: reminderSet ?? this.reminderSet,
        remindBefore: remindBefore ?? this.remindBefore);
  }

  WatchlistEntryRequest copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<enums.WatchlistEntryRequestType?>? type,
      Wrapped<String?>? title,
      Wrapped<String?>? showId,
      Wrapped<String?>? watchlistId,
      Wrapped<String?>? serviceId,
      Wrapped<bool?>? reminderSet,
      Wrapped<int?>? remindBefore}) {
    return WatchlistEntryRequest(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title),
        showId: (showId != null ? showId.value : this.showId),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        reminderSet:
            (reminderSet != null ? reminderSet.value : this.reminderSet),
        remindBefore:
            (remindBefore != null ? remindBefore.value : this.remindBefore));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleWatchlistEntryResponseBase {
  SimpleWatchlistEntryResponseBase({
    this.id,
    this.type,
    this.title,
    this.added,
    this.showId,
    this.isExpired,
    this.isRemoved,
    this.watchlistId,
    this.serviceId,
    this.reminderSet,
    this.remindBefore,
  });

  factory SimpleWatchlistEntryResponseBase.fromJson(
          Map<String, dynamic> json) =>
      _$SimpleWatchlistEntryResponseBaseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: simpleWatchlistEntryResponseBaseTypeToJson,
    fromJson: simpleWatchlistEntryResponseBaseTypeFromJson,
  )
  final enums.SimpleWatchlistEntryResponseBaseType? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'added', includeIfNull: false)
  final DateTime? added;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'isExpired', includeIfNull: false)
  final bool? isExpired;
  @JsonKey(name: 'isRemoved', includeIfNull: false)
  final bool? isRemoved;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'serviceId', includeIfNull: false, defaultValue: '')
  final String? serviceId;
  @JsonKey(name: 'reminderSet', includeIfNull: false)
  final bool? reminderSet;
  @JsonKey(name: 'remindBefore', includeIfNull: false)
  final int? remindBefore;
  static const fromJsonFactory = _$SimpleWatchlistEntryResponseBaseFromJson;
  static const toJsonFactory = _$SimpleWatchlistEntryResponseBaseToJson;
  Map<String, dynamic> toJson() =>
      _$SimpleWatchlistEntryResponseBaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleWatchlistEntryResponseBase &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.added, added) ||
                const DeepCollectionEquality().equals(other.added, added)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.isExpired, isExpired) ||
                const DeepCollectionEquality()
                    .equals(other.isExpired, isExpired)) &&
            (identical(other.isRemoved, isRemoved) ||
                const DeepCollectionEquality()
                    .equals(other.isRemoved, isRemoved)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.reminderSet, reminderSet) ||
                const DeepCollectionEquality()
                    .equals(other.reminderSet, reminderSet)) &&
            (identical(other.remindBefore, remindBefore) ||
                const DeepCollectionEquality()
                    .equals(other.remindBefore, remindBefore)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(added) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(isExpired) ^
      const DeepCollectionEquality().hash(isRemoved) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(reminderSet) ^
      const DeepCollectionEquality().hash(remindBefore) ^
      runtimeType.hashCode;
}

extension $SimpleWatchlistEntryResponseBaseExtension
    on SimpleWatchlistEntryResponseBase {
  SimpleWatchlistEntryResponseBase copyWith(
      {String? id,
      enums.SimpleWatchlistEntryResponseBaseType? type,
      String? title,
      DateTime? added,
      String? showId,
      bool? isExpired,
      bool? isRemoved,
      String? watchlistId,
      String? serviceId,
      bool? reminderSet,
      int? remindBefore}) {
    return SimpleWatchlistEntryResponseBase(
        id: id ?? this.id,
        type: type ?? this.type,
        title: title ?? this.title,
        added: added ?? this.added,
        showId: showId ?? this.showId,
        isExpired: isExpired ?? this.isExpired,
        isRemoved: isRemoved ?? this.isRemoved,
        watchlistId: watchlistId ?? this.watchlistId,
        serviceId: serviceId ?? this.serviceId,
        reminderSet: reminderSet ?? this.reminderSet,
        remindBefore: remindBefore ?? this.remindBefore);
  }

  SimpleWatchlistEntryResponseBase copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<enums.SimpleWatchlistEntryResponseBaseType?>? type,
      Wrapped<String?>? title,
      Wrapped<DateTime?>? added,
      Wrapped<String?>? showId,
      Wrapped<bool?>? isExpired,
      Wrapped<bool?>? isRemoved,
      Wrapped<String?>? watchlistId,
      Wrapped<String?>? serviceId,
      Wrapped<bool?>? reminderSet,
      Wrapped<int?>? remindBefore}) {
    return SimpleWatchlistEntryResponseBase(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title),
        added: (added != null ? added.value : this.added),
        showId: (showId != null ? showId.value : this.showId),
        isExpired: (isExpired != null ? isExpired.value : this.isExpired),
        isRemoved: (isRemoved != null ? isRemoved.value : this.isRemoved),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        reminderSet:
            (reminderSet != null ? reminderSet.value : this.reminderSet),
        remindBefore:
            (remindBefore != null ? remindBefore.value : this.remindBefore));
  }
}

@JsonSerializable(explicitToJson: true)
class GridEntryResponse {
  GridEntryResponse({
    this.feedType,
    this.feedTitle,
    this.entries,
    this.entryCount,
    this.totalResults,
  });

  factory GridEntryResponse.fromJson(Map<String, dynamic> json) =>
      _$GridEntryResponseFromJson(json);

  @JsonKey(
    name: 'feedType',
    includeIfNull: false,
    toJson: gridEntryResponseFeedTypeToJson,
    fromJson: gridEntryResponseFeedTypeFromJson,
  )
  final enums.GridEntryResponseFeedType? feedType;
  @JsonKey(name: 'feedTitle', includeIfNull: false, defaultValue: '')
  final String? feedTitle;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <WatchlistEntryResponseBase>[])
  final List<WatchlistEntryResponseBase>? entries;
  @JsonKey(name: 'entryCount', includeIfNull: false)
  final int? entryCount;
  @JsonKey(name: 'totalResults', includeIfNull: false)
  final int? totalResults;
  static const fromJsonFactory = _$GridEntryResponseFromJson;
  static const toJsonFactory = _$GridEntryResponseToJson;
  Map<String, dynamic> toJson() => _$GridEntryResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridEntryResponse &&
            (identical(other.feedType, feedType) ||
                const DeepCollectionEquality()
                    .equals(other.feedType, feedType)) &&
            (identical(other.feedTitle, feedTitle) ||
                const DeepCollectionEquality()
                    .equals(other.feedTitle, feedTitle)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality()
                    .equals(other.entries, entries)) &&
            (identical(other.entryCount, entryCount) ||
                const DeepCollectionEquality()
                    .equals(other.entryCount, entryCount)) &&
            (identical(other.totalResults, totalResults) ||
                const DeepCollectionEquality()
                    .equals(other.totalResults, totalResults)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(feedType) ^
      const DeepCollectionEquality().hash(feedTitle) ^
      const DeepCollectionEquality().hash(entries) ^
      const DeepCollectionEquality().hash(entryCount) ^
      const DeepCollectionEquality().hash(totalResults) ^
      runtimeType.hashCode;
}

extension $GridEntryResponseExtension on GridEntryResponse {
  GridEntryResponse copyWith(
      {enums.GridEntryResponseFeedType? feedType,
      String? feedTitle,
      List<WatchlistEntryResponseBase>? entries,
      int? entryCount,
      int? totalResults}) {
    return GridEntryResponse(
        feedType: feedType ?? this.feedType,
        feedTitle: feedTitle ?? this.feedTitle,
        entries: entries ?? this.entries,
        entryCount: entryCount ?? this.entryCount,
        totalResults: totalResults ?? this.totalResults);
  }

  GridEntryResponse copyWithWrapped(
      {Wrapped<enums.GridEntryResponseFeedType?>? feedType,
      Wrapped<String?>? feedTitle,
      Wrapped<List<WatchlistEntryResponseBase>?>? entries,
      Wrapped<int?>? entryCount,
      Wrapped<int?>? totalResults}) {
    return GridEntryResponse(
        feedType: (feedType != null ? feedType.value : this.feedType),
        feedTitle: (feedTitle != null ? feedTitle.value : this.feedTitle),
        entries: (entries != null ? entries.value : this.entries),
        entryCount: (entryCount != null ? entryCount.value : this.entryCount),
        totalResults:
            (totalResults != null ? totalResults.value : this.totalResults));
  }
}

@JsonSerializable(explicitToJson: true)
class GridResponse {
  GridResponse({
    this.feeds,
  });

  factory GridResponse.fromJson(Map<String, dynamic> json) =>
      _$GridResponseFromJson(json);

  @JsonKey(
      name: 'feeds', includeIfNull: false, defaultValue: <GridEntryResponse>[])
  final List<GridEntryResponse>? feeds;
  static const fromJsonFactory = _$GridResponseFromJson;
  static const toJsonFactory = _$GridResponseToJson;
  Map<String, dynamic> toJson() => _$GridResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GridResponse &&
            (identical(other.feeds, feeds) ||
                const DeepCollectionEquality().equals(other.feeds, feeds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(feeds) ^ runtimeType.hashCode;
}

extension $GridResponseExtension on GridResponse {
  GridResponse copyWith({List<GridEntryResponse>? feeds}) {
    return GridResponse(feeds: feeds ?? this.feeds);
  }

  GridResponse copyWithWrapped({Wrapped<List<GridEntryResponse>?>? feeds}) {
    return GridResponse(feeds: (feeds != null ? feeds.value : this.feeds));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistResponse {
  WatchlistResponse({
    this.name,
    this.entries,
    this.description,
    this.watchlistId,
    this.totalResults,
  });

  factory WatchlistResponse.fromJson(Map<String, dynamic> json) =>
      _$WatchlistResponseFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <WatchlistEntryResponseBase>[])
  final List<WatchlistEntryResponseBase>? entries;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  @JsonKey(name: 'totalResults', includeIfNull: false)
  final int? totalResults;
  static const fromJsonFactory = _$WatchlistResponseFromJson;
  static const toJsonFactory = _$WatchlistResponseToJson;
  Map<String, dynamic> toJson() => _$WatchlistResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistResponse &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality()
                    .equals(other.entries, entries)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)) &&
            (identical(other.totalResults, totalResults) ||
                const DeepCollectionEquality()
                    .equals(other.totalResults, totalResults)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(entries) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      const DeepCollectionEquality().hash(totalResults) ^
      runtimeType.hashCode;
}

extension $WatchlistResponseExtension on WatchlistResponse {
  WatchlistResponse copyWith(
      {String? name,
      List<WatchlistEntryResponseBase>? entries,
      String? description,
      String? watchlistId,
      int? totalResults}) {
    return WatchlistResponse(
        name: name ?? this.name,
        entries: entries ?? this.entries,
        description: description ?? this.description,
        watchlistId: watchlistId ?? this.watchlistId,
        totalResults: totalResults ?? this.totalResults);
  }

  WatchlistResponse copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<List<WatchlistEntryResponseBase>?>? entries,
      Wrapped<String?>? description,
      Wrapped<String?>? watchlistId,
      Wrapped<int?>? totalResults}) {
    return WatchlistResponse(
        name: (name != null ? name.value : this.name),
        entries: (entries != null ? entries.value : this.entries),
        description:
            (description != null ? description.value : this.description),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId),
        totalResults:
            (totalResults != null ? totalResults.value : this.totalResults));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistId {
  WatchlistId({
    this.watchlistId,
  });

  factory WatchlistId.fromJson(Map<String, dynamic> json) =>
      _$WatchlistIdFromJson(json);

  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  static const fromJsonFactory = _$WatchlistIdFromJson;
  static const toJsonFactory = _$WatchlistIdToJson;
  Map<String, dynamic> toJson() => _$WatchlistIdToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistId &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(watchlistId) ^ runtimeType.hashCode;
}

extension $WatchlistIdExtension on WatchlistId {
  WatchlistId copyWith({String? watchlistId}) {
    return WatchlistId(watchlistId: watchlistId ?? this.watchlistId);
  }

  WatchlistId copyWithWrapped({Wrapped<String?>? watchlistId}) {
    return WatchlistId(
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId));
  }
}

@JsonSerializable(explicitToJson: true)
class WatchlistRequest {
  WatchlistRequest({
    this.name,
    this.entries,
    this.description,
    this.profileId,
    this.watchlistId,
  });

  factory WatchlistRequest.fromJson(Map<String, dynamic> json) =>
      _$WatchlistRequestFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
      name: 'entries',
      includeIfNull: false,
      defaultValue: <WatchlistEntryRequest>[])
  final List<WatchlistEntryRequest>? entries;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'watchlistId', includeIfNull: false, defaultValue: '')
  final String? watchlistId;
  static const fromJsonFactory = _$WatchlistRequestFromJson;
  static const toJsonFactory = _$WatchlistRequestToJson;
  Map<String, dynamic> toJson() => _$WatchlistRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatchlistRequest &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.entries, entries) ||
                const DeepCollectionEquality()
                    .equals(other.entries, entries)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.watchlistId, watchlistId) ||
                const DeepCollectionEquality()
                    .equals(other.watchlistId, watchlistId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(entries) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(watchlistId) ^
      runtimeType.hashCode;
}

extension $WatchlistRequestExtension on WatchlistRequest {
  WatchlistRequest copyWith(
      {String? name,
      List<WatchlistEntryRequest>? entries,
      String? description,
      String? profileId,
      String? watchlistId}) {
    return WatchlistRequest(
        name: name ?? this.name,
        entries: entries ?? this.entries,
        description: description ?? this.description,
        profileId: profileId ?? this.profileId,
        watchlistId: watchlistId ?? this.watchlistId);
  }

  WatchlistRequest copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<List<WatchlistEntryRequest>?>? entries,
      Wrapped<String?>? description,
      Wrapped<String?>? profileId,
      Wrapped<String?>? watchlistId}) {
    return WatchlistRequest(
        name: (name != null ? name.value : this.name),
        entries: (entries != null ? entries.value : this.entries),
        description:
            (description != null ? description.value : this.description),
        profileId: (profileId != null ? profileId.value : this.profileId),
        watchlistId:
            (watchlistId != null ? watchlistId.value : this.watchlistId));
  }
}

String? watchlistEntryResponseBaseTypeToJson(
    enums.WatchlistEntryResponseBaseType? watchlistEntryResponseBaseType) {
  return enums
      .$WatchlistEntryResponseBaseTypeMap[watchlistEntryResponseBaseType];
}

enums.WatchlistEntryResponseBaseType watchlistEntryResponseBaseTypeFromJson(
  Object? watchlistEntryResponseBaseType, [
  enums.WatchlistEntryResponseBaseType? defaultValue,
]) {
  if (watchlistEntryResponseBaseType is String) {
    return enums.$WatchlistEntryResponseBaseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                watchlistEntryResponseBaseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.WatchlistEntryResponseBaseType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$WatchlistEntryResponseBaseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.WatchlistEntryResponseBaseType.swaggerGeneratedUnknown;
}

List<String> watchlistEntryResponseBaseTypeListToJson(
    List<enums.WatchlistEntryResponseBaseType>?
        watchlistEntryResponseBaseType) {
  if (watchlistEntryResponseBaseType == null) {
    return [];
  }

  return watchlistEntryResponseBaseType
      .map((e) => enums.$WatchlistEntryResponseBaseTypeMap[e]!)
      .toList();
}

List<enums.WatchlistEntryResponseBaseType>
    watchlistEntryResponseBaseTypeListFromJson(
  List? watchlistEntryResponseBaseType, [
  List<enums.WatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseType == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryResponseBaseType
      .map((e) => watchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryResponseBaseType>?
    watchlistEntryResponseBaseTypeNullableListFromJson(
  List? watchlistEntryResponseBaseType, [
  List<enums.WatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseType == null) {
    return defaultValue;
  }

  return watchlistEntryResponseBaseType
      .map((e) => watchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

String? watchlistEntryResponseBaseEntitlementStateToJson(
    enums.WatchlistEntryResponseBaseEntitlementState?
        watchlistEntryResponseBaseEntitlementState) {
  return enums.$WatchlistEntryResponseBaseEntitlementStateMap[
      watchlistEntryResponseBaseEntitlementState];
}

enums.WatchlistEntryResponseBaseEntitlementState
    watchlistEntryResponseBaseEntitlementStateFromJson(
  Object? watchlistEntryResponseBaseEntitlementState, [
  enums.WatchlistEntryResponseBaseEntitlementState? defaultValue,
]) {
  if (watchlistEntryResponseBaseEntitlementState is String) {
    return enums.$WatchlistEntryResponseBaseEntitlementStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                watchlistEntryResponseBaseEntitlementState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.WatchlistEntryResponseBaseEntitlementState
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$WatchlistEntryResponseBaseEntitlementStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.WatchlistEntryResponseBaseEntitlementState.swaggerGeneratedUnknown;
}

List<String> watchlistEntryResponseBaseEntitlementStateListToJson(
    List<enums.WatchlistEntryResponseBaseEntitlementState>?
        watchlistEntryResponseBaseEntitlementState) {
  if (watchlistEntryResponseBaseEntitlementState == null) {
    return [];
  }

  return watchlistEntryResponseBaseEntitlementState
      .map((e) => enums.$WatchlistEntryResponseBaseEntitlementStateMap[e]!)
      .toList();
}

List<enums.WatchlistEntryResponseBaseEntitlementState>
    watchlistEntryResponseBaseEntitlementStateListFromJson(
  List? watchlistEntryResponseBaseEntitlementState, [
  List<enums.WatchlistEntryResponseBaseEntitlementState>? defaultValue,
]) {
  if (watchlistEntryResponseBaseEntitlementState == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryResponseBaseEntitlementState
      .map((e) =>
          watchlistEntryResponseBaseEntitlementStateFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryResponseBaseEntitlementState>?
    watchlistEntryResponseBaseEntitlementStateNullableListFromJson(
  List? watchlistEntryResponseBaseEntitlementState, [
  List<enums.WatchlistEntryResponseBaseEntitlementState>? defaultValue,
]) {
  if (watchlistEntryResponseBaseEntitlementState == null) {
    return defaultValue;
  }

  return watchlistEntryResponseBaseEntitlementState
      .map((e) =>
          watchlistEntryResponseBaseEntitlementStateFromJson(e.toString()))
      .toList();
}

String? watchlistEntryResponseBaseProductTypeToJson(
    enums.WatchlistEntryResponseBaseProductType?
        watchlistEntryResponseBaseProductType) {
  return enums.$WatchlistEntryResponseBaseProductTypeMap[
      watchlistEntryResponseBaseProductType];
}

enums.WatchlistEntryResponseBaseProductType
    watchlistEntryResponseBaseProductTypeFromJson(
  Object? watchlistEntryResponseBaseProductType, [
  enums.WatchlistEntryResponseBaseProductType? defaultValue,
]) {
  if (watchlistEntryResponseBaseProductType is String) {
    return enums.$WatchlistEntryResponseBaseProductTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                watchlistEntryResponseBaseProductType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.WatchlistEntryResponseBaseProductType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$WatchlistEntryResponseBaseProductTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.WatchlistEntryResponseBaseProductType.swaggerGeneratedUnknown;
}

List<String> watchlistEntryResponseBaseProductTypeListToJson(
    List<enums.WatchlistEntryResponseBaseProductType>?
        watchlistEntryResponseBaseProductType) {
  if (watchlistEntryResponseBaseProductType == null) {
    return [];
  }

  return watchlistEntryResponseBaseProductType
      .map((e) => enums.$WatchlistEntryResponseBaseProductTypeMap[e]!)
      .toList();
}

List<enums.WatchlistEntryResponseBaseProductType>
    watchlistEntryResponseBaseProductTypeListFromJson(
  List? watchlistEntryResponseBaseProductType, [
  List<enums.WatchlistEntryResponseBaseProductType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseProductType == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryResponseBaseProductType
      .map((e) => watchlistEntryResponseBaseProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryResponseBaseProductType>?
    watchlistEntryResponseBaseProductTypeNullableListFromJson(
  List? watchlistEntryResponseBaseProductType, [
  List<enums.WatchlistEntryResponseBaseProductType>? defaultValue,
]) {
  if (watchlistEntryResponseBaseProductType == null) {
    return defaultValue;
  }

  return watchlistEntryResponseBaseProductType
      .map((e) => watchlistEntryResponseBaseProductTypeFromJson(e.toString()))
      .toList();
}

String? watchlistEntryRequestTypeToJson(
    enums.WatchlistEntryRequestType? watchlistEntryRequestType) {
  return enums.$WatchlistEntryRequestTypeMap[watchlistEntryRequestType];
}

enums.WatchlistEntryRequestType watchlistEntryRequestTypeFromJson(
  Object? watchlistEntryRequestType, [
  enums.WatchlistEntryRequestType? defaultValue,
]) {
  if (watchlistEntryRequestType is String) {
    return enums.$WatchlistEntryRequestTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                watchlistEntryRequestType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.WatchlistEntryRequestType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$WatchlistEntryRequestTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.WatchlistEntryRequestType.swaggerGeneratedUnknown;
}

List<String> watchlistEntryRequestTypeListToJson(
    List<enums.WatchlistEntryRequestType>? watchlistEntryRequestType) {
  if (watchlistEntryRequestType == null) {
    return [];
  }

  return watchlistEntryRequestType
      .map((e) => enums.$WatchlistEntryRequestTypeMap[e]!)
      .toList();
}

List<enums.WatchlistEntryRequestType> watchlistEntryRequestTypeListFromJson(
  List? watchlistEntryRequestType, [
  List<enums.WatchlistEntryRequestType>? defaultValue,
]) {
  if (watchlistEntryRequestType == null) {
    return defaultValue ?? [];
  }

  return watchlistEntryRequestType
      .map((e) => watchlistEntryRequestTypeFromJson(e.toString()))
      .toList();
}

List<enums.WatchlistEntryRequestType>?
    watchlistEntryRequestTypeNullableListFromJson(
  List? watchlistEntryRequestType, [
  List<enums.WatchlistEntryRequestType>? defaultValue,
]) {
  if (watchlistEntryRequestType == null) {
    return defaultValue;
  }

  return watchlistEntryRequestType
      .map((e) => watchlistEntryRequestTypeFromJson(e.toString()))
      .toList();
}

String? simpleWatchlistEntryResponseBaseTypeToJson(
    enums.SimpleWatchlistEntryResponseBaseType?
        simpleWatchlistEntryResponseBaseType) {
  return enums.$SimpleWatchlistEntryResponseBaseTypeMap[
      simpleWatchlistEntryResponseBaseType];
}

enums.SimpleWatchlistEntryResponseBaseType
    simpleWatchlistEntryResponseBaseTypeFromJson(
  Object? simpleWatchlistEntryResponseBaseType, [
  enums.SimpleWatchlistEntryResponseBaseType? defaultValue,
]) {
  if (simpleWatchlistEntryResponseBaseType is String) {
    return enums.$SimpleWatchlistEntryResponseBaseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                simpleWatchlistEntryResponseBaseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SimpleWatchlistEntryResponseBaseType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SimpleWatchlistEntryResponseBaseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SimpleWatchlistEntryResponseBaseType.swaggerGeneratedUnknown;
}

List<String> simpleWatchlistEntryResponseBaseTypeListToJson(
    List<enums.SimpleWatchlistEntryResponseBaseType>?
        simpleWatchlistEntryResponseBaseType) {
  if (simpleWatchlistEntryResponseBaseType == null) {
    return [];
  }

  return simpleWatchlistEntryResponseBaseType
      .map((e) => enums.$SimpleWatchlistEntryResponseBaseTypeMap[e]!)
      .toList();
}

List<enums.SimpleWatchlistEntryResponseBaseType>
    simpleWatchlistEntryResponseBaseTypeListFromJson(
  List? simpleWatchlistEntryResponseBaseType, [
  List<enums.SimpleWatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (simpleWatchlistEntryResponseBaseType == null) {
    return defaultValue ?? [];
  }

  return simpleWatchlistEntryResponseBaseType
      .map((e) => simpleWatchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

List<enums.SimpleWatchlistEntryResponseBaseType>?
    simpleWatchlistEntryResponseBaseTypeNullableListFromJson(
  List? simpleWatchlistEntryResponseBaseType, [
  List<enums.SimpleWatchlistEntryResponseBaseType>? defaultValue,
]) {
  if (simpleWatchlistEntryResponseBaseType == null) {
    return defaultValue;
  }

  return simpleWatchlistEntryResponseBaseType
      .map((e) => simpleWatchlistEntryResponseBaseTypeFromJson(e.toString()))
      .toList();
}

String? gridEntryResponseFeedTypeToJson(
    enums.GridEntryResponseFeedType? gridEntryResponseFeedType) {
  return enums.$GridEntryResponseFeedTypeMap[gridEntryResponseFeedType];
}

enums.GridEntryResponseFeedType gridEntryResponseFeedTypeFromJson(
  Object? gridEntryResponseFeedType, [
  enums.GridEntryResponseFeedType? defaultValue,
]) {
  if (gridEntryResponseFeedType is String) {
    return enums.$GridEntryResponseFeedTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                gridEntryResponseFeedType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.GridEntryResponseFeedType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$GridEntryResponseFeedTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.GridEntryResponseFeedType.swaggerGeneratedUnknown;
}

List<String> gridEntryResponseFeedTypeListToJson(
    List<enums.GridEntryResponseFeedType>? gridEntryResponseFeedType) {
  if (gridEntryResponseFeedType == null) {
    return [];
  }

  return gridEntryResponseFeedType
      .map((e) => enums.$GridEntryResponseFeedTypeMap[e]!)
      .toList();
}

List<enums.GridEntryResponseFeedType> gridEntryResponseFeedTypeListFromJson(
  List? gridEntryResponseFeedType, [
  List<enums.GridEntryResponseFeedType>? defaultValue,
]) {
  if (gridEntryResponseFeedType == null) {
    return defaultValue ?? [];
  }

  return gridEntryResponseFeedType
      .map((e) => gridEntryResponseFeedTypeFromJson(e.toString()))
      .toList();
}

List<enums.GridEntryResponseFeedType>?
    gridEntryResponseFeedTypeNullableListFromJson(
  List? gridEntryResponseFeedType, [
  List<enums.GridEntryResponseFeedType>? defaultValue,
]) {
  if (gridEntryResponseFeedType == null) {
    return defaultValue;
  }

  return gridEntryResponseFeedType
      .map((e) => gridEntryResponseFeedTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
