// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_watermark_service.swagger.chopper.dart';
part 'liberty_watermark_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyWatermarkService extends ChopperService {
  static LibertyWatermarkService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyWatermarkService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyWatermarkService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyWatermarkService(newClient);
  }

  ///
  ///@param nv-authorizations X-OESP-Token
  ///@param x-api-key Authorization token
  ///@param tenant Tenant name
  Future<chopper.Response<String>> tenantQmV1SurfacesGet({
    String? nvAuthorizations,
    String? xApiKey,
    required String? tenant,
    String? cacheControl,
  }) {
    return _tenantQmV1SurfacesGet(
        nvAuthorizations: nvAuthorizations,
        xApiKey: xApiKey,
        tenant: tenant,
        cacheControl: cacheControl);
  }

  ///
  ///@param nv-authorizations X-OESP-Token
  ///@param x-api-key Authorization token
  ///@param tenant Tenant name
  @Get(path: '/{tenant}/qm/v1/surfaces')
  Future<chopper.Response<String>> _tenantQmV1SurfacesGet({
    @Header('nv-authorizations') String? nvAuthorizations,
    @Header('x-api-key') String? xApiKey,
    @Path('tenant') required String? tenant,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param watermarkId Watermark ID
  ///@param timestamp Timestamp
  Future<chopper.Response<WatermarkMetadata>> watermarksWatermarkIdGet({
    required int? watermarkId,
    String? timestamp,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        WatermarkMetadata, () => WatermarkMetadata.fromJsonFactory);

    return _watermarksWatermarkIdGet(
        watermarkId: watermarkId,
        timestamp: timestamp,
        cacheControl: cacheControl);
  }

  ///
  ///@param watermarkId Watermark ID
  ///@param timestamp Timestamp
  @Get(path: '/watermarks/{watermarkId}')
  Future<chopper.Response<WatermarkMetadata>> _watermarksWatermarkIdGet({
    @Path('watermarkId') required int? watermarkId,
    @Query('timestamp') String? timestamp,
    @Header('Cache-Control') String? cacheControl,
  });

  ///
  ///@param customerId Customer ID.  **NOTE:** `customerId` is a concatenated string of the following format: `customerId_countryCode` where `countryCode` is a 2 letter lower case character string
  Future<chopper.Response> customersCustomerIdDelete({
    required String? customerId,
    String? cacheControl,
  }) {
    return _customersCustomerIdDelete(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///
  ///@param customerId Customer ID.  **NOTE:** `customerId` is a concatenated string of the following format: `customerId_countryCode` where `countryCode` is a 2 letter lower case character string
  @Delete(path: '/customers/{customerId}')
  Future<chopper.Response> _customersCustomerIdDelete({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class WatermarkMetadata {
  WatermarkMetadata({
    required this.customerId,
  });

  factory WatermarkMetadata.fromJson(Map<String, dynamic> json) =>
      _$WatermarkMetadataFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  static const fromJsonFactory = _$WatermarkMetadataFromJson;
  static const toJsonFactory = _$WatermarkMetadataToJson;
  Map<String, dynamic> toJson() => _$WatermarkMetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is WatermarkMetadata &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^ runtimeType.hashCode;
}

extension $WatermarkMetadataExtension on WatermarkMetadata {
  WatermarkMetadata copyWith({String? customerId}) {
    return WatermarkMetadata(customerId: customerId ?? this.customerId);
  }

  WatermarkMetadata copyWithWrapped({Wrapped<String>? customerId}) {
    return WatermarkMetadata(
        customerId: (customerId != null ? customerId.value : this.customerId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorList {
  ErrorList({
    required this.errors,
  });

  factory ErrorList.fromJson(Map<String, dynamic> json) =>
      _$ErrorListFromJson(json);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ErrorListFromJson;
  static const toJsonFactory = _$ErrorListToJson;
  Map<String, dynamic> toJson() => _$ErrorListToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorList &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ErrorListExtension on ErrorList {
  ErrorList copyWith({List<String>? errors}) {
    return ErrorList(errors: errors ?? this.errors);
  }

  ErrorList copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ErrorList(errors: (errors != null ? errors.value : this.errors));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
