// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'liberty_zero_touch_service.swagger.chopper.dart';
part 'liberty_zero_touch_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LibertyZeroTouchService extends ChopperService {
  static LibertyZeroTouchService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LibertyZeroTouchService(client);
    }

    final newClient = ChopperClient(
        services: [_$LibertyZeroTouchService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LibertyZeroTouchService(newClient);
  }

  ///
  Future<chopper.Response<Object>> getWiFiCredentialsPost({
    String? xDev,
    String? xRequestId,
    String? cacheControl,
    required Object? body,
  }) {
    return _getWiFiCredentialsPost(
        xDev: xDev,
        xRequestId: xRequestId,
        cacheControl: cacheControl,
        body: body);
  }

  ///
  @Post(path: '/getWiFiCredentials')
  Future<chopper.Response<Object>> _getWiFiCredentialsPost({
    @Header('x-dev') String? xDev,
    @Header('x-request-id') String? xRequestId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Object? body,
  });
}

@JsonSerializable(explicitToJson: true)
class Error {
  Error({
    this.error,
  });

  factory Error.fromJson(Map<String, dynamic> json) => _$ErrorFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final Error$Error? error;
  static const fromJsonFactory = _$ErrorFromJson;
  static const toJsonFactory = _$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorExtension on Error {
  Error copyWith({Error$Error? error}) {
    return Error(error: error ?? this.error);
  }

  Error copyWithWrapped({Wrapped<Error$Error?>? error}) {
    return Error(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class Error$Error {
  Error$Error({
    this.message,
    this.correlationId,
  });

  factory Error$Error.fromJson(Map<String, dynamic> json) =>
      _$Error$ErrorFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$Error$ErrorFromJson;
  static const toJsonFactory = _$Error$ErrorToJson;
  Map<String, dynamic> toJson() => _$Error$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error$Error &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $Error$ErrorExtension on Error$Error {
  Error$Error copyWith({String? message, String? correlationId}) {
    return Error$Error(
        message: message ?? this.message,
        correlationId: correlationId ?? this.correlationId);
  }

  Error$Error copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? correlationId}) {
    return Error$Error(
        message: (message != null ? message.value : this.message),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
