// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'linear_service.enums.swagger.dart' as enums;
export 'linear_service.enums.swagger.dart';

part 'linear_service.swagger.chopper.dart';
part 'linear_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class LinearService extends ChopperService {
  static LinearService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$LinearService(client);
    }

    final newClient = ChopperClient(
        services: [_$LinearService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$LinearService(newClient);
  }

  ///Get regionalized and localized channel lineup
  ///@param cityId identifier of the region/city
  ///@param language language for which data needs to be returned
  ///@param modelName model name of CPE
  ///@param productClass class of a product
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  Future<chopper.Response<List<ChannelV1>>> v1ChannelsGet({
    required String? cityId,
    String? language,
    String? modelName,
    String? productClass,
    String? ifModifiedSince,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ChannelV1, () => ChannelV1.fromJsonFactory);

    return _v1ChannelsGet(
        cityId: cityId,
        language: language,
        modelName: modelName,
        productClass: productClass,
        ifModifiedSince: ifModifiedSince,
        cacheControl: cacheControl);
  }

  ///Get regionalized and localized channel lineup
  ///@param cityId identifier of the region/city
  ///@param language language for which data needs to be returned
  ///@param modelName model name of CPE
  ///@param productClass class of a product
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  @Get(path: '/v1/channels')
  Future<chopper.Response<List<ChannelV1>>> _v1ChannelsGet({
    @Query('cityId') required String? cityId,
    @Query('language') String? language,
    @Query('modelName') String? modelName,
    @Query('productClass') String? productClass,
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get regionalized and localized channel lineup
  ///@param cityId identifier of the region/city
  ///@param language language for which data needs to be returned
  ///@param modelName model name of CPE
  ///@param productClass class of a product
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  Future<chopper.Response<List<Channel>>> v2ChannelsGet({
    required String? cityId,
    String? language,
    String? modelName,
    String? productClass,
    String? ifModifiedSince,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Channel, () => Channel.fromJsonFactory);

    return _v2ChannelsGet(
        cityId: cityId,
        language: language,
        modelName: modelName,
        productClass: productClass,
        ifModifiedSince: ifModifiedSince,
        cacheControl: cacheControl);
  }

  ///Get regionalized and localized channel lineup
  ///@param cityId identifier of the region/city
  ///@param language language for which data needs to be returned
  ///@param modelName model name of CPE
  ///@param productClass class of a product
  ///@param If-Modified-Since Returning 304 if the incoming request has been returned since specified date. Validation format is following: 'Wed, 21 Oct 2015 07:28:00 GMT' - Date must be always in GMT format, not local time
  @Get(path: '/v2/channels')
  Future<chopper.Response<List<Channel>>> _v2ChannelsGet({
    @Query('cityId') required String? cityId,
    @Query('language') String? language,
    @Query('modelName') String? modelName,
    @Query('productClass') String? productClass,
    @Header('If-Modified-Since') String? ifModifiedSince,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get LinearProducts by {channelId}
  ///@param channelId ID of the channel
  Future<chopper.Response<List<ChannelProduct>>>
      v1ChannelsChannelIdProductsLinearGet({
    required String? channelId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ChannelProduct, () => ChannelProduct.fromJsonFactory);

    return _v1ChannelsChannelIdProductsLinearGet(
        channelId: channelId, cacheControl: cacheControl);
  }

  ///Get LinearProducts by {channelId}
  ///@param channelId ID of the channel
  @Get(path: '/v1/channels/{channelId}/products/linear')
  Future<chopper.Response<List<ChannelProduct>>>
      _v1ChannelsChannelIdProductsLinearGet({
    @Path('channelId') required String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get ReplayProducts by {channelId}
  ///@param channelId ID of the channel
  Future<chopper.Response<List<ChannelProduct>>>
      v1ChannelsChannelIdProductsReplayGet({
    required String? channelId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ChannelProduct, () => ChannelProduct.fromJsonFactory);

    return _v1ChannelsChannelIdProductsReplayGet(
        channelId: channelId, cacheControl: cacheControl);
  }

  ///Get ReplayProducts by {channelId}
  ///@param channelId ID of the channel
  @Get(path: '/v1/channels/{channelId}/products/replay')
  Future<chopper.Response<List<ChannelProduct>>>
      _v1ChannelsChannelIdProductsReplayGet({
    @Path('channelId') required String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get details of a Replay event
  ///@param crid CRID,IMI for which details need to be returned
  ///@param returnLinearContent determines if empty response should be returned in case event is still using linear metadata (not switched to VOD metadata yet)
  ///@param language language code for which localized metadata needs to be returned
  Future<chopper.Response<ReplayEvent>> v1ReplayEventCridGet({
    required String? crid,
    required bool? returnLinearContent,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayEvent, () => ReplayEvent.fromJsonFactory);

    return _v1ReplayEventCridGet(
        crid: crid,
        returnLinearContent: returnLinearContent,
        language: language,
        cacheControl: cacheControl);
  }

  ///Get details of a Replay event
  ///@param crid CRID,IMI for which details need to be returned
  ///@param returnLinearContent determines if empty response should be returned in case event is still using linear metadata (not switched to VOD metadata yet)
  ///@param language language code for which localized metadata needs to be returned
  @Get(path: '/v1/replayEvent/{crid}')
  Future<chopper.Response<ReplayEvent>> _v1ReplayEventCridGet({
    @Path('crid') required String? crid,
    @Query('returnLinearContent') required bool? returnLinearContent,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get details of a Replay event
  ///@param crid CRID,IMI for which details need to be returned
  ///@param returnLinearContent determines if empty response should be returned in case event is still using linear metadata (not switched to VOD metadata yet)
  ///@param language language code for which localized metadata needs to be returned
  Future<chopper.Response<ReplayEventV2>> v2ReplayEventCridGet({
    required String? crid,
    required bool? returnLinearContent,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayEventV2, () => ReplayEventV2.fromJsonFactory);

    return _v2ReplayEventCridGet(
        crid: crid,
        returnLinearContent: returnLinearContent,
        language: language,
        cacheControl: cacheControl);
  }

  ///Get details of a Replay event
  ///@param crid CRID,IMI for which details need to be returned
  ///@param returnLinearContent determines if empty response should be returned in case event is still using linear metadata (not switched to VOD metadata yet)
  ///@param language language code for which localized metadata needs to be returned
  @Get(path: '/v2/replayEvent/{crid}')
  Future<chopper.Response<ReplayEventV2>> _v2ReplayEventCridGet({
    @Path('crid') required String? crid,
    @Query('returnLinearContent') required bool? returnLinearContent,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get ordered most watched channels ids
  ///@param cityId identifier of the region/city
  ///@param modelName model name of CPE
  ///@param productClass class of a product
  Future<chopper.Response<List<String>>> v1MostWatchedChannelsGet({
    required String? cityId,
    String? modelName,
    String? productClass,
    String? cacheControl,
  }) {
    return _v1MostWatchedChannelsGet(
        cityId: cityId,
        modelName: modelName,
        productClass: productClass,
        cacheControl: cacheControl);
  }

  ///Get ordered most watched channels ids
  ///@param cityId identifier of the region/city
  ///@param modelName model name of CPE
  ///@param productClass class of a product
  @Get(path: '/v1/mostWatchedChannels')
  Future<chopper.Response<List<String>>> _v1MostWatchedChannelsGet({
    @Query('cityId') required String? cityId,
    @Query('modelName') String? modelName,
    @Query('productClass') String? productClass,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Application {
  Application({
    required this.applicationId,
    this.deviceCode,
    this.name,
    this.url,
  });

  factory Application.fromJson(Map<String, dynamic> json) =>
      _$ApplicationFromJson(json);

  @JsonKey(name: 'applicationId', includeIfNull: false, defaultValue: '')
  final String applicationId;
  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String? deviceCode;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$ApplicationFromJson;
  static const toJsonFactory = _$ApplicationToJson;
  Map<String, dynamic> toJson() => _$ApplicationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Application &&
            (identical(other.applicationId, applicationId) ||
                const DeepCollectionEquality()
                    .equals(other.applicationId, applicationId)) &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(applicationId) ^
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ApplicationExtension on Application {
  Application copyWith(
      {String? applicationId, String? deviceCode, String? name, String? url}) {
    return Application(
        applicationId: applicationId ?? this.applicationId,
        deviceCode: deviceCode ?? this.deviceCode,
        name: name ?? this.name,
        url: url ?? this.url);
  }

  Application copyWithWrapped(
      {Wrapped<String>? applicationId,
      Wrapped<String?>? deviceCode,
      Wrapped<String?>? name,
      Wrapped<String?>? url}) {
    return Application(
        applicationId:
            (applicationId != null ? applicationId.value : this.applicationId),
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        name: (name != null ? name.value : this.name),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayEvent {
  ReplayEvent({
    required this.eventId,
    required this.channelId,
    required this.title,
    required this.startTime,
    required this.endTime,
    this.mergedId,
    this.minimumAge,
    this.replayTvMinAge,
    this.parentalGuidanceText,
    this.seriesId,
    this.parentSeriesId,
    this.episodeName,
    this.seasonNumber,
    this.episodeNumber,
    this.isAdult,
    this.hasReplayTV,
    this.replayTvAdult,
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.strictAvailabilityEnd,
    this.hasStartOver,
    this.isOpen,
    this.shortDescription,
    this.longDescription,
    this.actors,
    this.directors,
    this.producers,
    this.audioType,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.productionDate,
    this.countryOfOrigin,
    this.genres,
    this.resolution,
    this.isLive,
    this.actualStartOffset,
    this.actualEndOffset,
    this.replayTVDisplayAge,
    this.imageVersion,
    this.groupedStartTime,
    this.groupedEndTime,
    this.groupedActualEndOffset,
    this.episodePart,
    this.seriesMepSeriesFinale,
    this.seriesPremiereAirings,
    this.premiere,
  });

  factory ReplayEvent.fromJson(Map<String, dynamic> json) =>
      _$ReplayEventFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num endTime;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'replayTvMinAge', includeIfNull: false)
  final int? replayTvMinAge;
  @JsonKey(name: 'parentalGuidanceText', includeIfNull: false, defaultValue: '')
  final String? parentalGuidanceText;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'hasReplayTV', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTV;
  @JsonKey(name: 'replayTvAdult', includeIfNull: false)
  final bool? replayTvAdult;
  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final num? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final num? replayAvailabilityEnd;
  @JsonKey(name: 'strictAvailabilityEnd', includeIfNull: false)
  final num? strictAvailabilityEnd;
  @JsonKey(name: 'hasStartOver', includeIfNull: false, defaultValue: true)
  final bool? hasStartOver;
  @JsonKey(name: 'isOpen', includeIfNull: false)
  final bool? isOpen;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'actors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? actors;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'producers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? producers;
  @JsonKey(name: 'audioType', includeIfNull: false)
  final int? audioType;
  @JsonKey(
      name: 'audioLanguages', includeIfNull: false, defaultValue: <Language>[])
  final List<Language>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <Language>[])
  final List<Language>? captionLanguages;
  @JsonKey(
      name: 'signLanguages', includeIfNull: false, defaultValue: <Language>[])
  final List<Language>? signLanguages;
  @JsonKey(name: 'productionDate', includeIfNull: false, defaultValue: '')
  final String? productionDate;
  @JsonKey(name: 'countryOfOrigin', includeIfNull: false, defaultValue: '')
  final String? countryOfOrigin;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(
    name: 'resolution',
    includeIfNull: false,
    toJson: replayEventResolutionToJson,
    fromJson: replayEventResolutionFromJson,
  )
  final enums.ReplayEventResolution? resolution;
  @JsonKey(name: 'isLive', includeIfNull: false)
  final bool? isLive;
  @JsonKey(name: 'actualStartOffset', includeIfNull: false)
  final num? actualStartOffset;
  @JsonKey(name: 'actualEndOffset', includeIfNull: false)
  final num? actualEndOffset;
  @JsonKey(name: 'replayTVDisplayAge', includeIfNull: false)
  final bool? replayTVDisplayAge;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'groupedStartTime', includeIfNull: false)
  final num? groupedStartTime;
  @JsonKey(name: 'groupedEndTime', includeIfNull: false)
  final num? groupedEndTime;
  @JsonKey(name: 'groupedActualEndOffset', includeIfNull: false)
  final num? groupedActualEndOffset;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final num? episodePart;
  @JsonKey(name: 'seriesMepSeriesFinale', includeIfNull: false)
  final num? seriesMepSeriesFinale;
  @JsonKey(name: 'seriesPremiereAirings', includeIfNull: false)
  final bool? seriesPremiereAirings;
  @JsonKey(name: 'premiere', includeIfNull: false)
  final bool? premiere;
  static const fromJsonFactory = _$ReplayEventFromJson;
  static const toJsonFactory = _$ReplayEventToJson;
  Map<String, dynamic> toJson() => _$ReplayEventToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayEvent &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.replayTvMinAge, replayTvMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvMinAge, replayTvMinAge)) &&
            (identical(other.parentalGuidanceText, parentalGuidanceText) ||
                const DeepCollectionEquality().equals(
                    other.parentalGuidanceText, parentalGuidanceText)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.episodeName, episodeName) ||
                const DeepCollectionEquality()
                    .equals(other.episodeName, episodeName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.hasReplayTV, hasReplayTV) ||
                const DeepCollectionEquality()
                    .equals(other.hasReplayTV, hasReplayTV)) &&
            (identical(other.replayTvAdult, replayTvAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvAdult, replayTvAdult)) &&
            (identical(other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.strictAvailabilityEnd, strictAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.strictAvailabilityEnd, strictAvailabilityEnd)) &&
            (identical(other.hasStartOver, hasStartOver) ||
                const DeepCollectionEquality()
                    .equals(other.hasStartOver, hasStartOver)) &&
            (identical(other.isOpen, isOpen) || const DeepCollectionEquality().equals(other.isOpen, isOpen)) &&
            (identical(other.shortDescription, shortDescription) || const DeepCollectionEquality().equals(other.shortDescription, shortDescription)) &&
            (identical(other.longDescription, longDescription) || const DeepCollectionEquality().equals(other.longDescription, longDescription)) &&
            (identical(other.actors, actors) || const DeepCollectionEquality().equals(other.actors, actors)) &&
            (identical(other.directors, directors) || const DeepCollectionEquality().equals(other.directors, directors)) &&
            (identical(other.producers, producers) || const DeepCollectionEquality().equals(other.producers, producers)) &&
            (identical(other.audioType, audioType) || const DeepCollectionEquality().equals(other.audioType, audioType)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.productionDate, productionDate) || const DeepCollectionEquality().equals(other.productionDate, productionDate)) &&
            (identical(other.countryOfOrigin, countryOfOrigin) || const DeepCollectionEquality().equals(other.countryOfOrigin, countryOfOrigin)) &&
            (identical(other.genres, genres) || const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.isLive, isLive) || const DeepCollectionEquality().equals(other.isLive, isLive)) &&
            (identical(other.actualStartOffset, actualStartOffset) || const DeepCollectionEquality().equals(other.actualStartOffset, actualStartOffset)) &&
            (identical(other.actualEndOffset, actualEndOffset) || const DeepCollectionEquality().equals(other.actualEndOffset, actualEndOffset)) &&
            (identical(other.replayTVDisplayAge, replayTVDisplayAge) || const DeepCollectionEquality().equals(other.replayTVDisplayAge, replayTVDisplayAge)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.groupedStartTime, groupedStartTime) || const DeepCollectionEquality().equals(other.groupedStartTime, groupedStartTime)) &&
            (identical(other.groupedEndTime, groupedEndTime) || const DeepCollectionEquality().equals(other.groupedEndTime, groupedEndTime)) &&
            (identical(other.groupedActualEndOffset, groupedActualEndOffset) || const DeepCollectionEquality().equals(other.groupedActualEndOffset, groupedActualEndOffset)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.seriesMepSeriesFinale, seriesMepSeriesFinale) || const DeepCollectionEquality().equals(other.seriesMepSeriesFinale, seriesMepSeriesFinale)) &&
            (identical(other.seriesPremiereAirings, seriesPremiereAirings) || const DeepCollectionEquality().equals(other.seriesPremiereAirings, seriesPremiereAirings)) &&
            (identical(other.premiere, premiere) || const DeepCollectionEquality().equals(other.premiere, premiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(replayTvMinAge) ^
      const DeepCollectionEquality().hash(parentalGuidanceText) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(hasReplayTV) ^
      const DeepCollectionEquality().hash(replayTvAdult) ^
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(strictAvailabilityEnd) ^
      const DeepCollectionEquality().hash(hasStartOver) ^
      const DeepCollectionEquality().hash(isOpen) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(actors) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(producers) ^
      const DeepCollectionEquality().hash(audioType) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(productionDate) ^
      const DeepCollectionEquality().hash(countryOfOrigin) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(isLive) ^
      const DeepCollectionEquality().hash(actualStartOffset) ^
      const DeepCollectionEquality().hash(actualEndOffset) ^
      const DeepCollectionEquality().hash(replayTVDisplayAge) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(groupedStartTime) ^
      const DeepCollectionEquality().hash(groupedEndTime) ^
      const DeepCollectionEquality().hash(groupedActualEndOffset) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(seriesMepSeriesFinale) ^
      const DeepCollectionEquality().hash(seriesPremiereAirings) ^
      const DeepCollectionEquality().hash(premiere) ^
      runtimeType.hashCode;
}

extension $ReplayEventExtension on ReplayEvent {
  ReplayEvent copyWith(
      {String? eventId,
      String? channelId,
      String? title,
      num? startTime,
      num? endTime,
      String? mergedId,
      String? minimumAge,
      int? replayTvMinAge,
      String? parentalGuidanceText,
      String? seriesId,
      String? parentSeriesId,
      String? episodeName,
      int? seasonNumber,
      int? episodeNumber,
      bool? isAdult,
      bool? hasReplayTV,
      bool? replayTvAdult,
      num? replayAvailabilityStart,
      num? replayAvailabilityEnd,
      num? strictAvailabilityEnd,
      bool? hasStartOver,
      bool? isOpen,
      String? shortDescription,
      String? longDescription,
      List<String>? actors,
      List<String>? directors,
      List<String>? producers,
      int? audioType,
      List<Language>? audioLanguages,
      List<Language>? captionLanguages,
      List<Language>? signLanguages,
      String? productionDate,
      String? countryOfOrigin,
      List<String>? genres,
      enums.ReplayEventResolution? resolution,
      bool? isLive,
      num? actualStartOffset,
      num? actualEndOffset,
      bool? replayTVDisplayAge,
      String? imageVersion,
      num? groupedStartTime,
      num? groupedEndTime,
      num? groupedActualEndOffset,
      num? episodePart,
      num? seriesMepSeriesFinale,
      bool? seriesPremiereAirings,
      bool? premiere}) {
    return ReplayEvent(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        title: title ?? this.title,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        mergedId: mergedId ?? this.mergedId,
        minimumAge: minimumAge ?? this.minimumAge,
        replayTvMinAge: replayTvMinAge ?? this.replayTvMinAge,
        parentalGuidanceText: parentalGuidanceText ?? this.parentalGuidanceText,
        seriesId: seriesId ?? this.seriesId,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        episodeName: episodeName ?? this.episodeName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        isAdult: isAdult ?? this.isAdult,
        hasReplayTV: hasReplayTV ?? this.hasReplayTV,
        replayTvAdult: replayTvAdult ?? this.replayTvAdult,
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        strictAvailabilityEnd:
            strictAvailabilityEnd ?? this.strictAvailabilityEnd,
        hasStartOver: hasStartOver ?? this.hasStartOver,
        isOpen: isOpen ?? this.isOpen,
        shortDescription: shortDescription ?? this.shortDescription,
        longDescription: longDescription ?? this.longDescription,
        actors: actors ?? this.actors,
        directors: directors ?? this.directors,
        producers: producers ?? this.producers,
        audioType: audioType ?? this.audioType,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        productionDate: productionDate ?? this.productionDate,
        countryOfOrigin: countryOfOrigin ?? this.countryOfOrigin,
        genres: genres ?? this.genres,
        resolution: resolution ?? this.resolution,
        isLive: isLive ?? this.isLive,
        actualStartOffset: actualStartOffset ?? this.actualStartOffset,
        actualEndOffset: actualEndOffset ?? this.actualEndOffset,
        replayTVDisplayAge: replayTVDisplayAge ?? this.replayTVDisplayAge,
        imageVersion: imageVersion ?? this.imageVersion,
        groupedStartTime: groupedStartTime ?? this.groupedStartTime,
        groupedEndTime: groupedEndTime ?? this.groupedEndTime,
        groupedActualEndOffset:
            groupedActualEndOffset ?? this.groupedActualEndOffset,
        episodePart: episodePart ?? this.episodePart,
        seriesMepSeriesFinale:
            seriesMepSeriesFinale ?? this.seriesMepSeriesFinale,
        seriesPremiereAirings:
            seriesPremiereAirings ?? this.seriesPremiereAirings,
        premiere: premiere ?? this.premiere);
  }

  ReplayEvent copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<String>? title,
      Wrapped<num>? startTime,
      Wrapped<num>? endTime,
      Wrapped<String?>? mergedId,
      Wrapped<String?>? minimumAge,
      Wrapped<int?>? replayTvMinAge,
      Wrapped<String?>? parentalGuidanceText,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? episodeName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? hasReplayTV,
      Wrapped<bool?>? replayTvAdult,
      Wrapped<num?>? replayAvailabilityStart,
      Wrapped<num?>? replayAvailabilityEnd,
      Wrapped<num?>? strictAvailabilityEnd,
      Wrapped<bool?>? hasStartOver,
      Wrapped<bool?>? isOpen,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? longDescription,
      Wrapped<List<String>?>? actors,
      Wrapped<List<String>?>? directors,
      Wrapped<List<String>?>? producers,
      Wrapped<int?>? audioType,
      Wrapped<List<Language>?>? audioLanguages,
      Wrapped<List<Language>?>? captionLanguages,
      Wrapped<List<Language>?>? signLanguages,
      Wrapped<String?>? productionDate,
      Wrapped<String?>? countryOfOrigin,
      Wrapped<List<String>?>? genres,
      Wrapped<enums.ReplayEventResolution?>? resolution,
      Wrapped<bool?>? isLive,
      Wrapped<num?>? actualStartOffset,
      Wrapped<num?>? actualEndOffset,
      Wrapped<bool?>? replayTVDisplayAge,
      Wrapped<String?>? imageVersion,
      Wrapped<num?>? groupedStartTime,
      Wrapped<num?>? groupedEndTime,
      Wrapped<num?>? groupedActualEndOffset,
      Wrapped<num?>? episodePart,
      Wrapped<num?>? seriesMepSeriesFinale,
      Wrapped<bool?>? seriesPremiereAirings,
      Wrapped<bool?>? premiere}) {
    return ReplayEvent(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        title: (title != null ? title.value : this.title),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        replayTvMinAge: (replayTvMinAge != null
            ? replayTvMinAge.value
            : this.replayTvMinAge),
        parentalGuidanceText: (parentalGuidanceText != null
            ? parentalGuidanceText.value
            : this.parentalGuidanceText),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        hasReplayTV:
            (hasReplayTV != null ? hasReplayTV.value : this.hasReplayTV),
        replayTvAdult:
            (replayTvAdult != null ? replayTvAdult.value : this.replayTvAdult),
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        strictAvailabilityEnd: (strictAvailabilityEnd != null
            ? strictAvailabilityEnd.value
            : this.strictAvailabilityEnd),
        hasStartOver:
            (hasStartOver != null ? hasStartOver.value : this.hasStartOver),
        isOpen: (isOpen != null ? isOpen.value : this.isOpen),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        actors: (actors != null ? actors.value : this.actors),
        directors: (directors != null ? directors.value : this.directors),
        producers: (producers != null ? producers.value : this.producers),
        audioType: (audioType != null ? audioType.value : this.audioType),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        productionDate: (productionDate != null
            ? productionDate.value
            : this.productionDate),
        countryOfOrigin: (countryOfOrigin != null
            ? countryOfOrigin.value
            : this.countryOfOrigin),
        genres: (genres != null ? genres.value : this.genres),
        resolution: (resolution != null ? resolution.value : this.resolution),
        isLive: (isLive != null ? isLive.value : this.isLive),
        actualStartOffset: (actualStartOffset != null
            ? actualStartOffset.value
            : this.actualStartOffset),
        actualEndOffset: (actualEndOffset != null
            ? actualEndOffset.value
            : this.actualEndOffset),
        replayTVDisplayAge: (replayTVDisplayAge != null
            ? replayTVDisplayAge.value
            : this.replayTVDisplayAge),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        groupedStartTime: (groupedStartTime != null
            ? groupedStartTime.value
            : this.groupedStartTime),
        groupedEndTime: (groupedEndTime != null
            ? groupedEndTime.value
            : this.groupedEndTime),
        groupedActualEndOffset: (groupedActualEndOffset != null
            ? groupedActualEndOffset.value
            : this.groupedActualEndOffset),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        seriesMepSeriesFinale: (seriesMepSeriesFinale != null
            ? seriesMepSeriesFinale.value
            : this.seriesMepSeriesFinale),
        seriesPremiereAirings: (seriesPremiereAirings != null
            ? seriesPremiereAirings.value
            : this.seriesPremiereAirings),
        premiere: (premiere != null ? premiere.value : this.premiere));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayEventV2 {
  ReplayEventV2({
    required this.eventId,
    required this.channelId,
    required this.title,
    required this.startTime,
    required this.endTime,
    this.mergedId,
    this.minimumAge,
    this.replayTvMinAge,
    this.parentalGuidanceText,
    this.seriesId,
    this.parentSeriesId,
    this.episodeName,
    this.seasonNumber,
    this.episodeNumber,
    this.isAdult,
    this.hasReplayTV,
    this.replayTvAdult,
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.strictAvailabilityEnd,
    this.hasStartOver,
    this.isOpen,
    this.shortDescription,
    this.longDescription,
    this.actors,
    this.directors,
    this.producers,
    this.audioType,
    this.audioLanguages,
    this.captionLanguages,
    this.signLanguages,
    this.productionDate,
    this.countryOfOrigin,
    this.genres,
    this.resolution,
    this.isLive,
    this.actualStartOffset,
    this.actualEndOffset,
    this.replayTVDisplayAge,
    this.imageVersion,
    this.hasReplayTVOTT,
    this.hasLiveTVOTT,
    this.groupedStartTime,
    this.groupedEndTime,
    this.groupedActualEndOffset,
    this.episodePart,
    this.playableViaExternalApp,
    this.externalAppUrls,
    this.seriesMepSeriesFinale,
    this.seriesPremiereAirings,
    this.premiere,
  });

  factory ReplayEventV2.fromJson(Map<String, dynamic> json) =>
      _$ReplayEventV2FromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final num startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final num endTime;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'replayTvMinAge', includeIfNull: false)
  final int? replayTvMinAge;
  @JsonKey(name: 'parentalGuidanceText', includeIfNull: false, defaultValue: '')
  final String? parentalGuidanceText;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'hasReplayTV', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTV;
  @JsonKey(name: 'replayTvAdult', includeIfNull: false)
  final bool? replayTvAdult;
  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final num? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final num? replayAvailabilityEnd;
  @JsonKey(name: 'strictAvailabilityEnd', includeIfNull: false)
  final num? strictAvailabilityEnd;
  @JsonKey(name: 'hasStartOver', includeIfNull: false, defaultValue: true)
  final bool? hasStartOver;
  @JsonKey(name: 'isOpen', includeIfNull: false)
  final bool? isOpen;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'actors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? actors;
  @JsonKey(name: 'directors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? directors;
  @JsonKey(name: 'producers', includeIfNull: false, defaultValue: <String>[])
  final List<String>? producers;
  @JsonKey(name: 'audioType', includeIfNull: false)
  final int? audioType;
  @JsonKey(
      name: 'audioLanguages', includeIfNull: false, defaultValue: <Language>[])
  final List<Language>? audioLanguages;
  @JsonKey(
      name: 'captionLanguages',
      includeIfNull: false,
      defaultValue: <Language>[])
  final List<Language>? captionLanguages;
  @JsonKey(
      name: 'signLanguages', includeIfNull: false, defaultValue: <Language>[])
  final List<Language>? signLanguages;
  @JsonKey(name: 'productionDate', includeIfNull: false, defaultValue: '')
  final String? productionDate;
  @JsonKey(name: 'countryOfOrigin', includeIfNull: false, defaultValue: '')
  final String? countryOfOrigin;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(
    name: 'resolution',
    includeIfNull: false,
    toJson: replayEventV2ResolutionToJson,
    fromJson: replayEventV2ResolutionFromJson,
  )
  final enums.ReplayEventV2Resolution? resolution;
  @JsonKey(name: 'isLive', includeIfNull: false)
  final bool? isLive;
  @JsonKey(name: 'actualStartOffset', includeIfNull: false)
  final int? actualStartOffset;
  @JsonKey(name: 'actualEndOffset', includeIfNull: false)
  final int? actualEndOffset;
  @JsonKey(
      name: 'replayTVDisplayAge', includeIfNull: false, defaultValue: false)
  final bool? replayTVDisplayAge;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'hasReplayTVOTT', includeIfNull: false, defaultValue: true)
  final bool? hasReplayTVOTT;
  @JsonKey(name: 'hasLiveTVOTT', includeIfNull: false, defaultValue: true)
  final bool? hasLiveTVOTT;
  @JsonKey(name: 'groupedStartTime', includeIfNull: false)
  final num? groupedStartTime;
  @JsonKey(name: 'groupedEndTime', includeIfNull: false)
  final num? groupedEndTime;
  @JsonKey(name: 'groupedActualEndOffset', includeIfNull: false)
  final num? groupedActualEndOffset;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final num? episodePart;
  @JsonKey(name: 'playableViaExternalApp', includeIfNull: false)
  final bool? playableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrl>[])
  final List<ExternalAppUrl>? externalAppUrls;
  @JsonKey(name: 'seriesMepSeriesFinale', includeIfNull: false)
  final num? seriesMepSeriesFinale;
  @JsonKey(name: 'seriesPremiereAirings', includeIfNull: false)
  final bool? seriesPremiereAirings;
  @JsonKey(name: 'premiere', includeIfNull: false)
  final bool? premiere;
  static const fromJsonFactory = _$ReplayEventV2FromJson;
  static const toJsonFactory = _$ReplayEventV2ToJson;
  Map<String, dynamic> toJson() => _$ReplayEventV2ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayEventV2 &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.replayTvMinAge, replayTvMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvMinAge, replayTvMinAge)) &&
            (identical(other.parentalGuidanceText, parentalGuidanceText) ||
                const DeepCollectionEquality().equals(
                    other.parentalGuidanceText, parentalGuidanceText)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.episodeName, episodeName) ||
                const DeepCollectionEquality()
                    .equals(other.episodeName, episodeName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.hasReplayTV, hasReplayTV) ||
                const DeepCollectionEquality()
                    .equals(other.hasReplayTV, hasReplayTV)) &&
            (identical(other.replayTvAdult, replayTvAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayTvAdult, replayTvAdult)) &&
            (identical(other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.strictAvailabilityEnd, strictAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.strictAvailabilityEnd, strictAvailabilityEnd)) &&
            (identical(other.hasStartOver, hasStartOver) ||
                const DeepCollectionEquality()
                    .equals(other.hasStartOver, hasStartOver)) &&
            (identical(other.isOpen, isOpen) || const DeepCollectionEquality().equals(other.isOpen, isOpen)) &&
            (identical(other.shortDescription, shortDescription) || const DeepCollectionEquality().equals(other.shortDescription, shortDescription)) &&
            (identical(other.longDescription, longDescription) || const DeepCollectionEquality().equals(other.longDescription, longDescription)) &&
            (identical(other.actors, actors) || const DeepCollectionEquality().equals(other.actors, actors)) &&
            (identical(other.directors, directors) || const DeepCollectionEquality().equals(other.directors, directors)) &&
            (identical(other.producers, producers) || const DeepCollectionEquality().equals(other.producers, producers)) &&
            (identical(other.audioType, audioType) || const DeepCollectionEquality().equals(other.audioType, audioType)) &&
            (identical(other.audioLanguages, audioLanguages) || const DeepCollectionEquality().equals(other.audioLanguages, audioLanguages)) &&
            (identical(other.captionLanguages, captionLanguages) || const DeepCollectionEquality().equals(other.captionLanguages, captionLanguages)) &&
            (identical(other.signLanguages, signLanguages) || const DeepCollectionEquality().equals(other.signLanguages, signLanguages)) &&
            (identical(other.productionDate, productionDate) || const DeepCollectionEquality().equals(other.productionDate, productionDate)) &&
            (identical(other.countryOfOrigin, countryOfOrigin) || const DeepCollectionEquality().equals(other.countryOfOrigin, countryOfOrigin)) &&
            (identical(other.genres, genres) || const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.resolution, resolution) || const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.isLive, isLive) || const DeepCollectionEquality().equals(other.isLive, isLive)) &&
            (identical(other.actualStartOffset, actualStartOffset) || const DeepCollectionEquality().equals(other.actualStartOffset, actualStartOffset)) &&
            (identical(other.actualEndOffset, actualEndOffset) || const DeepCollectionEquality().equals(other.actualEndOffset, actualEndOffset)) &&
            (identical(other.replayTVDisplayAge, replayTVDisplayAge) || const DeepCollectionEquality().equals(other.replayTVDisplayAge, replayTVDisplayAge)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)) &&
            (identical(other.hasReplayTVOTT, hasReplayTVOTT) || const DeepCollectionEquality().equals(other.hasReplayTVOTT, hasReplayTVOTT)) &&
            (identical(other.hasLiveTVOTT, hasLiveTVOTT) || const DeepCollectionEquality().equals(other.hasLiveTVOTT, hasLiveTVOTT)) &&
            (identical(other.groupedStartTime, groupedStartTime) || const DeepCollectionEquality().equals(other.groupedStartTime, groupedStartTime)) &&
            (identical(other.groupedEndTime, groupedEndTime) || const DeepCollectionEquality().equals(other.groupedEndTime, groupedEndTime)) &&
            (identical(other.groupedActualEndOffset, groupedActualEndOffset) || const DeepCollectionEquality().equals(other.groupedActualEndOffset, groupedActualEndOffset)) &&
            (identical(other.episodePart, episodePart) || const DeepCollectionEquality().equals(other.episodePart, episodePart)) &&
            (identical(other.playableViaExternalApp, playableViaExternalApp) || const DeepCollectionEquality().equals(other.playableViaExternalApp, playableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) || const DeepCollectionEquality().equals(other.externalAppUrls, externalAppUrls)) &&
            (identical(other.seriesMepSeriesFinale, seriesMepSeriesFinale) || const DeepCollectionEquality().equals(other.seriesMepSeriesFinale, seriesMepSeriesFinale)) &&
            (identical(other.seriesPremiereAirings, seriesPremiereAirings) || const DeepCollectionEquality().equals(other.seriesPremiereAirings, seriesPremiereAirings)) &&
            (identical(other.premiere, premiere) || const DeepCollectionEquality().equals(other.premiere, premiere)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(replayTvMinAge) ^
      const DeepCollectionEquality().hash(parentalGuidanceText) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(hasReplayTV) ^
      const DeepCollectionEquality().hash(replayTvAdult) ^
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(strictAvailabilityEnd) ^
      const DeepCollectionEquality().hash(hasStartOver) ^
      const DeepCollectionEquality().hash(isOpen) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(actors) ^
      const DeepCollectionEquality().hash(directors) ^
      const DeepCollectionEquality().hash(producers) ^
      const DeepCollectionEquality().hash(audioType) ^
      const DeepCollectionEquality().hash(audioLanguages) ^
      const DeepCollectionEquality().hash(captionLanguages) ^
      const DeepCollectionEquality().hash(signLanguages) ^
      const DeepCollectionEquality().hash(productionDate) ^
      const DeepCollectionEquality().hash(countryOfOrigin) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(isLive) ^
      const DeepCollectionEquality().hash(actualStartOffset) ^
      const DeepCollectionEquality().hash(actualEndOffset) ^
      const DeepCollectionEquality().hash(replayTVDisplayAge) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(hasReplayTVOTT) ^
      const DeepCollectionEquality().hash(hasLiveTVOTT) ^
      const DeepCollectionEquality().hash(groupedStartTime) ^
      const DeepCollectionEquality().hash(groupedEndTime) ^
      const DeepCollectionEquality().hash(groupedActualEndOffset) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(playableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      const DeepCollectionEquality().hash(seriesMepSeriesFinale) ^
      const DeepCollectionEquality().hash(seriesPremiereAirings) ^
      const DeepCollectionEquality().hash(premiere) ^
      runtimeType.hashCode;
}

extension $ReplayEventV2Extension on ReplayEventV2 {
  ReplayEventV2 copyWith(
      {String? eventId,
      String? channelId,
      String? title,
      num? startTime,
      num? endTime,
      String? mergedId,
      String? minimumAge,
      int? replayTvMinAge,
      String? parentalGuidanceText,
      String? seriesId,
      String? parentSeriesId,
      String? episodeName,
      int? seasonNumber,
      int? episodeNumber,
      bool? isAdult,
      bool? hasReplayTV,
      bool? replayTvAdult,
      num? replayAvailabilityStart,
      num? replayAvailabilityEnd,
      num? strictAvailabilityEnd,
      bool? hasStartOver,
      bool? isOpen,
      String? shortDescription,
      String? longDescription,
      List<String>? actors,
      List<String>? directors,
      List<String>? producers,
      int? audioType,
      List<Language>? audioLanguages,
      List<Language>? captionLanguages,
      List<Language>? signLanguages,
      String? productionDate,
      String? countryOfOrigin,
      List<String>? genres,
      enums.ReplayEventV2Resolution? resolution,
      bool? isLive,
      int? actualStartOffset,
      int? actualEndOffset,
      bool? replayTVDisplayAge,
      String? imageVersion,
      bool? hasReplayTVOTT,
      bool? hasLiveTVOTT,
      num? groupedStartTime,
      num? groupedEndTime,
      num? groupedActualEndOffset,
      num? episodePart,
      bool? playableViaExternalApp,
      List<ExternalAppUrl>? externalAppUrls,
      num? seriesMepSeriesFinale,
      bool? seriesPremiereAirings,
      bool? premiere}) {
    return ReplayEventV2(
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        title: title ?? this.title,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        mergedId: mergedId ?? this.mergedId,
        minimumAge: minimumAge ?? this.minimumAge,
        replayTvMinAge: replayTvMinAge ?? this.replayTvMinAge,
        parentalGuidanceText: parentalGuidanceText ?? this.parentalGuidanceText,
        seriesId: seriesId ?? this.seriesId,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        episodeName: episodeName ?? this.episodeName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        isAdult: isAdult ?? this.isAdult,
        hasReplayTV: hasReplayTV ?? this.hasReplayTV,
        replayTvAdult: replayTvAdult ?? this.replayTvAdult,
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        strictAvailabilityEnd:
            strictAvailabilityEnd ?? this.strictAvailabilityEnd,
        hasStartOver: hasStartOver ?? this.hasStartOver,
        isOpen: isOpen ?? this.isOpen,
        shortDescription: shortDescription ?? this.shortDescription,
        longDescription: longDescription ?? this.longDescription,
        actors: actors ?? this.actors,
        directors: directors ?? this.directors,
        producers: producers ?? this.producers,
        audioType: audioType ?? this.audioType,
        audioLanguages: audioLanguages ?? this.audioLanguages,
        captionLanguages: captionLanguages ?? this.captionLanguages,
        signLanguages: signLanguages ?? this.signLanguages,
        productionDate: productionDate ?? this.productionDate,
        countryOfOrigin: countryOfOrigin ?? this.countryOfOrigin,
        genres: genres ?? this.genres,
        resolution: resolution ?? this.resolution,
        isLive: isLive ?? this.isLive,
        actualStartOffset: actualStartOffset ?? this.actualStartOffset,
        actualEndOffset: actualEndOffset ?? this.actualEndOffset,
        replayTVDisplayAge: replayTVDisplayAge ?? this.replayTVDisplayAge,
        imageVersion: imageVersion ?? this.imageVersion,
        hasReplayTVOTT: hasReplayTVOTT ?? this.hasReplayTVOTT,
        hasLiveTVOTT: hasLiveTVOTT ?? this.hasLiveTVOTT,
        groupedStartTime: groupedStartTime ?? this.groupedStartTime,
        groupedEndTime: groupedEndTime ?? this.groupedEndTime,
        groupedActualEndOffset:
            groupedActualEndOffset ?? this.groupedActualEndOffset,
        episodePart: episodePart ?? this.episodePart,
        playableViaExternalApp:
            playableViaExternalApp ?? this.playableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls,
        seriesMepSeriesFinale:
            seriesMepSeriesFinale ?? this.seriesMepSeriesFinale,
        seriesPremiereAirings:
            seriesPremiereAirings ?? this.seriesPremiereAirings,
        premiere: premiere ?? this.premiere);
  }

  ReplayEventV2 copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? channelId,
      Wrapped<String>? title,
      Wrapped<num>? startTime,
      Wrapped<num>? endTime,
      Wrapped<String?>? mergedId,
      Wrapped<String?>? minimumAge,
      Wrapped<int?>? replayTvMinAge,
      Wrapped<String?>? parentalGuidanceText,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? episodeName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? hasReplayTV,
      Wrapped<bool?>? replayTvAdult,
      Wrapped<num?>? replayAvailabilityStart,
      Wrapped<num?>? replayAvailabilityEnd,
      Wrapped<num?>? strictAvailabilityEnd,
      Wrapped<bool?>? hasStartOver,
      Wrapped<bool?>? isOpen,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? longDescription,
      Wrapped<List<String>?>? actors,
      Wrapped<List<String>?>? directors,
      Wrapped<List<String>?>? producers,
      Wrapped<int?>? audioType,
      Wrapped<List<Language>?>? audioLanguages,
      Wrapped<List<Language>?>? captionLanguages,
      Wrapped<List<Language>?>? signLanguages,
      Wrapped<String?>? productionDate,
      Wrapped<String?>? countryOfOrigin,
      Wrapped<List<String>?>? genres,
      Wrapped<enums.ReplayEventV2Resolution?>? resolution,
      Wrapped<bool?>? isLive,
      Wrapped<int?>? actualStartOffset,
      Wrapped<int?>? actualEndOffset,
      Wrapped<bool?>? replayTVDisplayAge,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? hasReplayTVOTT,
      Wrapped<bool?>? hasLiveTVOTT,
      Wrapped<num?>? groupedStartTime,
      Wrapped<num?>? groupedEndTime,
      Wrapped<num?>? groupedActualEndOffset,
      Wrapped<num?>? episodePart,
      Wrapped<bool?>? playableViaExternalApp,
      Wrapped<List<ExternalAppUrl>?>? externalAppUrls,
      Wrapped<num?>? seriesMepSeriesFinale,
      Wrapped<bool?>? seriesPremiereAirings,
      Wrapped<bool?>? premiere}) {
    return ReplayEventV2(
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        title: (title != null ? title.value : this.title),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        replayTvMinAge: (replayTvMinAge != null
            ? replayTvMinAge.value
            : this.replayTvMinAge),
        parentalGuidanceText: (parentalGuidanceText != null
            ? parentalGuidanceText.value
            : this.parentalGuidanceText),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        hasReplayTV:
            (hasReplayTV != null ? hasReplayTV.value : this.hasReplayTV),
        replayTvAdult:
            (replayTvAdult != null ? replayTvAdult.value : this.replayTvAdult),
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        strictAvailabilityEnd: (strictAvailabilityEnd != null
            ? strictAvailabilityEnd.value
            : this.strictAvailabilityEnd),
        hasStartOver:
            (hasStartOver != null ? hasStartOver.value : this.hasStartOver),
        isOpen: (isOpen != null ? isOpen.value : this.isOpen),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        actors: (actors != null ? actors.value : this.actors),
        directors: (directors != null ? directors.value : this.directors),
        producers: (producers != null ? producers.value : this.producers),
        audioType: (audioType != null ? audioType.value : this.audioType),
        audioLanguages: (audioLanguages != null
            ? audioLanguages.value
            : this.audioLanguages),
        captionLanguages: (captionLanguages != null
            ? captionLanguages.value
            : this.captionLanguages),
        signLanguages:
            (signLanguages != null ? signLanguages.value : this.signLanguages),
        productionDate: (productionDate != null
            ? productionDate.value
            : this.productionDate),
        countryOfOrigin: (countryOfOrigin != null
            ? countryOfOrigin.value
            : this.countryOfOrigin),
        genres: (genres != null ? genres.value : this.genres),
        resolution: (resolution != null ? resolution.value : this.resolution),
        isLive: (isLive != null ? isLive.value : this.isLive),
        actualStartOffset: (actualStartOffset != null
            ? actualStartOffset.value
            : this.actualStartOffset),
        actualEndOffset: (actualEndOffset != null
            ? actualEndOffset.value
            : this.actualEndOffset),
        replayTVDisplayAge: (replayTVDisplayAge != null
            ? replayTVDisplayAge.value
            : this.replayTVDisplayAge),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        hasReplayTVOTT: (hasReplayTVOTT != null
            ? hasReplayTVOTT.value
            : this.hasReplayTVOTT),
        hasLiveTVOTT:
            (hasLiveTVOTT != null ? hasLiveTVOTT.value : this.hasLiveTVOTT),
        groupedStartTime: (groupedStartTime != null
            ? groupedStartTime.value
            : this.groupedStartTime),
        groupedEndTime: (groupedEndTime != null
            ? groupedEndTime.value
            : this.groupedEndTime),
        groupedActualEndOffset: (groupedActualEndOffset != null
            ? groupedActualEndOffset.value
            : this.groupedActualEndOffset),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        playableViaExternalApp: (playableViaExternalApp != null
            ? playableViaExternalApp.value
            : this.playableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls),
        seriesMepSeriesFinale: (seriesMepSeriesFinale != null
            ? seriesMepSeriesFinale.value
            : this.seriesMepSeriesFinale),
        seriesPremiereAirings: (seriesPremiereAirings != null
            ? seriesPremiereAirings.value
            : this.seriesPremiereAirings),
        premiere: (premiere != null ? premiere.value : this.premiere));
  }
}

@JsonSerializable(explicitToJson: true)
class Language {
  Language({
    required this.lang,
    this.purpose,
  });

  factory Language.fromJson(Map<String, dynamic> json) =>
      _$LanguageFromJson(json);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String lang;
  @JsonKey(name: 'purpose', includeIfNull: false)
  final int? purpose;
  static const fromJsonFactory = _$LanguageFromJson;
  static const toJsonFactory = _$LanguageToJson;
  Map<String, dynamic> toJson() => _$LanguageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Language &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.purpose, purpose) ||
                const DeepCollectionEquality().equals(other.purpose, purpose)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(purpose) ^
      runtimeType.hashCode;
}

extension $LanguageExtension on Language {
  Language copyWith({String? lang, int? purpose}) {
    return Language(lang: lang ?? this.lang, purpose: purpose ?? this.purpose);
  }

  Language copyWithWrapped({Wrapped<String>? lang, Wrapped<int?>? purpose}) {
    return Language(
        lang: (lang != null ? lang.value : this.lang),
        purpose: (purpose != null ? purpose.value : this.purpose));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorList {
  ErrorList({
    this.errorCode,
    required this.errors,
  });

  factory ErrorList.fromJson(Map<String, dynamic> json) =>
      _$ErrorListFromJson(json);

  @JsonKey(
    name: 'errorCode',
    includeIfNull: false,
    toJson: errorCodeToJson,
    fromJson: errorCodeFromJson,
  )
  final enums.ErrorCode? errorCode;
  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ErrorListFromJson;
  static const toJsonFactory = _$ErrorListToJson;
  Map<String, dynamic> toJson() => _$ErrorListToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorList &&
            (identical(other.errorCode, errorCode) ||
                const DeepCollectionEquality()
                    .equals(other.errorCode, errorCode)) &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errorCode) ^
      const DeepCollectionEquality().hash(errors) ^
      runtimeType.hashCode;
}

extension $ErrorListExtension on ErrorList {
  ErrorList copyWith({enums.ErrorCode? errorCode, List<String>? errors}) {
    return ErrorList(
        errorCode: errorCode ?? this.errorCode, errors: errors ?? this.errors);
  }

  ErrorList copyWithWrapped(
      {Wrapped<enums.ErrorCode?>? errorCode, Wrapped<List<String>>? errors}) {
    return ErrorList(
        errorCode: (errorCode != null ? errorCode.value : this.errorCode),
        errors: (errors != null ? errors.value : this.errors));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelV1 {
  ChannelV1({
    required this.id,
    required this.name,
    required this.logicalChannelNumber,
    this.logo,
    this.isRadio,
    this.isAdult,
    this.is3D,
    this.isHidden,
    this.isWatershed,
    this.resolution,
    this.pinChallengeSchedule,
    this.pinChallengeDuration,
    this.replayAppId,
    this.replayAppChannelId,
    this.replayPrePadding,
    this.replayPostPadding,
    this.allowedOverlayApps,
    this.ldvrTrickPlayControl,
    this.hasLdvrChannelBasedAuthorization,
    this.hasLdvrRestrictCpeStreaming,
    this.replacement,
    this.saveReplayToNdvr,
    this.contextMenuActions,
    this.promotionalImage,
    this.appIdForDayPass,
    this.boundApps,
    this.isPPV,
    this.replaySources,
    this.replayProducts,
    this.linearProducts,
    this.providerId,
    this.locator,
    this.genre,
    this.ndvrBlackout,
    this.ndvrRetentionLimit,
    this.isDayPassEnabled,
    this.uidPlacement,
  });

  factory ChannelV1.fromJson(Map<String, dynamic> json) =>
      _$ChannelV1FromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'logicalChannelNumber', includeIfNull: false)
  final int logicalChannelNumber;
  @JsonKey(name: 'logo', includeIfNull: false)
  final ChannelV1$Logo? logo;
  @JsonKey(name: 'isRadio', includeIfNull: false)
  final bool? isRadio;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'is3D', includeIfNull: false)
  final bool? is3D;
  @JsonKey(name: 'isHidden', includeIfNull: false)
  final bool? isHidden;
  @JsonKey(name: 'isWatershed', includeIfNull: false)
  final bool? isWatershed;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'pinChallengeSchedule', includeIfNull: false, defaultValue: '')
  final String? pinChallengeSchedule;
  @JsonKey(name: 'pinChallengeDuration', includeIfNull: false, defaultValue: '')
  final String? pinChallengeDuration;
  @JsonKey(name: 'replayAppId', includeIfNull: false, defaultValue: '')
  final String? replayAppId;
  @JsonKey(name: 'replayAppChannelId', includeIfNull: false, defaultValue: '')
  final String? replayAppChannelId;
  @JsonKey(name: 'replayPrePadding', includeIfNull: false)
  final int? replayPrePadding;
  @JsonKey(name: 'replayPostPadding', includeIfNull: false)
  final int? replayPostPadding;
  @JsonKey(
      name: 'allowedOverlayApps',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? allowedOverlayApps;
  @JsonKey(
      name: 'ldvrTrickPlayControl',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? ldvrTrickPlayControl;
  @JsonKey(name: 'hasLdvrChannelBasedAuthorization', includeIfNull: false)
  final bool? hasLdvrChannelBasedAuthorization;
  @JsonKey(name: 'hasLdvrRestrictCpeStreaming', includeIfNull: false)
  final bool? hasLdvrRestrictCpeStreaming;
  @JsonKey(name: 'replacement', includeIfNull: false)
  final ChannelV1$Replacement? replacement;
  @JsonKey(name: 'saveReplayToNdvr', includeIfNull: false)
  final bool? saveReplayToNdvr;
  @JsonKey(name: 'contextMenuActions', includeIfNull: false, defaultValue: '')
  final String? contextMenuActions;
  @JsonKey(name: 'promotionalImage', includeIfNull: false, defaultValue: '')
  final String? promotionalImage;
  @JsonKey(name: 'appIdForDayPass', includeIfNull: false, defaultValue: '')
  final String? appIdForDayPass;
  @JsonKey(name: 'boundApps', includeIfNull: false, defaultValue: <BoundApp>[])
  final List<BoundApp>? boundApps;
  @JsonKey(name: 'isPPV', includeIfNull: false)
  final bool? isPPV;
  @JsonKey(
    name: 'replaySources',
    includeIfNull: false,
    toJson: channelV1ReplaySourcesListToJson,
    fromJson: channelV1ReplaySourcesListFromJson,
  )
  final List<enums.ChannelV1ReplaySources>? replaySources;
  @JsonKey(
      name: 'replayProducts',
      includeIfNull: false,
      defaultValue: <ReplayProduct>[])
  final List<ReplayProduct>? replayProducts;
  @JsonKey(
      name: 'linearProducts', includeIfNull: false, defaultValue: <String>[])
  final List<String>? linearProducts;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'locator', includeIfNull: false, defaultValue: '')
  final String? locator;
  @JsonKey(name: 'genre', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genre;
  @JsonKey(name: 'ndvrBlackout', includeIfNull: false)
  final bool? ndvrBlackout;
  @JsonKey(name: 'ndvrRetentionLimit', includeIfNull: false, defaultValue: '')
  final String? ndvrRetentionLimit;
  @JsonKey(name: 'isDayPassEnabled', includeIfNull: false)
  final bool? isDayPassEnabled;
  @JsonKey(name: 'uidPlacement', includeIfNull: false)
  final bool? uidPlacement;
  static const fromJsonFactory = _$ChannelV1FromJson;
  static const toJsonFactory = _$ChannelV1ToJson;
  Map<String, dynamic> toJson() => _$ChannelV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelV1 &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.logicalChannelNumber, logicalChannelNumber) ||
                const DeepCollectionEquality().equals(
                    other.logicalChannelNumber, logicalChannelNumber)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)) &&
            (identical(other.isRadio, isRadio) ||
                const DeepCollectionEquality()
                    .equals(other.isRadio, isRadio)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.is3D, is3D) ||
                const DeepCollectionEquality().equals(other.is3D, is3D)) &&
            (identical(other.isHidden, isHidden) ||
                const DeepCollectionEquality()
                    .equals(other.isHidden, isHidden)) &&
            (identical(other.isWatershed, isWatershed) ||
                const DeepCollectionEquality()
                    .equals(other.isWatershed, isWatershed)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.pinChallengeSchedule, pinChallengeSchedule) ||
                const DeepCollectionEquality().equals(
                    other.pinChallengeSchedule, pinChallengeSchedule)) &&
            (identical(other.pinChallengeDuration, pinChallengeDuration) ||
                const DeepCollectionEquality().equals(
                    other.pinChallengeDuration, pinChallengeDuration)) &&
            (identical(other.replayAppId, replayAppId) ||
                const DeepCollectionEquality()
                    .equals(other.replayAppId, replayAppId)) &&
            (identical(other.replayAppChannelId, replayAppChannelId) ||
                const DeepCollectionEquality()
                    .equals(other.replayAppChannelId, replayAppChannelId)) &&
            (identical(other.replayPrePadding, replayPrePadding) ||
                const DeepCollectionEquality()
                    .equals(other.replayPrePadding, replayPrePadding)) &&
            (identical(other.replayPostPadding, replayPostPadding) ||
                const DeepCollectionEquality()
                    .equals(other.replayPostPadding, replayPostPadding)) &&
            (identical(other.allowedOverlayApps, allowedOverlayApps) ||
                const DeepCollectionEquality()
                    .equals(other.allowedOverlayApps, allowedOverlayApps)) &&
            (identical(other.ldvrTrickPlayControl, ldvrTrickPlayControl) ||
                const DeepCollectionEquality().equals(
                    other.ldvrTrickPlayControl, ldvrTrickPlayControl)) &&
            (identical(other.hasLdvrChannelBasedAuthorization, hasLdvrChannelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.hasLdvrChannelBasedAuthorization,
                    hasLdvrChannelBasedAuthorization)) &&
            (identical(other.hasLdvrRestrictCpeStreaming, hasLdvrRestrictCpeStreaming) ||
                const DeepCollectionEquality().equals(
                    other.hasLdvrRestrictCpeStreaming,
                    hasLdvrRestrictCpeStreaming)) &&
            (identical(other.replacement, replacement) ||
                const DeepCollectionEquality()
                    .equals(other.replacement, replacement)) &&
            (identical(other.saveReplayToNdvr, saveReplayToNdvr) || const DeepCollectionEquality().equals(other.saveReplayToNdvr, saveReplayToNdvr)) &&
            (identical(other.contextMenuActions, contextMenuActions) || const DeepCollectionEquality().equals(other.contextMenuActions, contextMenuActions)) &&
            (identical(other.promotionalImage, promotionalImage) || const DeepCollectionEquality().equals(other.promotionalImage, promotionalImage)) &&
            (identical(other.appIdForDayPass, appIdForDayPass) || const DeepCollectionEquality().equals(other.appIdForDayPass, appIdForDayPass)) &&
            (identical(other.boundApps, boundApps) || const DeepCollectionEquality().equals(other.boundApps, boundApps)) &&
            (identical(other.isPPV, isPPV) || const DeepCollectionEquality().equals(other.isPPV, isPPV)) &&
            (identical(other.replaySources, replaySources) || const DeepCollectionEquality().equals(other.replaySources, replaySources)) &&
            (identical(other.replayProducts, replayProducts) || const DeepCollectionEquality().equals(other.replayProducts, replayProducts)) &&
            (identical(other.linearProducts, linearProducts) || const DeepCollectionEquality().equals(other.linearProducts, linearProducts)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)) &&
            (identical(other.locator, locator) || const DeepCollectionEquality().equals(other.locator, locator)) &&
            (identical(other.genre, genre) || const DeepCollectionEquality().equals(other.genre, genre)) &&
            (identical(other.ndvrBlackout, ndvrBlackout) || const DeepCollectionEquality().equals(other.ndvrBlackout, ndvrBlackout)) &&
            (identical(other.ndvrRetentionLimit, ndvrRetentionLimit) || const DeepCollectionEquality().equals(other.ndvrRetentionLimit, ndvrRetentionLimit)) &&
            (identical(other.isDayPassEnabled, isDayPassEnabled) || const DeepCollectionEquality().equals(other.isDayPassEnabled, isDayPassEnabled)) &&
            (identical(other.uidPlacement, uidPlacement) || const DeepCollectionEquality().equals(other.uidPlacement, uidPlacement)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(logicalChannelNumber) ^
      const DeepCollectionEquality().hash(logo) ^
      const DeepCollectionEquality().hash(isRadio) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(is3D) ^
      const DeepCollectionEquality().hash(isHidden) ^
      const DeepCollectionEquality().hash(isWatershed) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(pinChallengeSchedule) ^
      const DeepCollectionEquality().hash(pinChallengeDuration) ^
      const DeepCollectionEquality().hash(replayAppId) ^
      const DeepCollectionEquality().hash(replayAppChannelId) ^
      const DeepCollectionEquality().hash(replayPrePadding) ^
      const DeepCollectionEquality().hash(replayPostPadding) ^
      const DeepCollectionEquality().hash(allowedOverlayApps) ^
      const DeepCollectionEquality().hash(ldvrTrickPlayControl) ^
      const DeepCollectionEquality().hash(hasLdvrChannelBasedAuthorization) ^
      const DeepCollectionEquality().hash(hasLdvrRestrictCpeStreaming) ^
      const DeepCollectionEquality().hash(replacement) ^
      const DeepCollectionEquality().hash(saveReplayToNdvr) ^
      const DeepCollectionEquality().hash(contextMenuActions) ^
      const DeepCollectionEquality().hash(promotionalImage) ^
      const DeepCollectionEquality().hash(appIdForDayPass) ^
      const DeepCollectionEquality().hash(boundApps) ^
      const DeepCollectionEquality().hash(isPPV) ^
      const DeepCollectionEquality().hash(replaySources) ^
      const DeepCollectionEquality().hash(replayProducts) ^
      const DeepCollectionEquality().hash(linearProducts) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(locator) ^
      const DeepCollectionEquality().hash(genre) ^
      const DeepCollectionEquality().hash(ndvrBlackout) ^
      const DeepCollectionEquality().hash(ndvrRetentionLimit) ^
      const DeepCollectionEquality().hash(isDayPassEnabled) ^
      const DeepCollectionEquality().hash(uidPlacement) ^
      runtimeType.hashCode;
}

extension $ChannelV1Extension on ChannelV1 {
  ChannelV1 copyWith(
      {String? id,
      String? name,
      int? logicalChannelNumber,
      ChannelV1$Logo? logo,
      bool? isRadio,
      bool? isAdult,
      bool? is3D,
      bool? isHidden,
      bool? isWatershed,
      String? resolution,
      String? pinChallengeSchedule,
      String? pinChallengeDuration,
      String? replayAppId,
      String? replayAppChannelId,
      int? replayPrePadding,
      int? replayPostPadding,
      List<String>? allowedOverlayApps,
      List<String>? ldvrTrickPlayControl,
      bool? hasLdvrChannelBasedAuthorization,
      bool? hasLdvrRestrictCpeStreaming,
      ChannelV1$Replacement? replacement,
      bool? saveReplayToNdvr,
      String? contextMenuActions,
      String? promotionalImage,
      String? appIdForDayPass,
      List<BoundApp>? boundApps,
      bool? isPPV,
      List<enums.ChannelV1ReplaySources>? replaySources,
      List<ReplayProduct>? replayProducts,
      List<String>? linearProducts,
      String? providerId,
      String? locator,
      List<String>? genre,
      bool? ndvrBlackout,
      String? ndvrRetentionLimit,
      bool? isDayPassEnabled,
      bool? uidPlacement}) {
    return ChannelV1(
        id: id ?? this.id,
        name: name ?? this.name,
        logicalChannelNumber: logicalChannelNumber ?? this.logicalChannelNumber,
        logo: logo ?? this.logo,
        isRadio: isRadio ?? this.isRadio,
        isAdult: isAdult ?? this.isAdult,
        is3D: is3D ?? this.is3D,
        isHidden: isHidden ?? this.isHidden,
        isWatershed: isWatershed ?? this.isWatershed,
        resolution: resolution ?? this.resolution,
        pinChallengeSchedule: pinChallengeSchedule ?? this.pinChallengeSchedule,
        pinChallengeDuration: pinChallengeDuration ?? this.pinChallengeDuration,
        replayAppId: replayAppId ?? this.replayAppId,
        replayAppChannelId: replayAppChannelId ?? this.replayAppChannelId,
        replayPrePadding: replayPrePadding ?? this.replayPrePadding,
        replayPostPadding: replayPostPadding ?? this.replayPostPadding,
        allowedOverlayApps: allowedOverlayApps ?? this.allowedOverlayApps,
        ldvrTrickPlayControl: ldvrTrickPlayControl ?? this.ldvrTrickPlayControl,
        hasLdvrChannelBasedAuthorization: hasLdvrChannelBasedAuthorization ??
            this.hasLdvrChannelBasedAuthorization,
        hasLdvrRestrictCpeStreaming:
            hasLdvrRestrictCpeStreaming ?? this.hasLdvrRestrictCpeStreaming,
        replacement: replacement ?? this.replacement,
        saveReplayToNdvr: saveReplayToNdvr ?? this.saveReplayToNdvr,
        contextMenuActions: contextMenuActions ?? this.contextMenuActions,
        promotionalImage: promotionalImage ?? this.promotionalImage,
        appIdForDayPass: appIdForDayPass ?? this.appIdForDayPass,
        boundApps: boundApps ?? this.boundApps,
        isPPV: isPPV ?? this.isPPV,
        replaySources: replaySources ?? this.replaySources,
        replayProducts: replayProducts ?? this.replayProducts,
        linearProducts: linearProducts ?? this.linearProducts,
        providerId: providerId ?? this.providerId,
        locator: locator ?? this.locator,
        genre: genre ?? this.genre,
        ndvrBlackout: ndvrBlackout ?? this.ndvrBlackout,
        ndvrRetentionLimit: ndvrRetentionLimit ?? this.ndvrRetentionLimit,
        isDayPassEnabled: isDayPassEnabled ?? this.isDayPassEnabled,
        uidPlacement: uidPlacement ?? this.uidPlacement);
  }

  ChannelV1 copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<int>? logicalChannelNumber,
      Wrapped<ChannelV1$Logo?>? logo,
      Wrapped<bool?>? isRadio,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? is3D,
      Wrapped<bool?>? isHidden,
      Wrapped<bool?>? isWatershed,
      Wrapped<String?>? resolution,
      Wrapped<String?>? pinChallengeSchedule,
      Wrapped<String?>? pinChallengeDuration,
      Wrapped<String?>? replayAppId,
      Wrapped<String?>? replayAppChannelId,
      Wrapped<int?>? replayPrePadding,
      Wrapped<int?>? replayPostPadding,
      Wrapped<List<String>?>? allowedOverlayApps,
      Wrapped<List<String>?>? ldvrTrickPlayControl,
      Wrapped<bool?>? hasLdvrChannelBasedAuthorization,
      Wrapped<bool?>? hasLdvrRestrictCpeStreaming,
      Wrapped<ChannelV1$Replacement?>? replacement,
      Wrapped<bool?>? saveReplayToNdvr,
      Wrapped<String?>? contextMenuActions,
      Wrapped<String?>? promotionalImage,
      Wrapped<String?>? appIdForDayPass,
      Wrapped<List<BoundApp>?>? boundApps,
      Wrapped<bool?>? isPPV,
      Wrapped<List<enums.ChannelV1ReplaySources>?>? replaySources,
      Wrapped<List<ReplayProduct>?>? replayProducts,
      Wrapped<List<String>?>? linearProducts,
      Wrapped<String?>? providerId,
      Wrapped<String?>? locator,
      Wrapped<List<String>?>? genre,
      Wrapped<bool?>? ndvrBlackout,
      Wrapped<String?>? ndvrRetentionLimit,
      Wrapped<bool?>? isDayPassEnabled,
      Wrapped<bool?>? uidPlacement}) {
    return ChannelV1(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        logicalChannelNumber: (logicalChannelNumber != null
            ? logicalChannelNumber.value
            : this.logicalChannelNumber),
        logo: (logo != null ? logo.value : this.logo),
        isRadio: (isRadio != null ? isRadio.value : this.isRadio),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        is3D: (is3D != null ? is3D.value : this.is3D),
        isHidden: (isHidden != null ? isHidden.value : this.isHidden),
        isWatershed:
            (isWatershed != null ? isWatershed.value : this.isWatershed),
        resolution: (resolution != null ? resolution.value : this.resolution),
        pinChallengeSchedule: (pinChallengeSchedule != null
            ? pinChallengeSchedule.value
            : this.pinChallengeSchedule),
        pinChallengeDuration: (pinChallengeDuration != null
            ? pinChallengeDuration.value
            : this.pinChallengeDuration),
        replayAppId:
            (replayAppId != null ? replayAppId.value : this.replayAppId),
        replayAppChannelId: (replayAppChannelId != null
            ? replayAppChannelId.value
            : this.replayAppChannelId),
        replayPrePadding: (replayPrePadding != null
            ? replayPrePadding.value
            : this.replayPrePadding),
        replayPostPadding: (replayPostPadding != null
            ? replayPostPadding.value
            : this.replayPostPadding),
        allowedOverlayApps: (allowedOverlayApps != null
            ? allowedOverlayApps.value
            : this.allowedOverlayApps),
        ldvrTrickPlayControl: (ldvrTrickPlayControl != null
            ? ldvrTrickPlayControl.value
            : this.ldvrTrickPlayControl),
        hasLdvrChannelBasedAuthorization:
            (hasLdvrChannelBasedAuthorization != null
                ? hasLdvrChannelBasedAuthorization.value
                : this.hasLdvrChannelBasedAuthorization),
        hasLdvrRestrictCpeStreaming: (hasLdvrRestrictCpeStreaming != null
            ? hasLdvrRestrictCpeStreaming.value
            : this.hasLdvrRestrictCpeStreaming),
        replacement:
            (replacement != null ? replacement.value : this.replacement),
        saveReplayToNdvr: (saveReplayToNdvr != null
            ? saveReplayToNdvr.value
            : this.saveReplayToNdvr),
        contextMenuActions: (contextMenuActions != null
            ? contextMenuActions.value
            : this.contextMenuActions),
        promotionalImage: (promotionalImage != null
            ? promotionalImage.value
            : this.promotionalImage),
        appIdForDayPass: (appIdForDayPass != null
            ? appIdForDayPass.value
            : this.appIdForDayPass),
        boundApps: (boundApps != null ? boundApps.value : this.boundApps),
        isPPV: (isPPV != null ? isPPV.value : this.isPPV),
        replaySources:
            (replaySources != null ? replaySources.value : this.replaySources),
        replayProducts: (replayProducts != null
            ? replayProducts.value
            : this.replayProducts),
        linearProducts: (linearProducts != null
            ? linearProducts.value
            : this.linearProducts),
        providerId: (providerId != null ? providerId.value : this.providerId),
        locator: (locator != null ? locator.value : this.locator),
        genre: (genre != null ? genre.value : this.genre),
        ndvrBlackout:
            (ndvrBlackout != null ? ndvrBlackout.value : this.ndvrBlackout),
        ndvrRetentionLimit: (ndvrRetentionLimit != null
            ? ndvrRetentionLimit.value
            : this.ndvrRetentionLimit),
        isDayPassEnabled: (isDayPassEnabled != null
            ? isDayPassEnabled.value
            : this.isDayPassEnabled),
        uidPlacement:
            (uidPlacement != null ? uidPlacement.value : this.uidPlacement));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel {
  Channel({
    required this.id,
    required this.name,
    required this.logicalChannelNumber,
    this.logo,
    this.isRadio,
    this.isAdult,
    this.is3D,
    this.isHidden,
    this.isWatershed,
    this.resolution,
    this.pinChallengeSchedule,
    this.pinChallengeDuration,
    this.playableViaExternalApp,
    this.externalAppUrls,
    this.replayAppId,
    this.replayAppChannelId,
    this.replayPrePadding,
    this.replayPostPadding,
    this.allowedOverlayApps,
    this.ldvrTrickPlayControl,
    this.hasLdvrChannelBasedAuthorization,
    this.hasLdvrRestrictCpeStreaming,
    this.replacement,
    this.saveReplayToNdvr,
    this.contextMenuActions,
    this.promotionalImage,
    this.appIdForDayPass,
    this.boundApps,
    this.isPPV,
    this.replaySources,
    this.replayProducts,
    this.linearProducts,
    this.providerId,
    this.locator,
    this.locators,
    this.genre,
    this.ndvrBlackout,
    this.ndvrRetentionLimit,
    this.isDayPass,
    this.replayTVDisabledOnMobileClient,
    this.ppv,
    this.streamedViaExternalApp,
    this.applications,
    this.externalStreamingProtocols,
    this.imageStream,
    this.uidPlacement,
    this.isWifiOnlyEnabled,
    this.outOfCountry3GStreamingEnabled,
    this.outOfCountryStreamingDisabled,
  });

  factory Channel.fromJson(Map<String, dynamic> json) =>
      _$ChannelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'logicalChannelNumber', includeIfNull: false)
  final int logicalChannelNumber;
  @JsonKey(name: 'logo', includeIfNull: false)
  final Channel$Logo? logo;
  @JsonKey(name: 'isRadio', includeIfNull: false)
  final bool? isRadio;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'is3D', includeIfNull: false)
  final bool? is3D;
  @JsonKey(name: 'isHidden', includeIfNull: false)
  final bool? isHidden;
  @JsonKey(name: 'isWatershed', includeIfNull: false)
  final bool? isWatershed;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'pinChallengeSchedule', includeIfNull: false, defaultValue: '')
  final String? pinChallengeSchedule;
  @JsonKey(name: 'pinChallengeDuration', includeIfNull: false, defaultValue: '')
  final String? pinChallengeDuration;
  @JsonKey(name: 'playableViaExternalApp', includeIfNull: false)
  final bool? playableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrl>[])
  final List<ExternalAppUrl>? externalAppUrls;
  @JsonKey(name: 'replayAppId', includeIfNull: false, defaultValue: '')
  final String? replayAppId;
  @JsonKey(name: 'replayAppChannelId', includeIfNull: false, defaultValue: '')
  final String? replayAppChannelId;
  @JsonKey(name: 'replayPrePadding', includeIfNull: false)
  final int? replayPrePadding;
  @JsonKey(name: 'replayPostPadding', includeIfNull: false)
  final int? replayPostPadding;
  @JsonKey(
      name: 'allowedOverlayApps',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? allowedOverlayApps;
  @JsonKey(
      name: 'ldvrTrickPlayControl',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? ldvrTrickPlayControl;
  @JsonKey(name: 'hasLdvrChannelBasedAuthorization', includeIfNull: false)
  final bool? hasLdvrChannelBasedAuthorization;
  @JsonKey(name: 'hasLdvrRestrictCpeStreaming', includeIfNull: false)
  final bool? hasLdvrRestrictCpeStreaming;
  @JsonKey(name: 'replacement', includeIfNull: false)
  final Channel$Replacement? replacement;
  @JsonKey(name: 'saveReplayToNdvr', includeIfNull: false)
  final bool? saveReplayToNdvr;
  @JsonKey(name: 'contextMenuActions', includeIfNull: false, defaultValue: '')
  final String? contextMenuActions;
  @JsonKey(name: 'promotionalImage', includeIfNull: false, defaultValue: '')
  final String? promotionalImage;
  @JsonKey(name: 'appIdForDayPass', includeIfNull: false, defaultValue: '')
  final String? appIdForDayPass;
  @JsonKey(name: 'boundApps', includeIfNull: false, defaultValue: <BoundApp>[])
  final List<BoundApp>? boundApps;
  @JsonKey(name: 'isPPV', includeIfNull: false)
  final bool? isPPV;
  @JsonKey(
    name: 'replaySources',
    includeIfNull: false,
    toJson: channelReplaySourcesListToJson,
    fromJson: channelReplaySourcesListFromJson,
  )
  final List<enums.ChannelReplaySources>? replaySources;
  @JsonKey(
      name: 'replayProducts',
      includeIfNull: false,
      defaultValue: <ReplayProduct>[])
  final List<ReplayProduct>? replayProducts;
  @JsonKey(
      name: 'linearProducts', includeIfNull: false, defaultValue: <String>[])
  final List<String>? linearProducts;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  @JsonKey(name: 'locator', includeIfNull: false, defaultValue: '')
  final String? locator;
  @JsonKey(name: 'locators', includeIfNull: false)
  final Map<String, dynamic>? locators;
  @JsonKey(name: 'genre', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genre;
  @JsonKey(name: 'ndvrBlackout', includeIfNull: false)
  final bool? ndvrBlackout;
  @JsonKey(name: 'ndvrRetentionLimit', includeIfNull: false, defaultValue: '')
  final String? ndvrRetentionLimit;
  @JsonKey(name: 'isDayPass', includeIfNull: false)
  final bool? isDayPass;
  @JsonKey(name: 'replayTVDisabledOnMobileClient', includeIfNull: false)
  final bool? replayTVDisabledOnMobileClient;
  @JsonKey(name: 'ppv', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ppv;
  @JsonKey(name: 'streamedViaExternalApp', includeIfNull: false)
  final bool? streamedViaExternalApp;
  @JsonKey(
      name: 'applications', includeIfNull: false, defaultValue: <Application>[])
  final List<Application>? applications;
  @JsonKey(name: 'externalStreamingProtocols', includeIfNull: false)
  final Channel$ExternalStreamingProtocols? externalStreamingProtocols;
  @JsonKey(name: 'imageStream', includeIfNull: false)
  final Channel$ImageStream? imageStream;
  @JsonKey(name: 'uidPlacement', includeIfNull: false)
  final bool? uidPlacement;
  @JsonKey(name: 'isWifiOnlyEnabled', includeIfNull: false)
  final bool? isWifiOnlyEnabled;
  @JsonKey(name: 'outOfCountry3GStreamingEnabled', includeIfNull: false)
  final bool? outOfCountry3GStreamingEnabled;
  @JsonKey(
      name: 'outOfCountryStreamingDisabled',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? outOfCountryStreamingDisabled;
  static const fromJsonFactory = _$ChannelFromJson;
  static const toJsonFactory = _$ChannelToJson;
  Map<String, dynamic> toJson() => _$ChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.logicalChannelNumber, logicalChannelNumber) ||
                const DeepCollectionEquality().equals(
                    other.logicalChannelNumber, logicalChannelNumber)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)) &&
            (identical(other.isRadio, isRadio) ||
                const DeepCollectionEquality()
                    .equals(other.isRadio, isRadio)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.is3D, is3D) ||
                const DeepCollectionEquality().equals(other.is3D, is3D)) &&
            (identical(other.isHidden, isHidden) ||
                const DeepCollectionEquality()
                    .equals(other.isHidden, isHidden)) &&
            (identical(other.isWatershed, isWatershed) ||
                const DeepCollectionEquality()
                    .equals(other.isWatershed, isWatershed)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.pinChallengeSchedule, pinChallengeSchedule) ||
                const DeepCollectionEquality().equals(
                    other.pinChallengeSchedule, pinChallengeSchedule)) &&
            (identical(other.pinChallengeDuration, pinChallengeDuration) ||
                const DeepCollectionEquality().equals(
                    other.pinChallengeDuration, pinChallengeDuration)) &&
            (identical(other.playableViaExternalApp, playableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.playableViaExternalApp, playableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) ||
                const DeepCollectionEquality()
                    .equals(other.externalAppUrls, externalAppUrls)) &&
            (identical(other.replayAppId, replayAppId) ||
                const DeepCollectionEquality()
                    .equals(other.replayAppId, replayAppId)) &&
            (identical(other.replayAppChannelId, replayAppChannelId) ||
                const DeepCollectionEquality()
                    .equals(other.replayAppChannelId, replayAppChannelId)) &&
            (identical(other.replayPrePadding, replayPrePadding) ||
                const DeepCollectionEquality()
                    .equals(other.replayPrePadding, replayPrePadding)) &&
            (identical(other.replayPostPadding, replayPostPadding) ||
                const DeepCollectionEquality()
                    .equals(other.replayPostPadding, replayPostPadding)) &&
            (identical(other.allowedOverlayApps, allowedOverlayApps) ||
                const DeepCollectionEquality()
                    .equals(other.allowedOverlayApps, allowedOverlayApps)) &&
            (identical(other.ldvrTrickPlayControl, ldvrTrickPlayControl) ||
                const DeepCollectionEquality().equals(
                    other.ldvrTrickPlayControl, ldvrTrickPlayControl)) &&
            (identical(other.hasLdvrChannelBasedAuthorization, hasLdvrChannelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.hasLdvrChannelBasedAuthorization,
                    hasLdvrChannelBasedAuthorization)) &&
            (identical(other.hasLdvrRestrictCpeStreaming, hasLdvrRestrictCpeStreaming) ||
                const DeepCollectionEquality()
                    .equals(other.hasLdvrRestrictCpeStreaming, hasLdvrRestrictCpeStreaming)) &&
            (identical(other.replacement, replacement) || const DeepCollectionEquality().equals(other.replacement, replacement)) &&
            (identical(other.saveReplayToNdvr, saveReplayToNdvr) || const DeepCollectionEquality().equals(other.saveReplayToNdvr, saveReplayToNdvr)) &&
            (identical(other.contextMenuActions, contextMenuActions) || const DeepCollectionEquality().equals(other.contextMenuActions, contextMenuActions)) &&
            (identical(other.promotionalImage, promotionalImage) || const DeepCollectionEquality().equals(other.promotionalImage, promotionalImage)) &&
            (identical(other.appIdForDayPass, appIdForDayPass) || const DeepCollectionEquality().equals(other.appIdForDayPass, appIdForDayPass)) &&
            (identical(other.boundApps, boundApps) || const DeepCollectionEquality().equals(other.boundApps, boundApps)) &&
            (identical(other.isPPV, isPPV) || const DeepCollectionEquality().equals(other.isPPV, isPPV)) &&
            (identical(other.replaySources, replaySources) || const DeepCollectionEquality().equals(other.replaySources, replaySources)) &&
            (identical(other.replayProducts, replayProducts) || const DeepCollectionEquality().equals(other.replayProducts, replayProducts)) &&
            (identical(other.linearProducts, linearProducts) || const DeepCollectionEquality().equals(other.linearProducts, linearProducts)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)) &&
            (identical(other.locator, locator) || const DeepCollectionEquality().equals(other.locator, locator)) &&
            (identical(other.locators, locators) || const DeepCollectionEquality().equals(other.locators, locators)) &&
            (identical(other.genre, genre) || const DeepCollectionEquality().equals(other.genre, genre)) &&
            (identical(other.ndvrBlackout, ndvrBlackout) || const DeepCollectionEquality().equals(other.ndvrBlackout, ndvrBlackout)) &&
            (identical(other.ndvrRetentionLimit, ndvrRetentionLimit) || const DeepCollectionEquality().equals(other.ndvrRetentionLimit, ndvrRetentionLimit)) &&
            (identical(other.isDayPass, isDayPass) || const DeepCollectionEquality().equals(other.isDayPass, isDayPass)) &&
            (identical(other.replayTVDisabledOnMobileClient, replayTVDisabledOnMobileClient) || const DeepCollectionEquality().equals(other.replayTVDisabledOnMobileClient, replayTVDisabledOnMobileClient)) &&
            (identical(other.ppv, ppv) || const DeepCollectionEquality().equals(other.ppv, ppv)) &&
            (identical(other.streamedViaExternalApp, streamedViaExternalApp) || const DeepCollectionEquality().equals(other.streamedViaExternalApp, streamedViaExternalApp)) &&
            (identical(other.applications, applications) || const DeepCollectionEquality().equals(other.applications, applications)) &&
            (identical(other.externalStreamingProtocols, externalStreamingProtocols) || const DeepCollectionEquality().equals(other.externalStreamingProtocols, externalStreamingProtocols)) &&
            (identical(other.imageStream, imageStream) || const DeepCollectionEquality().equals(other.imageStream, imageStream)) &&
            (identical(other.uidPlacement, uidPlacement) || const DeepCollectionEquality().equals(other.uidPlacement, uidPlacement)) &&
            (identical(other.isWifiOnlyEnabled, isWifiOnlyEnabled) || const DeepCollectionEquality().equals(other.isWifiOnlyEnabled, isWifiOnlyEnabled)) &&
            (identical(other.outOfCountry3GStreamingEnabled, outOfCountry3GStreamingEnabled) || const DeepCollectionEquality().equals(other.outOfCountry3GStreamingEnabled, outOfCountry3GStreamingEnabled)) &&
            (identical(other.outOfCountryStreamingDisabled, outOfCountryStreamingDisabled) || const DeepCollectionEquality().equals(other.outOfCountryStreamingDisabled, outOfCountryStreamingDisabled)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(logicalChannelNumber) ^
      const DeepCollectionEquality().hash(logo) ^
      const DeepCollectionEquality().hash(isRadio) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(is3D) ^
      const DeepCollectionEquality().hash(isHidden) ^
      const DeepCollectionEquality().hash(isWatershed) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(pinChallengeSchedule) ^
      const DeepCollectionEquality().hash(pinChallengeDuration) ^
      const DeepCollectionEquality().hash(playableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      const DeepCollectionEquality().hash(replayAppId) ^
      const DeepCollectionEquality().hash(replayAppChannelId) ^
      const DeepCollectionEquality().hash(replayPrePadding) ^
      const DeepCollectionEquality().hash(replayPostPadding) ^
      const DeepCollectionEquality().hash(allowedOverlayApps) ^
      const DeepCollectionEquality().hash(ldvrTrickPlayControl) ^
      const DeepCollectionEquality().hash(hasLdvrChannelBasedAuthorization) ^
      const DeepCollectionEquality().hash(hasLdvrRestrictCpeStreaming) ^
      const DeepCollectionEquality().hash(replacement) ^
      const DeepCollectionEquality().hash(saveReplayToNdvr) ^
      const DeepCollectionEquality().hash(contextMenuActions) ^
      const DeepCollectionEquality().hash(promotionalImage) ^
      const DeepCollectionEquality().hash(appIdForDayPass) ^
      const DeepCollectionEquality().hash(boundApps) ^
      const DeepCollectionEquality().hash(isPPV) ^
      const DeepCollectionEquality().hash(replaySources) ^
      const DeepCollectionEquality().hash(replayProducts) ^
      const DeepCollectionEquality().hash(linearProducts) ^
      const DeepCollectionEquality().hash(providerId) ^
      const DeepCollectionEquality().hash(locator) ^
      const DeepCollectionEquality().hash(locators) ^
      const DeepCollectionEquality().hash(genre) ^
      const DeepCollectionEquality().hash(ndvrBlackout) ^
      const DeepCollectionEquality().hash(ndvrRetentionLimit) ^
      const DeepCollectionEquality().hash(isDayPass) ^
      const DeepCollectionEquality().hash(replayTVDisabledOnMobileClient) ^
      const DeepCollectionEquality().hash(ppv) ^
      const DeepCollectionEquality().hash(streamedViaExternalApp) ^
      const DeepCollectionEquality().hash(applications) ^
      const DeepCollectionEquality().hash(externalStreamingProtocols) ^
      const DeepCollectionEquality().hash(imageStream) ^
      const DeepCollectionEquality().hash(uidPlacement) ^
      const DeepCollectionEquality().hash(isWifiOnlyEnabled) ^
      const DeepCollectionEquality().hash(outOfCountry3GStreamingEnabled) ^
      const DeepCollectionEquality().hash(outOfCountryStreamingDisabled) ^
      runtimeType.hashCode;
}

extension $ChannelExtension on Channel {
  Channel copyWith(
      {String? id,
      String? name,
      int? logicalChannelNumber,
      Channel$Logo? logo,
      bool? isRadio,
      bool? isAdult,
      bool? is3D,
      bool? isHidden,
      bool? isWatershed,
      String? resolution,
      String? pinChallengeSchedule,
      String? pinChallengeDuration,
      bool? playableViaExternalApp,
      List<ExternalAppUrl>? externalAppUrls,
      String? replayAppId,
      String? replayAppChannelId,
      int? replayPrePadding,
      int? replayPostPadding,
      List<String>? allowedOverlayApps,
      List<String>? ldvrTrickPlayControl,
      bool? hasLdvrChannelBasedAuthorization,
      bool? hasLdvrRestrictCpeStreaming,
      Channel$Replacement? replacement,
      bool? saveReplayToNdvr,
      String? contextMenuActions,
      String? promotionalImage,
      String? appIdForDayPass,
      List<BoundApp>? boundApps,
      bool? isPPV,
      List<enums.ChannelReplaySources>? replaySources,
      List<ReplayProduct>? replayProducts,
      List<String>? linearProducts,
      String? providerId,
      String? locator,
      Map<String, dynamic>? locators,
      List<String>? genre,
      bool? ndvrBlackout,
      String? ndvrRetentionLimit,
      bool? isDayPass,
      bool? replayTVDisabledOnMobileClient,
      List<String>? ppv,
      bool? streamedViaExternalApp,
      List<Application>? applications,
      Channel$ExternalStreamingProtocols? externalStreamingProtocols,
      Channel$ImageStream? imageStream,
      bool? uidPlacement,
      bool? isWifiOnlyEnabled,
      bool? outOfCountry3GStreamingEnabled,
      List<String>? outOfCountryStreamingDisabled}) {
    return Channel(
        id: id ?? this.id,
        name: name ?? this.name,
        logicalChannelNumber: logicalChannelNumber ?? this.logicalChannelNumber,
        logo: logo ?? this.logo,
        isRadio: isRadio ?? this.isRadio,
        isAdult: isAdult ?? this.isAdult,
        is3D: is3D ?? this.is3D,
        isHidden: isHidden ?? this.isHidden,
        isWatershed: isWatershed ?? this.isWatershed,
        resolution: resolution ?? this.resolution,
        pinChallengeSchedule: pinChallengeSchedule ?? this.pinChallengeSchedule,
        pinChallengeDuration: pinChallengeDuration ?? this.pinChallengeDuration,
        playableViaExternalApp:
            playableViaExternalApp ?? this.playableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls,
        replayAppId: replayAppId ?? this.replayAppId,
        replayAppChannelId: replayAppChannelId ?? this.replayAppChannelId,
        replayPrePadding: replayPrePadding ?? this.replayPrePadding,
        replayPostPadding: replayPostPadding ?? this.replayPostPadding,
        allowedOverlayApps: allowedOverlayApps ?? this.allowedOverlayApps,
        ldvrTrickPlayControl: ldvrTrickPlayControl ?? this.ldvrTrickPlayControl,
        hasLdvrChannelBasedAuthorization: hasLdvrChannelBasedAuthorization ??
            this.hasLdvrChannelBasedAuthorization,
        hasLdvrRestrictCpeStreaming:
            hasLdvrRestrictCpeStreaming ?? this.hasLdvrRestrictCpeStreaming,
        replacement: replacement ?? this.replacement,
        saveReplayToNdvr: saveReplayToNdvr ?? this.saveReplayToNdvr,
        contextMenuActions: contextMenuActions ?? this.contextMenuActions,
        promotionalImage: promotionalImage ?? this.promotionalImage,
        appIdForDayPass: appIdForDayPass ?? this.appIdForDayPass,
        boundApps: boundApps ?? this.boundApps,
        isPPV: isPPV ?? this.isPPV,
        replaySources: replaySources ?? this.replaySources,
        replayProducts: replayProducts ?? this.replayProducts,
        linearProducts: linearProducts ?? this.linearProducts,
        providerId: providerId ?? this.providerId,
        locator: locator ?? this.locator,
        locators: locators ?? this.locators,
        genre: genre ?? this.genre,
        ndvrBlackout: ndvrBlackout ?? this.ndvrBlackout,
        ndvrRetentionLimit: ndvrRetentionLimit ?? this.ndvrRetentionLimit,
        isDayPass: isDayPass ?? this.isDayPass,
        replayTVDisabledOnMobileClient: replayTVDisabledOnMobileClient ??
            this.replayTVDisabledOnMobileClient,
        ppv: ppv ?? this.ppv,
        streamedViaExternalApp:
            streamedViaExternalApp ?? this.streamedViaExternalApp,
        applications: applications ?? this.applications,
        externalStreamingProtocols:
            externalStreamingProtocols ?? this.externalStreamingProtocols,
        imageStream: imageStream ?? this.imageStream,
        uidPlacement: uidPlacement ?? this.uidPlacement,
        isWifiOnlyEnabled: isWifiOnlyEnabled ?? this.isWifiOnlyEnabled,
        outOfCountry3GStreamingEnabled: outOfCountry3GStreamingEnabled ??
            this.outOfCountry3GStreamingEnabled,
        outOfCountryStreamingDisabled: outOfCountryStreamingDisabled ??
            this.outOfCountryStreamingDisabled);
  }

  Channel copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<int>? logicalChannelNumber,
      Wrapped<Channel$Logo?>? logo,
      Wrapped<bool?>? isRadio,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? is3D,
      Wrapped<bool?>? isHidden,
      Wrapped<bool?>? isWatershed,
      Wrapped<String?>? resolution,
      Wrapped<String?>? pinChallengeSchedule,
      Wrapped<String?>? pinChallengeDuration,
      Wrapped<bool?>? playableViaExternalApp,
      Wrapped<List<ExternalAppUrl>?>? externalAppUrls,
      Wrapped<String?>? replayAppId,
      Wrapped<String?>? replayAppChannelId,
      Wrapped<int?>? replayPrePadding,
      Wrapped<int?>? replayPostPadding,
      Wrapped<List<String>?>? allowedOverlayApps,
      Wrapped<List<String>?>? ldvrTrickPlayControl,
      Wrapped<bool?>? hasLdvrChannelBasedAuthorization,
      Wrapped<bool?>? hasLdvrRestrictCpeStreaming,
      Wrapped<Channel$Replacement?>? replacement,
      Wrapped<bool?>? saveReplayToNdvr,
      Wrapped<String?>? contextMenuActions,
      Wrapped<String?>? promotionalImage,
      Wrapped<String?>? appIdForDayPass,
      Wrapped<List<BoundApp>?>? boundApps,
      Wrapped<bool?>? isPPV,
      Wrapped<List<enums.ChannelReplaySources>?>? replaySources,
      Wrapped<List<ReplayProduct>?>? replayProducts,
      Wrapped<List<String>?>? linearProducts,
      Wrapped<String?>? providerId,
      Wrapped<String?>? locator,
      Wrapped<Map<String, dynamic>?>? locators,
      Wrapped<List<String>?>? genre,
      Wrapped<bool?>? ndvrBlackout,
      Wrapped<String?>? ndvrRetentionLimit,
      Wrapped<bool?>? isDayPass,
      Wrapped<bool?>? replayTVDisabledOnMobileClient,
      Wrapped<List<String>?>? ppv,
      Wrapped<bool?>? streamedViaExternalApp,
      Wrapped<List<Application>?>? applications,
      Wrapped<Channel$ExternalStreamingProtocols?>? externalStreamingProtocols,
      Wrapped<Channel$ImageStream?>? imageStream,
      Wrapped<bool?>? uidPlacement,
      Wrapped<bool?>? isWifiOnlyEnabled,
      Wrapped<bool?>? outOfCountry3GStreamingEnabled,
      Wrapped<List<String>?>? outOfCountryStreamingDisabled}) {
    return Channel(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        logicalChannelNumber: (logicalChannelNumber != null
            ? logicalChannelNumber.value
            : this.logicalChannelNumber),
        logo: (logo != null ? logo.value : this.logo),
        isRadio: (isRadio != null ? isRadio.value : this.isRadio),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        is3D: (is3D != null ? is3D.value : this.is3D),
        isHidden: (isHidden != null ? isHidden.value : this.isHidden),
        isWatershed:
            (isWatershed != null ? isWatershed.value : this.isWatershed),
        resolution: (resolution != null ? resolution.value : this.resolution),
        pinChallengeSchedule: (pinChallengeSchedule != null
            ? pinChallengeSchedule.value
            : this.pinChallengeSchedule),
        pinChallengeDuration: (pinChallengeDuration != null
            ? pinChallengeDuration.value
            : this.pinChallengeDuration),
        playableViaExternalApp: (playableViaExternalApp != null
            ? playableViaExternalApp.value
            : this.playableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls),
        replayAppId:
            (replayAppId != null ? replayAppId.value : this.replayAppId),
        replayAppChannelId: (replayAppChannelId != null
            ? replayAppChannelId.value
            : this.replayAppChannelId),
        replayPrePadding: (replayPrePadding != null
            ? replayPrePadding.value
            : this.replayPrePadding),
        replayPostPadding: (replayPostPadding != null
            ? replayPostPadding.value
            : this.replayPostPadding),
        allowedOverlayApps: (allowedOverlayApps != null
            ? allowedOverlayApps.value
            : this.allowedOverlayApps),
        ldvrTrickPlayControl: (ldvrTrickPlayControl != null
            ? ldvrTrickPlayControl.value
            : this.ldvrTrickPlayControl),
        hasLdvrChannelBasedAuthorization:
            (hasLdvrChannelBasedAuthorization != null
                ? hasLdvrChannelBasedAuthorization.value
                : this.hasLdvrChannelBasedAuthorization),
        hasLdvrRestrictCpeStreaming: (hasLdvrRestrictCpeStreaming != null
            ? hasLdvrRestrictCpeStreaming.value
            : this.hasLdvrRestrictCpeStreaming),
        replacement:
            (replacement != null ? replacement.value : this.replacement),
        saveReplayToNdvr: (saveReplayToNdvr != null
            ? saveReplayToNdvr.value
            : this.saveReplayToNdvr),
        contextMenuActions: (contextMenuActions != null
            ? contextMenuActions.value
            : this.contextMenuActions),
        promotionalImage: (promotionalImage != null
            ? promotionalImage.value
            : this.promotionalImage),
        appIdForDayPass: (appIdForDayPass != null
            ? appIdForDayPass.value
            : this.appIdForDayPass),
        boundApps: (boundApps != null ? boundApps.value : this.boundApps),
        isPPV: (isPPV != null ? isPPV.value : this.isPPV),
        replaySources:
            (replaySources != null ? replaySources.value : this.replaySources),
        replayProducts: (replayProducts != null
            ? replayProducts.value
            : this.replayProducts),
        linearProducts: (linearProducts != null
            ? linearProducts.value
            : this.linearProducts),
        providerId: (providerId != null ? providerId.value : this.providerId),
        locator: (locator != null ? locator.value : this.locator),
        locators: (locators != null ? locators.value : this.locators),
        genre: (genre != null ? genre.value : this.genre),
        ndvrBlackout:
            (ndvrBlackout != null ? ndvrBlackout.value : this.ndvrBlackout),
        ndvrRetentionLimit: (ndvrRetentionLimit != null
            ? ndvrRetentionLimit.value
            : this.ndvrRetentionLimit),
        isDayPass: (isDayPass != null ? isDayPass.value : this.isDayPass),
        replayTVDisabledOnMobileClient: (replayTVDisabledOnMobileClient != null
            ? replayTVDisabledOnMobileClient.value
            : this.replayTVDisabledOnMobileClient),
        ppv: (ppv != null ? ppv.value : this.ppv),
        streamedViaExternalApp: (streamedViaExternalApp != null
            ? streamedViaExternalApp.value
            : this.streamedViaExternalApp),
        applications:
            (applications != null ? applications.value : this.applications),
        externalStreamingProtocols: (externalStreamingProtocols != null
            ? externalStreamingProtocols.value
            : this.externalStreamingProtocols),
        imageStream:
            (imageStream != null ? imageStream.value : this.imageStream),
        uidPlacement:
            (uidPlacement != null ? uidPlacement.value : this.uidPlacement),
        isWifiOnlyEnabled: (isWifiOnlyEnabled != null
            ? isWifiOnlyEnabled.value
            : this.isWifiOnlyEnabled),
        outOfCountry3GStreamingEnabled: (outOfCountry3GStreamingEnabled != null
            ? outOfCountry3GStreamingEnabled.value
            : this.outOfCountry3GStreamingEnabled),
        outOfCountryStreamingDisabled: (outOfCountryStreamingDisabled != null
            ? outOfCountryStreamingDisabled.value
            : this.outOfCountryStreamingDisabled));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelProduct {
  ChannelProduct({
    required this.productId,
    required this.edsProductId,
  });

  factory ChannelProduct.fromJson(Map<String, dynamic> json) =>
      _$ChannelProductFromJson(json);

  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String productId;
  @JsonKey(name: 'edsProductId', includeIfNull: false, defaultValue: '')
  final String edsProductId;
  static const fromJsonFactory = _$ChannelProductFromJson;
  static const toJsonFactory = _$ChannelProductToJson;
  Map<String, dynamic> toJson() => _$ChannelProductToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelProduct &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.edsProductId, edsProductId) ||
                const DeepCollectionEquality()
                    .equals(other.edsProductId, edsProductId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(edsProductId) ^
      runtimeType.hashCode;
}

extension $ChannelProductExtension on ChannelProduct {
  ChannelProduct copyWith({String? productId, String? edsProductId}) {
    return ChannelProduct(
        productId: productId ?? this.productId,
        edsProductId: edsProductId ?? this.edsProductId);
  }

  ChannelProduct copyWithWrapped(
      {Wrapped<String>? productId, Wrapped<String>? edsProductId}) {
    return ChannelProduct(
        productId: (productId != null ? productId.value : this.productId),
        edsProductId:
            (edsProductId != null ? edsProductId.value : this.edsProductId));
  }
}

@JsonSerializable(explicitToJson: true)
class ExternalAppUrl {
  ExternalAppUrl({
    this.deviceCode,
    required this.url,
  });

  factory ExternalAppUrl.fromJson(Map<String, dynamic> json) =>
      _$ExternalAppUrlFromJson(json);

  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String? deviceCode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$ExternalAppUrlFromJson;
  static const toJsonFactory = _$ExternalAppUrlToJson;
  Map<String, dynamic> toJson() => _$ExternalAppUrlToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ExternalAppUrl &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ExternalAppUrlExtension on ExternalAppUrl {
  ExternalAppUrl copyWith({String? deviceCode, String? url}) {
    return ExternalAppUrl(
        deviceCode: deviceCode ?? this.deviceCode, url: url ?? this.url);
  }

  ExternalAppUrl copyWithWrapped(
      {Wrapped<String?>? deviceCode, Wrapped<String>? url}) {
    return ExternalAppUrl(
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayProduct {
  ReplayProduct({
    this.entitlementId,
    this.allowStartOver,
    this.replayDuration,
    this.replayMode,
  });

  factory ReplayProduct.fromJson(Map<String, dynamic> json) =>
      _$ReplayProductFromJson(json);

  @JsonKey(name: 'entitlementId', includeIfNull: false, defaultValue: '')
  final String? entitlementId;
  @JsonKey(name: 'allowStartOver', includeIfNull: false)
  final bool? allowStartOver;
  @JsonKey(name: 'replayDuration', includeIfNull: false)
  final int? replayDuration;
  @JsonKey(
    name: 'replayMode',
    includeIfNull: false,
    toJson: replayProductReplayModeToJson,
    fromJson: replayProductReplayModeFromJson,
  )
  final enums.ReplayProductReplayMode? replayMode;
  static const fromJsonFactory = _$ReplayProductFromJson;
  static const toJsonFactory = _$ReplayProductToJson;
  Map<String, dynamic> toJson() => _$ReplayProductToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayProduct &&
            (identical(other.entitlementId, entitlementId) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementId, entitlementId)) &&
            (identical(other.allowStartOver, allowStartOver) ||
                const DeepCollectionEquality()
                    .equals(other.allowStartOver, allowStartOver)) &&
            (identical(other.replayDuration, replayDuration) ||
                const DeepCollectionEquality()
                    .equals(other.replayDuration, replayDuration)) &&
            (identical(other.replayMode, replayMode) ||
                const DeepCollectionEquality()
                    .equals(other.replayMode, replayMode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlementId) ^
      const DeepCollectionEquality().hash(allowStartOver) ^
      const DeepCollectionEquality().hash(replayDuration) ^
      const DeepCollectionEquality().hash(replayMode) ^
      runtimeType.hashCode;
}

extension $ReplayProductExtension on ReplayProduct {
  ReplayProduct copyWith(
      {String? entitlementId,
      bool? allowStartOver,
      int? replayDuration,
      enums.ReplayProductReplayMode? replayMode}) {
    return ReplayProduct(
        entitlementId: entitlementId ?? this.entitlementId,
        allowStartOver: allowStartOver ?? this.allowStartOver,
        replayDuration: replayDuration ?? this.replayDuration,
        replayMode: replayMode ?? this.replayMode);
  }

  ReplayProduct copyWithWrapped(
      {Wrapped<String?>? entitlementId,
      Wrapped<bool?>? allowStartOver,
      Wrapped<int?>? replayDuration,
      Wrapped<enums.ReplayProductReplayMode?>? replayMode}) {
    return ReplayProduct(
        entitlementId:
            (entitlementId != null ? entitlementId.value : this.entitlementId),
        allowStartOver: (allowStartOver != null
            ? allowStartOver.value
            : this.allowStartOver),
        replayDuration: (replayDuration != null
            ? replayDuration.value
            : this.replayDuration),
        replayMode: (replayMode != null ? replayMode.value : this.replayMode));
  }
}

@JsonSerializable(explicitToJson: true)
class BoundApp {
  BoundApp({
    required this.deepLink,
    this.trigger,
    this.toastImage,
    this.delay,
    this.displayTime,
    this.repeat,
    this.interval,
    this.channelBound,
    this.appLogo,
    this.posterLogo,
    this.toasterMessage,
    this.synopsis,
  });

  factory BoundApp.fromJson(Map<String, dynamic> json) =>
      _$BoundAppFromJson(json);

  @JsonKey(name: 'deepLink', includeIfNull: false, defaultValue: '')
  final String deepLink;
  @JsonKey(name: 'trigger', includeIfNull: false, defaultValue: '')
  final String? trigger;
  @JsonKey(name: 'toastImage', includeIfNull: false, defaultValue: '')
  final String? toastImage;
  @JsonKey(name: 'delay', includeIfNull: false)
  final int? delay;
  @JsonKey(name: 'displayTime', includeIfNull: false)
  final int? displayTime;
  @JsonKey(name: 'repeat', includeIfNull: false)
  final int? repeat;
  @JsonKey(name: 'interval', includeIfNull: false)
  final int? interval;
  @JsonKey(name: 'channelBound', includeIfNull: false, defaultValue: '')
  final String? channelBound;
  @JsonKey(name: 'appLogo', includeIfNull: false, defaultValue: '')
  final String? appLogo;
  @JsonKey(name: 'posterLogo', includeIfNull: false, defaultValue: '')
  final String? posterLogo;
  @JsonKey(name: 'toasterMessage', includeIfNull: false, defaultValue: '')
  final String? toasterMessage;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  static const fromJsonFactory = _$BoundAppFromJson;
  static const toJsonFactory = _$BoundAppToJson;
  Map<String, dynamic> toJson() => _$BoundAppToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BoundApp &&
            (identical(other.deepLink, deepLink) ||
                const DeepCollectionEquality()
                    .equals(other.deepLink, deepLink)) &&
            (identical(other.trigger, trigger) ||
                const DeepCollectionEquality()
                    .equals(other.trigger, trigger)) &&
            (identical(other.toastImage, toastImage) ||
                const DeepCollectionEquality()
                    .equals(other.toastImage, toastImage)) &&
            (identical(other.delay, delay) ||
                const DeepCollectionEquality().equals(other.delay, delay)) &&
            (identical(other.displayTime, displayTime) ||
                const DeepCollectionEquality()
                    .equals(other.displayTime, displayTime)) &&
            (identical(other.repeat, repeat) ||
                const DeepCollectionEquality().equals(other.repeat, repeat)) &&
            (identical(other.interval, interval) ||
                const DeepCollectionEquality()
                    .equals(other.interval, interval)) &&
            (identical(other.channelBound, channelBound) ||
                const DeepCollectionEquality()
                    .equals(other.channelBound, channelBound)) &&
            (identical(other.appLogo, appLogo) ||
                const DeepCollectionEquality()
                    .equals(other.appLogo, appLogo)) &&
            (identical(other.posterLogo, posterLogo) ||
                const DeepCollectionEquality()
                    .equals(other.posterLogo, posterLogo)) &&
            (identical(other.toasterMessage, toasterMessage) ||
                const DeepCollectionEquality()
                    .equals(other.toasterMessage, toasterMessage)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deepLink) ^
      const DeepCollectionEquality().hash(trigger) ^
      const DeepCollectionEquality().hash(toastImage) ^
      const DeepCollectionEquality().hash(delay) ^
      const DeepCollectionEquality().hash(displayTime) ^
      const DeepCollectionEquality().hash(repeat) ^
      const DeepCollectionEquality().hash(interval) ^
      const DeepCollectionEquality().hash(channelBound) ^
      const DeepCollectionEquality().hash(appLogo) ^
      const DeepCollectionEquality().hash(posterLogo) ^
      const DeepCollectionEquality().hash(toasterMessage) ^
      const DeepCollectionEquality().hash(synopsis) ^
      runtimeType.hashCode;
}

extension $BoundAppExtension on BoundApp {
  BoundApp copyWith(
      {String? deepLink,
      String? trigger,
      String? toastImage,
      int? delay,
      int? displayTime,
      int? repeat,
      int? interval,
      String? channelBound,
      String? appLogo,
      String? posterLogo,
      String? toasterMessage,
      String? synopsis}) {
    return BoundApp(
        deepLink: deepLink ?? this.deepLink,
        trigger: trigger ?? this.trigger,
        toastImage: toastImage ?? this.toastImage,
        delay: delay ?? this.delay,
        displayTime: displayTime ?? this.displayTime,
        repeat: repeat ?? this.repeat,
        interval: interval ?? this.interval,
        channelBound: channelBound ?? this.channelBound,
        appLogo: appLogo ?? this.appLogo,
        posterLogo: posterLogo ?? this.posterLogo,
        toasterMessage: toasterMessage ?? this.toasterMessage,
        synopsis: synopsis ?? this.synopsis);
  }

  BoundApp copyWithWrapped(
      {Wrapped<String>? deepLink,
      Wrapped<String?>? trigger,
      Wrapped<String?>? toastImage,
      Wrapped<int?>? delay,
      Wrapped<int?>? displayTime,
      Wrapped<int?>? repeat,
      Wrapped<int?>? interval,
      Wrapped<String?>? channelBound,
      Wrapped<String?>? appLogo,
      Wrapped<String?>? posterLogo,
      Wrapped<String?>? toasterMessage,
      Wrapped<String?>? synopsis}) {
    return BoundApp(
        deepLink: (deepLink != null ? deepLink.value : this.deepLink),
        trigger: (trigger != null ? trigger.value : this.trigger),
        toastImage: (toastImage != null ? toastImage.value : this.toastImage),
        delay: (delay != null ? delay.value : this.delay),
        displayTime:
            (displayTime != null ? displayTime.value : this.displayTime),
        repeat: (repeat != null ? repeat.value : this.repeat),
        interval: (interval != null ? interval.value : this.interval),
        channelBound:
            (channelBound != null ? channelBound.value : this.channelBound),
        appLogo: (appLogo != null ? appLogo.value : this.appLogo),
        posterLogo: (posterLogo != null ? posterLogo.value : this.posterLogo),
        toasterMessage: (toasterMessage != null
            ? toasterMessage.value
            : this.toasterMessage),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelV1$Logo {
  ChannelV1$Logo({
    this.focused,
    this.nonFocused,
    this.providerLogo,
  });

  factory ChannelV1$Logo.fromJson(Map<String, dynamic> json) =>
      _$ChannelV1$LogoFromJson(json);

  @JsonKey(name: 'focused', includeIfNull: false, defaultValue: '')
  final String? focused;
  @JsonKey(name: 'nonFocused', includeIfNull: false, defaultValue: '')
  final String? nonFocused;
  @JsonKey(name: 'providerLogo', includeIfNull: false, defaultValue: '')
  final String? providerLogo;
  static const fromJsonFactory = _$ChannelV1$LogoFromJson;
  static const toJsonFactory = _$ChannelV1$LogoToJson;
  Map<String, dynamic> toJson() => _$ChannelV1$LogoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelV1$Logo &&
            (identical(other.focused, focused) ||
                const DeepCollectionEquality()
                    .equals(other.focused, focused)) &&
            (identical(other.nonFocused, nonFocused) ||
                const DeepCollectionEquality()
                    .equals(other.nonFocused, nonFocused)) &&
            (identical(other.providerLogo, providerLogo) ||
                const DeepCollectionEquality()
                    .equals(other.providerLogo, providerLogo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(focused) ^
      const DeepCollectionEquality().hash(nonFocused) ^
      const DeepCollectionEquality().hash(providerLogo) ^
      runtimeType.hashCode;
}

extension $ChannelV1$LogoExtension on ChannelV1$Logo {
  ChannelV1$Logo copyWith(
      {String? focused, String? nonFocused, String? providerLogo}) {
    return ChannelV1$Logo(
        focused: focused ?? this.focused,
        nonFocused: nonFocused ?? this.nonFocused,
        providerLogo: providerLogo ?? this.providerLogo);
  }

  ChannelV1$Logo copyWithWrapped(
      {Wrapped<String?>? focused,
      Wrapped<String?>? nonFocused,
      Wrapped<String?>? providerLogo}) {
    return ChannelV1$Logo(
        focused: (focused != null ? focused.value : this.focused),
        nonFocused: (nonFocused != null ? nonFocused.value : this.nonFocused),
        providerLogo:
            (providerLogo != null ? providerLogo.value : this.providerLogo));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelV1$Replacement {
  ChannelV1$Replacement({
    required this.startTimeLocal,
    required this.endTimeLocal,
    required this.replacementUri,
    this.replacementChannel,
  });

  factory ChannelV1$Replacement.fromJson(Map<String, dynamic> json) =>
      _$ChannelV1$ReplacementFromJson(json);

  @JsonKey(name: 'startTimeLocal', includeIfNull: false, defaultValue: '')
  final String startTimeLocal;
  @JsonKey(name: 'endTimeLocal', includeIfNull: false, defaultValue: '')
  final String endTimeLocal;
  @JsonKey(name: 'replacementUri', includeIfNull: false, defaultValue: '')
  final String replacementUri;
  @JsonKey(name: 'replacementChannel', includeIfNull: false, defaultValue: '')
  final String? replacementChannel;
  static const fromJsonFactory = _$ChannelV1$ReplacementFromJson;
  static const toJsonFactory = _$ChannelV1$ReplacementToJson;
  Map<String, dynamic> toJson() => _$ChannelV1$ReplacementToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelV1$Replacement &&
            (identical(other.startTimeLocal, startTimeLocal) ||
                const DeepCollectionEquality()
                    .equals(other.startTimeLocal, startTimeLocal)) &&
            (identical(other.endTimeLocal, endTimeLocal) ||
                const DeepCollectionEquality()
                    .equals(other.endTimeLocal, endTimeLocal)) &&
            (identical(other.replacementUri, replacementUri) ||
                const DeepCollectionEquality()
                    .equals(other.replacementUri, replacementUri)) &&
            (identical(other.replacementChannel, replacementChannel) ||
                const DeepCollectionEquality()
                    .equals(other.replacementChannel, replacementChannel)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTimeLocal) ^
      const DeepCollectionEquality().hash(endTimeLocal) ^
      const DeepCollectionEquality().hash(replacementUri) ^
      const DeepCollectionEquality().hash(replacementChannel) ^
      runtimeType.hashCode;
}

extension $ChannelV1$ReplacementExtension on ChannelV1$Replacement {
  ChannelV1$Replacement copyWith(
      {String? startTimeLocal,
      String? endTimeLocal,
      String? replacementUri,
      String? replacementChannel}) {
    return ChannelV1$Replacement(
        startTimeLocal: startTimeLocal ?? this.startTimeLocal,
        endTimeLocal: endTimeLocal ?? this.endTimeLocal,
        replacementUri: replacementUri ?? this.replacementUri,
        replacementChannel: replacementChannel ?? this.replacementChannel);
  }

  ChannelV1$Replacement copyWithWrapped(
      {Wrapped<String>? startTimeLocal,
      Wrapped<String>? endTimeLocal,
      Wrapped<String>? replacementUri,
      Wrapped<String?>? replacementChannel}) {
    return ChannelV1$Replacement(
        startTimeLocal: (startTimeLocal != null
            ? startTimeLocal.value
            : this.startTimeLocal),
        endTimeLocal:
            (endTimeLocal != null ? endTimeLocal.value : this.endTimeLocal),
        replacementUri: (replacementUri != null
            ? replacementUri.value
            : this.replacementUri),
        replacementChannel: (replacementChannel != null
            ? replacementChannel.value
            : this.replacementChannel));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel$Logo {
  Channel$Logo({
    this.focused,
    this.nonFocused,
    this.providerLogo,
  });

  factory Channel$Logo.fromJson(Map<String, dynamic> json) =>
      _$Channel$LogoFromJson(json);

  @JsonKey(name: 'focused', includeIfNull: false, defaultValue: '')
  final String? focused;
  @JsonKey(name: 'nonFocused', includeIfNull: false, defaultValue: '')
  final String? nonFocused;
  @JsonKey(name: 'providerLogo', includeIfNull: false, defaultValue: '')
  final String? providerLogo;
  static const fromJsonFactory = _$Channel$LogoFromJson;
  static const toJsonFactory = _$Channel$LogoToJson;
  Map<String, dynamic> toJson() => _$Channel$LogoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel$Logo &&
            (identical(other.focused, focused) ||
                const DeepCollectionEquality()
                    .equals(other.focused, focused)) &&
            (identical(other.nonFocused, nonFocused) ||
                const DeepCollectionEquality()
                    .equals(other.nonFocused, nonFocused)) &&
            (identical(other.providerLogo, providerLogo) ||
                const DeepCollectionEquality()
                    .equals(other.providerLogo, providerLogo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(focused) ^
      const DeepCollectionEquality().hash(nonFocused) ^
      const DeepCollectionEquality().hash(providerLogo) ^
      runtimeType.hashCode;
}

extension $Channel$LogoExtension on Channel$Logo {
  Channel$Logo copyWith(
      {String? focused, String? nonFocused, String? providerLogo}) {
    return Channel$Logo(
        focused: focused ?? this.focused,
        nonFocused: nonFocused ?? this.nonFocused,
        providerLogo: providerLogo ?? this.providerLogo);
  }

  Channel$Logo copyWithWrapped(
      {Wrapped<String?>? focused,
      Wrapped<String?>? nonFocused,
      Wrapped<String?>? providerLogo}) {
    return Channel$Logo(
        focused: (focused != null ? focused.value : this.focused),
        nonFocused: (nonFocused != null ? nonFocused.value : this.nonFocused),
        providerLogo:
            (providerLogo != null ? providerLogo.value : this.providerLogo));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel$Replacement {
  Channel$Replacement({
    this.startTimeLocal,
    this.endTimeLocal,
    this.replacementUri,
    this.replacementChannel,
  });

  factory Channel$Replacement.fromJson(Map<String, dynamic> json) =>
      _$Channel$ReplacementFromJson(json);

  @JsonKey(name: 'startTimeLocal', includeIfNull: false, defaultValue: '')
  final String? startTimeLocal;
  @JsonKey(name: 'endTimeLocal', includeIfNull: false, defaultValue: '')
  final String? endTimeLocal;
  @JsonKey(name: 'replacementUri', includeIfNull: false, defaultValue: '')
  final String? replacementUri;
  @JsonKey(name: 'replacementChannel', includeIfNull: false, defaultValue: '')
  final String? replacementChannel;
  static const fromJsonFactory = _$Channel$ReplacementFromJson;
  static const toJsonFactory = _$Channel$ReplacementToJson;
  Map<String, dynamic> toJson() => _$Channel$ReplacementToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel$Replacement &&
            (identical(other.startTimeLocal, startTimeLocal) ||
                const DeepCollectionEquality()
                    .equals(other.startTimeLocal, startTimeLocal)) &&
            (identical(other.endTimeLocal, endTimeLocal) ||
                const DeepCollectionEquality()
                    .equals(other.endTimeLocal, endTimeLocal)) &&
            (identical(other.replacementUri, replacementUri) ||
                const DeepCollectionEquality()
                    .equals(other.replacementUri, replacementUri)) &&
            (identical(other.replacementChannel, replacementChannel) ||
                const DeepCollectionEquality()
                    .equals(other.replacementChannel, replacementChannel)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startTimeLocal) ^
      const DeepCollectionEquality().hash(endTimeLocal) ^
      const DeepCollectionEquality().hash(replacementUri) ^
      const DeepCollectionEquality().hash(replacementChannel) ^
      runtimeType.hashCode;
}

extension $Channel$ReplacementExtension on Channel$Replacement {
  Channel$Replacement copyWith(
      {String? startTimeLocal,
      String? endTimeLocal,
      String? replacementUri,
      String? replacementChannel}) {
    return Channel$Replacement(
        startTimeLocal: startTimeLocal ?? this.startTimeLocal,
        endTimeLocal: endTimeLocal ?? this.endTimeLocal,
        replacementUri: replacementUri ?? this.replacementUri,
        replacementChannel: replacementChannel ?? this.replacementChannel);
  }

  Channel$Replacement copyWithWrapped(
      {Wrapped<String?>? startTimeLocal,
      Wrapped<String?>? endTimeLocal,
      Wrapped<String?>? replacementUri,
      Wrapped<String?>? replacementChannel}) {
    return Channel$Replacement(
        startTimeLocal: (startTimeLocal != null
            ? startTimeLocal.value
            : this.startTimeLocal),
        endTimeLocal:
            (endTimeLocal != null ? endTimeLocal.value : this.endTimeLocal),
        replacementUri: (replacementUri != null
            ? replacementUri.value
            : this.replacementUri),
        replacementChannel: (replacementChannel != null
            ? replacementChannel.value
            : this.replacementChannel));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel$ExternalStreamingProtocols {
  Channel$ExternalStreamingProtocols({
    this.startOver,
    this.linear,
    this.ndvr,
    this.replay,
  });

  factory Channel$ExternalStreamingProtocols.fromJson(
          Map<String, dynamic> json) =>
      _$Channel$ExternalStreamingProtocolsFromJson(json);

  @JsonKey(name: 'startOver', includeIfNull: false, defaultValue: <String>[])
  final List<String>? startOver;
  @JsonKey(name: 'linear', includeIfNull: false, defaultValue: <String>[])
  final List<String>? linear;
  @JsonKey(name: 'NDVR', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ndvr;
  @JsonKey(name: 'replay', includeIfNull: false, defaultValue: <String>[])
  final List<String>? replay;
  static const fromJsonFactory = _$Channel$ExternalStreamingProtocolsFromJson;
  static const toJsonFactory = _$Channel$ExternalStreamingProtocolsToJson;
  Map<String, dynamic> toJson() =>
      _$Channel$ExternalStreamingProtocolsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel$ExternalStreamingProtocols &&
            (identical(other.startOver, startOver) ||
                const DeepCollectionEquality()
                    .equals(other.startOver, startOver)) &&
            (identical(other.linear, linear) ||
                const DeepCollectionEquality().equals(other.linear, linear)) &&
            (identical(other.ndvr, ndvr) ||
                const DeepCollectionEquality().equals(other.ndvr, ndvr)) &&
            (identical(other.replay, replay) ||
                const DeepCollectionEquality().equals(other.replay, replay)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startOver) ^
      const DeepCollectionEquality().hash(linear) ^
      const DeepCollectionEquality().hash(ndvr) ^
      const DeepCollectionEquality().hash(replay) ^
      runtimeType.hashCode;
}

extension $Channel$ExternalStreamingProtocolsExtension
    on Channel$ExternalStreamingProtocols {
  Channel$ExternalStreamingProtocols copyWith(
      {List<String>? startOver,
      List<String>? linear,
      List<String>? ndvr,
      List<String>? replay}) {
    return Channel$ExternalStreamingProtocols(
        startOver: startOver ?? this.startOver,
        linear: linear ?? this.linear,
        ndvr: ndvr ?? this.ndvr,
        replay: replay ?? this.replay);
  }

  Channel$ExternalStreamingProtocols copyWithWrapped(
      {Wrapped<List<String>?>? startOver,
      Wrapped<List<String>?>? linear,
      Wrapped<List<String>?>? ndvr,
      Wrapped<List<String>?>? replay}) {
    return Channel$ExternalStreamingProtocols(
        startOver: (startOver != null ? startOver.value : this.startOver),
        linear: (linear != null ? linear.value : this.linear),
        ndvr: (ndvr != null ? ndvr.value : this.ndvr),
        replay: (replay != null ? replay.value : this.replay));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel$ImageStream {
  Channel$ImageStream({
    this.full,
    this.small,
  });

  factory Channel$ImageStream.fromJson(Map<String, dynamic> json) =>
      _$Channel$ImageStreamFromJson(json);

  @JsonKey(name: 'full', includeIfNull: false, defaultValue: '')
  final String? full;
  @JsonKey(name: 'small', includeIfNull: false, defaultValue: '')
  final String? small;
  static const fromJsonFactory = _$Channel$ImageStreamFromJson;
  static const toJsonFactory = _$Channel$ImageStreamToJson;
  Map<String, dynamic> toJson() => _$Channel$ImageStreamToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel$ImageStream &&
            (identical(other.full, full) ||
                const DeepCollectionEquality().equals(other.full, full)) &&
            (identical(other.small, small) ||
                const DeepCollectionEquality().equals(other.small, small)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(full) ^
      const DeepCollectionEquality().hash(small) ^
      runtimeType.hashCode;
}

extension $Channel$ImageStreamExtension on Channel$ImageStream {
  Channel$ImageStream copyWith({String? full, String? small}) {
    return Channel$ImageStream(
        full: full ?? this.full, small: small ?? this.small);
  }

  Channel$ImageStream copyWithWrapped(
      {Wrapped<String?>? full, Wrapped<String?>? small}) {
    return Channel$ImageStream(
        full: (full != null ? full.value : this.full),
        small: (small != null ? small.value : this.small));
  }
}

String? replayEventResolutionToJson(
    enums.ReplayEventResolution? replayEventResolution) {
  return enums.$ReplayEventResolutionMap[replayEventResolution];
}

enums.ReplayEventResolution replayEventResolutionFromJson(
  Object? replayEventResolution, [
  enums.ReplayEventResolution? defaultValue,
]) {
  if (replayEventResolution is String) {
    return enums.$ReplayEventResolutionMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                replayEventResolution.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReplayEventResolution.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReplayEventResolutionMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReplayEventResolution.swaggerGeneratedUnknown;
}

List<String> replayEventResolutionListToJson(
    List<enums.ReplayEventResolution>? replayEventResolution) {
  if (replayEventResolution == null) {
    return [];
  }

  return replayEventResolution
      .map((e) => enums.$ReplayEventResolutionMap[e]!)
      .toList();
}

List<enums.ReplayEventResolution> replayEventResolutionListFromJson(
  List? replayEventResolution, [
  List<enums.ReplayEventResolution>? defaultValue,
]) {
  if (replayEventResolution == null) {
    return defaultValue ?? [];
  }

  return replayEventResolution
      .map((e) => replayEventResolutionFromJson(e.toString()))
      .toList();
}

List<enums.ReplayEventResolution>? replayEventResolutionNullableListFromJson(
  List? replayEventResolution, [
  List<enums.ReplayEventResolution>? defaultValue,
]) {
  if (replayEventResolution == null) {
    return defaultValue;
  }

  return replayEventResolution
      .map((e) => replayEventResolutionFromJson(e.toString()))
      .toList();
}

String? replayEventV2ResolutionToJson(
    enums.ReplayEventV2Resolution? replayEventV2Resolution) {
  return enums.$ReplayEventV2ResolutionMap[replayEventV2Resolution];
}

enums.ReplayEventV2Resolution replayEventV2ResolutionFromJson(
  Object? replayEventV2Resolution, [
  enums.ReplayEventV2Resolution? defaultValue,
]) {
  if (replayEventV2Resolution is String) {
    return enums.$ReplayEventV2ResolutionMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                replayEventV2Resolution.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReplayEventV2Resolution.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReplayEventV2ResolutionMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReplayEventV2Resolution.swaggerGeneratedUnknown;
}

List<String> replayEventV2ResolutionListToJson(
    List<enums.ReplayEventV2Resolution>? replayEventV2Resolution) {
  if (replayEventV2Resolution == null) {
    return [];
  }

  return replayEventV2Resolution
      .map((e) => enums.$ReplayEventV2ResolutionMap[e]!)
      .toList();
}

List<enums.ReplayEventV2Resolution> replayEventV2ResolutionListFromJson(
  List? replayEventV2Resolution, [
  List<enums.ReplayEventV2Resolution>? defaultValue,
]) {
  if (replayEventV2Resolution == null) {
    return defaultValue ?? [];
  }

  return replayEventV2Resolution
      .map((e) => replayEventV2ResolutionFromJson(e.toString()))
      .toList();
}

List<enums.ReplayEventV2Resolution>?
    replayEventV2ResolutionNullableListFromJson(
  List? replayEventV2Resolution, [
  List<enums.ReplayEventV2Resolution>? defaultValue,
]) {
  if (replayEventV2Resolution == null) {
    return defaultValue;
  }

  return replayEventV2Resolution
      .map((e) => replayEventV2ResolutionFromJson(e.toString()))
      .toList();
}

int? languagePurposeToJson(enums.LanguagePurpose? languagePurpose) {
  return enums.$LanguagePurposeMap[languagePurpose];
}

enums.LanguagePurpose languagePurposeFromJson(
  Object? languagePurpose, [
  enums.LanguagePurpose? defaultValue,
]) {
  if (languagePurpose is int) {
    return enums.$LanguagePurposeMap.entries
        .firstWhere((element) => element.value == languagePurpose,
            orElse: () => const MapEntry(
                enums.LanguagePurpose.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LanguagePurposeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LanguagePurpose.swaggerGeneratedUnknown;
}

List<int> languagePurposeListToJson(
    List<enums.LanguagePurpose>? languagePurpose) {
  if (languagePurpose == null) {
    return [];
  }

  return languagePurpose.map((e) => enums.$LanguagePurposeMap[e]!).toList();
}

List<enums.LanguagePurpose> languagePurposeListFromJson(
  List? languagePurpose, [
  List<enums.LanguagePurpose>? defaultValue,
]) {
  if (languagePurpose == null) {
    return defaultValue ?? [];
  }

  return languagePurpose
      .map((e) => languagePurposeFromJson(e.toString()))
      .toList();
}

List<enums.LanguagePurpose>? languagePurposeNullableListFromJson(
  List? languagePurpose, [
  List<enums.LanguagePurpose>? defaultValue,
]) {
  if (languagePurpose == null) {
    return defaultValue;
  }

  return languagePurpose
      .map((e) => languagePurposeFromJson(e.toString()))
      .toList();
}

String? errorCodeToJson(enums.ErrorCode? errorCode) {
  return enums.$ErrorCodeMap[errorCode];
}

enums.ErrorCode errorCodeFromJson(
  Object? errorCode, [
  enums.ErrorCode? defaultValue,
]) {
  if (errorCode is String) {
    return enums.$ErrorCodeMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == errorCode.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ErrorCode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ErrorCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ErrorCode.swaggerGeneratedUnknown;
}

List<String> errorCodeListToJson(List<enums.ErrorCode>? errorCode) {
  if (errorCode == null) {
    return [];
  }

  return errorCode.map((e) => enums.$ErrorCodeMap[e]!).toList();
}

List<enums.ErrorCode> errorCodeListFromJson(
  List? errorCode, [
  List<enums.ErrorCode>? defaultValue,
]) {
  if (errorCode == null) {
    return defaultValue ?? [];
  }

  return errorCode.map((e) => errorCodeFromJson(e.toString())).toList();
}

List<enums.ErrorCode>? errorCodeNullableListFromJson(
  List? errorCode, [
  List<enums.ErrorCode>? defaultValue,
]) {
  if (errorCode == null) {
    return defaultValue;
  }

  return errorCode.map((e) => errorCodeFromJson(e.toString())).toList();
}

String? channelV1ReplaySourcesToJson(
    enums.ChannelV1ReplaySources? channelV1ReplaySources) {
  return enums.$ChannelV1ReplaySourcesMap[channelV1ReplaySources];
}

enums.ChannelV1ReplaySources channelV1ReplaySourcesFromJson(
  Object? channelV1ReplaySources, [
  enums.ChannelV1ReplaySources? defaultValue,
]) {
  if (channelV1ReplaySources is String) {
    return enums.$ChannelV1ReplaySourcesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                channelV1ReplaySources.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelV1ReplaySources.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelV1ReplaySourcesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelV1ReplaySources.swaggerGeneratedUnknown;
}

List<String> channelV1ReplaySourcesListToJson(
    List<enums.ChannelV1ReplaySources>? channelV1ReplaySources) {
  if (channelV1ReplaySources == null) {
    return [];
  }

  return channelV1ReplaySources
      .map((e) => enums.$ChannelV1ReplaySourcesMap[e]!)
      .toList();
}

List<enums.ChannelV1ReplaySources> channelV1ReplaySourcesListFromJson(
  List? channelV1ReplaySources, [
  List<enums.ChannelV1ReplaySources>? defaultValue,
]) {
  if (channelV1ReplaySources == null) {
    return defaultValue ?? [];
  }

  return channelV1ReplaySources
      .map((e) => channelV1ReplaySourcesFromJson(e.toString()))
      .toList();
}

List<enums.ChannelV1ReplaySources>? channelV1ReplaySourcesNullableListFromJson(
  List? channelV1ReplaySources, [
  List<enums.ChannelV1ReplaySources>? defaultValue,
]) {
  if (channelV1ReplaySources == null) {
    return defaultValue;
  }

  return channelV1ReplaySources
      .map((e) => channelV1ReplaySourcesFromJson(e.toString()))
      .toList();
}

String? channelReplaySourcesToJson(
    enums.ChannelReplaySources? channelReplaySources) {
  return enums.$ChannelReplaySourcesMap[channelReplaySources];
}

enums.ChannelReplaySources channelReplaySourcesFromJson(
  Object? channelReplaySources, [
  enums.ChannelReplaySources? defaultValue,
]) {
  if (channelReplaySources is String) {
    return enums.$ChannelReplaySourcesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                channelReplaySources.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelReplaySources.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelReplaySourcesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelReplaySources.swaggerGeneratedUnknown;
}

List<String> channelReplaySourcesListToJson(
    List<enums.ChannelReplaySources>? channelReplaySources) {
  if (channelReplaySources == null) {
    return [];
  }

  return channelReplaySources
      .map((e) => enums.$ChannelReplaySourcesMap[e]!)
      .toList();
}

List<enums.ChannelReplaySources> channelReplaySourcesListFromJson(
  List? channelReplaySources, [
  List<enums.ChannelReplaySources>? defaultValue,
]) {
  if (channelReplaySources == null) {
    return defaultValue ?? [];
  }

  return channelReplaySources
      .map((e) => channelReplaySourcesFromJson(e.toString()))
      .toList();
}

List<enums.ChannelReplaySources>? channelReplaySourcesNullableListFromJson(
  List? channelReplaySources, [
  List<enums.ChannelReplaySources>? defaultValue,
]) {
  if (channelReplaySources == null) {
    return defaultValue;
  }

  return channelReplaySources
      .map((e) => channelReplaySourcesFromJson(e.toString()))
      .toList();
}

String? replayProductReplayModeToJson(
    enums.ReplayProductReplayMode? replayProductReplayMode) {
  return enums.$ReplayProductReplayModeMap[replayProductReplayMode];
}

enums.ReplayProductReplayMode replayProductReplayModeFromJson(
  Object? replayProductReplayMode, [
  enums.ReplayProductReplayMode? defaultValue,
]) {
  if (replayProductReplayMode is String) {
    return enums.$ReplayProductReplayModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                replayProductReplayMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ReplayProductReplayMode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ReplayProductReplayModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ReplayProductReplayMode.swaggerGeneratedUnknown;
}

List<String> replayProductReplayModeListToJson(
    List<enums.ReplayProductReplayMode>? replayProductReplayMode) {
  if (replayProductReplayMode == null) {
    return [];
  }

  return replayProductReplayMode
      .map((e) => enums.$ReplayProductReplayModeMap[e]!)
      .toList();
}

List<enums.ReplayProductReplayMode> replayProductReplayModeListFromJson(
  List? replayProductReplayMode, [
  List<enums.ReplayProductReplayMode>? defaultValue,
]) {
  if (replayProductReplayMode == null) {
    return defaultValue ?? [];
  }

  return replayProductReplayMode
      .map((e) => replayProductReplayModeFromJson(e.toString()))
      .toList();
}

List<enums.ReplayProductReplayMode>?
    replayProductReplayModeNullableListFromJson(
  List? replayProductReplayMode, [
  List<enums.ReplayProductReplayMode>? defaultValue,
]) {
  if (replayProductReplayMode == null) {
    return defaultValue;
  }

  return replayProductReplayMode
      .map((e) => replayProductReplayModeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
