// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'open_api_sample.swagger.chopper.dart';
part 'open_api_sample.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class OpenApiSample extends ChopperService {
  static OpenApiSample create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$OpenApiSample(client);
    }

    final newClient = ChopperClient(
        services: [_$OpenApiSample()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$OpenApiSample(newClient);
  }

  ///Log in and get api token
  Future<chopper.Response<Object>> userLoginPost({
    String? cacheControl,
    required UserLoginPost$RequestBody? body,
  }) {
    return _userLoginPost(cacheControl: cacheControl, body: body);
  }

  ///Log in and get api token
  @Post(path: '/user/login')
  Future<chopper.Response<Object>> _userLoginPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserLoginPost$RequestBody? body,
  });

  ///Add product
  Future<chopper.Response<ProductModel>> productAddPost({
    String? cacheControl,
    required ProductModel? body,
  }) {
    generatedMapping.putIfAbsent(
        ProductModel, () => ProductModel.fromJsonFactory);

    return _productAddPost(cacheControl: cacheControl, body: body);
  }

  ///Add product
  @Post(path: '/product/add')
  Future<chopper.Response<ProductModel>> _productAddPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ProductModel? body,
  });
}

@JsonSerializable(explicitToJson: true)
class ProductModel {
  ProductModel({
    this.id,
    this.name,
    this.price,
    this.priceCoins,
    this.barcodes,
    this.images,
    this.stocks,
  });

  factory ProductModel.fromJson(Map<String, dynamic> json) =>
      _$ProductModelFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'price', includeIfNull: false)
  final double? price;
  @JsonKey(name: 'price_coins', includeIfNull: false)
  final double? priceCoins;
  @JsonKey(name: 'barcodes', includeIfNull: false, defaultValue: <String>[])
  final List<String>? barcodes;
  @JsonKey(
      name: 'images',
      includeIfNull: false,
      defaultValue: <ProductModel$Images>[])
  final List<ProductModel$Images>? images;
  @JsonKey(
      name: 'stocks',
      includeIfNull: false,
      defaultValue: <ProductModel$Stocks>[])
  final List<ProductModel$Stocks>? stocks;
  static const fromJsonFactory = _$ProductModelFromJson;
  static const toJsonFactory = _$ProductModelToJson;
  Map<String, dynamic> toJson() => _$ProductModelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductModel &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.priceCoins, priceCoins) ||
                const DeepCollectionEquality()
                    .equals(other.priceCoins, priceCoins)) &&
            (identical(other.barcodes, barcodes) ||
                const DeepCollectionEquality()
                    .equals(other.barcodes, barcodes)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.stocks, stocks) ||
                const DeepCollectionEquality().equals(other.stocks, stocks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(priceCoins) ^
      const DeepCollectionEquality().hash(barcodes) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(stocks) ^
      runtimeType.hashCode;
}

extension $ProductModelExtension on ProductModel {
  ProductModel copyWith(
      {int? id,
      String? name,
      double? price,
      double? priceCoins,
      List<String>? barcodes,
      List<ProductModel$Images>? images,
      List<ProductModel$Stocks>? stocks}) {
    return ProductModel(
        id: id ?? this.id,
        name: name ?? this.name,
        price: price ?? this.price,
        priceCoins: priceCoins ?? this.priceCoins,
        barcodes: barcodes ?? this.barcodes,
        images: images ?? this.images,
        stocks: stocks ?? this.stocks);
  }

  ProductModel copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<double?>? price,
      Wrapped<double?>? priceCoins,
      Wrapped<List<String>?>? barcodes,
      Wrapped<List<ProductModel$Images>?>? images,
      Wrapped<List<ProductModel$Stocks>?>? stocks}) {
    return ProductModel(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        price: (price != null ? price.value : this.price),
        priceCoins: (priceCoins != null ? priceCoins.value : this.priceCoins),
        barcodes: (barcodes != null ? barcodes.value : this.barcodes),
        images: (images != null ? images.value : this.images),
        stocks: (stocks != null ? stocks.value : this.stocks));
  }
}

@JsonSerializable(explicitToJson: true)
class Stock {
  Stock({
    this.id,
    this.name,
    this.address,
    this.gps,
    this.key,
    this.isMarketplace,
  });

  factory Stock.fromJson(Map<String, dynamic> json) => _$StockFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'address', includeIfNull: false, defaultValue: '')
  final String? address;
  @JsonKey(name: 'gps', includeIfNull: false, defaultValue: '')
  final String? gps;
  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String? key;
  @JsonKey(name: 'is_marketplace', includeIfNull: false)
  final bool? isMarketplace;
  static const fromJsonFactory = _$StockFromJson;
  static const toJsonFactory = _$StockToJson;
  Map<String, dynamic> toJson() => _$StockToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Stock &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.gps, gps) ||
                const DeepCollectionEquality().equals(other.gps, gps)) &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.isMarketplace, isMarketplace) ||
                const DeepCollectionEquality()
                    .equals(other.isMarketplace, isMarketplace)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(gps) ^
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(isMarketplace) ^
      runtimeType.hashCode;
}

extension $StockExtension on Stock {
  Stock copyWith(
      {int? id,
      String? name,
      String? address,
      String? gps,
      String? key,
      bool? isMarketplace}) {
    return Stock(
        id: id ?? this.id,
        name: name ?? this.name,
        address: address ?? this.address,
        gps: gps ?? this.gps,
        key: key ?? this.key,
        isMarketplace: isMarketplace ?? this.isMarketplace);
  }

  Stock copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? address,
      Wrapped<String?>? gps,
      Wrapped<String?>? key,
      Wrapped<bool?>? isMarketplace}) {
    return Stock(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        address: (address != null ? address.value : this.address),
        gps: (gps != null ? gps.value : this.gps),
        key: (key != null ? key.value : this.key),
        isMarketplace:
            (isMarketplace != null ? isMarketplace.value : this.isMarketplace));
  }
}

typedef ProductModel$Images = List<ProductModel$Images$Item>;

@JsonSerializable(explicitToJson: true)
class ProductModel$Images$Item {
  ProductModel$Images$Item({
    this.id,
    this.image,
  });

  factory ProductModel$Images$Item.fromJson(Map<String, dynamic> json) =>
      _$ProductModel$Images$ItemFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$ProductModel$Images$ItemFromJson;
  static const toJsonFactory = _$ProductModel$Images$ItemToJson;
  Map<String, dynamic> toJson() => _$ProductModel$Images$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductModel$Images$Item &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $ProductModel$Images$ItemExtension on ProductModel$Images$Item {
  ProductModel$Images$Item copyWith({int? id, String? image}) {
    return ProductModel$Images$Item(
        id: id ?? this.id, image: image ?? this.image);
  }

  ProductModel$Images$Item copyWithWrapped(
      {Wrapped<int?>? id, Wrapped<String?>? image}) {
    return ProductModel$Images$Item(
        id: (id != null ? id.value : this.id),
        image: (image != null ? image.value : this.image));
  }
}

typedef ProductModel$Stocks = List<ProductModel$Stocks$Item>;

@JsonSerializable(explicitToJson: true)
class ProductModel$Stocks$Item {
  ProductModel$Stocks$Item({
    this.stock,
    this.count,
  });

  factory ProductModel$Stocks$Item.fromJson(Map<String, dynamic> json) =>
      _$ProductModel$Stocks$ItemFromJson(json);

  @JsonKey(name: 'stock', includeIfNull: false)
  final Stock? stock;
  @JsonKey(name: 'count', includeIfNull: false)
  final int? count;
  static const fromJsonFactory = _$ProductModel$Stocks$ItemFromJson;
  static const toJsonFactory = _$ProductModel$Stocks$ItemToJson;
  Map<String, dynamic> toJson() => _$ProductModel$Stocks$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductModel$Stocks$Item &&
            (identical(other.stock, stock) ||
                const DeepCollectionEquality().equals(other.stock, stock)) &&
            (identical(other.count, count) ||
                const DeepCollectionEquality().equals(other.count, count)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stock) ^
      const DeepCollectionEquality().hash(count) ^
      runtimeType.hashCode;
}

extension $ProductModel$Stocks$ItemExtension on ProductModel$Stocks$Item {
  ProductModel$Stocks$Item copyWith({Stock? stock, int? count}) {
    return ProductModel$Stocks$Item(
        stock: stock ?? this.stock, count: count ?? this.count);
  }

  ProductModel$Stocks$Item copyWithWrapped(
      {Wrapped<Stock?>? stock, Wrapped<int?>? count}) {
    return ProductModel$Stocks$Item(
        stock: (stock != null ? stock.value : this.stock),
        count: (count != null ? count.value : this.count));
  }
}

@JsonSerializable(explicitToJson: true)
class UserLoginPost$RequestBody {
  UserLoginPost$RequestBody({
    required this.email,
    required this.password,
    this.stocks,
  });

  factory UserLoginPost$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$UserLoginPost$RequestBodyFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  @JsonKey(name: 'stocks', includeIfNull: false, defaultValue: <Stock>[])
  final List<Stock>? stocks;
  static const fromJsonFactory = _$UserLoginPost$RequestBodyFromJson;
  static const toJsonFactory = _$UserLoginPost$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$UserLoginPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserLoginPost$RequestBody &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.stocks, stocks) ||
                const DeepCollectionEquality().equals(other.stocks, stocks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(stocks) ^
      runtimeType.hashCode;
}

extension $UserLoginPost$RequestBodyExtension on UserLoginPost$RequestBody {
  UserLoginPost$RequestBody copyWith(
      {String? email, String? password, List<Stock>? stocks}) {
    return UserLoginPost$RequestBody(
        email: email ?? this.email,
        password: password ?? this.password,
        stocks: stocks ?? this.stocks);
  }

  UserLoginPost$RequestBody copyWithWrapped(
      {Wrapped<String>? email,
      Wrapped<String>? password,
      Wrapped<List<Stock>?>? stocks}) {
    return UserLoginPost$RequestBody(
        email: (email != null ? email.value : this.email),
        password: (password != null ? password.value : this.password),
        stocks: (stocks != null ? stocks.value : this.stocks));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
