// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'personal_home_service.enums.swagger.dart' as enums;
export 'personal_home_service.enums.swagger.dart';

part 'personal_home_service.swagger.chopper.dart';
part 'personal_home_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PersonalHomeService extends ChopperService {
  static PersonalHomeService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PersonalHomeService(client);
    }

    final newClient = ChopperClient(
        services: [_$PersonalHomeService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$PersonalHomeService(newClient);
  }

  ///
  ///@param customerId
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param recentlyUsedApps
  ///@param x-cus
  ///@param x-dev
  ///@param x-entitlements-token
  Future<chopper.Response<Screen>>
      customersCustomerIdProfilesProfileIdScreenGet({
    required String? customerId,
    required String? profileId,
    String? language,
    String? cpeId,
    String? clientType,
    String? maxRes,
    int? cityId,
    String? replayOptInDate,
    List<String>? recentlyUsedApps,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Screen, () => Screen.fromJsonFactory);

    return _customersCustomerIdProfilesProfileIdScreenGet(
        customerId: customerId,
        profileId: profileId,
        language: language,
        cpeId: cpeId,
        clientType: clientType,
        maxRes: maxRes,
        cityId: cityId,
        replayOptInDate: replayOptInDate,
        recentlyUsedApps: recentlyUsedApps,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///
  ///@param customerId
  ///@param profileId
  ///@param language
  ///@param cpeId
  ///@param clientType Available values: STB-EOS, HZNGO, STB-SELENE, STB-APOLLO
  ///@param maxRes Available values : SD, HD, 4K, 5K, 8K
  ///@param cityId
  ///@param replayOptInDate
  ///@param recentlyUsedApps
  ///@param x-cus
  ///@param x-dev
  ///@param x-entitlements-token
  @Get(path: '/customers/{customerId}/profiles/{profileId}/screen')
  Future<chopper.Response<Screen>>
      _customersCustomerIdProfilesProfileIdScreenGet({
    @Path('customerId') required String? customerId,
    @Path('profileId') required String? profileId,
    @Query('language') String? language,
    @Query('cpeId') String? cpeId,
    @Query('clientType') String? clientType,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptInDate') String? replayOptInDate,
    @Query('recentlyUsedApps') List<String>? recentlyUsedApps,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Screen {
  Screen({
    required this.collections,
    this.aspot,
  });

  factory Screen.fromJson(Map<String, dynamic> json) => _$ScreenFromJson(json);

  @JsonKey(
      name: 'collections',
      includeIfNull: false,
      defaultValue: <ScreenCollection>[])
  final List<ScreenCollection> collections;
  @JsonKey(name: 'aspot', includeIfNull: false)
  final Aspot? aspot;
  static const fromJsonFactory = _$ScreenFromJson;
  static const toJsonFactory = _$ScreenToJson;
  Map<String, dynamic> toJson() => _$ScreenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Screen &&
            (identical(other.collections, collections) ||
                const DeepCollectionEquality()
                    .equals(other.collections, collections)) &&
            (identical(other.aspot, aspot) ||
                const DeepCollectionEquality().equals(other.aspot, aspot)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(collections) ^
      const DeepCollectionEquality().hash(aspot) ^
      runtimeType.hashCode;
}

extension $ScreenExtension on Screen {
  Screen copyWith({List<ScreenCollection>? collections, Aspot? aspot}) {
    return Screen(
        collections: collections ?? this.collections,
        aspot: aspot ?? this.aspot);
  }

  Screen copyWithWrapped(
      {Wrapped<List<ScreenCollection>>? collections, Wrapped<Aspot?>? aspot}) {
    return Screen(
        collections:
            (collections != null ? collections.value : this.collections),
        aspot: (aspot != null ? aspot.value : this.aspot));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenCollection {
  ScreenCollection({
    required this.id,
    this.title,
    required this.type,
    this.layout,
    this.items,
    this.subcollections,
  });

  factory ScreenCollection.fromJson(Map<String, dynamic> json) =>
      _$ScreenCollectionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(
    name: 'layout',
    includeIfNull: false,
    toJson: screenCollectionLayoutToJson,
    fromJson: screenCollectionLayoutFromJson,
  )
  final enums.ScreenCollectionLayout? layout;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <ScreenItem>[])
  final List<ScreenItem>? items;
  @JsonKey(
      name: 'subcollections',
      includeIfNull: false,
      defaultValue: <ScreenSubcollection>[])
  final List<ScreenSubcollection>? subcollections;
  static const fromJsonFactory = _$ScreenCollectionFromJson;
  static const toJsonFactory = _$ScreenCollectionToJson;
  Map<String, dynamic> toJson() => _$ScreenCollectionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenCollection &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.layout, layout) ||
                const DeepCollectionEquality().equals(other.layout, layout)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)) &&
            (identical(other.subcollections, subcollections) ||
                const DeepCollectionEquality()
                    .equals(other.subcollections, subcollections)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(layout) ^
      const DeepCollectionEquality().hash(items) ^
      const DeepCollectionEquality().hash(subcollections) ^
      runtimeType.hashCode;
}

extension $ScreenCollectionExtension on ScreenCollection {
  ScreenCollection copyWith(
      {String? id,
      String? title,
      String? type,
      enums.ScreenCollectionLayout? layout,
      List<ScreenItem>? items,
      List<ScreenSubcollection>? subcollections}) {
    return ScreenCollection(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        layout: layout ?? this.layout,
        items: items ?? this.items,
        subcollections: subcollections ?? this.subcollections);
  }

  ScreenCollection copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? title,
      Wrapped<String>? type,
      Wrapped<enums.ScreenCollectionLayout?>? layout,
      Wrapped<List<ScreenItem>?>? items,
      Wrapped<List<ScreenSubcollection>?>? subcollections}) {
    return ScreenCollection(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        layout: (layout != null ? layout.value : this.layout),
        items: (items != null ? items.value : this.items),
        subcollections: (subcollections != null
            ? subcollections.value
            : this.subcollections));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenSubcollection {
  ScreenSubcollection({
    required this.id,
    required this.title,
    required this.type,
    this.items,
  });

  factory ScreenSubcollection.fromJson(Map<String, dynamic> json) =>
      _$ScreenSubcollectionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <ScreenItem>[])
  final List<ScreenItem>? items;
  static const fromJsonFactory = _$ScreenSubcollectionFromJson;
  static const toJsonFactory = _$ScreenSubcollectionToJson;
  Map<String, dynamic> toJson() => _$ScreenSubcollectionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenSubcollection &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(items) ^
      runtimeType.hashCode;
}

extension $ScreenSubcollectionExtension on ScreenSubcollection {
  ScreenSubcollection copyWith(
      {String? id, String? title, String? type, List<ScreenItem>? items}) {
    return ScreenSubcollection(
        id: id ?? this.id,
        title: title ?? this.title,
        type: type ?? this.type,
        items: items ?? this.items);
  }

  ScreenSubcollection copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<String>? type,
      Wrapped<List<ScreenItem>?>? items}) {
    return ScreenSubcollection(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        type: (type != null ? type.value : this.type),
        items: (items != null ? items.value : this.items));
  }
}

@JsonSerializable(explicitToJson: true)
class ScreenItem {
  ScreenItem({
    this.id,
    this.title,
    this.brandingProviderId,
    this.type,
    this.subType,
    this.ageRating,
    this.channelId,
    this.startTime,
    this.endTime,
    this.duration,
    this.bookmark,
    this.priceDisplay,
    this.minPriceDisplay,
    this.tvodEntitlementEnd,
    this.isRemoved,
    this.isExpired,
    this.isBoxset,
    this.seasonNumber,
    this.episodeNumber,
    this.recordingState,
    this.seasonCount,
    this.expirationDate,
    this.earliestBroadcastStartTime,
    this.isPurchased,
    this.seriesId,
    this.rootId,
    this.providerId,
  });

  factory ScreenItem.fromJson(Map<String, dynamic> json) =>
      _$ScreenItemFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'subType', includeIfNull: false, defaultValue: '')
  final String? subType;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'tvodEntitlementEnd', includeIfNull: false)
  final DateTime? tvodEntitlementEnd;
  @JsonKey(name: 'isRemoved', includeIfNull: false)
  final bool? isRemoved;
  @JsonKey(name: 'isExpired', includeIfNull: false)
  final bool? isExpired;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'recordingState', includeIfNull: false, defaultValue: '')
  final String? recordingState;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(name: 'earliestBroadcastStartTime', includeIfNull: false)
  final DateTime? earliestBroadcastStartTime;
  @JsonKey(name: 'isPurchased', includeIfNull: false)
  final bool? isPurchased;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'rootId', includeIfNull: false, defaultValue: '')
  final String? rootId;
  @JsonKey(name: 'providerId', includeIfNull: false, defaultValue: '')
  final String? providerId;
  static const fromJsonFactory = _$ScreenItemFromJson;
  static const toJsonFactory = _$ScreenItemToJson;
  Map<String, dynamic> toJson() => _$ScreenItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScreenItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.subType, subType) ||
                const DeepCollectionEquality()
                    .equals(other.subType, subType)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.tvodEntitlementEnd, tvodEntitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.tvodEntitlementEnd, tvodEntitlementEnd)) &&
            (identical(other.isRemoved, isRemoved) ||
                const DeepCollectionEquality()
                    .equals(other.isRemoved, isRemoved)) &&
            (identical(other.isExpired, isExpired) ||
                const DeepCollectionEquality()
                    .equals(other.isExpired, isExpired)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.earliestBroadcastStartTime, earliestBroadcastStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.earliestBroadcastStartTime, earliestBroadcastStartTime)) &&
            (identical(other.isPurchased, isPurchased) || const DeepCollectionEquality().equals(other.isPurchased, isPurchased)) &&
            (identical(other.seriesId, seriesId) || const DeepCollectionEquality().equals(other.seriesId, seriesId)) &&
            (identical(other.rootId, rootId) || const DeepCollectionEquality().equals(other.rootId, rootId)) &&
            (identical(other.providerId, providerId) || const DeepCollectionEquality().equals(other.providerId, providerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(subType) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(tvodEntitlementEnd) ^
      const DeepCollectionEquality().hash(isRemoved) ^
      const DeepCollectionEquality().hash(isExpired) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(earliestBroadcastStartTime) ^
      const DeepCollectionEquality().hash(isPurchased) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(rootId) ^
      const DeepCollectionEquality().hash(providerId) ^
      runtimeType.hashCode;
}

extension $ScreenItemExtension on ScreenItem {
  ScreenItem copyWith(
      {String? id,
      String? title,
      String? brandingProviderId,
      String? type,
      String? subType,
      String? ageRating,
      String? channelId,
      DateTime? startTime,
      DateTime? endTime,
      int? duration,
      int? bookmark,
      String? priceDisplay,
      String? minPriceDisplay,
      DateTime? tvodEntitlementEnd,
      bool? isRemoved,
      bool? isExpired,
      bool? isBoxset,
      int? seasonNumber,
      int? episodeNumber,
      String? recordingState,
      int? seasonCount,
      DateTime? expirationDate,
      DateTime? earliestBroadcastStartTime,
      bool? isPurchased,
      String? seriesId,
      String? rootId,
      String? providerId}) {
    return ScreenItem(
        id: id ?? this.id,
        title: title ?? this.title,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        type: type ?? this.type,
        subType: subType ?? this.subType,
        ageRating: ageRating ?? this.ageRating,
        channelId: channelId ?? this.channelId,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        bookmark: bookmark ?? this.bookmark,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        tvodEntitlementEnd: tvodEntitlementEnd ?? this.tvodEntitlementEnd,
        isRemoved: isRemoved ?? this.isRemoved,
        isExpired: isExpired ?? this.isExpired,
        isBoxset: isBoxset ?? this.isBoxset,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        recordingState: recordingState ?? this.recordingState,
        seasonCount: seasonCount ?? this.seasonCount,
        expirationDate: expirationDate ?? this.expirationDate,
        earliestBroadcastStartTime:
            earliestBroadcastStartTime ?? this.earliestBroadcastStartTime,
        isPurchased: isPurchased ?? this.isPurchased,
        seriesId: seriesId ?? this.seriesId,
        rootId: rootId ?? this.rootId,
        providerId: providerId ?? this.providerId);
  }

  ScreenItem copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? type,
      Wrapped<String?>? subType,
      Wrapped<String?>? ageRating,
      Wrapped<String?>? channelId,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<int?>? duration,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<DateTime?>? tvodEntitlementEnd,
      Wrapped<bool?>? isRemoved,
      Wrapped<bool?>? isExpired,
      Wrapped<bool?>? isBoxset,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? recordingState,
      Wrapped<int?>? seasonCount,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<DateTime?>? earliestBroadcastStartTime,
      Wrapped<bool?>? isPurchased,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? rootId,
      Wrapped<String?>? providerId}) {
    return ScreenItem(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        type: (type != null ? type.value : this.type),
        subType: (subType != null ? subType.value : this.subType),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        channelId: (channelId != null ? channelId.value : this.channelId),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        tvodEntitlementEnd: (tvodEntitlementEnd != null
            ? tvodEntitlementEnd.value
            : this.tvodEntitlementEnd),
        isRemoved: (isRemoved != null ? isRemoved.value : this.isRemoved),
        isExpired: (isExpired != null ? isExpired.value : this.isExpired),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        earliestBroadcastStartTime: (earliestBroadcastStartTime != null
            ? earliestBroadcastStartTime.value
            : this.earliestBroadcastStartTime),
        isPurchased:
            (isPurchased != null ? isPurchased.value : this.isPurchased),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        rootId: (rootId != null ? rootId.value : this.rootId),
        providerId: (providerId != null ? providerId.value : this.providerId));
  }
}

@JsonSerializable(explicitToJson: true)
class Aspot {
  Aspot({
    this.id,
    this.type,
    this.isBoxset,
    this.brandingProviderId,
  });

  factory Aspot.fromJson(Map<String, dynamic> json) => _$AspotFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  static const fromJsonFactory = _$AspotFromJson;
  static const toJsonFactory = _$AspotToJson;
  Map<String, dynamic> toJson() => _$AspotToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Aspot &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      runtimeType.hashCode;
}

extension $AspotExtension on Aspot {
  Aspot copyWith(
      {String? id, String? type, bool? isBoxset, String? brandingProviderId}) {
    return Aspot(
        id: id ?? this.id,
        type: type ?? this.type,
        isBoxset: isBoxset ?? this.isBoxset,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId);
  }

  Aspot copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? type,
      Wrapped<bool?>? isBoxset,
      Wrapped<String?>? brandingProviderId}) {
    return Aspot(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error?>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    this.httpStatusCode,
    this.statusCode,
    this.message,
    this.details,
    this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int? httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;
  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int?>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String?>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? screenCollectionLayoutToJson(
    enums.ScreenCollectionLayout? screenCollectionLayout) {
  return enums.$ScreenCollectionLayoutMap[screenCollectionLayout];
}

enums.ScreenCollectionLayout screenCollectionLayoutFromJson(
  Object? screenCollectionLayout, [
  enums.ScreenCollectionLayout? defaultValue,
]) {
  if (screenCollectionLayout is String) {
    return enums.$ScreenCollectionLayoutMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                screenCollectionLayout.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ScreenCollectionLayout.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ScreenCollectionLayoutMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ScreenCollectionLayout.swaggerGeneratedUnknown;
}

List<String> screenCollectionLayoutListToJson(
    List<enums.ScreenCollectionLayout>? screenCollectionLayout) {
  if (screenCollectionLayout == null) {
    return [];
  }

  return screenCollectionLayout
      .map((e) => enums.$ScreenCollectionLayoutMap[e]!)
      .toList();
}

List<enums.ScreenCollectionLayout> screenCollectionLayoutListFromJson(
  List? screenCollectionLayout, [
  List<enums.ScreenCollectionLayout>? defaultValue,
]) {
  if (screenCollectionLayout == null) {
    return defaultValue ?? [];
  }

  return screenCollectionLayout
      .map((e) => screenCollectionLayoutFromJson(e.toString()))
      .toList();
}

List<enums.ScreenCollectionLayout>? screenCollectionLayoutNullableListFromJson(
  List? screenCollectionLayout, [
  List<enums.ScreenCollectionLayout>? defaultValue,
]) {
  if (screenCollectionLayout == null) {
    return defaultValue;
  }

  return screenCollectionLayout
      .map((e) => screenCollectionLayoutFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
