// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'personalization_service.enums.swagger.dart' as enums;
export 'personalization_service.enums.swagger.dart';

part 'personalization_service.swagger.chopper.dart';
part 'personalization_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PersonalizationService extends ChopperService {
  static PersonalizationService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PersonalizationService(client);
    }

    final newClient = ChopperClient(
        services: [_$PersonalizationService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$PersonalizationService(newClient);
  }

  ///Retrieve available profile colors for a given country
  ///@param country
  Future<chopper.Response<Object>> v1CommonsAvailableColoursGet({
    String? country,
    String? cacheControl,
  }) {
    return _v1CommonsAvailableColoursGet(
        country: country, cacheControl: cacheControl);
  }

  ///Retrieve available profile colors for a given country
  ///@param country
  @Get(path: '/v1/commons/availableColours')
  Future<chopper.Response<Object>> _v1CommonsAvailableColoursGet({
    @Query('country') String? country,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve genre information for a given language
  ///@param language
  Future<chopper.Response<Genre>> v1CommonsAvailableGenresGet({
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Genre, () => Genre.fromJsonFactory);

    return _v1CommonsAvailableGenresGet(
        language: language, cacheControl: cacheControl);
  }

  ///Retrieve genre information for a given language
  ///@param language
  @Get(path: '/v1/commons/availableGenres')
  Future<chopper.Response<Genre>> _v1CommonsAvailableGenresGet({
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve a list of available colour maps for a specific country
  ///@param country
  Future<chopper.Response<List<Map>>> v2CommonsAvailableColoursGet({
    String? country,
    String? cacheControl,
  }) {
    return _v2CommonsAvailableColoursGet(
        country: country, cacheControl: cacheControl);
  }

  ///Retrieve a list of available colour maps for a specific country
  ///@param country
  @Get(path: '/v2/commons/availableColours')
  Future<chopper.Response<List<Map>>> _v2CommonsAvailableColoursGet({
    @Query('country') String? country,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve genre information for a given language
  ///@param language Language
  Future<chopper.Response<List<GenreV2Result>>> v2CommonsAvailableGenresGet({
    required String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        GenreV2Result, () => GenreV2Result.fromJsonFactory);

    return _v2CommonsAvailableGenresGet(
        language: language, cacheControl: cacheControl);
  }

  ///Retrieve genre information for a given language
  ///@param language Language
  @Get(path: '/v2/commons/availableGenres')
  Future<chopper.Response<List<GenreV2Result>>> _v2CommonsAvailableGenresGet({
    @Query('language') required String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve customer information
  ///@param customerId
  Future<chopper.Response<CpsCustomerResponse>> v1CpsCustomerCustomerIdGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CpsCustomerResponse, () => CpsCustomerResponse.fromJsonFactory);

    return _v1CpsCustomerCustomerIdGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve customer information
  ///@param customerId
  @Get(path: '/v1/cps/customer/{customerId}')
  Future<chopper.Response<CpsCustomerResponse>> _v1CpsCustomerCustomerIdGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Purge customer from Datastore
  ///@param customerId
  Future<chopper.Response> v1CpsCustomerCustomerIdDelete({
    required String? customerId,
    String? cacheControl,
  }) {
    return _v1CpsCustomerCustomerIdDelete(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Purge customer from Datastore
  ///@param customerId
  @Delete(path: '/v1/cps/customer/{customerId}')
  Future<chopper.Response> _v1CpsCustomerCustomerIdDelete({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Reset the given pin type for given customer
  ///@param customerId The customer Id
  ///@param pinType The pin type
  Future<chopper.Response> v1CpsCustomerCustomerIdResetPinGet({
    required String? customerId,
    required enums.V1CpsCustomerCustomerIdResetPinGetPinType? pinType,
    String? cacheControl,
  }) {
    return _v1CpsCustomerCustomerIdResetPinGet(
        customerId: customerId,
        pinType: enums.$V1CpsCustomerCustomerIdResetPinGetPinTypeMap[pinType]
            ?.toString(),
        cacheControl: cacheControl);
  }

  ///Reset the given pin type for given customer
  ///@param customerId The customer Id
  ///@param pinType The pin type
  @Get(path: '/v1/cps/customer/{customerId}/resetPin')
  Future<chopper.Response> _v1CpsCustomerCustomerIdResetPinGet({
    @Path('customerId') required String? customerId,
    @Query('pinType') required String? pinType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update customer status
  ///@param customerId
  Future<chopper.Response> v1CpsCustomerCustomerIdStatusPut({
    required String? customerId,
    String? cacheControl,
    required String? body,
  }) {
    return _v1CpsCustomerCustomerIdStatusPut(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Update customer status
  ///@param customerId
  @Put(path: '/v1/cps/customer/{customerId}/status')
  Future<chopper.Response> _v1CpsCustomerCustomerIdStatusPut({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required String? body,
  });

  ///Update customer
  Future<chopper.Response> v1CpsCustomerPut({
    String? cacheControl,
    required Customer? body,
  }) {
    return _v1CpsCustomerPut(cacheControl: cacheControl, body: body);
  }

  ///Update customer
  @Put(path: '/v1/cps/customer')
  Future<chopper.Response> _v1CpsCustomerPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Customer? body,
  });

  ///Create customer
  Future<chopper.Response> v1CpsCustomerPost({
    String? cacheControl,
    required CpsCustomerRequest? body,
  }) {
    return _v1CpsCustomerPost(cacheControl: cacheControl, body: body);
  }

  ///Create customer
  @Post(path: '/v1/cps/customer')
  Future<chopper.Response> _v1CpsCustomerPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CpsCustomerRequest? body,
  });

  ///Update CPS customer ADS opt-in (advanced advertising)
  ///@param customerId
  Future<chopper.Response> v1CpsCustomerCustomerIdUpdateAvAdPut({
    required String? customerId,
    String? cacheControl,
    required AdvancedAdvertising? body,
  }) {
    return _v1CpsCustomerCustomerIdUpdateAvAdPut(
        customerId: customerId, cacheControl: cacheControl, body: body);
  }

  ///Update CPS customer ADS opt-in (advanced advertising)
  ///@param customerId
  @Put(path: '/v1/cps/customer/{customerId}/updateAvAd')
  Future<chopper.Response> _v1CpsCustomerCustomerIdUpdateAvAdPut({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AdvancedAdvertising? body,
  });

  ///Retrieve customer
  ///@param X-cus The customer Id
  ///@param customerId
  ///@param with
  Future<chopper.Response<Customer>> v1CustomerCustomerIdGet({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? $with,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Customer, () => Customer.fromJsonFactory);

    return _v1CustomerCustomerIdGet(
        xCus: xCus,
        customerId: customerId,
        $with: $with,
        cacheControl: cacheControl);
  }

  ///Retrieve customer
  ///@param X-cus The customer Id
  ///@param customerId
  ///@param with
  @Get(path: '/v1/customer/{customerId}')
  Future<chopper.Response<Customer>> _v1CustomerCustomerIdGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Query('with') String? $with,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response> v1CustomerCustomerIdPut({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
    required Customer? body,
  }) {
    return _v1CustomerCustomerIdPut(
        xCus: xCus,
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Put(path: '/v1/customer/{customerId}')
  Future<chopper.Response> _v1CustomerCustomerIdPut({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Customer? body,
  });

  ///Reset pin for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response<Customer>> v1CustomerCustomerIdResetPinGet({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Customer, () => Customer.fromJsonFactory);

    return _v1CustomerCustomerIdResetPinGet(
        xCus: xCus,
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl);
  }

  ///Reset pin for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/resetPin')
  Future<chopper.Response<Customer>> _v1CustomerCustomerIdResetPinGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify Pin
  ///@param X-cus The customer Id
  ///@param customerId
  Future<chopper.Response> v1CustomerCustomerIdVerifyPinPost({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? cacheControl,
    required Customer? body,
  }) {
    return _v1CustomerCustomerIdVerifyPinPost(
        xCus: xCus,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Verify Pin
  ///@param X-cus The customer Id
  ///@param customerId
  @Post(path: '/v1/customer/{customerId}/verifyPin')
  Future<chopper.Response> _v1CustomerCustomerIdVerifyPinPost({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Customer? body,
  });

  ///Retrieve customer information by device Id
  ///@param user-agent
  ///@param byDeviceId
  ///@param with
  Future<chopper.Response<Customer>> v1CustomerGet({
    String? userAgent,
    String? byDeviceId,
    String? $with,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Customer, () => Customer.fromJsonFactory);

    return _v1CustomerGet(
        userAgent: userAgent,
        byDeviceId: byDeviceId,
        $with: $with,
        cacheControl: cacheControl);
  }

  ///Retrieve customer information by device Id
  ///@param user-agent
  ///@param byDeviceId
  ///@param with
  @Get(path: '/v1/customer')
  Future<chopper.Response<Customer>> _v1CustomerGet({
    @Header('user-agent') String? userAgent,
    @Query('byDeviceId') String? byDeviceId,
    @Query('with') String? $with,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve device information for given customer
  ///@param X-cus The customer Id
  ///@param user-agent
  ///@param customerId
  ///@param deviceId
  Future<chopper.Response<Device>> v1CustomerCustomerIdDevicesDeviceIdGet({
    String? xCus = 'X-Cus',
    String? userAgent,
    required String? customerId,
    required String? deviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Device, () => Device.fromJsonFactory);

    return _v1CustomerCustomerIdDevicesDeviceIdGet(
        xCus: xCus,
        userAgent: userAgent,
        customerId: customerId,
        deviceId: deviceId,
        cacheControl: cacheControl);
  }

  ///Retrieve device information for given customer
  ///@param X-cus The customer Id
  ///@param user-agent
  ///@param customerId
  ///@param deviceId
  @Get(path: '/v1/customer/{customerId}/devices/{deviceId}')
  Future<chopper.Response<Device>> _v1CustomerCustomerIdDevicesDeviceIdGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('user-agent') String? userAgent,
    @Path('customerId') required String? customerId,
    @Path('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update given device for a given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param deviceId
  Future<chopper.Response> v1CustomerCustomerIdDevicesDeviceIdPut({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xGoDev,
    required String? customerId,
    required String? deviceId,
    String? cacheControl,
    required Device? body,
  }) {
    return _v1CustomerCustomerIdDevicesDeviceIdPut(
        xCus: xCus,
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        deviceId: deviceId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update given device for a given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param deviceId
  @Put(path: '/v1/customer/{customerId}/devices/{deviceId}')
  Future<chopper.Response> _v1CustomerCustomerIdDevicesDeviceIdPut({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('deviceId') required String? deviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Device? body,
  });

  ///Retrieve all device informations for given customer
  ///@param X-cus The customer Id
  ///@param customerId
  Future<chopper.Response<List<Device>>> v1CustomerCustomerIdDevicesGet({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Device, () => Device.fromJsonFactory);

    return _v1CustomerCustomerIdDevicesGet(
        xCus: xCus, customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve all device informations for given customer
  ///@param X-cus The customer Id
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/devices')
  Future<chopper.Response<List<Device>>> _v1CustomerCustomerIdDevicesGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update profile for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  Future<chopper.Response> v1CustomerCustomerIdProfilesProfileIdPut({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xGoDev,
    required String? customerId,
    required String? profileId,
    String? cacheControl,
    required Profile? body,
  }) {
    return _v1CustomerCustomerIdProfilesProfileIdPut(
        xCus: xCus,
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        profileId: profileId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update profile for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  @Put(path: '/v1/customer/{customerId}/profiles/{profileId}')
  Future<chopper.Response> _v1CustomerCustomerIdProfilesProfileIdPut({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Profile? body,
  });

  ///Delete profile for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  Future<chopper.Response> v1CustomerCustomerIdProfilesProfileIdDelete({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xGoDev,
    required String? customerId,
    required String? profileId,
    String? cacheControl,
  }) {
    return _v1CustomerCustomerIdProfilesProfileIdDelete(
        xCus: xCus,
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        profileId: profileId,
        cacheControl: cacheControl);
  }

  ///Delete profile for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  ///@param profileId
  @Delete(path: '/v1/customer/{customerId}/profiles/{profileId}')
  Future<chopper.Response> _v1CustomerCustomerIdProfilesProfileIdDelete({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('profileId') required String? profileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve list of profiles for given customer
  ///@param X-cus The customer Id
  ///@param customerId
  Future<chopper.Response<List<Profile>>> v1CustomerCustomerIdProfilesGet({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Profile, () => Profile.fromJsonFactory);

    return _v1CustomerCustomerIdProfilesGet(
        xCus: xCus, customerId: customerId, cacheControl: cacheControl);
  }

  ///Retrieve list of profiles for given customer
  ///@param X-cus The customer Id
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/profiles')
  Future<chopper.Response<List<Profile>>> _v1CustomerCustomerIdProfilesGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create profile for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response<ProfileId>> v1CustomerCustomerIdProfilesPost({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
    required Profile? body,
  }) {
    generatedMapping.putIfAbsent(ProfileId, () => ProfileId.fromJsonFactory);

    return _v1CustomerCustomerIdProfilesPost(
        xCus: xCus,
        xDev: xDev,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create profile for given customer
  ///@param X-cus The customer Id
  ///@param X-Dev
  ///@param X-Go-Dev
  ///@param customerId
  @Post(path: '/v1/customer/{customerId}/profiles')
  Future<chopper.Response<ProfileId>> _v1CustomerCustomerIdProfilesPost({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Profile? body,
  });

  ///Get reminders for given customer
  ///@param X-cus The x-cus header
  ///@param customerId The customer Id
  Future<chopper.Response<List<Reminder>>> v1CustomerCustomerIdRemindersGet({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Reminder, () => Reminder.fromJsonFactory);

    return _v1CustomerCustomerIdRemindersGet(
        xCus: xCus, customerId: customerId, cacheControl: cacheControl);
  }

  ///Get reminders for given customer
  ///@param X-cus The x-cus header
  ///@param customerId The customer Id
  @Get(path: '/v1/customer/{customerId}/reminders')
  Future<chopper.Response<List<Reminder>>> _v1CustomerCustomerIdRemindersGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set reminder for given customer
  ///@param X-cus The x-cus header
  ///@param customerId The customer Id
  Future<chopper.Response<ReminderId>> v1CustomerCustomerIdRemindersPost({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? cacheControl,
    required Reminder? body,
  }) {
    generatedMapping.putIfAbsent(ReminderId, () => ReminderId.fromJsonFactory);

    return _v1CustomerCustomerIdRemindersPost(
        xCus: xCus,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Set reminder for given customer
  ///@param X-cus The x-cus header
  ///@param customerId The customer Id
  @Post(path: '/v1/customer/{customerId}/reminders')
  Future<chopper.Response<ReminderId>> _v1CustomerCustomerIdRemindersPost({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Reminder? body,
  });

  ///Delete a specific reminder for a given customer
  ///@param X-cus The x-cus header
  ///@param customerId The customer Id
  ///@param reminderId The reminder Id
  Future<chopper.Response> v1CustomerCustomerIdRemindersReminderIdDelete({
    String? xCus = 'X-Cus',
    required String? customerId,
    required String? reminderId,
    String? cacheControl,
  }) {
    return _v1CustomerCustomerIdRemindersReminderIdDelete(
        xCus: xCus,
        customerId: customerId,
        reminderId: reminderId,
        cacheControl: cacheControl);
  }

  ///Delete a specific reminder for a given customer
  ///@param X-cus The x-cus header
  ///@param customerId The customer Id
  ///@param reminderId The reminder Id
  @Delete(path: '/v1/customer/{customerId}/reminders/{reminderId}')
  Future<chopper.Response> _v1CustomerCustomerIdRemindersReminderIdDelete({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Path('reminderId') required String? reminderId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve customer information by profile Id
  ///@param byProfileId
  ///@param with
  Future<chopper.Response<RengCustomerInformation>> v1RengCustomerGet({
    String? byProfileId,
    String? $with,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RengCustomerInformation, () => RengCustomerInformation.fromJsonFactory);

    return _v1RengCustomerGet(
        byProfileId: byProfileId, $with: $with, cacheControl: cacheControl);
  }

  ///Retrieve customer information by profile Id
  ///@param byProfileId
  ///@param with
  @Get(path: '/v1/reng/customer')
  Future<chopper.Response<RengCustomerInformation>> _v1RengCustomerGet({
    @Query('byProfileId') String? byProfileId,
    @Query('with') String? $with,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get customer config
  Future<chopper.Response> v1ConfigsCustomerconfigGet({String? cacheControl}) {
    return _v1ConfigsCustomerconfigGet(cacheControl: cacheControl);
  }

  ///Get customer config
  @Get(path: '/v1/configs/customerconfig')
  Future<chopper.Response> _v1ConfigsCustomerconfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get customer config
  Future<chopper.Response> v1ConfigsDeviceconfigGet({String? cacheControl}) {
    return _v1ConfigsDeviceconfigGet(cacheControl: cacheControl);
  }

  ///Get customer config
  @Get(path: '/v1/configs/deviceconfig')
  Future<chopper.Response> _v1ConfigsDeviceconfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get shared profile config
  Future<chopper.Response> v1ConfigsSharedprofileconfigGet(
      {String? cacheControl}) {
    return _v1ConfigsSharedprofileconfigGet(cacheControl: cacheControl);
  }

  ///Get shared profile config
  @Get(path: '/v1/configs/sharedprofileconfig')
  Future<chopper.Response> _v1ConfigsSharedprofileconfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Create OTT device for given customer
  ///@param X-cus
  ///@param X-Go-Dev
  ///@param customerId
  Future<chopper.Response> v1OttCustomerIdDevicePost({
    String? xCus = 'X-Cus',
    String? xGoDev,
    required String? customerId,
    String? cacheControl,
    required CreateOttDeviceRequest? body,
  }) {
    return _v1OttCustomerIdDevicePost(
        xCus: xCus,
        xGoDev: xGoDev,
        customerId: customerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create OTT device for given customer
  ///@param X-cus
  ///@param X-Go-Dev
  ///@param customerId
  @Post(path: '/v1/ott/{customerId}/device')
  Future<chopper.Response> _v1OttCustomerIdDevicePost({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CreateOttDeviceRequest? body,
  });

  ///Update OTT device for given customer
  ///@param X-cus
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  Future<chopper.Response> v1CustomerCustomerIdOttDrmDeviceIdPut({
    String? xCus = 'X-Cus',
    String? xGoDev,
    required String? customerId,
    required String? drmDeviceId,
    String? cacheControl,
    required UpdateOttDeviceRequest? body,
  }) {
    return _v1CustomerCustomerIdOttDrmDeviceIdPut(
        xCus: xCus,
        xGoDev: xGoDev,
        customerId: customerId,
        drmDeviceId: drmDeviceId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update OTT device for given customer
  ///@param X-cus
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  @Put(path: '/v1/customer/{customerId}/ott/{drmDeviceId}')
  Future<chopper.Response> _v1CustomerCustomerIdOttDrmDeviceIdPut({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('drmDeviceId') required String? drmDeviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required UpdateOttDeviceRequest? body,
  });

  ///Delete OTT device for given customer
  ///@param X-cus
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  Future<chopper.Response> v1CustomerCustomerIdOttDrmDeviceIdDelete({
    String? xCus = 'X-Cus',
    String? xGoDev,
    required String? customerId,
    required String? drmDeviceId,
    String? cacheControl,
  }) {
    return _v1CustomerCustomerIdOttDrmDeviceIdDelete(
        xCus: xCus,
        xGoDev: xGoDev,
        customerId: customerId,
        drmDeviceId: drmDeviceId,
        cacheControl: cacheControl);
  }

  ///Delete OTT device for given customer
  ///@param X-cus
  ///@param X-Go-Dev
  ///@param customerId
  ///@param drmDeviceId
  @Delete(path: '/v1/customer/{customerId}/ott/{drmDeviceId}')
  Future<chopper.Response> _v1CustomerCustomerIdOttDrmDeviceIdDelete({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('X-Go-Dev') String? xGoDev,
    @Path('customerId') required String? customerId,
    @Path('drmDeviceId') required String? drmDeviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get OTT devices for given customer
  ///@param X-cus
  ///@param customerId
  Future<chopper.Response<List<CustomerOttDevice>>>
      v1CustomerCustomerIdDevicesOttGet({
    String? xCus = 'X-Cus',
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CustomerOttDevice, () => CustomerOttDevice.fromJsonFactory);

    return _v1CustomerCustomerIdDevicesOttGet(
        xCus: xCus, customerId: customerId, cacheControl: cacheControl);
  }

  ///Get OTT devices for given customer
  ///@param X-cus
  ///@param customerId
  @Get(path: '/v1/customer/{customerId}/devices/ott')
  Future<chopper.Response<List<CustomerOttDevice>>>
      _v1CustomerCustomerIdDevicesOttGet({
    @Header('X-cus') String? xCus = 'X-Cus',
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Features {
  Features({
    this.features,
  });

  factory Features.fromJson(Map<String, dynamic> json) =>
      _$FeaturesFromJson(json);

  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$FeaturesFromJson;
  static const toJsonFactory = _$FeaturesToJson;
  Map<String, dynamic> toJson() => _$FeaturesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Features &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(features) ^ runtimeType.hashCode;
}

extension $FeaturesExtension on Features {
  Features copyWith({List<String>? features}) {
    return Features(features: features ?? this.features);
  }

  Features copyWithWrapped({Wrapped<List<String>?>? features}) {
    return Features(
        features: (features != null ? features.value : this.features));
  }
}

@JsonSerializable(explicitToJson: true)
class Genre {
  Genre({
    this.features,
    this.images,
    this.genreTranslations,
    this.termIds,
    this.type,
    this.language,
  });

  factory Genre.fromJson(Map<String, dynamic> json) => _$GenreFromJson(json);

  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <Features>[])
  final List<Features>? features;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <String>[])
  final List<String>? images;
  @JsonKey(
      name: 'genreTranslations', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genreTranslations;
  @JsonKey(name: 'termIds', includeIfNull: false, defaultValue: <TermIds>[])
  final List<TermIds>? termIds;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'language', includeIfNull: false, defaultValue: '')
  final String? language;
  static const fromJsonFactory = _$GenreFromJson;
  static const toJsonFactory = _$GenreToJson;
  Map<String, dynamic> toJson() => _$GenreToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Genre &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.genreTranslations, genreTranslations) ||
                const DeepCollectionEquality()
                    .equals(other.genreTranslations, genreTranslations)) &&
            (identical(other.termIds, termIds) ||
                const DeepCollectionEquality()
                    .equals(other.termIds, termIds)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.language, language) ||
                const DeepCollectionEquality()
                    .equals(other.language, language)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(features) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(genreTranslations) ^
      const DeepCollectionEquality().hash(termIds) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(language) ^
      runtimeType.hashCode;
}

extension $GenreExtension on Genre {
  Genre copyWith(
      {List<Features>? features,
      List<String>? images,
      List<String>? genreTranslations,
      List<TermIds>? termIds,
      String? type,
      String? language}) {
    return Genre(
        features: features ?? this.features,
        images: images ?? this.images,
        genreTranslations: genreTranslations ?? this.genreTranslations,
        termIds: termIds ?? this.termIds,
        type: type ?? this.type,
        language: language ?? this.language);
  }

  Genre copyWithWrapped(
      {Wrapped<List<Features>?>? features,
      Wrapped<List<String>?>? images,
      Wrapped<List<String>?>? genreTranslations,
      Wrapped<List<TermIds>?>? termIds,
      Wrapped<String?>? type,
      Wrapped<String?>? language}) {
    return Genre(
        features: (features != null ? features.value : this.features),
        images: (images != null ? images.value : this.images),
        genreTranslations: (genreTranslations != null
            ? genreTranslations.value
            : this.genreTranslations),
        termIds: (termIds != null ? termIds.value : this.termIds),
        type: (type != null ? type.value : this.type),
        language: (language != null ? language.value : this.language));
  }
}

@JsonSerializable(explicitToJson: true)
class TermIds {
  TermIds({
    this.termIds,
  });

  factory TermIds.fromJson(Map<String, dynamic> json) =>
      _$TermIdsFromJson(json);

  @JsonKey(name: 'termIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? termIds;
  static const fromJsonFactory = _$TermIdsFromJson;
  static const toJsonFactory = _$TermIdsToJson;
  Map<String, dynamic> toJson() => _$TermIdsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TermIds &&
            (identical(other.termIds, termIds) ||
                const DeepCollectionEquality().equals(other.termIds, termIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(termIds) ^ runtimeType.hashCode;
}

extension $TermIdsExtension on TermIds {
  TermIds copyWith({List<String>? termIds}) {
    return TermIds(termIds: termIds ?? this.termIds);
  }

  TermIds copyWithWrapped({Wrapped<List<String>?>? termIds}) {
    return TermIds(termIds: (termIds != null ? termIds.value : this.termIds));
  }
}

@JsonSerializable(explicitToJson: true)
class GenreV2Result {
  GenreV2Result({
    this.image,
    this.name,
    this.termIds,
    this.features,
  });

  factory GenreV2Result.fromJson(Map<String, dynamic> json) =>
      _$GenreV2ResultFromJson(json);

  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'termIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? termIds;
  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$GenreV2ResultFromJson;
  static const toJsonFactory = _$GenreV2ResultToJson;
  Map<String, dynamic> toJson() => _$GenreV2ResultToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GenreV2Result &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.termIds, termIds) ||
                const DeepCollectionEquality()
                    .equals(other.termIds, termIds)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(termIds) ^
      const DeepCollectionEquality().hash(features) ^
      runtimeType.hashCode;
}

extension $GenreV2ResultExtension on GenreV2Result {
  GenreV2Result copyWith(
      {String? image,
      String? name,
      List<String>? termIds,
      List<String>? features}) {
    return GenreV2Result(
        image: image ?? this.image,
        name: name ?? this.name,
        termIds: termIds ?? this.termIds,
        features: features ?? this.features);
  }

  GenreV2Result copyWithWrapped(
      {Wrapped<String?>? image,
      Wrapped<String?>? name,
      Wrapped<List<String>?>? termIds,
      Wrapped<List<String>?>? features}) {
    return GenreV2Result(
        image: (image != null ? image.value : this.image),
        name: (name != null ? name.value : this.name),
        termIds: (termIds != null ? termIds.value : this.termIds),
        features: (features != null ? features.value : this.features));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsCustomerRequest {
  CpsCustomerRequest({
    this.customerId,
    this.assignedDevices,
    this.customerStatus,
    this.countryId,
    this.cityId,
    this.pin,
    this.disableAdvancedAdvertising,
    this.advancedAdvertisingMode,
  });

  factory CpsCustomerRequest.fromJson(Map<String, dynamic> json) =>
      _$CpsCustomerRequestFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'assignedDevices',
      includeIfNull: false,
      defaultValue: <CpsDeviceRequest>[])
  final List<CpsDeviceRequest>? assignedDevices;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: cpsCustomerRequestCustomerStatusToJson,
    fromJson: cpsCustomerRequestCustomerStatusFromJson,
  )
  final enums.CpsCustomerRequestCustomerStatus? customerStatus;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  @JsonKey(name: 'disableAdvancedAdvertising', includeIfNull: false)
  final bool? disableAdvancedAdvertising;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  static const fromJsonFactory = _$CpsCustomerRequestFromJson;
  static const toJsonFactory = _$CpsCustomerRequestToJson;
  Map<String, dynamic> toJson() => _$CpsCustomerRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsCustomerRequest &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising) ||
                const DeepCollectionEquality().equals(
                    other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(disableAdvancedAdvertising) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      runtimeType.hashCode;
}

extension $CpsCustomerRequestExtension on CpsCustomerRequest {
  CpsCustomerRequest copyWith(
      {String? customerId,
      List<CpsDeviceRequest>? assignedDevices,
      enums.CpsCustomerRequestCustomerStatus? customerStatus,
      String? countryId,
      int? cityId,
      String? pin,
      bool? disableAdvancedAdvertising,
      String? advancedAdvertisingMode}) {
    return CpsCustomerRequest(
        customerId: customerId ?? this.customerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        customerStatus: customerStatus ?? this.customerStatus,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        pin: pin ?? this.pin,
        disableAdvancedAdvertising:
            disableAdvancedAdvertising ?? this.disableAdvancedAdvertising,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode);
  }

  CpsCustomerRequest copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<List<CpsDeviceRequest>?>? assignedDevices,
      Wrapped<enums.CpsCustomerRequestCustomerStatus?>? customerStatus,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<String?>? pin,
      Wrapped<bool?>? disableAdvancedAdvertising,
      Wrapped<String?>? advancedAdvertisingMode}) {
    return CpsCustomerRequest(
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        pin: (pin != null ? pin.value : this.pin),
        disableAdvancedAdvertising: (disableAdvancedAdvertising != null
            ? disableAdvancedAdvertising.value
            : this.disableAdvancedAdvertising),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsDeviceRequest {
  CpsDeviceRequest({
    this.deviceType,
    this.smartCardId,
    this.serialNumber,
    this.deviceId,
    this.platformType,
  });

  factory CpsDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$CpsDeviceRequestFromJson(json);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  static const fromJsonFactory = _$CpsDeviceRequestFromJson;
  static const toJsonFactory = _$CpsDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$CpsDeviceRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsDeviceRequest &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(platformType) ^
      runtimeType.hashCode;
}

extension $CpsDeviceRequestExtension on CpsDeviceRequest {
  CpsDeviceRequest copyWith(
      {String? deviceType,
      String? smartCardId,
      String? serialNumber,
      String? deviceId,
      String? platformType}) {
    return CpsDeviceRequest(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        platformType: platformType ?? this.platformType);
  }

  CpsDeviceRequest copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? platformType}) {
    return CpsDeviceRequest(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        platformType:
            (platformType != null ? platformType.value : this.platformType));
  }
}

@JsonSerializable(explicitToJson: true)
class Customer {
  Customer({
    this.lastModified,
    this.customerOptIns,
    this.profiles,
    this.customerId,
    this.assignedDevices,
    this.ottDevices,
    this.customerStatus,
    this.autoDeleteFunction,
    this.deleteRecordingReminder,
    this.recordingRetentionPeriod,
    this.countryId,
    this.cityId,
    this.lockedChannels,
    this.pin,
    this.defaultHhStb,
    this.statusModifiedDate,
    this.ageLock,
    this.deleteRecordingReminderModifiedAt,
    this.dvrPrePadding,
    this.dvrPostPadding,
    this.isFtiPassed,
    this.recordingRetentionPeriodModifiedAt,
    this.autoDeleteFunctionModifiedAt,
  });

  factory Customer.fromJson(Map<String, dynamic> json) =>
      _$CustomerFromJson(json);

  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(
      name: 'customerOptIns',
      includeIfNull: false,
      defaultValue: <CustomerOptIn>[])
  final List<CustomerOptIn>? customerOptIns;
  @JsonKey(name: 'profiles', includeIfNull: false, defaultValue: <Profile>[])
  final List<Profile>? profiles;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'assignedDevices', includeIfNull: false, defaultValue: <Device>[])
  final List<Device>? assignedDevices;
  @JsonKey(
      name: 'ottDevices',
      includeIfNull: false,
      defaultValue: <CustomerOttDevice>[])
  final List<CustomerOttDevice>? ottDevices;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: customerCustomerStatusToJson,
    fromJson: customerCustomerStatusFromJson,
  )
  final enums.CustomerCustomerStatus? customerStatus;
  @JsonKey(name: 'autoDeleteFunction', includeIfNull: false)
  final bool? autoDeleteFunction;
  @JsonKey(name: 'deleteRecordingReminder', includeIfNull: false)
  final bool? deleteRecordingReminder;
  @JsonKey(name: 'recordingRetentionPeriod', includeIfNull: false)
  final int? recordingRetentionPeriod;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(
      name: 'lockedChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? lockedChannels;
  @JsonKey(name: 'pin', includeIfNull: false, defaultValue: '')
  final String? pin;
  @JsonKey(name: 'defaultHhStb', includeIfNull: false, defaultValue: '')
  final String? defaultHhStb;
  @JsonKey(name: 'statusModifiedDate', includeIfNull: false)
  final DateTime? statusModifiedDate;
  @JsonKey(name: 'ageLock', includeIfNull: false)
  final int? ageLock;
  @JsonKey(name: 'deleteRecordingReminderModifiedAt', includeIfNull: false)
  final DateTime? deleteRecordingReminderModifiedAt;
  @JsonKey(name: 'dvrPrePadding', includeIfNull: false)
  final int? dvrPrePadding;
  @JsonKey(name: 'dvrPostPadding', includeIfNull: false)
  final int? dvrPostPadding;
  @JsonKey(name: 'isFtiPassed', includeIfNull: false)
  final bool? isFtiPassed;
  @JsonKey(name: 'recordingRetentionPeriodModifiedAt', includeIfNull: false)
  final DateTime? recordingRetentionPeriodModifiedAt;
  @JsonKey(name: 'autoDeleteFunctionModifiedAt', includeIfNull: false)
  final DateTime? autoDeleteFunctionModifiedAt;
  static const fromJsonFactory = _$CustomerFromJson;
  static const toJsonFactory = _$CustomerToJson;
  Map<String, dynamic> toJson() => _$CustomerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Customer &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.customerOptIns, customerOptIns) ||
                const DeepCollectionEquality()
                    .equals(other.customerOptIns, customerOptIns)) &&
            (identical(other.profiles, profiles) ||
                const DeepCollectionEquality()
                    .equals(other.profiles, profiles)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.ottDevices, ottDevices) ||
                const DeepCollectionEquality()
                    .equals(other.ottDevices, ottDevices)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.autoDeleteFunction, autoDeleteFunction) ||
                const DeepCollectionEquality()
                    .equals(other.autoDeleteFunction, autoDeleteFunction)) &&
            (identical(other.deleteRecordingReminder, deleteRecordingReminder) ||
                const DeepCollectionEquality().equals(
                    other.deleteRecordingReminder, deleteRecordingReminder)) &&
            (identical(other.recordingRetentionPeriod, recordingRetentionPeriod) ||
                const DeepCollectionEquality().equals(
                    other.recordingRetentionPeriod,
                    recordingRetentionPeriod)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.lockedChannels, lockedChannels) ||
                const DeepCollectionEquality()
                    .equals(other.lockedChannels, lockedChannels)) &&
            (identical(other.pin, pin) ||
                const DeepCollectionEquality().equals(other.pin, pin)) &&
            (identical(other.defaultHhStb, defaultHhStb) ||
                const DeepCollectionEquality()
                    .equals(other.defaultHhStb, defaultHhStb)) &&
            (identical(other.statusModifiedDate, statusModifiedDate) ||
                const DeepCollectionEquality()
                    .equals(other.statusModifiedDate, statusModifiedDate)) &&
            (identical(other.ageLock, ageLock) ||
                const DeepCollectionEquality()
                    .equals(other.ageLock, ageLock)) &&
            (identical(other.deleteRecordingReminderModifiedAt, deleteRecordingReminderModifiedAt) ||
                const DeepCollectionEquality().equals(other.deleteRecordingReminderModifiedAt, deleteRecordingReminderModifiedAt)) &&
            (identical(other.dvrPrePadding, dvrPrePadding) || const DeepCollectionEquality().equals(other.dvrPrePadding, dvrPrePadding)) &&
            (identical(other.dvrPostPadding, dvrPostPadding) || const DeepCollectionEquality().equals(other.dvrPostPadding, dvrPostPadding)) &&
            (identical(other.isFtiPassed, isFtiPassed) || const DeepCollectionEquality().equals(other.isFtiPassed, isFtiPassed)) &&
            (identical(other.recordingRetentionPeriodModifiedAt, recordingRetentionPeriodModifiedAt) || const DeepCollectionEquality().equals(other.recordingRetentionPeriodModifiedAt, recordingRetentionPeriodModifiedAt)) &&
            (identical(other.autoDeleteFunctionModifiedAt, autoDeleteFunctionModifiedAt) || const DeepCollectionEquality().equals(other.autoDeleteFunctionModifiedAt, autoDeleteFunctionModifiedAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(customerOptIns) ^
      const DeepCollectionEquality().hash(profiles) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(ottDevices) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(autoDeleteFunction) ^
      const DeepCollectionEquality().hash(deleteRecordingReminder) ^
      const DeepCollectionEquality().hash(recordingRetentionPeriod) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(lockedChannels) ^
      const DeepCollectionEquality().hash(pin) ^
      const DeepCollectionEquality().hash(defaultHhStb) ^
      const DeepCollectionEquality().hash(statusModifiedDate) ^
      const DeepCollectionEquality().hash(ageLock) ^
      const DeepCollectionEquality().hash(deleteRecordingReminderModifiedAt) ^
      const DeepCollectionEquality().hash(dvrPrePadding) ^
      const DeepCollectionEquality().hash(dvrPostPadding) ^
      const DeepCollectionEquality().hash(isFtiPassed) ^
      const DeepCollectionEquality().hash(recordingRetentionPeriodModifiedAt) ^
      const DeepCollectionEquality().hash(autoDeleteFunctionModifiedAt) ^
      runtimeType.hashCode;
}

extension $CustomerExtension on Customer {
  Customer copyWith(
      {DateTime? lastModified,
      List<CustomerOptIn>? customerOptIns,
      List<Profile>? profiles,
      String? customerId,
      List<Device>? assignedDevices,
      List<CustomerOttDevice>? ottDevices,
      enums.CustomerCustomerStatus? customerStatus,
      bool? autoDeleteFunction,
      bool? deleteRecordingReminder,
      int? recordingRetentionPeriod,
      String? countryId,
      int? cityId,
      List<String>? lockedChannels,
      String? pin,
      String? defaultHhStb,
      DateTime? statusModifiedDate,
      int? ageLock,
      DateTime? deleteRecordingReminderModifiedAt,
      int? dvrPrePadding,
      int? dvrPostPadding,
      bool? isFtiPassed,
      DateTime? recordingRetentionPeriodModifiedAt,
      DateTime? autoDeleteFunctionModifiedAt}) {
    return Customer(
        lastModified: lastModified ?? this.lastModified,
        customerOptIns: customerOptIns ?? this.customerOptIns,
        profiles: profiles ?? this.profiles,
        customerId: customerId ?? this.customerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        ottDevices: ottDevices ?? this.ottDevices,
        customerStatus: customerStatus ?? this.customerStatus,
        autoDeleteFunction: autoDeleteFunction ?? this.autoDeleteFunction,
        deleteRecordingReminder:
            deleteRecordingReminder ?? this.deleteRecordingReminder,
        recordingRetentionPeriod:
            recordingRetentionPeriod ?? this.recordingRetentionPeriod,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        lockedChannels: lockedChannels ?? this.lockedChannels,
        pin: pin ?? this.pin,
        defaultHhStb: defaultHhStb ?? this.defaultHhStb,
        statusModifiedDate: statusModifiedDate ?? this.statusModifiedDate,
        ageLock: ageLock ?? this.ageLock,
        deleteRecordingReminderModifiedAt: deleteRecordingReminderModifiedAt ??
            this.deleteRecordingReminderModifiedAt,
        dvrPrePadding: dvrPrePadding ?? this.dvrPrePadding,
        dvrPostPadding: dvrPostPadding ?? this.dvrPostPadding,
        isFtiPassed: isFtiPassed ?? this.isFtiPassed,
        recordingRetentionPeriodModifiedAt:
            recordingRetentionPeriodModifiedAt ??
                this.recordingRetentionPeriodModifiedAt,
        autoDeleteFunctionModifiedAt:
            autoDeleteFunctionModifiedAt ?? this.autoDeleteFunctionModifiedAt);
  }

  Customer copyWithWrapped(
      {Wrapped<DateTime?>? lastModified,
      Wrapped<List<CustomerOptIn>?>? customerOptIns,
      Wrapped<List<Profile>?>? profiles,
      Wrapped<String?>? customerId,
      Wrapped<List<Device>?>? assignedDevices,
      Wrapped<List<CustomerOttDevice>?>? ottDevices,
      Wrapped<enums.CustomerCustomerStatus?>? customerStatus,
      Wrapped<bool?>? autoDeleteFunction,
      Wrapped<bool?>? deleteRecordingReminder,
      Wrapped<int?>? recordingRetentionPeriod,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<List<String>?>? lockedChannels,
      Wrapped<String?>? pin,
      Wrapped<String?>? defaultHhStb,
      Wrapped<DateTime?>? statusModifiedDate,
      Wrapped<int?>? ageLock,
      Wrapped<DateTime?>? deleteRecordingReminderModifiedAt,
      Wrapped<int?>? dvrPrePadding,
      Wrapped<int?>? dvrPostPadding,
      Wrapped<bool?>? isFtiPassed,
      Wrapped<DateTime?>? recordingRetentionPeriodModifiedAt,
      Wrapped<DateTime?>? autoDeleteFunctionModifiedAt}) {
    return Customer(
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        customerOptIns: (customerOptIns != null
            ? customerOptIns.value
            : this.customerOptIns),
        profiles: (profiles != null ? profiles.value : this.profiles),
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        ottDevices: (ottDevices != null ? ottDevices.value : this.ottDevices),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        autoDeleteFunction: (autoDeleteFunction != null
            ? autoDeleteFunction.value
            : this.autoDeleteFunction),
        deleteRecordingReminder: (deleteRecordingReminder != null
            ? deleteRecordingReminder.value
            : this.deleteRecordingReminder),
        recordingRetentionPeriod: (recordingRetentionPeriod != null
            ? recordingRetentionPeriod.value
            : this.recordingRetentionPeriod),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        lockedChannels: (lockedChannels != null
            ? lockedChannels.value
            : this.lockedChannels),
        pin: (pin != null ? pin.value : this.pin),
        defaultHhStb:
            (defaultHhStb != null ? defaultHhStb.value : this.defaultHhStb),
        statusModifiedDate: (statusModifiedDate != null
            ? statusModifiedDate.value
            : this.statusModifiedDate),
        ageLock: (ageLock != null ? ageLock.value : this.ageLock),
        deleteRecordingReminderModifiedAt:
            (deleteRecordingReminderModifiedAt != null
                ? deleteRecordingReminderModifiedAt.value
                : this.deleteRecordingReminderModifiedAt),
        dvrPrePadding:
            (dvrPrePadding != null ? dvrPrePadding.value : this.dvrPrePadding),
        dvrPostPadding: (dvrPostPadding != null
            ? dvrPostPadding.value
            : this.dvrPostPadding),
        isFtiPassed:
            (isFtiPassed != null ? isFtiPassed.value : this.isFtiPassed),
        recordingRetentionPeriodModifiedAt:
            (recordingRetentionPeriodModifiedAt != null
                ? recordingRetentionPeriodModifiedAt.value
                : this.recordingRetentionPeriodModifiedAt),
        autoDeleteFunctionModifiedAt: (autoDeleteFunctionModifiedAt != null
            ? autoDeleteFunctionModifiedAt.value
            : this.autoDeleteFunctionModifiedAt));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerOptIn {
  CustomerOptIn({
    this.lastModified,
    this.termsAndConditionsVersion,
    this.enabled,
    this.optInType,
  });

  factory CustomerOptIn.fromJson(Map<String, dynamic> json) =>
      _$CustomerOptInFromJson(json);

  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(
      name: 'termsAndConditionsVersion', includeIfNull: false, defaultValue: '')
  final String? termsAndConditionsVersion;
  @JsonKey(name: 'enabled', includeIfNull: false)
  final bool? enabled;
  @JsonKey(name: 'optInType', includeIfNull: false, defaultValue: '')
  final String? optInType;
  static const fromJsonFactory = _$CustomerOptInFromJson;
  static const toJsonFactory = _$CustomerOptInToJson;
  Map<String, dynamic> toJson() => _$CustomerOptInToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerOptIn &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.termsAndConditionsVersion,
                    termsAndConditionsVersion) ||
                const DeepCollectionEquality().equals(
                    other.termsAndConditionsVersion,
                    termsAndConditionsVersion)) &&
            (identical(other.enabled, enabled) ||
                const DeepCollectionEquality()
                    .equals(other.enabled, enabled)) &&
            (identical(other.optInType, optInType) ||
                const DeepCollectionEquality()
                    .equals(other.optInType, optInType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(termsAndConditionsVersion) ^
      const DeepCollectionEquality().hash(enabled) ^
      const DeepCollectionEquality().hash(optInType) ^
      runtimeType.hashCode;
}

extension $CustomerOptInExtension on CustomerOptIn {
  CustomerOptIn copyWith(
      {DateTime? lastModified,
      String? termsAndConditionsVersion,
      bool? enabled,
      String? optInType}) {
    return CustomerOptIn(
        lastModified: lastModified ?? this.lastModified,
        termsAndConditionsVersion:
            termsAndConditionsVersion ?? this.termsAndConditionsVersion,
        enabled: enabled ?? this.enabled,
        optInType: optInType ?? this.optInType);
  }

  CustomerOptIn copyWithWrapped(
      {Wrapped<DateTime?>? lastModified,
      Wrapped<String?>? termsAndConditionsVersion,
      Wrapped<bool?>? enabled,
      Wrapped<String?>? optInType}) {
    return CustomerOptIn(
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        termsAndConditionsVersion: (termsAndConditionsVersion != null
            ? termsAndConditionsVersion.value
            : this.termsAndConditionsVersion),
        enabled: (enabled != null ? enabled.value : this.enabled),
        optInType: (optInType != null ? optInType.value : this.optInType));
  }
}

@JsonSerializable(explicitToJson: true)
class Device {
  Device({
    this.deviceType,
    this.smartCardId,
    this.lastModified,
    this.serialNumber,
    this.deviceId,
    this.customerId,
    this.wifiMacAddress,
    this.ethernetMacAddress,
    this.platformType,
    this.defaultProfileId,
    this.capabilities,
    this.settings,
  });

  factory Device.fromJson(Map<String, dynamic> json) => _$DeviceFromJson(json);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'wifiMacAddress', includeIfNull: false, defaultValue: '')
  final String? wifiMacAddress;
  @JsonKey(name: 'ethernetMacAddress', includeIfNull: false, defaultValue: '')
  final String? ethernetMacAddress;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  @JsonKey(name: 'defaultProfileId', includeIfNull: false, defaultValue: '')
  final String? defaultProfileId;
  @JsonKey(name: 'capabilities', includeIfNull: false)
  final DeviceCapabilities? capabilities;
  @JsonKey(name: 'settings', includeIfNull: false)
  final DeviceSettings? settings;
  static const fromJsonFactory = _$DeviceFromJson;
  static const toJsonFactory = _$DeviceToJson;
  Map<String, dynamic> toJson() => _$DeviceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Device &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.wifiMacAddress, wifiMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.wifiMacAddress, wifiMacAddress)) &&
            (identical(other.ethernetMacAddress, ethernetMacAddress) ||
                const DeepCollectionEquality()
                    .equals(other.ethernetMacAddress, ethernetMacAddress)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)) &&
            (identical(other.defaultProfileId, defaultProfileId) ||
                const DeepCollectionEquality()
                    .equals(other.defaultProfileId, defaultProfileId)) &&
            (identical(other.capabilities, capabilities) ||
                const DeepCollectionEquality()
                    .equals(other.capabilities, capabilities)) &&
            (identical(other.settings, settings) ||
                const DeepCollectionEquality()
                    .equals(other.settings, settings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(wifiMacAddress) ^
      const DeepCollectionEquality().hash(ethernetMacAddress) ^
      const DeepCollectionEquality().hash(platformType) ^
      const DeepCollectionEquality().hash(defaultProfileId) ^
      const DeepCollectionEquality().hash(capabilities) ^
      const DeepCollectionEquality().hash(settings) ^
      runtimeType.hashCode;
}

extension $DeviceExtension on Device {
  Device copyWith(
      {String? deviceType,
      String? smartCardId,
      DateTime? lastModified,
      String? serialNumber,
      String? deviceId,
      String? customerId,
      String? wifiMacAddress,
      String? ethernetMacAddress,
      String? platformType,
      String? defaultProfileId,
      DeviceCapabilities? capabilities,
      DeviceSettings? settings}) {
    return Device(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        lastModified: lastModified ?? this.lastModified,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        customerId: customerId ?? this.customerId,
        wifiMacAddress: wifiMacAddress ?? this.wifiMacAddress,
        ethernetMacAddress: ethernetMacAddress ?? this.ethernetMacAddress,
        platformType: platformType ?? this.platformType,
        defaultProfileId: defaultProfileId ?? this.defaultProfileId,
        capabilities: capabilities ?? this.capabilities,
        settings: settings ?? this.settings);
  }

  Device copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<DateTime?>? lastModified,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? customerId,
      Wrapped<String?>? wifiMacAddress,
      Wrapped<String?>? ethernetMacAddress,
      Wrapped<String?>? platformType,
      Wrapped<String?>? defaultProfileId,
      Wrapped<DeviceCapabilities?>? capabilities,
      Wrapped<DeviceSettings?>? settings}) {
    return Device(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        customerId: (customerId != null ? customerId.value : this.customerId),
        wifiMacAddress: (wifiMacAddress != null
            ? wifiMacAddress.value
            : this.wifiMacAddress),
        ethernetMacAddress: (ethernetMacAddress != null
            ? ethernetMacAddress.value
            : this.ethernetMacAddress),
        platformType:
            (platformType != null ? platformType.value : this.platformType),
        defaultProfileId: (defaultProfileId != null
            ? defaultProfileId.value
            : this.defaultProfileId),
        capabilities:
            (capabilities != null ? capabilities.value : this.capabilities),
        settings: (settings != null ? settings.value : this.settings));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceCapabilities {
  DeviceCapabilities({
    this.hasHDD,
    this.maxRes,
  });

  factory DeviceCapabilities.fromJson(Map<String, dynamic> json) =>
      _$DeviceCapabilitiesFromJson(json);

  @JsonKey(name: 'hasHDD', includeIfNull: false)
  final bool? hasHDD;
  @JsonKey(name: 'maxRes', includeIfNull: false, defaultValue: '')
  final String? maxRes;
  static const fromJsonFactory = _$DeviceCapabilitiesFromJson;
  static const toJsonFactory = _$DeviceCapabilitiesToJson;
  Map<String, dynamic> toJson() => _$DeviceCapabilitiesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceCapabilities &&
            (identical(other.hasHDD, hasHDD) ||
                const DeepCollectionEquality().equals(other.hasHDD, hasHDD)) &&
            (identical(other.maxRes, maxRes) ||
                const DeepCollectionEquality().equals(other.maxRes, maxRes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(hasHDD) ^
      const DeepCollectionEquality().hash(maxRes) ^
      runtimeType.hashCode;
}

extension $DeviceCapabilitiesExtension on DeviceCapabilities {
  DeviceCapabilities copyWith({bool? hasHDD, String? maxRes}) {
    return DeviceCapabilities(
        hasHDD: hasHDD ?? this.hasHDD, maxRes: maxRes ?? this.maxRes);
  }

  DeviceCapabilities copyWithWrapped(
      {Wrapped<bool?>? hasHDD, Wrapped<String?>? maxRes}) {
    return DeviceCapabilities(
        hasHDD: (hasHDD != null ? hasHDD.value : this.hasHDD),
        maxRes: (maxRes != null ? maxRes.value : this.maxRes));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceSettings {
  DeviceSettings({
    this.autoStandby,
    this.standbyMode,
    this.aspectRatio,
    this.isDataAnonymized,
    this.privacyLevel,
    this.hdmiResolution,
    this.isAudioDolbyDigital,
    this.sdtvDisplayMode,
    this.widescreenDisplayMode,
    this.volume,
    this.primaryVideoOutput,
    this.isDeepStandby,
    this.customData,
    this.ccDigitalService,
    this.ccAnalogService,
    this.audioDelay,
    this.dolbyDigital,
    this.isPurchasePinActive,
    this.isParentalControlPinActive,
    this.prePadding,
    this.postPadding,
    this.prePaddingModifiedAt,
    this.postPaddingModifiedAt,
    this.deviceFriendlyNameModifiedAt,
    this.hdmiColorOutput,
    this.deviceFriendlyName,
    this.isCecEnabled,
    this.isTvAutoStartup,
    this.oneTouchViewTurnOffPolicy,
    this.ccsMessages,
  });

  factory DeviceSettings.fromJson(Map<String, dynamic> json) =>
      _$DeviceSettingsFromJson(json);

  @JsonKey(name: 'autoStandby', includeIfNull: false)
  final int? autoStandby;
  @JsonKey(name: 'standbyMode', includeIfNull: false, defaultValue: '')
  final String? standbyMode;
  @JsonKey(name: 'aspectRatio', includeIfNull: false, defaultValue: '')
  final String? aspectRatio;
  @JsonKey(name: 'isDataAnonymized', includeIfNull: false)
  final bool? isDataAnonymized;
  @JsonKey(name: 'privacyLevel', includeIfNull: false, defaultValue: '')
  final String? privacyLevel;
  @JsonKey(name: 'hdmiResolution', includeIfNull: false, defaultValue: '')
  final String? hdmiResolution;
  @JsonKey(name: 'isAudioDolbyDigital', includeIfNull: false)
  final bool? isAudioDolbyDigital;
  @JsonKey(name: 'sdtvDisplayMode', includeIfNull: false, defaultValue: '')
  final String? sdtvDisplayMode;
  @JsonKey(
      name: 'widescreenDisplayMode', includeIfNull: false, defaultValue: '')
  final String? widescreenDisplayMode;
  @JsonKey(name: 'volume', includeIfNull: false)
  final int? volume;
  @JsonKey(name: 'primaryVideoOutput', includeIfNull: false, defaultValue: '')
  final String? primaryVideoOutput;
  @JsonKey(name: 'isDeepStandby', includeIfNull: false)
  final bool? isDeepStandby;
  @JsonKey(name: 'customData', includeIfNull: false, defaultValue: '')
  final String? customData;
  @JsonKey(
    name: 'ccDigitalService',
    includeIfNull: false,
    toJson: deviceSettingsCcDigitalServiceToJson,
    fromJson: deviceSettingsCcDigitalServiceFromJson,
  )
  final enums.DeviceSettingsCcDigitalService? ccDigitalService;
  @JsonKey(
    name: 'ccAnalogService',
    includeIfNull: false,
    toJson: deviceSettingsCcAnalogServiceToJson,
    fromJson: deviceSettingsCcAnalogServiceFromJson,
  )
  final enums.DeviceSettingsCcAnalogService? ccAnalogService;
  @JsonKey(name: 'audioDelay', includeIfNull: false)
  final int? audioDelay;
  @JsonKey(name: 'dolbyDigital', includeIfNull: false, defaultValue: '')
  final String? dolbyDigital;
  @JsonKey(name: 'isPurchasePinActive', includeIfNull: false)
  final bool? isPurchasePinActive;
  @JsonKey(name: 'isParentalControlPinActive', includeIfNull: false)
  final bool? isParentalControlPinActive;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(name: 'prePaddingModifiedAt', includeIfNull: false)
  final DateTime? prePaddingModifiedAt;
  @JsonKey(name: 'postPaddingModifiedAt', includeIfNull: false)
  final DateTime? postPaddingModifiedAt;
  @JsonKey(name: 'deviceFriendlyNameModifiedAt', includeIfNull: false)
  final DateTime? deviceFriendlyNameModifiedAt;
  @JsonKey(name: 'hdmiColorOutput', includeIfNull: false, defaultValue: '')
  final String? hdmiColorOutput;
  @JsonKey(name: 'deviceFriendlyName', includeIfNull: false, defaultValue: '')
  final String? deviceFriendlyName;
  @JsonKey(name: 'isCecEnabled', includeIfNull: false)
  final bool? isCecEnabled;
  @JsonKey(name: 'isTvAutoStartup', includeIfNull: false)
  final bool? isTvAutoStartup;
  @JsonKey(name: 'oneTouchViewTurnOffPolicy', includeIfNull: false)
  final bool? oneTouchViewTurnOffPolicy;
  @JsonKey(name: 'ccsMessages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? ccsMessages;
  static const fromJsonFactory = _$DeviceSettingsFromJson;
  static const toJsonFactory = _$DeviceSettingsToJson;
  Map<String, dynamic> toJson() => _$DeviceSettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceSettings &&
            (identical(other.autoStandby, autoStandby) ||
                const DeepCollectionEquality()
                    .equals(other.autoStandby, autoStandby)) &&
            (identical(other.standbyMode, standbyMode) ||
                const DeepCollectionEquality()
                    .equals(other.standbyMode, standbyMode)) &&
            (identical(other.aspectRatio, aspectRatio) ||
                const DeepCollectionEquality()
                    .equals(other.aspectRatio, aspectRatio)) &&
            (identical(other.isDataAnonymized, isDataAnonymized) ||
                const DeepCollectionEquality()
                    .equals(other.isDataAnonymized, isDataAnonymized)) &&
            (identical(other.privacyLevel, privacyLevel) ||
                const DeepCollectionEquality()
                    .equals(other.privacyLevel, privacyLevel)) &&
            (identical(other.hdmiResolution, hdmiResolution) ||
                const DeepCollectionEquality()
                    .equals(other.hdmiResolution, hdmiResolution)) &&
            (identical(other.isAudioDolbyDigital, isAudioDolbyDigital) ||
                const DeepCollectionEquality()
                    .equals(other.isAudioDolbyDigital, isAudioDolbyDigital)) &&
            (identical(other.sdtvDisplayMode, sdtvDisplayMode) ||
                const DeepCollectionEquality()
                    .equals(other.sdtvDisplayMode, sdtvDisplayMode)) &&
            (identical(other.widescreenDisplayMode, widescreenDisplayMode) ||
                const DeepCollectionEquality().equals(
                    other.widescreenDisplayMode, widescreenDisplayMode)) &&
            (identical(other.volume, volume) ||
                const DeepCollectionEquality().equals(other.volume, volume)) &&
            (identical(other.primaryVideoOutput, primaryVideoOutput) ||
                const DeepCollectionEquality()
                    .equals(other.primaryVideoOutput, primaryVideoOutput)) &&
            (identical(other.isDeepStandby, isDeepStandby) ||
                const DeepCollectionEquality()
                    .equals(other.isDeepStandby, isDeepStandby)) &&
            (identical(other.customData, customData) ||
                const DeepCollectionEquality()
                    .equals(other.customData, customData)) &&
            (identical(other.ccDigitalService, ccDigitalService) ||
                const DeepCollectionEquality()
                    .equals(other.ccDigitalService, ccDigitalService)) &&
            (identical(other.ccAnalogService, ccAnalogService) ||
                const DeepCollectionEquality()
                    .equals(other.ccAnalogService, ccAnalogService)) &&
            (identical(other.audioDelay, audioDelay) ||
                const DeepCollectionEquality()
                    .equals(other.audioDelay, audioDelay)) &&
            (identical(other.dolbyDigital, dolbyDigital) ||
                const DeepCollectionEquality()
                    .equals(other.dolbyDigital, dolbyDigital)) &&
            (identical(other.isPurchasePinActive, isPurchasePinActive) ||
                const DeepCollectionEquality()
                    .equals(other.isPurchasePinActive, isPurchasePinActive)) &&
            (identical(other.isParentalControlPinActive, isParentalControlPinActive) ||
                const DeepCollectionEquality().equals(
                    other.isParentalControlPinActive,
                    isParentalControlPinActive)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.prePaddingModifiedAt, prePaddingModifiedAt) || const DeepCollectionEquality().equals(other.prePaddingModifiedAt, prePaddingModifiedAt)) &&
            (identical(other.postPaddingModifiedAt, postPaddingModifiedAt) || const DeepCollectionEquality().equals(other.postPaddingModifiedAt, postPaddingModifiedAt)) &&
            (identical(other.deviceFriendlyNameModifiedAt, deviceFriendlyNameModifiedAt) || const DeepCollectionEquality().equals(other.deviceFriendlyNameModifiedAt, deviceFriendlyNameModifiedAt)) &&
            (identical(other.hdmiColorOutput, hdmiColorOutput) || const DeepCollectionEquality().equals(other.hdmiColorOutput, hdmiColorOutput)) &&
            (identical(other.deviceFriendlyName, deviceFriendlyName) || const DeepCollectionEquality().equals(other.deviceFriendlyName, deviceFriendlyName)) &&
            (identical(other.isCecEnabled, isCecEnabled) || const DeepCollectionEquality().equals(other.isCecEnabled, isCecEnabled)) &&
            (identical(other.isTvAutoStartup, isTvAutoStartup) || const DeepCollectionEquality().equals(other.isTvAutoStartup, isTvAutoStartup)) &&
            (identical(other.oneTouchViewTurnOffPolicy, oneTouchViewTurnOffPolicy) || const DeepCollectionEquality().equals(other.oneTouchViewTurnOffPolicy, oneTouchViewTurnOffPolicy)) &&
            (identical(other.ccsMessages, ccsMessages) || const DeepCollectionEquality().equals(other.ccsMessages, ccsMessages)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(autoStandby) ^
      const DeepCollectionEquality().hash(standbyMode) ^
      const DeepCollectionEquality().hash(aspectRatio) ^
      const DeepCollectionEquality().hash(isDataAnonymized) ^
      const DeepCollectionEquality().hash(privacyLevel) ^
      const DeepCollectionEquality().hash(hdmiResolution) ^
      const DeepCollectionEquality().hash(isAudioDolbyDigital) ^
      const DeepCollectionEquality().hash(sdtvDisplayMode) ^
      const DeepCollectionEquality().hash(widescreenDisplayMode) ^
      const DeepCollectionEquality().hash(volume) ^
      const DeepCollectionEquality().hash(primaryVideoOutput) ^
      const DeepCollectionEquality().hash(isDeepStandby) ^
      const DeepCollectionEquality().hash(customData) ^
      const DeepCollectionEquality().hash(ccDigitalService) ^
      const DeepCollectionEquality().hash(ccAnalogService) ^
      const DeepCollectionEquality().hash(audioDelay) ^
      const DeepCollectionEquality().hash(dolbyDigital) ^
      const DeepCollectionEquality().hash(isPurchasePinActive) ^
      const DeepCollectionEquality().hash(isParentalControlPinActive) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(prePaddingModifiedAt) ^
      const DeepCollectionEquality().hash(postPaddingModifiedAt) ^
      const DeepCollectionEquality().hash(deviceFriendlyNameModifiedAt) ^
      const DeepCollectionEquality().hash(hdmiColorOutput) ^
      const DeepCollectionEquality().hash(deviceFriendlyName) ^
      const DeepCollectionEquality().hash(isCecEnabled) ^
      const DeepCollectionEquality().hash(isTvAutoStartup) ^
      const DeepCollectionEquality().hash(oneTouchViewTurnOffPolicy) ^
      const DeepCollectionEquality().hash(ccsMessages) ^
      runtimeType.hashCode;
}

extension $DeviceSettingsExtension on DeviceSettings {
  DeviceSettings copyWith(
      {int? autoStandby,
      String? standbyMode,
      String? aspectRatio,
      bool? isDataAnonymized,
      String? privacyLevel,
      String? hdmiResolution,
      bool? isAudioDolbyDigital,
      String? sdtvDisplayMode,
      String? widescreenDisplayMode,
      int? volume,
      String? primaryVideoOutput,
      bool? isDeepStandby,
      String? customData,
      enums.DeviceSettingsCcDigitalService? ccDigitalService,
      enums.DeviceSettingsCcAnalogService? ccAnalogService,
      int? audioDelay,
      String? dolbyDigital,
      bool? isPurchasePinActive,
      bool? isParentalControlPinActive,
      int? prePadding,
      int? postPadding,
      DateTime? prePaddingModifiedAt,
      DateTime? postPaddingModifiedAt,
      DateTime? deviceFriendlyNameModifiedAt,
      String? hdmiColorOutput,
      String? deviceFriendlyName,
      bool? isCecEnabled,
      bool? isTvAutoStartup,
      bool? oneTouchViewTurnOffPolicy,
      List<String>? ccsMessages}) {
    return DeviceSettings(
        autoStandby: autoStandby ?? this.autoStandby,
        standbyMode: standbyMode ?? this.standbyMode,
        aspectRatio: aspectRatio ?? this.aspectRatio,
        isDataAnonymized: isDataAnonymized ?? this.isDataAnonymized,
        privacyLevel: privacyLevel ?? this.privacyLevel,
        hdmiResolution: hdmiResolution ?? this.hdmiResolution,
        isAudioDolbyDigital: isAudioDolbyDigital ?? this.isAudioDolbyDigital,
        sdtvDisplayMode: sdtvDisplayMode ?? this.sdtvDisplayMode,
        widescreenDisplayMode:
            widescreenDisplayMode ?? this.widescreenDisplayMode,
        volume: volume ?? this.volume,
        primaryVideoOutput: primaryVideoOutput ?? this.primaryVideoOutput,
        isDeepStandby: isDeepStandby ?? this.isDeepStandby,
        customData: customData ?? this.customData,
        ccDigitalService: ccDigitalService ?? this.ccDigitalService,
        ccAnalogService: ccAnalogService ?? this.ccAnalogService,
        audioDelay: audioDelay ?? this.audioDelay,
        dolbyDigital: dolbyDigital ?? this.dolbyDigital,
        isPurchasePinActive: isPurchasePinActive ?? this.isPurchasePinActive,
        isParentalControlPinActive:
            isParentalControlPinActive ?? this.isParentalControlPinActive,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        prePaddingModifiedAt: prePaddingModifiedAt ?? this.prePaddingModifiedAt,
        postPaddingModifiedAt:
            postPaddingModifiedAt ?? this.postPaddingModifiedAt,
        deviceFriendlyNameModifiedAt:
            deviceFriendlyNameModifiedAt ?? this.deviceFriendlyNameModifiedAt,
        hdmiColorOutput: hdmiColorOutput ?? this.hdmiColorOutput,
        deviceFriendlyName: deviceFriendlyName ?? this.deviceFriendlyName,
        isCecEnabled: isCecEnabled ?? this.isCecEnabled,
        isTvAutoStartup: isTvAutoStartup ?? this.isTvAutoStartup,
        oneTouchViewTurnOffPolicy:
            oneTouchViewTurnOffPolicy ?? this.oneTouchViewTurnOffPolicy,
        ccsMessages: ccsMessages ?? this.ccsMessages);
  }

  DeviceSettings copyWithWrapped(
      {Wrapped<int?>? autoStandby,
      Wrapped<String?>? standbyMode,
      Wrapped<String?>? aspectRatio,
      Wrapped<bool?>? isDataAnonymized,
      Wrapped<String?>? privacyLevel,
      Wrapped<String?>? hdmiResolution,
      Wrapped<bool?>? isAudioDolbyDigital,
      Wrapped<String?>? sdtvDisplayMode,
      Wrapped<String?>? widescreenDisplayMode,
      Wrapped<int?>? volume,
      Wrapped<String?>? primaryVideoOutput,
      Wrapped<bool?>? isDeepStandby,
      Wrapped<String?>? customData,
      Wrapped<enums.DeviceSettingsCcDigitalService?>? ccDigitalService,
      Wrapped<enums.DeviceSettingsCcAnalogService?>? ccAnalogService,
      Wrapped<int?>? audioDelay,
      Wrapped<String?>? dolbyDigital,
      Wrapped<bool?>? isPurchasePinActive,
      Wrapped<bool?>? isParentalControlPinActive,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<DateTime?>? prePaddingModifiedAt,
      Wrapped<DateTime?>? postPaddingModifiedAt,
      Wrapped<DateTime?>? deviceFriendlyNameModifiedAt,
      Wrapped<String?>? hdmiColorOutput,
      Wrapped<String?>? deviceFriendlyName,
      Wrapped<bool?>? isCecEnabled,
      Wrapped<bool?>? isTvAutoStartup,
      Wrapped<bool?>? oneTouchViewTurnOffPolicy,
      Wrapped<List<String>?>? ccsMessages}) {
    return DeviceSettings(
        autoStandby:
            (autoStandby != null ? autoStandby.value : this.autoStandby),
        standbyMode:
            (standbyMode != null ? standbyMode.value : this.standbyMode),
        aspectRatio:
            (aspectRatio != null ? aspectRatio.value : this.aspectRatio),
        isDataAnonymized: (isDataAnonymized != null
            ? isDataAnonymized.value
            : this.isDataAnonymized),
        privacyLevel:
            (privacyLevel != null ? privacyLevel.value : this.privacyLevel),
        hdmiResolution: (hdmiResolution != null
            ? hdmiResolution.value
            : this.hdmiResolution),
        isAudioDolbyDigital: (isAudioDolbyDigital != null
            ? isAudioDolbyDigital.value
            : this.isAudioDolbyDigital),
        sdtvDisplayMode: (sdtvDisplayMode != null
            ? sdtvDisplayMode.value
            : this.sdtvDisplayMode),
        widescreenDisplayMode: (widescreenDisplayMode != null
            ? widescreenDisplayMode.value
            : this.widescreenDisplayMode),
        volume: (volume != null ? volume.value : this.volume),
        primaryVideoOutput: (primaryVideoOutput != null
            ? primaryVideoOutput.value
            : this.primaryVideoOutput),
        isDeepStandby:
            (isDeepStandby != null ? isDeepStandby.value : this.isDeepStandby),
        customData: (customData != null ? customData.value : this.customData),
        ccDigitalService: (ccDigitalService != null
            ? ccDigitalService.value
            : this.ccDigitalService),
        ccAnalogService: (ccAnalogService != null
            ? ccAnalogService.value
            : this.ccAnalogService),
        audioDelay: (audioDelay != null ? audioDelay.value : this.audioDelay),
        dolbyDigital:
            (dolbyDigital != null ? dolbyDigital.value : this.dolbyDigital),
        isPurchasePinActive: (isPurchasePinActive != null
            ? isPurchasePinActive.value
            : this.isPurchasePinActive),
        isParentalControlPinActive: (isParentalControlPinActive != null
            ? isParentalControlPinActive.value
            : this.isParentalControlPinActive),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        prePaddingModifiedAt: (prePaddingModifiedAt != null
            ? prePaddingModifiedAt.value
            : this.prePaddingModifiedAt),
        postPaddingModifiedAt: (postPaddingModifiedAt != null
            ? postPaddingModifiedAt.value
            : this.postPaddingModifiedAt),
        deviceFriendlyNameModifiedAt: (deviceFriendlyNameModifiedAt != null
            ? deviceFriendlyNameModifiedAt.value
            : this.deviceFriendlyNameModifiedAt),
        hdmiColorOutput: (hdmiColorOutput != null
            ? hdmiColorOutput.value
            : this.hdmiColorOutput),
        deviceFriendlyName: (deviceFriendlyName != null
            ? deviceFriendlyName.value
            : this.deviceFriendlyName),
        isCecEnabled:
            (isCecEnabled != null ? isCecEnabled.value : this.isCecEnabled),
        isTvAutoStartup: (isTvAutoStartup != null
            ? isTvAutoStartup.value
            : this.isTvAutoStartup),
        oneTouchViewTurnOffPolicy: (oneTouchViewTurnOffPolicy != null
            ? oneTouchViewTurnOffPolicy.value
            : this.oneTouchViewTurnOffPolicy),
        ccsMessages:
            (ccsMessages != null ? ccsMessages.value : this.ccsMessages));
  }
}

@JsonSerializable(explicitToJson: true)
class JsonNode {
  JsonNode({
    this.nodeType,
    this.valueNode,
    this.containerNode,
    this.missingNode,
    this.object,
    this.pojo,
    this.number,
    this.integralNumber,
    this.floatingPointNumber,
    this.short,
    this.$int,
    this.long,
    this.$float,
    this.$double,
    this.bigDecimal,
    this.bigInteger,
    this.textual,
    this.$boolean,
    this.binary,
    this.array,
    this.$null,
  });

  factory JsonNode.fromJson(Map<String, dynamic> json) =>
      _$JsonNodeFromJson(json);

  @JsonKey(
    name: 'nodeType',
    includeIfNull: false,
    toJson: jsonNodeNodeTypeToJson,
    fromJson: jsonNodeNodeTypeFromJson,
  )
  final enums.JsonNodeNodeType? nodeType;
  @JsonKey(name: 'valueNode', includeIfNull: false)
  final bool? valueNode;
  @JsonKey(name: 'containerNode', includeIfNull: false)
  final bool? containerNode;
  @JsonKey(name: 'missingNode', includeIfNull: false)
  final bool? missingNode;
  @JsonKey(name: 'object', includeIfNull: false)
  final bool? object;
  @JsonKey(name: 'pojo', includeIfNull: false)
  final bool? pojo;
  @JsonKey(name: 'number', includeIfNull: false)
  final bool? number;
  @JsonKey(name: 'integralNumber', includeIfNull: false)
  final bool? integralNumber;
  @JsonKey(name: 'floatingPointNumber', includeIfNull: false)
  final bool? floatingPointNumber;
  @JsonKey(name: 'short', includeIfNull: false)
  final bool? short;
  @JsonKey(name: 'int', includeIfNull: false)
  final bool? $int;
  @JsonKey(name: 'long', includeIfNull: false)
  final bool? long;
  @JsonKey(name: 'float', includeIfNull: false)
  final bool? $float;
  @JsonKey(name: 'double', includeIfNull: false)
  final bool? $double;
  @JsonKey(name: 'bigDecimal', includeIfNull: false)
  final bool? bigDecimal;
  @JsonKey(name: 'bigInteger', includeIfNull: false)
  final bool? bigInteger;
  @JsonKey(name: 'textual', includeIfNull: false)
  final bool? textual;
  @JsonKey(name: 'boolean', includeIfNull: false)
  final bool? $boolean;
  @JsonKey(name: 'binary', includeIfNull: false)
  final bool? binary;
  @JsonKey(name: 'array', includeIfNull: false)
  final bool? array;
  @JsonKey(name: 'null', includeIfNull: false)
  final bool? $null;
  static const fromJsonFactory = _$JsonNodeFromJson;
  static const toJsonFactory = _$JsonNodeToJson;
  Map<String, dynamic> toJson() => _$JsonNodeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is JsonNode &&
            (identical(other.nodeType, nodeType) ||
                const DeepCollectionEquality()
                    .equals(other.nodeType, nodeType)) &&
            (identical(other.valueNode, valueNode) ||
                const DeepCollectionEquality()
                    .equals(other.valueNode, valueNode)) &&
            (identical(other.containerNode, containerNode) ||
                const DeepCollectionEquality()
                    .equals(other.containerNode, containerNode)) &&
            (identical(other.missingNode, missingNode) ||
                const DeepCollectionEquality()
                    .equals(other.missingNode, missingNode)) &&
            (identical(other.object, object) ||
                const DeepCollectionEquality().equals(other.object, object)) &&
            (identical(other.pojo, pojo) ||
                const DeepCollectionEquality().equals(other.pojo, pojo)) &&
            (identical(other.number, number) ||
                const DeepCollectionEquality().equals(other.number, number)) &&
            (identical(other.integralNumber, integralNumber) ||
                const DeepCollectionEquality()
                    .equals(other.integralNumber, integralNumber)) &&
            (identical(other.floatingPointNumber, floatingPointNumber) ||
                const DeepCollectionEquality()
                    .equals(other.floatingPointNumber, floatingPointNumber)) &&
            (identical(other.short, short) ||
                const DeepCollectionEquality().equals(other.short, short)) &&
            (identical(other.$int, $int) ||
                const DeepCollectionEquality().equals(other.$int, $int)) &&
            (identical(other.long, long) ||
                const DeepCollectionEquality().equals(other.long, long)) &&
            (identical(other.$float, $float) ||
                const DeepCollectionEquality().equals(other.$float, $float)) &&
            (identical(other.$double, $double) ||
                const DeepCollectionEquality()
                    .equals(other.$double, $double)) &&
            (identical(other.bigDecimal, bigDecimal) ||
                const DeepCollectionEquality()
                    .equals(other.bigDecimal, bigDecimal)) &&
            (identical(other.bigInteger, bigInteger) ||
                const DeepCollectionEquality()
                    .equals(other.bigInteger, bigInteger)) &&
            (identical(other.textual, textual) ||
                const DeepCollectionEquality()
                    .equals(other.textual, textual)) &&
            (identical(other.$boolean, $boolean) ||
                const DeepCollectionEquality()
                    .equals(other.$boolean, $boolean)) &&
            (identical(other.binary, binary) ||
                const DeepCollectionEquality().equals(other.binary, binary)) &&
            (identical(other.array, array) ||
                const DeepCollectionEquality().equals(other.array, array)) &&
            (identical(other.$null, $null) ||
                const DeepCollectionEquality().equals(other.$null, $null)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nodeType) ^
      const DeepCollectionEquality().hash(valueNode) ^
      const DeepCollectionEquality().hash(containerNode) ^
      const DeepCollectionEquality().hash(missingNode) ^
      const DeepCollectionEquality().hash(object) ^
      const DeepCollectionEquality().hash(pojo) ^
      const DeepCollectionEquality().hash(number) ^
      const DeepCollectionEquality().hash(integralNumber) ^
      const DeepCollectionEquality().hash(floatingPointNumber) ^
      const DeepCollectionEquality().hash(short) ^
      const DeepCollectionEquality().hash($int) ^
      const DeepCollectionEquality().hash(long) ^
      const DeepCollectionEquality().hash($float) ^
      const DeepCollectionEquality().hash($double) ^
      const DeepCollectionEquality().hash(bigDecimal) ^
      const DeepCollectionEquality().hash(bigInteger) ^
      const DeepCollectionEquality().hash(textual) ^
      const DeepCollectionEquality().hash($boolean) ^
      const DeepCollectionEquality().hash(binary) ^
      const DeepCollectionEquality().hash(array) ^
      const DeepCollectionEquality().hash($null) ^
      runtimeType.hashCode;
}

extension $JsonNodeExtension on JsonNode {
  JsonNode copyWith(
      {enums.JsonNodeNodeType? nodeType,
      bool? valueNode,
      bool? containerNode,
      bool? missingNode,
      bool? object,
      bool? pojo,
      bool? number,
      bool? integralNumber,
      bool? floatingPointNumber,
      bool? short,
      bool? $int,
      bool? long,
      bool? $float,
      bool? $double,
      bool? bigDecimal,
      bool? bigInteger,
      bool? textual,
      bool? $boolean,
      bool? binary,
      bool? array,
      bool? $null}) {
    return JsonNode(
        nodeType: nodeType ?? this.nodeType,
        valueNode: valueNode ?? this.valueNode,
        containerNode: containerNode ?? this.containerNode,
        missingNode: missingNode ?? this.missingNode,
        object: object ?? this.object,
        pojo: pojo ?? this.pojo,
        number: number ?? this.number,
        integralNumber: integralNumber ?? this.integralNumber,
        floatingPointNumber: floatingPointNumber ?? this.floatingPointNumber,
        short: short ?? this.short,
        $int: $int ?? this.$int,
        long: long ?? this.long,
        $float: $float ?? this.$float,
        $double: $double ?? this.$double,
        bigDecimal: bigDecimal ?? this.bigDecimal,
        bigInteger: bigInteger ?? this.bigInteger,
        textual: textual ?? this.textual,
        $boolean: $boolean ?? this.$boolean,
        binary: binary ?? this.binary,
        array: array ?? this.array,
        $null: $null ?? this.$null);
  }

  JsonNode copyWithWrapped(
      {Wrapped<enums.JsonNodeNodeType?>? nodeType,
      Wrapped<bool?>? valueNode,
      Wrapped<bool?>? containerNode,
      Wrapped<bool?>? missingNode,
      Wrapped<bool?>? object,
      Wrapped<bool?>? pojo,
      Wrapped<bool?>? number,
      Wrapped<bool?>? integralNumber,
      Wrapped<bool?>? floatingPointNumber,
      Wrapped<bool?>? short,
      Wrapped<bool?>? $int,
      Wrapped<bool?>? long,
      Wrapped<bool?>? $float,
      Wrapped<bool?>? $double,
      Wrapped<bool?>? bigDecimal,
      Wrapped<bool?>? bigInteger,
      Wrapped<bool?>? textual,
      Wrapped<bool?>? $boolean,
      Wrapped<bool?>? binary,
      Wrapped<bool?>? array,
      Wrapped<bool?>? $null}) {
    return JsonNode(
        nodeType: (nodeType != null ? nodeType.value : this.nodeType),
        valueNode: (valueNode != null ? valueNode.value : this.valueNode),
        containerNode:
            (containerNode != null ? containerNode.value : this.containerNode),
        missingNode:
            (missingNode != null ? missingNode.value : this.missingNode),
        object: (object != null ? object.value : this.object),
        pojo: (pojo != null ? pojo.value : this.pojo),
        number: (number != null ? number.value : this.number),
        integralNumber: (integralNumber != null
            ? integralNumber.value
            : this.integralNumber),
        floatingPointNumber: (floatingPointNumber != null
            ? floatingPointNumber.value
            : this.floatingPointNumber),
        short: (short != null ? short.value : this.short),
        $int: ($int != null ? $int.value : this.$int),
        long: (long != null ? long.value : this.long),
        $float: ($float != null ? $float.value : this.$float),
        $double: ($double != null ? $double.value : this.$double),
        bigDecimal: (bigDecimal != null ? bigDecimal.value : this.bigDecimal),
        bigInteger: (bigInteger != null ? bigInteger.value : this.bigInteger),
        textual: (textual != null ? textual.value : this.textual),
        $boolean: ($boolean != null ? $boolean.value : this.$boolean),
        binary: (binary != null ? binary.value : this.binary),
        array: (array != null ? array.value : this.array),
        $null: ($null != null ? $null.value : this.$null));
  }
}

@JsonSerializable(explicitToJson: true)
class Profile {
  Profile({
    this.externalId,
    this.lastWatchedChannel,
    this.lastModified,
    this.options,
    this.customerId,
    this.profileId,
    this.shared,
    this.colour,
    this.favoriteChannels,
    this.jsonOptions,
    this.recentlyUsedApps,
    this.recentlyUsedSettings,
    this.name,
  });

  factory Profile.fromJson(Map<String, dynamic> json) =>
      _$ProfileFromJson(json);

  @JsonKey(name: 'externalId', includeIfNull: false, defaultValue: '')
  final String? externalId;
  @JsonKey(name: 'lastWatchedChannel', includeIfNull: false)
  final int? lastWatchedChannel;
  @JsonKey(name: 'lastModified', includeIfNull: false)
  final DateTime? lastModified;
  @JsonKey(name: 'options', includeIfNull: false)
  final ProfileOptions? options;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'shared', includeIfNull: false)
  final bool? shared;
  @JsonKey(name: 'colour', includeIfNull: false, defaultValue: '')
  final String? colour;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? favoriteChannels;
  @JsonKey(name: 'jsonOptions', includeIfNull: false)
  final ProfileJsonOptions? jsonOptions;
  @JsonKey(
      name: 'recentlyUsedApps', includeIfNull: false, defaultValue: <String>[])
  final List<String>? recentlyUsedApps;
  @JsonKey(
      name: 'recentlyUsedSettings',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? recentlyUsedSettings;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$ProfileFromJson;
  static const toJsonFactory = _$ProfileToJson;
  Map<String, dynamic> toJson() => _$ProfileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Profile &&
            (identical(other.externalId, externalId) ||
                const DeepCollectionEquality()
                    .equals(other.externalId, externalId)) &&
            (identical(other.lastWatchedChannel, lastWatchedChannel) ||
                const DeepCollectionEquality()
                    .equals(other.lastWatchedChannel, lastWatchedChannel)) &&
            (identical(other.lastModified, lastModified) ||
                const DeepCollectionEquality()
                    .equals(other.lastModified, lastModified)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality()
                    .equals(other.options, options)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.shared, shared) ||
                const DeepCollectionEquality().equals(other.shared, shared)) &&
            (identical(other.colour, colour) ||
                const DeepCollectionEquality().equals(other.colour, colour)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)) &&
            (identical(other.jsonOptions, jsonOptions) ||
                const DeepCollectionEquality()
                    .equals(other.jsonOptions, jsonOptions)) &&
            (identical(other.recentlyUsedApps, recentlyUsedApps) ||
                const DeepCollectionEquality()
                    .equals(other.recentlyUsedApps, recentlyUsedApps)) &&
            (identical(other.recentlyUsedSettings, recentlyUsedSettings) ||
                const DeepCollectionEquality().equals(
                    other.recentlyUsedSettings, recentlyUsedSettings)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(externalId) ^
      const DeepCollectionEquality().hash(lastWatchedChannel) ^
      const DeepCollectionEquality().hash(lastModified) ^
      const DeepCollectionEquality().hash(options) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(shared) ^
      const DeepCollectionEquality().hash(colour) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      const DeepCollectionEquality().hash(jsonOptions) ^
      const DeepCollectionEquality().hash(recentlyUsedApps) ^
      const DeepCollectionEquality().hash(recentlyUsedSettings) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $ProfileExtension on Profile {
  Profile copyWith(
      {String? externalId,
      int? lastWatchedChannel,
      DateTime? lastModified,
      ProfileOptions? options,
      String? customerId,
      String? profileId,
      bool? shared,
      String? colour,
      List<String>? favoriteChannels,
      ProfileJsonOptions? jsonOptions,
      List<String>? recentlyUsedApps,
      List<String>? recentlyUsedSettings,
      String? name}) {
    return Profile(
        externalId: externalId ?? this.externalId,
        lastWatchedChannel: lastWatchedChannel ?? this.lastWatchedChannel,
        lastModified: lastModified ?? this.lastModified,
        options: options ?? this.options,
        customerId: customerId ?? this.customerId,
        profileId: profileId ?? this.profileId,
        shared: shared ?? this.shared,
        colour: colour ?? this.colour,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels,
        jsonOptions: jsonOptions ?? this.jsonOptions,
        recentlyUsedApps: recentlyUsedApps ?? this.recentlyUsedApps,
        recentlyUsedSettings: recentlyUsedSettings ?? this.recentlyUsedSettings,
        name: name ?? this.name);
  }

  Profile copyWithWrapped(
      {Wrapped<String?>? externalId,
      Wrapped<int?>? lastWatchedChannel,
      Wrapped<DateTime?>? lastModified,
      Wrapped<ProfileOptions?>? options,
      Wrapped<String?>? customerId,
      Wrapped<String?>? profileId,
      Wrapped<bool?>? shared,
      Wrapped<String?>? colour,
      Wrapped<List<String>?>? favoriteChannels,
      Wrapped<ProfileJsonOptions?>? jsonOptions,
      Wrapped<List<String>?>? recentlyUsedApps,
      Wrapped<List<String>?>? recentlyUsedSettings,
      Wrapped<String?>? name}) {
    return Profile(
        externalId: (externalId != null ? externalId.value : this.externalId),
        lastWatchedChannel: (lastWatchedChannel != null
            ? lastWatchedChannel.value
            : this.lastWatchedChannel),
        lastModified:
            (lastModified != null ? lastModified.value : this.lastModified),
        options: (options != null ? options.value : this.options),
        customerId: (customerId != null ? customerId.value : this.customerId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        shared: (shared != null ? shared.value : this.shared),
        colour: (colour != null ? colour.value : this.colour),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels),
        jsonOptions:
            (jsonOptions != null ? jsonOptions.value : this.jsonOptions),
        recentlyUsedApps: (recentlyUsedApps != null
            ? recentlyUsedApps.value
            : this.recentlyUsedApps),
        recentlyUsedSettings: (recentlyUsedSettings != null
            ? recentlyUsedSettings.value
            : this.recentlyUsedSettings),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileJsonOptions {
  ProfileJsonOptions({
    this.tipsAndTricksModifiedAt,
    this.tipsAndTricks,
  });

  factory ProfileJsonOptions.fromJson(Map<String, dynamic> json) =>
      _$ProfileJsonOptionsFromJson(json);

  @JsonKey(name: 'tipsAndTricksModifiedAt', includeIfNull: false)
  final DateTime? tipsAndTricksModifiedAt;
  @JsonKey(name: 'tipsAndTricks', includeIfNull: false)
  final JsonNode? tipsAndTricks;
  static const fromJsonFactory = _$ProfileJsonOptionsFromJson;
  static const toJsonFactory = _$ProfileJsonOptionsToJson;
  Map<String, dynamic> toJson() => _$ProfileJsonOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileJsonOptions &&
            (identical(
                    other.tipsAndTricksModifiedAt, tipsAndTricksModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.tipsAndTricksModifiedAt, tipsAndTricksModifiedAt)) &&
            (identical(other.tipsAndTricks, tipsAndTricks) ||
                const DeepCollectionEquality()
                    .equals(other.tipsAndTricks, tipsAndTricks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tipsAndTricksModifiedAt) ^
      const DeepCollectionEquality().hash(tipsAndTricks) ^
      runtimeType.hashCode;
}

extension $ProfileJsonOptionsExtension on ProfileJsonOptions {
  ProfileJsonOptions copyWith(
      {DateTime? tipsAndTricksModifiedAt, JsonNode? tipsAndTricks}) {
    return ProfileJsonOptions(
        tipsAndTricksModifiedAt:
            tipsAndTricksModifiedAt ?? this.tipsAndTricksModifiedAt,
        tipsAndTricks: tipsAndTricks ?? this.tipsAndTricks);
  }

  ProfileJsonOptions copyWithWrapped(
      {Wrapped<DateTime?>? tipsAndTricksModifiedAt,
      Wrapped<JsonNode?>? tipsAndTricks}) {
    return ProfileJsonOptions(
        tipsAndTricksModifiedAt: (tipsAndTricksModifiedAt != null
            ? tipsAndTricksModifiedAt.value
            : this.tipsAndTricksModifiedAt),
        tipsAndTricks:
            (tipsAndTricks != null ? tipsAndTricks.value : this.tipsAndTricks));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileOptions {
  ProfileOptions({
    this.langModifiedAt,
    this.audioLangModifiedAt,
    this.subLang,
    this.subLangModifiedAt,
    this.hardOfHearing,
    this.hardOfHearingModifiedAt,
    this.audioDescription,
    this.audioDescriptionModifiedAt,
    this.showSubtitlesModifiedAt,
    this.keyboardModeModifiedAt,
    this.myListId,
    this.lang,
    this.audioLang,
    this.showSubtitles,
    this.signLanguage,
    this.signLanguageModifiedAt,
    this.keyboardMode,
  });

  factory ProfileOptions.fromJson(Map<String, dynamic> json) =>
      _$ProfileOptionsFromJson(json);

  @JsonKey(name: 'langModifiedAt', includeIfNull: false)
  final DateTime? langModifiedAt;
  @JsonKey(name: 'audioLangModifiedAt', includeIfNull: false)
  final DateTime? audioLangModifiedAt;
  @JsonKey(name: 'subLang', includeIfNull: false, defaultValue: '')
  final String? subLang;
  @JsonKey(name: 'subLangModifiedAt', includeIfNull: false)
  final DateTime? subLangModifiedAt;
  @JsonKey(name: 'hardOfHearing', includeIfNull: false)
  final bool? hardOfHearing;
  @JsonKey(name: 'hardOfHearingModifiedAt', includeIfNull: false)
  final DateTime? hardOfHearingModifiedAt;
  @JsonKey(name: 'audioDescription', includeIfNull: false)
  final bool? audioDescription;
  @JsonKey(name: 'audioDescriptionModifiedAt', includeIfNull: false)
  final DateTime? audioDescriptionModifiedAt;
  @JsonKey(name: 'showSubtitlesModifiedAt', includeIfNull: false)
  final DateTime? showSubtitlesModifiedAt;
  @JsonKey(name: 'keyboardModeModifiedAt', includeIfNull: false)
  final DateTime? keyboardModeModifiedAt;
  @JsonKey(name: 'myListId', includeIfNull: false, defaultValue: '')
  final String? myListId;
  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String? lang;
  @JsonKey(name: 'audioLang', includeIfNull: false, defaultValue: '')
  final String? audioLang;
  @JsonKey(name: 'showSubtitles', includeIfNull: false)
  final bool? showSubtitles;
  @JsonKey(name: 'signLanguage', includeIfNull: false)
  final bool? signLanguage;
  @JsonKey(name: 'signLanguageModifiedAt', includeIfNull: false)
  final DateTime? signLanguageModifiedAt;
  @JsonKey(name: 'keyboardMode', includeIfNull: false, defaultValue: '')
  final String? keyboardMode;
  static const fromJsonFactory = _$ProfileOptionsFromJson;
  static const toJsonFactory = _$ProfileOptionsToJson;
  Map<String, dynamic> toJson() => _$ProfileOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileOptions &&
            (identical(other.langModifiedAt, langModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.langModifiedAt, langModifiedAt)) &&
            (identical(other.audioLangModifiedAt, audioLangModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.audioLangModifiedAt, audioLangModifiedAt)) &&
            (identical(other.subLang, subLang) ||
                const DeepCollectionEquality()
                    .equals(other.subLang, subLang)) &&
            (identical(other.subLangModifiedAt, subLangModifiedAt) ||
                const DeepCollectionEquality()
                    .equals(other.subLangModifiedAt, subLangModifiedAt)) &&
            (identical(other.hardOfHearing, hardOfHearing) ||
                const DeepCollectionEquality()
                    .equals(other.hardOfHearing, hardOfHearing)) &&
            (identical(other.hardOfHearingModifiedAt, hardOfHearingModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.hardOfHearingModifiedAt, hardOfHearingModifiedAt)) &&
            (identical(other.audioDescription, audioDescription) ||
                const DeepCollectionEquality()
                    .equals(other.audioDescription, audioDescription)) &&
            (identical(other.audioDescriptionModifiedAt, audioDescriptionModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.audioDescriptionModifiedAt,
                    audioDescriptionModifiedAt)) &&
            (identical(other.showSubtitlesModifiedAt, showSubtitlesModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.showSubtitlesModifiedAt, showSubtitlesModifiedAt)) &&
            (identical(other.keyboardModeModifiedAt, keyboardModeModifiedAt) ||
                const DeepCollectionEquality().equals(
                    other.keyboardModeModifiedAt, keyboardModeModifiedAt)) &&
            (identical(other.myListId, myListId) ||
                const DeepCollectionEquality()
                    .equals(other.myListId, myListId)) &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.audioLang, audioLang) ||
                const DeepCollectionEquality()
                    .equals(other.audioLang, audioLang)) &&
            (identical(other.showSubtitles, showSubtitles) ||
                const DeepCollectionEquality()
                    .equals(other.showSubtitles, showSubtitles)) &&
            (identical(other.signLanguage, signLanguage) ||
                const DeepCollectionEquality().equals(other.signLanguage, signLanguage)) &&
            (identical(other.signLanguageModifiedAt, signLanguageModifiedAt) || const DeepCollectionEquality().equals(other.signLanguageModifiedAt, signLanguageModifiedAt)) &&
            (identical(other.keyboardMode, keyboardMode) || const DeepCollectionEquality().equals(other.keyboardMode, keyboardMode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(langModifiedAt) ^
      const DeepCollectionEquality().hash(audioLangModifiedAt) ^
      const DeepCollectionEquality().hash(subLang) ^
      const DeepCollectionEquality().hash(subLangModifiedAt) ^
      const DeepCollectionEquality().hash(hardOfHearing) ^
      const DeepCollectionEquality().hash(hardOfHearingModifiedAt) ^
      const DeepCollectionEquality().hash(audioDescription) ^
      const DeepCollectionEquality().hash(audioDescriptionModifiedAt) ^
      const DeepCollectionEquality().hash(showSubtitlesModifiedAt) ^
      const DeepCollectionEquality().hash(keyboardModeModifiedAt) ^
      const DeepCollectionEquality().hash(myListId) ^
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(audioLang) ^
      const DeepCollectionEquality().hash(showSubtitles) ^
      const DeepCollectionEquality().hash(signLanguage) ^
      const DeepCollectionEquality().hash(signLanguageModifiedAt) ^
      const DeepCollectionEquality().hash(keyboardMode) ^
      runtimeType.hashCode;
}

extension $ProfileOptionsExtension on ProfileOptions {
  ProfileOptions copyWith(
      {DateTime? langModifiedAt,
      DateTime? audioLangModifiedAt,
      String? subLang,
      DateTime? subLangModifiedAt,
      bool? hardOfHearing,
      DateTime? hardOfHearingModifiedAt,
      bool? audioDescription,
      DateTime? audioDescriptionModifiedAt,
      DateTime? showSubtitlesModifiedAt,
      DateTime? keyboardModeModifiedAt,
      String? myListId,
      String? lang,
      String? audioLang,
      bool? showSubtitles,
      bool? signLanguage,
      DateTime? signLanguageModifiedAt,
      String? keyboardMode}) {
    return ProfileOptions(
        langModifiedAt: langModifiedAt ?? this.langModifiedAt,
        audioLangModifiedAt: audioLangModifiedAt ?? this.audioLangModifiedAt,
        subLang: subLang ?? this.subLang,
        subLangModifiedAt: subLangModifiedAt ?? this.subLangModifiedAt,
        hardOfHearing: hardOfHearing ?? this.hardOfHearing,
        hardOfHearingModifiedAt:
            hardOfHearingModifiedAt ?? this.hardOfHearingModifiedAt,
        audioDescription: audioDescription ?? this.audioDescription,
        audioDescriptionModifiedAt:
            audioDescriptionModifiedAt ?? this.audioDescriptionModifiedAt,
        showSubtitlesModifiedAt:
            showSubtitlesModifiedAt ?? this.showSubtitlesModifiedAt,
        keyboardModeModifiedAt:
            keyboardModeModifiedAt ?? this.keyboardModeModifiedAt,
        myListId: myListId ?? this.myListId,
        lang: lang ?? this.lang,
        audioLang: audioLang ?? this.audioLang,
        showSubtitles: showSubtitles ?? this.showSubtitles,
        signLanguage: signLanguage ?? this.signLanguage,
        signLanguageModifiedAt:
            signLanguageModifiedAt ?? this.signLanguageModifiedAt,
        keyboardMode: keyboardMode ?? this.keyboardMode);
  }

  ProfileOptions copyWithWrapped(
      {Wrapped<DateTime?>? langModifiedAt,
      Wrapped<DateTime?>? audioLangModifiedAt,
      Wrapped<String?>? subLang,
      Wrapped<DateTime?>? subLangModifiedAt,
      Wrapped<bool?>? hardOfHearing,
      Wrapped<DateTime?>? hardOfHearingModifiedAt,
      Wrapped<bool?>? audioDescription,
      Wrapped<DateTime?>? audioDescriptionModifiedAt,
      Wrapped<DateTime?>? showSubtitlesModifiedAt,
      Wrapped<DateTime?>? keyboardModeModifiedAt,
      Wrapped<String?>? myListId,
      Wrapped<String?>? lang,
      Wrapped<String?>? audioLang,
      Wrapped<bool?>? showSubtitles,
      Wrapped<bool?>? signLanguage,
      Wrapped<DateTime?>? signLanguageModifiedAt,
      Wrapped<String?>? keyboardMode}) {
    return ProfileOptions(
        langModifiedAt: (langModifiedAt != null
            ? langModifiedAt.value
            : this.langModifiedAt),
        audioLangModifiedAt: (audioLangModifiedAt != null
            ? audioLangModifiedAt.value
            : this.audioLangModifiedAt),
        subLang: (subLang != null ? subLang.value : this.subLang),
        subLangModifiedAt: (subLangModifiedAt != null
            ? subLangModifiedAt.value
            : this.subLangModifiedAt),
        hardOfHearing:
            (hardOfHearing != null ? hardOfHearing.value : this.hardOfHearing),
        hardOfHearingModifiedAt: (hardOfHearingModifiedAt != null
            ? hardOfHearingModifiedAt.value
            : this.hardOfHearingModifiedAt),
        audioDescription: (audioDescription != null
            ? audioDescription.value
            : this.audioDescription),
        audioDescriptionModifiedAt: (audioDescriptionModifiedAt != null
            ? audioDescriptionModifiedAt.value
            : this.audioDescriptionModifiedAt),
        showSubtitlesModifiedAt: (showSubtitlesModifiedAt != null
            ? showSubtitlesModifiedAt.value
            : this.showSubtitlesModifiedAt),
        keyboardModeModifiedAt: (keyboardModeModifiedAt != null
            ? keyboardModeModifiedAt.value
            : this.keyboardModeModifiedAt),
        myListId: (myListId != null ? myListId.value : this.myListId),
        lang: (lang != null ? lang.value : this.lang),
        audioLang: (audioLang != null ? audioLang.value : this.audioLang),
        showSubtitles:
            (showSubtitles != null ? showSubtitles.value : this.showSubtitles),
        signLanguage:
            (signLanguage != null ? signLanguage.value : this.signLanguage),
        signLanguageModifiedAt: (signLanguageModifiedAt != null
            ? signLanguageModifiedAt.value
            : this.signLanguageModifiedAt),
        keyboardMode:
            (keyboardMode != null ? keyboardMode.value : this.keyboardMode));
  }
}

@JsonSerializable(explicitToJson: true)
class AdvancedAdvertising {
  AdvancedAdvertising({
    this.disableAdvancedAdvertising,
    this.advancedAdvertisingMode,
  });

  factory AdvancedAdvertising.fromJson(Map<String, dynamic> json) =>
      _$AdvancedAdvertisingFromJson(json);

  @JsonKey(name: 'disableAdvancedAdvertising', includeIfNull: false)
  final bool? disableAdvancedAdvertising;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  static const fromJsonFactory = _$AdvancedAdvertisingFromJson;
  static const toJsonFactory = _$AdvancedAdvertisingToJson;
  Map<String, dynamic> toJson() => _$AdvancedAdvertisingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AdvancedAdvertising &&
            (identical(other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising) ||
                const DeepCollectionEquality().equals(
                    other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(disableAdvancedAdvertising) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      runtimeType.hashCode;
}

extension $AdvancedAdvertisingExtension on AdvancedAdvertising {
  AdvancedAdvertising copyWith(
      {bool? disableAdvancedAdvertising, String? advancedAdvertisingMode}) {
    return AdvancedAdvertising(
        disableAdvancedAdvertising:
            disableAdvancedAdvertising ?? this.disableAdvancedAdvertising,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode);
  }

  AdvancedAdvertising copyWithWrapped(
      {Wrapped<bool?>? disableAdvancedAdvertising,
      Wrapped<String?>? advancedAdvertisingMode}) {
    return AdvancedAdvertising(
        disableAdvancedAdvertising: (disableAdvancedAdvertising != null
            ? disableAdvancedAdvertising.value
            : this.disableAdvancedAdvertising),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsCustomerResponse {
  CpsCustomerResponse({
    this.customerId,
    this.assignedDevices,
    this.customerStatus,
    this.countryId,
    this.cityId,
    this.disableAdvancedAdvertising,
    this.advancedAdvertisingMode,
    this.statusModifiedDate,
  });

  factory CpsCustomerResponse.fromJson(Map<String, dynamic> json) =>
      _$CpsCustomerResponseFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(
      name: 'assignedDevices',
      includeIfNull: false,
      defaultValue: <CpsDeviceResponse>[])
  final List<CpsDeviceResponse>? assignedDevices;
  @JsonKey(
    name: 'customerStatus',
    includeIfNull: false,
    toJson: cpsCustomerResponseCustomerStatusToJson,
    fromJson: cpsCustomerResponseCustomerStatusFromJson,
  )
  final enums.CpsCustomerResponseCustomerStatus? customerStatus;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(name: 'disableAdvancedAdvertising', includeIfNull: false)
  final bool? disableAdvancedAdvertising;
  @JsonKey(
      name: 'advancedAdvertisingMode', includeIfNull: false, defaultValue: '')
  final String? advancedAdvertisingMode;
  @JsonKey(name: 'statusModifiedDate', includeIfNull: false)
  final DateTime? statusModifiedDate;
  static const fromJsonFactory = _$CpsCustomerResponseFromJson;
  static const toJsonFactory = _$CpsCustomerResponseToJson;
  Map<String, dynamic> toJson() => _$CpsCustomerResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsCustomerResponse &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.assignedDevices, assignedDevices) ||
                const DeepCollectionEquality()
                    .equals(other.assignedDevices, assignedDevices)) &&
            (identical(other.customerStatus, customerStatus) ||
                const DeepCollectionEquality()
                    .equals(other.customerStatus, customerStatus)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising) ||
                const DeepCollectionEquality().equals(
                    other.disableAdvancedAdvertising,
                    disableAdvancedAdvertising)) &&
            (identical(
                    other.advancedAdvertisingMode, advancedAdvertisingMode) ||
                const DeepCollectionEquality().equals(
                    other.advancedAdvertisingMode, advancedAdvertisingMode)) &&
            (identical(other.statusModifiedDate, statusModifiedDate) ||
                const DeepCollectionEquality()
                    .equals(other.statusModifiedDate, statusModifiedDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(assignedDevices) ^
      const DeepCollectionEquality().hash(customerStatus) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(disableAdvancedAdvertising) ^
      const DeepCollectionEquality().hash(advancedAdvertisingMode) ^
      const DeepCollectionEquality().hash(statusModifiedDate) ^
      runtimeType.hashCode;
}

extension $CpsCustomerResponseExtension on CpsCustomerResponse {
  CpsCustomerResponse copyWith(
      {String? customerId,
      List<CpsDeviceResponse>? assignedDevices,
      enums.CpsCustomerResponseCustomerStatus? customerStatus,
      String? countryId,
      int? cityId,
      bool? disableAdvancedAdvertising,
      String? advancedAdvertisingMode,
      DateTime? statusModifiedDate}) {
    return CpsCustomerResponse(
        customerId: customerId ?? this.customerId,
        assignedDevices: assignedDevices ?? this.assignedDevices,
        customerStatus: customerStatus ?? this.customerStatus,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        disableAdvancedAdvertising:
            disableAdvancedAdvertising ?? this.disableAdvancedAdvertising,
        advancedAdvertisingMode:
            advancedAdvertisingMode ?? this.advancedAdvertisingMode,
        statusModifiedDate: statusModifiedDate ?? this.statusModifiedDate);
  }

  CpsCustomerResponse copyWithWrapped(
      {Wrapped<String?>? customerId,
      Wrapped<List<CpsDeviceResponse>?>? assignedDevices,
      Wrapped<enums.CpsCustomerResponseCustomerStatus?>? customerStatus,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<bool?>? disableAdvancedAdvertising,
      Wrapped<String?>? advancedAdvertisingMode,
      Wrapped<DateTime?>? statusModifiedDate}) {
    return CpsCustomerResponse(
        customerId: (customerId != null ? customerId.value : this.customerId),
        assignedDevices: (assignedDevices != null
            ? assignedDevices.value
            : this.assignedDevices),
        customerStatus: (customerStatus != null
            ? customerStatus.value
            : this.customerStatus),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        disableAdvancedAdvertising: (disableAdvancedAdvertising != null
            ? disableAdvancedAdvertising.value
            : this.disableAdvancedAdvertising),
        advancedAdvertisingMode: (advancedAdvertisingMode != null
            ? advancedAdvertisingMode.value
            : this.advancedAdvertisingMode),
        statusModifiedDate: (statusModifiedDate != null
            ? statusModifiedDate.value
            : this.statusModifiedDate));
  }
}

@JsonSerializable(explicitToJson: true)
class CpsDeviceResponse {
  CpsDeviceResponse({
    this.deviceType,
    this.smartCardId,
    this.serialNumber,
    this.deviceId,
    this.platformType,
  });

  factory CpsDeviceResponse.fromJson(Map<String, dynamic> json) =>
      _$CpsDeviceResponseFromJson(json);

  @JsonKey(name: 'deviceType', includeIfNull: false, defaultValue: '')
  final String? deviceType;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String? smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'platformType', includeIfNull: false, defaultValue: '')
  final String? platformType;
  static const fromJsonFactory = _$CpsDeviceResponseFromJson;
  static const toJsonFactory = _$CpsDeviceResponseToJson;
  Map<String, dynamic> toJson() => _$CpsDeviceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpsDeviceResponse &&
            (identical(other.deviceType, deviceType) ||
                const DeepCollectionEquality()
                    .equals(other.deviceType, deviceType)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.platformType, platformType) ||
                const DeepCollectionEquality()
                    .equals(other.platformType, platformType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceType) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(platformType) ^
      runtimeType.hashCode;
}

extension $CpsDeviceResponseExtension on CpsDeviceResponse {
  CpsDeviceResponse copyWith(
      {String? deviceType,
      String? smartCardId,
      String? serialNumber,
      String? deviceId,
      String? platformType}) {
    return CpsDeviceResponse(
        deviceType: deviceType ?? this.deviceType,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber,
        deviceId: deviceId ?? this.deviceId,
        platformType: platformType ?? this.platformType);
  }

  CpsDeviceResponse copyWithWrapped(
      {Wrapped<String?>? deviceType,
      Wrapped<String?>? smartCardId,
      Wrapped<String?>? serialNumber,
      Wrapped<String?>? deviceId,
      Wrapped<String?>? platformType}) {
    return CpsDeviceResponse(
        deviceType: (deviceType != null ? deviceType.value : this.deviceType),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        platformType:
            (platformType != null ? platformType.value : this.platformType));
  }
}

@JsonSerializable(explicitToJson: true)
class ProfileId {
  ProfileId({
    this.profileId,
  });

  factory ProfileId.fromJson(Map<String, dynamic> json) =>
      _$ProfileIdFromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  static const fromJsonFactory = _$ProfileIdFromJson;
  static const toJsonFactory = _$ProfileIdToJson;
  Map<String, dynamic> toJson() => _$ProfileIdToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileId &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^ runtimeType.hashCode;
}

extension $ProfileIdExtension on ProfileId {
  ProfileId copyWith({String? profileId}) {
    return ProfileId(profileId: profileId ?? this.profileId);
  }

  ProfileId copyWithWrapped({Wrapped<String?>? profileId}) {
    return ProfileId(
        profileId: (profileId != null ? profileId.value : this.profileId));
  }
}

@JsonSerializable(explicitToJson: true)
class Reminder {
  Reminder({
    this.deviceId,
    this.reminderId,
    this.availabilityStart,
    this.channelId,
    this.profileId,
    this.content,
  });

  factory Reminder.fromJson(Map<String, dynamic> json) =>
      _$ReminderFromJson(json);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String? deviceId;
  @JsonKey(name: 'reminderId', includeIfNull: false, defaultValue: '')
  final String? reminderId;
  @JsonKey(name: 'availabilityStart', includeIfNull: false)
  final DateTime? availabilityStart;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'content', includeIfNull: false, defaultValue: '')
  final String? content;
  static const fromJsonFactory = _$ReminderFromJson;
  static const toJsonFactory = _$ReminderToJson;
  Map<String, dynamic> toJson() => _$ReminderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Reminder &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.reminderId, reminderId) ||
                const DeepCollectionEquality()
                    .equals(other.reminderId, reminderId)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality().equals(other.content, content)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(reminderId) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(content) ^
      runtimeType.hashCode;
}

extension $ReminderExtension on Reminder {
  Reminder copyWith(
      {String? deviceId,
      String? reminderId,
      DateTime? availabilityStart,
      String? channelId,
      String? profileId,
      String? content}) {
    return Reminder(
        deviceId: deviceId ?? this.deviceId,
        reminderId: reminderId ?? this.reminderId,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        channelId: channelId ?? this.channelId,
        profileId: profileId ?? this.profileId,
        content: content ?? this.content);
  }

  Reminder copyWithWrapped(
      {Wrapped<String?>? deviceId,
      Wrapped<String?>? reminderId,
      Wrapped<DateTime?>? availabilityStart,
      Wrapped<String?>? channelId,
      Wrapped<String?>? profileId,
      Wrapped<String?>? content}) {
    return Reminder(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        reminderId: (reminderId != null ? reminderId.value : this.reminderId),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        channelId: (channelId != null ? channelId.value : this.channelId),
        profileId: (profileId != null ? profileId.value : this.profileId),
        content: (content != null ? content.value : this.content));
  }
}

@JsonSerializable(explicitToJson: true)
class ReminderId {
  ReminderId({
    this.reminderId,
  });

  factory ReminderId.fromJson(Map<String, dynamic> json) =>
      _$ReminderIdFromJson(json);

  @JsonKey(name: 'reminderId', includeIfNull: false, defaultValue: '')
  final String? reminderId;
  static const fromJsonFactory = _$ReminderIdFromJson;
  static const toJsonFactory = _$ReminderIdToJson;
  Map<String, dynamic> toJson() => _$ReminderIdToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReminderId &&
            (identical(other.reminderId, reminderId) ||
                const DeepCollectionEquality()
                    .equals(other.reminderId, reminderId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(reminderId) ^ runtimeType.hashCode;
}

extension $ReminderIdExtension on ReminderId {
  ReminderId copyWith({String? reminderId}) {
    return ReminderId(reminderId: reminderId ?? this.reminderId);
  }

  ReminderId copyWithWrapped({Wrapped<String?>? reminderId}) {
    return ReminderId(
        reminderId: (reminderId != null ? reminderId.value : this.reminderId));
  }
}

@JsonSerializable(explicitToJson: true)
class RengCustomer {
  RengCustomer({
    this.personalization,
    this.customerId,
    this.countryId,
    this.cityId,
    this.lockedChannels,
    this.ageLock,
  });

  factory RengCustomer.fromJson(Map<String, dynamic> json) =>
      _$RengCustomerFromJson(json);

  @JsonKey(name: 'personalization', includeIfNull: false)
  final bool? personalization;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  @JsonKey(name: 'countryId', includeIfNull: false, defaultValue: '')
  final String? countryId;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  @JsonKey(
      name: 'lockedChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? lockedChannels;
  @JsonKey(name: 'ageLock', includeIfNull: false)
  final int? ageLock;
  static const fromJsonFactory = _$RengCustomerFromJson;
  static const toJsonFactory = _$RengCustomerToJson;
  Map<String, dynamic> toJson() => _$RengCustomerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RengCustomer &&
            (identical(other.personalization, personalization) ||
                const DeepCollectionEquality()
                    .equals(other.personalization, personalization)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.countryId, countryId) ||
                const DeepCollectionEquality()
                    .equals(other.countryId, countryId)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)) &&
            (identical(other.lockedChannels, lockedChannels) ||
                const DeepCollectionEquality()
                    .equals(other.lockedChannels, lockedChannels)) &&
            (identical(other.ageLock, ageLock) ||
                const DeepCollectionEquality().equals(other.ageLock, ageLock)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(personalization) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(countryId) ^
      const DeepCollectionEquality().hash(cityId) ^
      const DeepCollectionEquality().hash(lockedChannels) ^
      const DeepCollectionEquality().hash(ageLock) ^
      runtimeType.hashCode;
}

extension $RengCustomerExtension on RengCustomer {
  RengCustomer copyWith(
      {bool? personalization,
      String? customerId,
      String? countryId,
      int? cityId,
      List<String>? lockedChannels,
      int? ageLock}) {
    return RengCustomer(
        personalization: personalization ?? this.personalization,
        customerId: customerId ?? this.customerId,
        countryId: countryId ?? this.countryId,
        cityId: cityId ?? this.cityId,
        lockedChannels: lockedChannels ?? this.lockedChannels,
        ageLock: ageLock ?? this.ageLock);
  }

  RengCustomer copyWithWrapped(
      {Wrapped<bool?>? personalization,
      Wrapped<String?>? customerId,
      Wrapped<String?>? countryId,
      Wrapped<int?>? cityId,
      Wrapped<List<String>?>? lockedChannels,
      Wrapped<int?>? ageLock}) {
    return RengCustomer(
        personalization: (personalization != null
            ? personalization.value
            : this.personalization),
        customerId: (customerId != null ? customerId.value : this.customerId),
        countryId: (countryId != null ? countryId.value : this.countryId),
        cityId: (cityId != null ? cityId.value : this.cityId),
        lockedChannels: (lockedChannels != null
            ? lockedChannels.value
            : this.lockedChannels),
        ageLock: (ageLock != null ? ageLock.value : this.ageLock));
  }
}

@JsonSerializable(explicitToJson: true)
class RengCustomerInformation {
  RengCustomerInformation({
    this.customer,
    this.profile,
  });

  factory RengCustomerInformation.fromJson(Map<String, dynamic> json) =>
      _$RengCustomerInformationFromJson(json);

  @JsonKey(name: 'customer', includeIfNull: false)
  final RengCustomer? customer;
  @JsonKey(name: 'profile', includeIfNull: false)
  final RengProfile? profile;
  static const fromJsonFactory = _$RengCustomerInformationFromJson;
  static const toJsonFactory = _$RengCustomerInformationToJson;
  Map<String, dynamic> toJson() => _$RengCustomerInformationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RengCustomerInformation &&
            (identical(other.customer, customer) ||
                const DeepCollectionEquality()
                    .equals(other.customer, customer)) &&
            (identical(other.profile, profile) ||
                const DeepCollectionEquality().equals(other.profile, profile)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customer) ^
      const DeepCollectionEquality().hash(profile) ^
      runtimeType.hashCode;
}

extension $RengCustomerInformationExtension on RengCustomerInformation {
  RengCustomerInformation copyWith(
      {RengCustomer? customer, RengProfile? profile}) {
    return RengCustomerInformation(
        customer: customer ?? this.customer, profile: profile ?? this.profile);
  }

  RengCustomerInformation copyWithWrapped(
      {Wrapped<RengCustomer?>? customer, Wrapped<RengProfile?>? profile}) {
    return RengCustomerInformation(
        customer: (customer != null ? customer.value : this.customer),
        profile: (profile != null ? profile.value : this.profile));
  }
}

@JsonSerializable(explicitToJson: true)
class RengProfile {
  RengProfile({
    this.ageRating,
    this.lang,
    this.profileId,
    this.shared,
    this.favoriteChannels,
  });

  factory RengProfile.fromJson(Map<String, dynamic> json) =>
      _$RengProfileFromJson(json);

  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String? lang;
  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'shared', includeIfNull: false)
  final bool? shared;
  @JsonKey(
      name: 'favoriteChannels', includeIfNull: false, defaultValue: <String>[])
  final List<String>? favoriteChannels;
  static const fromJsonFactory = _$RengProfileFromJson;
  static const toJsonFactory = _$RengProfileToJson;
  Map<String, dynamic> toJson() => _$RengProfileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RengProfile &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.shared, shared) ||
                const DeepCollectionEquality().equals(other.shared, shared)) &&
            (identical(other.favoriteChannels, favoriteChannels) ||
                const DeepCollectionEquality()
                    .equals(other.favoriteChannels, favoriteChannels)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(shared) ^
      const DeepCollectionEquality().hash(favoriteChannels) ^
      runtimeType.hashCode;
}

extension $RengProfileExtension on RengProfile {
  RengProfile copyWith(
      {int? ageRating,
      String? lang,
      String? profileId,
      bool? shared,
      List<String>? favoriteChannels}) {
    return RengProfile(
        ageRating: ageRating ?? this.ageRating,
        lang: lang ?? this.lang,
        profileId: profileId ?? this.profileId,
        shared: shared ?? this.shared,
        favoriteChannels: favoriteChannels ?? this.favoriteChannels);
  }

  RengProfile copyWithWrapped(
      {Wrapped<int?>? ageRating,
      Wrapped<String?>? lang,
      Wrapped<String?>? profileId,
      Wrapped<bool?>? shared,
      Wrapped<List<String>?>? favoriteChannels}) {
    return RengProfile(
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        lang: (lang != null ? lang.value : this.lang),
        profileId: (profileId != null ? profileId.value : this.profileId),
        shared: (shared != null ? shared.value : this.shared),
        favoriteChannels: (favoriteChannels != null
            ? favoriteChannels.value
            : this.favoriteChannels));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerConfiguration {
  CustomerConfiguration({
    required this.ldvrCleanupEnabled,
    required this.switchDevice,
    required this.defaultPin,
    required this.defaultOptIns,
    required this.ldvrEnabled,
  });

  factory CustomerConfiguration.fromJson(Map<String, dynamic> json) =>
      _$CustomerConfigurationFromJson(json);

  @JsonKey(name: 'ldvrCleanupEnabled', includeIfNull: false)
  final bool ldvrCleanupEnabled;
  @JsonKey(name: 'switchDevice', includeIfNull: false)
  final bool switchDevice;
  @JsonKey(name: 'defaultPin', includeIfNull: false, defaultValue: '')
  final String defaultPin;
  @JsonKey(
      name: 'defaultOptIns',
      includeIfNull: false,
      defaultValue: <CustomerOptIn>[])
  final List<CustomerOptIn> defaultOptIns;
  @JsonKey(name: 'ldvrEnabled', includeIfNull: false)
  final bool ldvrEnabled;
  static const fromJsonFactory = _$CustomerConfigurationFromJson;
  static const toJsonFactory = _$CustomerConfigurationToJson;
  Map<String, dynamic> toJson() => _$CustomerConfigurationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerConfiguration &&
            (identical(other.ldvrCleanupEnabled, ldvrCleanupEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.ldvrCleanupEnabled, ldvrCleanupEnabled)) &&
            (identical(other.switchDevice, switchDevice) ||
                const DeepCollectionEquality()
                    .equals(other.switchDevice, switchDevice)) &&
            (identical(other.defaultPin, defaultPin) ||
                const DeepCollectionEquality()
                    .equals(other.defaultPin, defaultPin)) &&
            (identical(other.defaultOptIns, defaultOptIns) ||
                const DeepCollectionEquality()
                    .equals(other.defaultOptIns, defaultOptIns)) &&
            (identical(other.ldvrEnabled, ldvrEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.ldvrEnabled, ldvrEnabled)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ldvrCleanupEnabled) ^
      const DeepCollectionEquality().hash(switchDevice) ^
      const DeepCollectionEquality().hash(defaultPin) ^
      const DeepCollectionEquality().hash(defaultOptIns) ^
      const DeepCollectionEquality().hash(ldvrEnabled) ^
      runtimeType.hashCode;
}

extension $CustomerConfigurationExtension on CustomerConfiguration {
  CustomerConfiguration copyWith(
      {bool? ldvrCleanupEnabled,
      bool? switchDevice,
      String? defaultPin,
      List<CustomerOptIn>? defaultOptIns,
      bool? ldvrEnabled}) {
    return CustomerConfiguration(
        ldvrCleanupEnabled: ldvrCleanupEnabled ?? this.ldvrCleanupEnabled,
        switchDevice: switchDevice ?? this.switchDevice,
        defaultPin: defaultPin ?? this.defaultPin,
        defaultOptIns: defaultOptIns ?? this.defaultOptIns,
        ldvrEnabled: ldvrEnabled ?? this.ldvrEnabled);
  }

  CustomerConfiguration copyWithWrapped(
      {Wrapped<bool>? ldvrCleanupEnabled,
      Wrapped<bool>? switchDevice,
      Wrapped<String>? defaultPin,
      Wrapped<List<CustomerOptIn>>? defaultOptIns,
      Wrapped<bool>? ldvrEnabled}) {
    return CustomerConfiguration(
        ldvrCleanupEnabled: (ldvrCleanupEnabled != null
            ? ldvrCleanupEnabled.value
            : this.ldvrCleanupEnabled),
        switchDevice:
            (switchDevice != null ? switchDevice.value : this.switchDevice),
        defaultPin: (defaultPin != null ? defaultPin.value : this.defaultPin),
        defaultOptIns:
            (defaultOptIns != null ? defaultOptIns.value : this.defaultOptIns),
        ldvrEnabled:
            (ldvrEnabled != null ? ldvrEnabled.value : this.ldvrEnabled));
  }
}

@JsonSerializable(explicitToJson: true)
class DeviceConfiguration {
  DeviceConfiguration({
    required this.deviceFriendlyName,
    this.isCecEnabled,
    this.isTvAutoStartup,
    this.oneTouchViewTurnOffPolicy,
  });

  factory DeviceConfiguration.fromJson(Map<String, dynamic> json) =>
      _$DeviceConfigurationFromJson(json);

  @JsonKey(name: 'deviceFriendlyName', includeIfNull: false, defaultValue: '')
  final String deviceFriendlyName;
  @JsonKey(name: 'isCecEnabled', includeIfNull: false)
  final bool? isCecEnabled;
  @JsonKey(name: 'isTvAutoStartup', includeIfNull: false)
  final bool? isTvAutoStartup;
  @JsonKey(name: 'oneTouchViewTurnOffPolicy', includeIfNull: false)
  final bool? oneTouchViewTurnOffPolicy;
  static const fromJsonFactory = _$DeviceConfigurationFromJson;
  static const toJsonFactory = _$DeviceConfigurationToJson;
  Map<String, dynamic> toJson() => _$DeviceConfigurationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeviceConfiguration &&
            (identical(other.deviceFriendlyName, deviceFriendlyName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFriendlyName, deviceFriendlyName)) &&
            (identical(other.isCecEnabled, isCecEnabled) ||
                const DeepCollectionEquality()
                    .equals(other.isCecEnabled, isCecEnabled)) &&
            (identical(other.isTvAutoStartup, isTvAutoStartup) ||
                const DeepCollectionEquality()
                    .equals(other.isTvAutoStartup, isTvAutoStartup)) &&
            (identical(other.oneTouchViewTurnOffPolicy,
                    oneTouchViewTurnOffPolicy) ||
                const DeepCollectionEquality().equals(
                    other.oneTouchViewTurnOffPolicy,
                    oneTouchViewTurnOffPolicy)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceFriendlyName) ^
      const DeepCollectionEquality().hash(isCecEnabled) ^
      const DeepCollectionEquality().hash(isTvAutoStartup) ^
      const DeepCollectionEquality().hash(oneTouchViewTurnOffPolicy) ^
      runtimeType.hashCode;
}

extension $DeviceConfigurationExtension on DeviceConfiguration {
  DeviceConfiguration copyWith(
      {String? deviceFriendlyName,
      bool? isCecEnabled,
      bool? isTvAutoStartup,
      bool? oneTouchViewTurnOffPolicy}) {
    return DeviceConfiguration(
        deviceFriendlyName: deviceFriendlyName ?? this.deviceFriendlyName,
        isCecEnabled: isCecEnabled ?? this.isCecEnabled,
        isTvAutoStartup: isTvAutoStartup ?? this.isTvAutoStartup,
        oneTouchViewTurnOffPolicy:
            oneTouchViewTurnOffPolicy ?? this.oneTouchViewTurnOffPolicy);
  }

  DeviceConfiguration copyWithWrapped(
      {Wrapped<String>? deviceFriendlyName,
      Wrapped<bool?>? isCecEnabled,
      Wrapped<bool?>? isTvAutoStartup,
      Wrapped<bool?>? oneTouchViewTurnOffPolicy}) {
    return DeviceConfiguration(
        deviceFriendlyName: (deviceFriendlyName != null
            ? deviceFriendlyName.value
            : this.deviceFriendlyName),
        isCecEnabled:
            (isCecEnabled != null ? isCecEnabled.value : this.isCecEnabled),
        isTvAutoStartup: (isTvAutoStartup != null
            ? isTvAutoStartup.value
            : this.isTvAutoStartup),
        oneTouchViewTurnOffPolicy: (oneTouchViewTurnOffPolicy != null
            ? oneTouchViewTurnOffPolicy.value
            : this.oneTouchViewTurnOffPolicy));
  }
}

@JsonSerializable(explicitToJson: true)
class SharedProfileConfiguration {
  SharedProfileConfiguration({
    this.lang,
    this.audioLang,
    this.subtitlesLang,
    this.showSubtitles,
    this.keyboardMode,
  });

  factory SharedProfileConfiguration.fromJson(Map<String, dynamic> json) =>
      _$SharedProfileConfigurationFromJson(json);

  @JsonKey(name: 'lang', includeIfNull: false, defaultValue: '')
  final String? lang;
  @JsonKey(name: 'audioLang', includeIfNull: false, defaultValue: '')
  final String? audioLang;
  @JsonKey(name: 'subtitlesLang', includeIfNull: false, defaultValue: '')
  final String? subtitlesLang;
  @JsonKey(name: 'showSubtitles', includeIfNull: false)
  final bool? showSubtitles;
  @JsonKey(name: 'keyboardMode', includeIfNull: false, defaultValue: '')
  final String? keyboardMode;
  static const fromJsonFactory = _$SharedProfileConfigurationFromJson;
  static const toJsonFactory = _$SharedProfileConfigurationToJson;
  Map<String, dynamic> toJson() => _$SharedProfileConfigurationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SharedProfileConfiguration &&
            (identical(other.lang, lang) ||
                const DeepCollectionEquality().equals(other.lang, lang)) &&
            (identical(other.audioLang, audioLang) ||
                const DeepCollectionEquality()
                    .equals(other.audioLang, audioLang)) &&
            (identical(other.subtitlesLang, subtitlesLang) ||
                const DeepCollectionEquality()
                    .equals(other.subtitlesLang, subtitlesLang)) &&
            (identical(other.showSubtitles, showSubtitles) ||
                const DeepCollectionEquality()
                    .equals(other.showSubtitles, showSubtitles)) &&
            (identical(other.keyboardMode, keyboardMode) ||
                const DeepCollectionEquality()
                    .equals(other.keyboardMode, keyboardMode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lang) ^
      const DeepCollectionEquality().hash(audioLang) ^
      const DeepCollectionEquality().hash(subtitlesLang) ^
      const DeepCollectionEquality().hash(showSubtitles) ^
      const DeepCollectionEquality().hash(keyboardMode) ^
      runtimeType.hashCode;
}

extension $SharedProfileConfigurationExtension on SharedProfileConfiguration {
  SharedProfileConfiguration copyWith(
      {String? lang,
      String? audioLang,
      String? subtitlesLang,
      bool? showSubtitles,
      String? keyboardMode}) {
    return SharedProfileConfiguration(
        lang: lang ?? this.lang,
        audioLang: audioLang ?? this.audioLang,
        subtitlesLang: subtitlesLang ?? this.subtitlesLang,
        showSubtitles: showSubtitles ?? this.showSubtitles,
        keyboardMode: keyboardMode ?? this.keyboardMode);
  }

  SharedProfileConfiguration copyWithWrapped(
      {Wrapped<String?>? lang,
      Wrapped<String?>? audioLang,
      Wrapped<String?>? subtitlesLang,
      Wrapped<bool?>? showSubtitles,
      Wrapped<String?>? keyboardMode}) {
    return SharedProfileConfiguration(
        lang: (lang != null ? lang.value : this.lang),
        audioLang: (audioLang != null ? audioLang.value : this.audioLang),
        subtitlesLang:
            (subtitlesLang != null ? subtitlesLang.value : this.subtitlesLang),
        showSubtitles:
            (showSubtitles != null ? showSubtitles.value : this.showSubtitles),
        keyboardMode:
            (keyboardMode != null ? keyboardMode.value : this.keyboardMode));
  }
}

@JsonSerializable(explicitToJson: true)
class CreateOttDeviceRequest {
  CreateOttDeviceRequest({
    this.deviceName,
    this.deviceFamily,
    this.drmDeviceId,
    this.ottDeviceLimit,
  });

  factory CreateOttDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$CreateOttDeviceRequestFromJson(json);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  @JsonKey(name: 'deviceFamily', includeIfNull: false, defaultValue: '')
  final String? deviceFamily;
  @JsonKey(name: 'drmDeviceId', includeIfNull: false, defaultValue: '')
  final String? drmDeviceId;
  @JsonKey(name: 'ottDeviceLimit', includeIfNull: false)
  final int? ottDeviceLimit;
  static const fromJsonFactory = _$CreateOttDeviceRequestFromJson;
  static const toJsonFactory = _$CreateOttDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$CreateOttDeviceRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CreateOttDeviceRequest &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.deviceFamily, deviceFamily) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFamily, deviceFamily)) &&
            (identical(other.drmDeviceId, drmDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.drmDeviceId, drmDeviceId)) &&
            (identical(other.ottDeviceLimit, ottDeviceLimit) ||
                const DeepCollectionEquality()
                    .equals(other.ottDeviceLimit, ottDeviceLimit)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(deviceFamily) ^
      const DeepCollectionEquality().hash(drmDeviceId) ^
      const DeepCollectionEquality().hash(ottDeviceLimit) ^
      runtimeType.hashCode;
}

extension $CreateOttDeviceRequestExtension on CreateOttDeviceRequest {
  CreateOttDeviceRequest copyWith(
      {String? deviceName,
      String? deviceFamily,
      String? drmDeviceId,
      int? ottDeviceLimit}) {
    return CreateOttDeviceRequest(
        deviceName: deviceName ?? this.deviceName,
        deviceFamily: deviceFamily ?? this.deviceFamily,
        drmDeviceId: drmDeviceId ?? this.drmDeviceId,
        ottDeviceLimit: ottDeviceLimit ?? this.ottDeviceLimit);
  }

  CreateOttDeviceRequest copyWithWrapped(
      {Wrapped<String?>? deviceName,
      Wrapped<String?>? deviceFamily,
      Wrapped<String?>? drmDeviceId,
      Wrapped<int?>? ottDeviceLimit}) {
    return CreateOttDeviceRequest(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        deviceFamily:
            (deviceFamily != null ? deviceFamily.value : this.deviceFamily),
        drmDeviceId:
            (drmDeviceId != null ? drmDeviceId.value : this.drmDeviceId),
        ottDeviceLimit: (ottDeviceLimit != null
            ? ottDeviceLimit.value
            : this.ottDeviceLimit));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateOttDeviceRequest {
  UpdateOttDeviceRequest({
    this.deviceName,
  });

  factory UpdateOttDeviceRequest.fromJson(Map<String, dynamic> json) =>
      _$UpdateOttDeviceRequestFromJson(json);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  static const fromJsonFactory = _$UpdateOttDeviceRequestFromJson;
  static const toJsonFactory = _$UpdateOttDeviceRequestToJson;
  Map<String, dynamic> toJson() => _$UpdateOttDeviceRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateOttDeviceRequest &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^ runtimeType.hashCode;
}

extension $UpdateOttDeviceRequestExtension on UpdateOttDeviceRequest {
  UpdateOttDeviceRequest copyWith({String? deviceName}) {
    return UpdateOttDeviceRequest(deviceName: deviceName ?? this.deviceName);
  }

  UpdateOttDeviceRequest copyWithWrapped({Wrapped<String?>? deviceName}) {
    return UpdateOttDeviceRequest(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerOttDevice {
  CustomerOttDevice({
    this.deviceName,
    this.deviceFamily,
    this.drmDeviceId,
    this.createdAt,
    this.cooldownTill,
  });

  factory CustomerOttDevice.fromJson(Map<String, dynamic> json) =>
      _$CustomerOttDeviceFromJson(json);

  @JsonKey(name: 'deviceName', includeIfNull: false, defaultValue: '')
  final String? deviceName;
  @JsonKey(name: 'deviceFamily', includeIfNull: false, defaultValue: '')
  final String? deviceFamily;
  @JsonKey(name: 'drmDeviceId', includeIfNull: false, defaultValue: '')
  final String? drmDeviceId;
  @JsonKey(name: 'createdAt', includeIfNull: false)
  final DateTime? createdAt;
  @JsonKey(name: 'cooldownTill', includeIfNull: false)
  final DateTime? cooldownTill;
  static const fromJsonFactory = _$CustomerOttDeviceFromJson;
  static const toJsonFactory = _$CustomerOttDeviceToJson;
  Map<String, dynamic> toJson() => _$CustomerOttDeviceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerOttDevice &&
            (identical(other.deviceName, deviceName) ||
                const DeepCollectionEquality()
                    .equals(other.deviceName, deviceName)) &&
            (identical(other.deviceFamily, deviceFamily) ||
                const DeepCollectionEquality()
                    .equals(other.deviceFamily, deviceFamily)) &&
            (identical(other.drmDeviceId, drmDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.drmDeviceId, drmDeviceId)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.cooldownTill, cooldownTill) ||
                const DeepCollectionEquality()
                    .equals(other.cooldownTill, cooldownTill)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceName) ^
      const DeepCollectionEquality().hash(deviceFamily) ^
      const DeepCollectionEquality().hash(drmDeviceId) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(cooldownTill) ^
      runtimeType.hashCode;
}

extension $CustomerOttDeviceExtension on CustomerOttDevice {
  CustomerOttDevice copyWith(
      {String? deviceName,
      String? deviceFamily,
      String? drmDeviceId,
      DateTime? createdAt,
      DateTime? cooldownTill}) {
    return CustomerOttDevice(
        deviceName: deviceName ?? this.deviceName,
        deviceFamily: deviceFamily ?? this.deviceFamily,
        drmDeviceId: drmDeviceId ?? this.drmDeviceId,
        createdAt: createdAt ?? this.createdAt,
        cooldownTill: cooldownTill ?? this.cooldownTill);
  }

  CustomerOttDevice copyWithWrapped(
      {Wrapped<String?>? deviceName,
      Wrapped<String?>? deviceFamily,
      Wrapped<String?>? drmDeviceId,
      Wrapped<DateTime?>? createdAt,
      Wrapped<DateTime?>? cooldownTill}) {
    return CustomerOttDevice(
        deviceName: (deviceName != null ? deviceName.value : this.deviceName),
        deviceFamily:
            (deviceFamily != null ? deviceFamily.value : this.deviceFamily),
        drmDeviceId:
            (drmDeviceId != null ? drmDeviceId.value : this.drmDeviceId),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        cooldownTill:
            (cooldownTill != null ? cooldownTill.value : this.cooldownTill));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;
  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class ValidationErrorMessage {
  ValidationErrorMessage({
    required this.errors,
  });

  factory ValidationErrorMessage.fromJson(Map<String, dynamic> json) =>
      _$ValidationErrorMessageFromJson(json);

  @JsonKey(name: 'errors', includeIfNull: false, defaultValue: <String>[])
  final List<String> errors;
  static const fromJsonFactory = _$ValidationErrorMessageFromJson;
  static const toJsonFactory = _$ValidationErrorMessageToJson;
  Map<String, dynamic> toJson() => _$ValidationErrorMessageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidationErrorMessage &&
            (identical(other.errors, errors) ||
                const DeepCollectionEquality().equals(other.errors, errors)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(errors) ^ runtimeType.hashCode;
}

extension $ValidationErrorMessageExtension on ValidationErrorMessage {
  ValidationErrorMessage copyWith({List<String>? errors}) {
    return ValidationErrorMessage(errors: errors ?? this.errors);
  }

  ValidationErrorMessage copyWithWrapped({Wrapped<List<String>>? errors}) {
    return ValidationErrorMessage(
        errors: (errors != null ? errors.value : this.errors));
  }
}

String? v1CpsCustomerCustomerIdResetPinGetPinTypeToJson(
    enums.V1CpsCustomerCustomerIdResetPinGetPinType?
        v1CpsCustomerCustomerIdResetPinGetPinType) {
  return enums.$V1CpsCustomerCustomerIdResetPinGetPinTypeMap[
      v1CpsCustomerCustomerIdResetPinGetPinType];
}

enums.V1CpsCustomerCustomerIdResetPinGetPinType
    v1CpsCustomerCustomerIdResetPinGetPinTypeFromJson(
  Object? v1CpsCustomerCustomerIdResetPinGetPinType, [
  enums.V1CpsCustomerCustomerIdResetPinGetPinType? defaultValue,
]) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType is String) {
    return enums.$V1CpsCustomerCustomerIdResetPinGetPinTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1CpsCustomerCustomerIdResetPinGetPinType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1CpsCustomerCustomerIdResetPinGetPinType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1CpsCustomerCustomerIdResetPinGetPinTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1CpsCustomerCustomerIdResetPinGetPinType.swaggerGeneratedUnknown;
}

List<String> v1CpsCustomerCustomerIdResetPinGetPinTypeListToJson(
    List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>?
        v1CpsCustomerCustomerIdResetPinGetPinType) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType == null) {
    return [];
  }

  return v1CpsCustomerCustomerIdResetPinGetPinType
      .map((e) => enums.$V1CpsCustomerCustomerIdResetPinGetPinTypeMap[e]!)
      .toList();
}

List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>
    v1CpsCustomerCustomerIdResetPinGetPinTypeListFromJson(
  List? v1CpsCustomerCustomerIdResetPinGetPinType, [
  List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>? defaultValue,
]) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType == null) {
    return defaultValue ?? [];
  }

  return v1CpsCustomerCustomerIdResetPinGetPinType
      .map((e) =>
          v1CpsCustomerCustomerIdResetPinGetPinTypeFromJson(e.toString()))
      .toList();
}

List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>?
    v1CpsCustomerCustomerIdResetPinGetPinTypeNullableListFromJson(
  List? v1CpsCustomerCustomerIdResetPinGetPinType, [
  List<enums.V1CpsCustomerCustomerIdResetPinGetPinType>? defaultValue,
]) {
  if (v1CpsCustomerCustomerIdResetPinGetPinType == null) {
    return defaultValue;
  }

  return v1CpsCustomerCustomerIdResetPinGetPinType
      .map((e) =>
          v1CpsCustomerCustomerIdResetPinGetPinTypeFromJson(e.toString()))
      .toList();
}

String? cpsCustomerRequestCustomerStatusToJson(
    enums.CpsCustomerRequestCustomerStatus? cpsCustomerRequestCustomerStatus) {
  return enums
      .$CpsCustomerRequestCustomerStatusMap[cpsCustomerRequestCustomerStatus];
}

enums.CpsCustomerRequestCustomerStatus cpsCustomerRequestCustomerStatusFromJson(
  Object? cpsCustomerRequestCustomerStatus, [
  enums.CpsCustomerRequestCustomerStatus? defaultValue,
]) {
  if (cpsCustomerRequestCustomerStatus is String) {
    return enums.$CpsCustomerRequestCustomerStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpsCustomerRequestCustomerStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpsCustomerRequestCustomerStatus.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpsCustomerRequestCustomerStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpsCustomerRequestCustomerStatus.swaggerGeneratedUnknown;
}

List<String> cpsCustomerRequestCustomerStatusListToJson(
    List<enums.CpsCustomerRequestCustomerStatus>?
        cpsCustomerRequestCustomerStatus) {
  if (cpsCustomerRequestCustomerStatus == null) {
    return [];
  }

  return cpsCustomerRequestCustomerStatus
      .map((e) => enums.$CpsCustomerRequestCustomerStatusMap[e]!)
      .toList();
}

List<enums.CpsCustomerRequestCustomerStatus>
    cpsCustomerRequestCustomerStatusListFromJson(
  List? cpsCustomerRequestCustomerStatus, [
  List<enums.CpsCustomerRequestCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerRequestCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return cpsCustomerRequestCustomerStatus
      .map((e) => cpsCustomerRequestCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CpsCustomerRequestCustomerStatus>?
    cpsCustomerRequestCustomerStatusNullableListFromJson(
  List? cpsCustomerRequestCustomerStatus, [
  List<enums.CpsCustomerRequestCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerRequestCustomerStatus == null) {
    return defaultValue;
  }

  return cpsCustomerRequestCustomerStatus
      .map((e) => cpsCustomerRequestCustomerStatusFromJson(e.toString()))
      .toList();
}

String? customerCustomerStatusToJson(
    enums.CustomerCustomerStatus? customerCustomerStatus) {
  return enums.$CustomerCustomerStatusMap[customerCustomerStatus];
}

enums.CustomerCustomerStatus customerCustomerStatusFromJson(
  Object? customerCustomerStatus, [
  enums.CustomerCustomerStatus? defaultValue,
]) {
  if (customerCustomerStatus is String) {
    return enums.$CustomerCustomerStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customerCustomerStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomerCustomerStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomerCustomerStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomerCustomerStatus.swaggerGeneratedUnknown;
}

List<String> customerCustomerStatusListToJson(
    List<enums.CustomerCustomerStatus>? customerCustomerStatus) {
  if (customerCustomerStatus == null) {
    return [];
  }

  return customerCustomerStatus
      .map((e) => enums.$CustomerCustomerStatusMap[e]!)
      .toList();
}

List<enums.CustomerCustomerStatus> customerCustomerStatusListFromJson(
  List? customerCustomerStatus, [
  List<enums.CustomerCustomerStatus>? defaultValue,
]) {
  if (customerCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return customerCustomerStatus
      .map((e) => customerCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CustomerCustomerStatus>? customerCustomerStatusNullableListFromJson(
  List? customerCustomerStatus, [
  List<enums.CustomerCustomerStatus>? defaultValue,
]) {
  if (customerCustomerStatus == null) {
    return defaultValue;
  }

  return customerCustomerStatus
      .map((e) => customerCustomerStatusFromJson(e.toString()))
      .toList();
}

String? deviceSettingsCcDigitalServiceToJson(
    enums.DeviceSettingsCcDigitalService? deviceSettingsCcDigitalService) {
  return enums
      .$DeviceSettingsCcDigitalServiceMap[deviceSettingsCcDigitalService];
}

enums.DeviceSettingsCcDigitalService deviceSettingsCcDigitalServiceFromJson(
  Object? deviceSettingsCcDigitalService, [
  enums.DeviceSettingsCcDigitalService? defaultValue,
]) {
  if (deviceSettingsCcDigitalService is String) {
    return enums.$DeviceSettingsCcDigitalServiceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                deviceSettingsCcDigitalService.toLowerCase(),
            orElse: () => const MapEntry(
                enums.DeviceSettingsCcDigitalService.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$DeviceSettingsCcDigitalServiceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.DeviceSettingsCcDigitalService.swaggerGeneratedUnknown;
}

List<String> deviceSettingsCcDigitalServiceListToJson(
    List<enums.DeviceSettingsCcDigitalService>?
        deviceSettingsCcDigitalService) {
  if (deviceSettingsCcDigitalService == null) {
    return [];
  }

  return deviceSettingsCcDigitalService
      .map((e) => enums.$DeviceSettingsCcDigitalServiceMap[e]!)
      .toList();
}

List<enums.DeviceSettingsCcDigitalService>
    deviceSettingsCcDigitalServiceListFromJson(
  List? deviceSettingsCcDigitalService, [
  List<enums.DeviceSettingsCcDigitalService>? defaultValue,
]) {
  if (deviceSettingsCcDigitalService == null) {
    return defaultValue ?? [];
  }

  return deviceSettingsCcDigitalService
      .map((e) => deviceSettingsCcDigitalServiceFromJson(e.toString()))
      .toList();
}

List<enums.DeviceSettingsCcDigitalService>?
    deviceSettingsCcDigitalServiceNullableListFromJson(
  List? deviceSettingsCcDigitalService, [
  List<enums.DeviceSettingsCcDigitalService>? defaultValue,
]) {
  if (deviceSettingsCcDigitalService == null) {
    return defaultValue;
  }

  return deviceSettingsCcDigitalService
      .map((e) => deviceSettingsCcDigitalServiceFromJson(e.toString()))
      .toList();
}

String? deviceSettingsCcAnalogServiceToJson(
    enums.DeviceSettingsCcAnalogService? deviceSettingsCcAnalogService) {
  return enums.$DeviceSettingsCcAnalogServiceMap[deviceSettingsCcAnalogService];
}

enums.DeviceSettingsCcAnalogService deviceSettingsCcAnalogServiceFromJson(
  Object? deviceSettingsCcAnalogService, [
  enums.DeviceSettingsCcAnalogService? defaultValue,
]) {
  if (deviceSettingsCcAnalogService is String) {
    return enums.$DeviceSettingsCcAnalogServiceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                deviceSettingsCcAnalogService.toLowerCase(),
            orElse: () => const MapEntry(
                enums.DeviceSettingsCcAnalogService.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$DeviceSettingsCcAnalogServiceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.DeviceSettingsCcAnalogService.swaggerGeneratedUnknown;
}

List<String> deviceSettingsCcAnalogServiceListToJson(
    List<enums.DeviceSettingsCcAnalogService>? deviceSettingsCcAnalogService) {
  if (deviceSettingsCcAnalogService == null) {
    return [];
  }

  return deviceSettingsCcAnalogService
      .map((e) => enums.$DeviceSettingsCcAnalogServiceMap[e]!)
      .toList();
}

List<enums.DeviceSettingsCcAnalogService>
    deviceSettingsCcAnalogServiceListFromJson(
  List? deviceSettingsCcAnalogService, [
  List<enums.DeviceSettingsCcAnalogService>? defaultValue,
]) {
  if (deviceSettingsCcAnalogService == null) {
    return defaultValue ?? [];
  }

  return deviceSettingsCcAnalogService
      .map((e) => deviceSettingsCcAnalogServiceFromJson(e.toString()))
      .toList();
}

List<enums.DeviceSettingsCcAnalogService>?
    deviceSettingsCcAnalogServiceNullableListFromJson(
  List? deviceSettingsCcAnalogService, [
  List<enums.DeviceSettingsCcAnalogService>? defaultValue,
]) {
  if (deviceSettingsCcAnalogService == null) {
    return defaultValue;
  }

  return deviceSettingsCcAnalogService
      .map((e) => deviceSettingsCcAnalogServiceFromJson(e.toString()))
      .toList();
}

String? jsonNodeNodeTypeToJson(enums.JsonNodeNodeType? jsonNodeNodeType) {
  return enums.$JsonNodeNodeTypeMap[jsonNodeNodeType];
}

enums.JsonNodeNodeType jsonNodeNodeTypeFromJson(
  Object? jsonNodeNodeType, [
  enums.JsonNodeNodeType? defaultValue,
]) {
  if (jsonNodeNodeType is String) {
    return enums.$JsonNodeNodeTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == jsonNodeNodeType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.JsonNodeNodeType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$JsonNodeNodeTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.JsonNodeNodeType.swaggerGeneratedUnknown;
}

List<String> jsonNodeNodeTypeListToJson(
    List<enums.JsonNodeNodeType>? jsonNodeNodeType) {
  if (jsonNodeNodeType == null) {
    return [];
  }

  return jsonNodeNodeType.map((e) => enums.$JsonNodeNodeTypeMap[e]!).toList();
}

List<enums.JsonNodeNodeType> jsonNodeNodeTypeListFromJson(
  List? jsonNodeNodeType, [
  List<enums.JsonNodeNodeType>? defaultValue,
]) {
  if (jsonNodeNodeType == null) {
    return defaultValue ?? [];
  }

  return jsonNodeNodeType
      .map((e) => jsonNodeNodeTypeFromJson(e.toString()))
      .toList();
}

List<enums.JsonNodeNodeType>? jsonNodeNodeTypeNullableListFromJson(
  List? jsonNodeNodeType, [
  List<enums.JsonNodeNodeType>? defaultValue,
]) {
  if (jsonNodeNodeType == null) {
    return defaultValue;
  }

  return jsonNodeNodeType
      .map((e) => jsonNodeNodeTypeFromJson(e.toString()))
      .toList();
}

String? cpsCustomerResponseCustomerStatusToJson(
    enums.CpsCustomerResponseCustomerStatus?
        cpsCustomerResponseCustomerStatus) {
  return enums
      .$CpsCustomerResponseCustomerStatusMap[cpsCustomerResponseCustomerStatus];
}

enums.CpsCustomerResponseCustomerStatus
    cpsCustomerResponseCustomerStatusFromJson(
  Object? cpsCustomerResponseCustomerStatus, [
  enums.CpsCustomerResponseCustomerStatus? defaultValue,
]) {
  if (cpsCustomerResponseCustomerStatus is String) {
    return enums.$CpsCustomerResponseCustomerStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpsCustomerResponseCustomerStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpsCustomerResponseCustomerStatus.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpsCustomerResponseCustomerStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpsCustomerResponseCustomerStatus.swaggerGeneratedUnknown;
}

List<String> cpsCustomerResponseCustomerStatusListToJson(
    List<enums.CpsCustomerResponseCustomerStatus>?
        cpsCustomerResponseCustomerStatus) {
  if (cpsCustomerResponseCustomerStatus == null) {
    return [];
  }

  return cpsCustomerResponseCustomerStatus
      .map((e) => enums.$CpsCustomerResponseCustomerStatusMap[e]!)
      .toList();
}

List<enums.CpsCustomerResponseCustomerStatus>
    cpsCustomerResponseCustomerStatusListFromJson(
  List? cpsCustomerResponseCustomerStatus, [
  List<enums.CpsCustomerResponseCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerResponseCustomerStatus == null) {
    return defaultValue ?? [];
  }

  return cpsCustomerResponseCustomerStatus
      .map((e) => cpsCustomerResponseCustomerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CpsCustomerResponseCustomerStatus>?
    cpsCustomerResponseCustomerStatusNullableListFromJson(
  List? cpsCustomerResponseCustomerStatus, [
  List<enums.CpsCustomerResponseCustomerStatus>? defaultValue,
]) {
  if (cpsCustomerResponseCustomerStatus == null) {
    return defaultValue;
  }

  return cpsCustomerResponseCustomerStatus
      .map((e) => cpsCustomerResponseCustomerStatusFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
