// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'podcast_insider.swagger.chopper.dart';
part 'podcast_insider.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PodcastInsider extends ChopperService {
  static PodcastInsider create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PodcastInsider(client);
    }

    final newClient = ChopperClient(
        services: [_$PodcastInsider()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://petstore.swagger.io/v2');
    return _$PodcastInsider(newClient);
  }

  ///Search stocks
  ///@param keywords
  Future<chopper.Response<SearchStocks>> apiV1StocksSearchGet({
    required String? keywords,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SearchStocks$Item, () => SearchStocks$Item.fromJsonFactory);

    return _apiV1StocksSearchGet(
        keywords: keywords, cacheControl: cacheControl);
  }

  ///Search stocks
  ///@param keywords
  @Get(path: '/api/v1/stocks/search')
  Future<chopper.Response<SearchStocks>> _apiV1StocksSearchGet({
    @Query('keywords') required String? keywords,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get a list of all currencies
  Future<chopper.Response<Currency>> apiV1CurrenciesAllGet(
      {String? cacheControl}) {
    return _apiV1CurrenciesAllGet(cacheControl: cacheControl);
  }

  ///Get a list of all currencies
  @Get(path: '/api/v1/currencies/all')
  Future<chopper.Response<Currency>> _apiV1CurrenciesAllGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get current user profile
  Future<chopper.Response<Profile>> apiV1ProfilesMyGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Profile, () => Profile.fromJsonFactory);

    return _apiV1ProfilesMyGet(cacheControl: cacheControl);
  }

  ///Get current user profile
  @Get(path: '/api/v1/profiles/my')
  Future<chopper.Response<Profile>> _apiV1ProfilesMyGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Update current user profile
  Future<chopper.Response<Profile>> apiV1ProfilesMyPost({
    String? cacheControl,
    required Profile? body,
  }) {
    generatedMapping.putIfAbsent(Profile, () => Profile.fromJsonFactory);

    return _apiV1ProfilesMyPost(cacheControl: cacheControl, body: body);
  }

  ///Update current user profile
  @Post(path: '/api/v1/profiles/my')
  Future<chopper.Response<Profile>> _apiV1ProfilesMyPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Profile? body,
  });
}

typedef SearchStocks = List<SearchStocks$Item>;

@JsonSerializable(explicitToJson: true)
class SearchStocks$Item {
  SearchStocks$Item({
    this.symbol,
    this.name,
    this.type,
    this.region,
    this.currency,
  });

  factory SearchStocks$Item.fromJson(Map<String, dynamic> json) =>
      _$SearchStocks$ItemFromJson(json);

  @JsonKey(name: 'symbol', includeIfNull: false, defaultValue: '')
  final String? symbol;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'region', includeIfNull: false, defaultValue: '')
  final String? region;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  static const fromJsonFactory = _$SearchStocks$ItemFromJson;
  static const toJsonFactory = _$SearchStocks$ItemToJson;
  Map<String, dynamic> toJson() => _$SearchStocks$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchStocks$Item &&
            (identical(other.symbol, symbol) ||
                const DeepCollectionEquality().equals(other.symbol, symbol)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.region, region) ||
                const DeepCollectionEquality().equals(other.region, region)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(symbol) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(region) ^
      const DeepCollectionEquality().hash(currency) ^
      runtimeType.hashCode;
}

extension $SearchStocks$ItemExtension on SearchStocks$Item {
  SearchStocks$Item copyWith(
      {String? symbol,
      String? name,
      String? type,
      String? region,
      String? currency}) {
    return SearchStocks$Item(
        symbol: symbol ?? this.symbol,
        name: name ?? this.name,
        type: type ?? this.type,
        region: region ?? this.region,
        currency: currency ?? this.currency);
  }

  SearchStocks$Item copyWithWrapped(
      {Wrapped<String?>? symbol,
      Wrapped<String?>? name,
      Wrapped<String?>? type,
      Wrapped<String?>? region,
      Wrapped<String?>? currency}) {
    return SearchStocks$Item(
        symbol: (symbol != null ? symbol.value : this.symbol),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        region: (region != null ? region.value : this.region),
        currency: (currency != null ? currency.value : this.currency));
  }
}

@JsonSerializable(explicitToJson: true)
class Profile {
  Profile({
    this.currency,
    this.watchList,
  });

  factory Profile.fromJson(Map<String, dynamic> json) =>
      _$ProfileFromJson(json);

  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'watchList', includeIfNull: false, defaultValue: <String>[])
  final List<String>? watchList;
  static const fromJsonFactory = _$ProfileFromJson;
  static const toJsonFactory = _$ProfileToJson;
  Map<String, dynamic> toJson() => _$ProfileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Profile &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.watchList, watchList) ||
                const DeepCollectionEquality()
                    .equals(other.watchList, watchList)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(watchList) ^
      runtimeType.hashCode;
}

extension $ProfileExtension on Profile {
  Profile copyWith({String? currency, List<String>? watchList}) {
    return Profile(
        currency: currency ?? this.currency,
        watchList: watchList ?? this.watchList);
  }

  Profile copyWithWrapped(
      {Wrapped<String?>? currency, Wrapped<List<String>?>? watchList}) {
    return Profile(
        currency: (currency != null ? currency.value : this.currency),
        watchList: (watchList != null ? watchList.value : this.watchList));
  }
}

typedef Currency = List<Object>;

@JsonSerializable(explicitToJson: true)
class UnauthorizedError {
  UnauthorizedError({
    this.message,
  });

  factory UnauthorizedError.fromJson(Map<String, dynamic> json) =>
      _$UnauthorizedErrorFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  static const fromJsonFactory = _$UnauthorizedErrorFromJson;
  static const toJsonFactory = _$UnauthorizedErrorToJson;
  Map<String, dynamic> toJson() => _$UnauthorizedErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UnauthorizedError &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $UnauthorizedErrorExtension on UnauthorizedError {
  UnauthorizedError copyWith({String? message}) {
    return UnauthorizedError(message: message ?? this.message);
  }

  UnauthorizedError copyWithWrapped({Wrapped<String?>? message}) {
    return UnauthorizedError(
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class NotFoundError {
  NotFoundError({
    this.message,
  });

  factory NotFoundError.fromJson(Map<String, dynamic> json) =>
      _$NotFoundErrorFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  static const fromJsonFactory = _$NotFoundErrorFromJson;
  static const toJsonFactory = _$NotFoundErrorToJson;
  Map<String, dynamic> toJson() => _$NotFoundErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotFoundError &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $NotFoundErrorExtension on NotFoundError {
  NotFoundError copyWith({String? message}) {
    return NotFoundError(message: message ?? this.message);
  }

  NotFoundError copyWithWrapped({Wrapped<String?>? message}) {
    return NotFoundError(
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class InvalidError {
  InvalidError({
    this.message,
  });

  factory InvalidError.fromJson(Map<String, dynamic> json) =>
      _$InvalidErrorFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  static const fromJsonFactory = _$InvalidErrorFromJson;
  static const toJsonFactory = _$InvalidErrorToJson;
  Map<String, dynamic> toJson() => _$InvalidErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InvalidError &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $InvalidErrorExtension on InvalidError {
  InvalidError copyWith({String? message}) {
    return InvalidError(message: message ?? this.message);
  }

  InvalidError copyWithWrapped({Wrapped<String?>? message}) {
    return InvalidError(
        message: (message != null ? message.value : this.message));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
