// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'product_search_remote_data_source.enums.swagger.dart' as enums;
export 'product_search_remote_data_source.enums.swagger.dart';

part 'product_search_remote_data_source.swagger.chopper.dart';
part 'product_search_remote_data_source.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ProductSearchRemoteDataSource extends ChopperService {
  static ProductSearchRemoteDataSource create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ProductSearchRemoteDataSource(client);
    }

    final newClient = ChopperClient(
        services: [_$ProductSearchRemoteDataSource()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$ProductSearchRemoteDataSource(newClient);
  }

  ///product-search
  ///@param x-application
  ///@param Appie-Current-Order-Id
  ///@param query Search terms to find in product index
  ///@param filters Filters
  ///@param sortOn Sort on
  ///@param size Number of records per page
  ///@param page Results page you want to retrieve (0..N)
  Future<chopper.Response<SearchResponse>> v1Get({
    String? xApplication,
    String? appieCurrentOrderId,
    String? query,
    String? filters,
    enums.V1GetSortOn? sortOn,
    int? size,
    int? page,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SearchResponse, () => SearchResponse.fromJsonFactory);

    return _v1Get(
        xApplication: xApplication,
        appieCurrentOrderId: appieCurrentOrderId,
        query: query,
        filters: filters,
        sortOn: enums.$V1GetSortOnMap[sortOn]?.toString(),
        size: size,
        page: page,
        cacheControl: cacheControl);
  }

  ///product-search
  ///@param x-application
  ///@param Appie-Current-Order-Id
  ///@param query Search terms to find in product index
  ///@param filters Filters
  ///@param sortOn Sort on
  ///@param size Number of records per page
  ///@param page Results page you want to retrieve (0..N)
  @Get(path: '/v1')
  Future<chopper.Response<SearchResponse>> _v1Get({
    @Header('x-application') String? xApplication,
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Query('query') String? query,
    @Query('filters') String? filters,
    @Query('sortOn') String? sortOn,
    @Query('size') int? size,
    @Query('page') int? page,
    @Header('Cache-Control') String? cacheControl,
  });

  ///product-search-gtin
  ///@param x-application
  ///@param Appie-Current-Order-Id
  ///@param code GTIN of the product
  Future<chopper.Response<ProductCard>> v1GtinCodeGet({
    String? xApplication,
    String? appieCurrentOrderId,
    required num? code,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProductCard, () => ProductCard.fromJsonFactory);

    return _v1GtinCodeGet(
        xApplication: xApplication,
        appieCurrentOrderId: appieCurrentOrderId,
        code: code,
        cacheControl: cacheControl);
  }

  ///product-search-gtin
  ///@param x-application
  ///@param Appie-Current-Order-Id
  ///@param code GTIN of the product
  @Get(path: '/v1/gtin/{code}')
  Future<chopper.Response<ProductCard>> _v1GtinCodeGet({
    @Header('x-application') String? xApplication,
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Path('code') required num? code,
    @Header('Cache-Control') String? cacheControl,
  });

  ///product-search-suggestions
  ///@param x-application
  ///@param query Term to find suggestions for
  ///@param amount Amount of suggestions
  Future<chopper.Response<List<String>>> v1SuggestionsGet({
    String? xApplication,
    required String? query,
    required String? amount,
    String? cacheControl,
  }) {
    return _v1SuggestionsGet(
        xApplication: xApplication,
        query: query,
        amount: amount,
        cacheControl: cacheControl);
  }

  ///product-search-suggestions
  ///@param x-application
  ///@param query Term to find suggestions for
  ///@param amount Amount of suggestions
  @Get(path: '/v1/suggestions')
  Future<chopper.Response<List<String>>> _v1SuggestionsGet({
    @Header('x-application') String? xApplication,
    @Query('query') required String? query,
    @Query('amount') required String? amount,
    @Header('Cache-Control') String? cacheControl,
  });

  ///product-search
  ///@param x-application
  ///@param Appie-Current-Order-Id
  ///@param query Search terms to find in product index
  ///@param filters Filters
  ///@param sortOn Sort on
  ///@param taxonomyId taxonomyId
  ///@param suggestionId The suggestionId is used by the product-service for improving the autocomplete algorithm. When a customer uses before search the search call can be combined with the given suggestionId to help product-service to learn.
  ///@param size Number of records per page
  ///@param page Results page you want to retrieve (0..N)
  Future<chopper.Response<SearchResponse>> v2Get({
    String? xApplication,
    String? appieCurrentOrderId,
    String? query,
    String? filters,
    enums.V2GetSortOn? sortOn,
    num? taxonomyId,
    String? suggestionId,
    int? size,
    int? page,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SearchResponse, () => SearchResponse.fromJsonFactory);

    return _v2Get(
        xApplication: xApplication,
        appieCurrentOrderId: appieCurrentOrderId,
        query: query,
        filters: filters,
        sortOn: enums.$V2GetSortOnMap[sortOn]?.toString(),
        taxonomyId: taxonomyId,
        suggestionId: suggestionId,
        size: size,
        page: page,
        cacheControl: cacheControl);
  }

  ///product-search
  ///@param x-application
  ///@param Appie-Current-Order-Id
  ///@param query Search terms to find in product index
  ///@param filters Filters
  ///@param sortOn Sort on
  ///@param taxonomyId taxonomyId
  ///@param suggestionId The suggestionId is used by the product-service for improving the autocomplete algorithm. When a customer uses before search the search call can be combined with the given suggestionId to help product-service to learn.
  ///@param size Number of records per page
  ///@param page Results page you want to retrieve (0..N)
  @Get(path: '/v2')
  Future<chopper.Response<SearchResponse>> _v2Get({
    @Header('x-application') String? xApplication,
    @Header('Appie-Current-Order-Id') String? appieCurrentOrderId,
    @Query('query') String? query,
    @Query('filters') String? filters,
    @Query('sortOn') String? sortOn,
    @Query('taxonomyId') num? taxonomyId,
    @Query('suggestionId') String? suggestionId,
    @Query('size') int? size,
    @Query('page') int? page,
    @Header('Cache-Control') String? cacheControl,
  });

  ///product-search-suggestions
  ///@param x-application
  ///@param query Term to find suggestions for
  ///@param amount Amount of suggestions
  Future<chopper.Response<SuggestionsResponse>> v2SuggestionsGet({
    String? xApplication,
    required String? query,
    required String? amount,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SuggestionsResponse, () => SuggestionsResponse.fromJsonFactory);

    return _v2SuggestionsGet(
        xApplication: xApplication,
        query: query,
        amount: amount,
        cacheControl: cacheControl);
  }

  ///product-search-suggestions
  ///@param x-application
  ///@param query Term to find suggestions for
  ///@param amount Amount of suggestions
  @Get(path: '/v2/suggestions')
  Future<chopper.Response<SuggestionsResponse>> _v2SuggestionsGet({
    @Header('x-application') String? xApplication,
    @Query('query') required String? query,
    @Query('amount') required String? amount,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Filter {
  Filter({
    required this.id,
    this.allLabel,
    required this.label,
    this.options,
    required this.type,
    required this.booleanFilter,
  });

  factory Filter.fromJson(Map<String, dynamic> json) => _$FilterFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'allLabel', includeIfNull: false, defaultValue: '')
  final String? allLabel;
  @JsonKey(name: 'label', includeIfNull: false, defaultValue: '')
  final String label;
  @JsonKey(name: 'options', includeIfNull: false, defaultValue: <Option>[])
  final List<Option>? options;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: filterTypeToJson,
    fromJson: filterTypeFromJson,
  )
  final enums.FilterType type;
  @JsonKey(name: 'booleanFilter', includeIfNull: false)
  final bool booleanFilter;
  static const fromJsonFactory = _$FilterFromJson;
  static const toJsonFactory = _$FilterToJson;
  Map<String, dynamic> toJson() => _$FilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Filter &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.allLabel, allLabel) ||
                const DeepCollectionEquality()
                    .equals(other.allLabel, allLabel)) &&
            (identical(other.label, label) ||
                const DeepCollectionEquality().equals(other.label, label)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality()
                    .equals(other.options, options)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.booleanFilter, booleanFilter) ||
                const DeepCollectionEquality()
                    .equals(other.booleanFilter, booleanFilter)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(allLabel) ^
      const DeepCollectionEquality().hash(label) ^
      const DeepCollectionEquality().hash(options) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(booleanFilter) ^
      runtimeType.hashCode;
}

extension $FilterExtension on Filter {
  Filter copyWith(
      {String? id,
      String? allLabel,
      String? label,
      List<Option>? options,
      enums.FilterType? type,
      bool? booleanFilter}) {
    return Filter(
        id: id ?? this.id,
        allLabel: allLabel ?? this.allLabel,
        label: label ?? this.label,
        options: options ?? this.options,
        type: type ?? this.type,
        booleanFilter: booleanFilter ?? this.booleanFilter);
  }

  Filter copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? allLabel,
      Wrapped<String>? label,
      Wrapped<List<Option>?>? options,
      Wrapped<enums.FilterType>? type,
      Wrapped<bool>? booleanFilter}) {
    return Filter(
        id: (id != null ? id.value : this.id),
        allLabel: (allLabel != null ? allLabel.value : this.allLabel),
        label: (label != null ? label.value : this.label),
        options: (options != null ? options.value : this.options),
        type: (type != null ? type.value : this.type),
        booleanFilter:
            (booleanFilter != null ? booleanFilter.value : this.booleanFilter));
  }
}

@JsonSerializable(explicitToJson: true)
class FrontendConfiguration {
  FrontendConfiguration({
    required this.googleBanners,
  });

  factory FrontendConfiguration.fromJson(Map<String, dynamic> json) =>
      _$FrontendConfigurationFromJson(json);

  @JsonKey(name: 'googleBanners', includeIfNull: false)
  final GoogleBanners googleBanners;
  static const fromJsonFactory = _$FrontendConfigurationFromJson;
  static const toJsonFactory = _$FrontendConfigurationToJson;
  Map<String, dynamic> toJson() => _$FrontendConfigurationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FrontendConfiguration &&
            (identical(other.googleBanners, googleBanners) ||
                const DeepCollectionEquality()
                    .equals(other.googleBanners, googleBanners)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(googleBanners) ^ runtimeType.hashCode;
}

extension $FrontendConfigurationExtension on FrontendConfiguration {
  FrontendConfiguration copyWith({GoogleBanners? googleBanners}) {
    return FrontendConfiguration(
        googleBanners: googleBanners ?? this.googleBanners);
  }

  FrontendConfiguration copyWithWrapped(
      {Wrapped<GoogleBanners>? googleBanners}) {
    return FrontendConfiguration(
        googleBanners:
            (googleBanners != null ? googleBanners.value : this.googleBanners));
  }
}

@JsonSerializable(explicitToJson: true)
class GoogleBanners {
  GoogleBanners({
    required this.adUnitPath,
    required this.customTemplateId,
    required this.divGptAd,
  });

  factory GoogleBanners.fromJson(Map<String, dynamic> json) =>
      _$GoogleBannersFromJson(json);

  @JsonKey(name: 'adUnitPath', includeIfNull: false, defaultValue: '')
  final String adUnitPath;
  @JsonKey(name: 'customTemplateId', includeIfNull: false, defaultValue: '')
  final String customTemplateId;
  @JsonKey(name: 'divGptAd', includeIfNull: false, defaultValue: '')
  final String divGptAd;
  static const fromJsonFactory = _$GoogleBannersFromJson;
  static const toJsonFactory = _$GoogleBannersToJson;
  Map<String, dynamic> toJson() => _$GoogleBannersToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GoogleBanners &&
            (identical(other.adUnitPath, adUnitPath) ||
                const DeepCollectionEquality()
                    .equals(other.adUnitPath, adUnitPath)) &&
            (identical(other.customTemplateId, customTemplateId) ||
                const DeepCollectionEquality()
                    .equals(other.customTemplateId, customTemplateId)) &&
            (identical(other.divGptAd, divGptAd) ||
                const DeepCollectionEquality()
                    .equals(other.divGptAd, divGptAd)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(adUnitPath) ^
      const DeepCollectionEquality().hash(customTemplateId) ^
      const DeepCollectionEquality().hash(divGptAd) ^
      runtimeType.hashCode;
}

extension $GoogleBannersExtension on GoogleBanners {
  GoogleBanners copyWith(
      {String? adUnitPath, String? customTemplateId, String? divGptAd}) {
    return GoogleBanners(
        adUnitPath: adUnitPath ?? this.adUnitPath,
        customTemplateId: customTemplateId ?? this.customTemplateId,
        divGptAd: divGptAd ?? this.divGptAd);
  }

  GoogleBanners copyWithWrapped(
      {Wrapped<String>? adUnitPath,
      Wrapped<String>? customTemplateId,
      Wrapped<String>? divGptAd}) {
    return GoogleBanners(
        adUnitPath: (adUnitPath != null ? adUnitPath.value : this.adUnitPath),
        customTemplateId: (customTemplateId != null
            ? customTemplateId.value
            : this.customTemplateId),
        divGptAd: (divGptAd != null ? divGptAd.value : this.divGptAd));
  }
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    required this.width,
    required this.height,
    required this.url,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  @JsonKey(name: 'width', includeIfNull: false)
  final int width;
  @JsonKey(name: 'height', includeIfNull: false)
  final int height;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$ImageFromJson;
  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.width, width) ||
                const DeepCollectionEquality().equals(other.width, width)) &&
            (identical(other.height, height) ||
                const DeepCollectionEquality().equals(other.height, height)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(width) ^
      const DeepCollectionEquality().hash(height) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({int? width, int? height, String? url}) {
    return Image(
        width: width ?? this.width,
        height: height ?? this.height,
        url: url ?? this.url);
  }

  Image copyWithWrapped(
      {Wrapped<int>? width, Wrapped<int>? height, Wrapped<String>? url}) {
    return Image(
        width: (width != null ? width.value : this.width),
        height: (height != null ? height.value : this.height),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class Option {
  Option({
    required this.id,
    required this.label,
    required this.count,
    required this.display,
  });

  factory Option.fromJson(Map<String, dynamic> json) => _$OptionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'label', includeIfNull: false, defaultValue: '')
  final String label;
  @JsonKey(name: 'count', includeIfNull: false)
  final int count;
  @JsonKey(name: 'display', includeIfNull: false)
  final bool display;
  static const fromJsonFactory = _$OptionFromJson;
  static const toJsonFactory = _$OptionToJson;
  Map<String, dynamic> toJson() => _$OptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Option &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.label, label) ||
                const DeepCollectionEquality().equals(other.label, label)) &&
            (identical(other.count, count) ||
                const DeepCollectionEquality().equals(other.count, count)) &&
            (identical(other.display, display) ||
                const DeepCollectionEquality().equals(other.display, display)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(label) ^
      const DeepCollectionEquality().hash(count) ^
      const DeepCollectionEquality().hash(display) ^
      runtimeType.hashCode;
}

extension $OptionExtension on Option {
  Option copyWith({String? id, String? label, int? count, bool? display}) {
    return Option(
        id: id ?? this.id,
        label: label ?? this.label,
        count: count ?? this.count,
        display: display ?? this.display);
  }

  Option copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? label,
      Wrapped<int>? count,
      Wrapped<bool>? display}) {
    return Option(
        id: (id != null ? id.value : this.id),
        label: (label != null ? label.value : this.label),
        count: (count != null ? count.value : this.count),
        display: (display != null ? display.value : this.display));
  }
}

@JsonSerializable(explicitToJson: true)
class Page {
  Page({
    required this.size,
    required this.totalElements,
    required this.totalPages,
    required this.number,
  });

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  @JsonKey(name: 'size', includeIfNull: false)
  final int size;
  @JsonKey(name: 'totalElements', includeIfNull: false)
  final int totalElements;
  @JsonKey(name: 'totalPages', includeIfNull: false)
  final int totalPages;
  @JsonKey(name: 'number', includeIfNull: false)
  final int number;
  static const fromJsonFactory = _$PageFromJson;
  static const toJsonFactory = _$PageToJson;
  Map<String, dynamic> toJson() => _$PageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Page &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.totalElements, totalElements) ||
                const DeepCollectionEquality()
                    .equals(other.totalElements, totalElements)) &&
            (identical(other.totalPages, totalPages) ||
                const DeepCollectionEquality()
                    .equals(other.totalPages, totalPages)) &&
            (identical(other.number, number) ||
                const DeepCollectionEquality().equals(other.number, number)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(totalElements) ^
      const DeepCollectionEquality().hash(totalPages) ^
      const DeepCollectionEquality().hash(number) ^
      runtimeType.hashCode;
}

extension $PageExtension on Page {
  Page copyWith({int? size, int? totalElements, int? totalPages, int? number}) {
    return Page(
        size: size ?? this.size,
        totalElements: totalElements ?? this.totalElements,
        totalPages: totalPages ?? this.totalPages,
        number: number ?? this.number);
  }

  Page copyWithWrapped(
      {Wrapped<int>? size,
      Wrapped<int>? totalElements,
      Wrapped<int>? totalPages,
      Wrapped<int>? number}) {
    return Page(
        size: (size != null ? size.value : this.size),
        totalElements:
            (totalElements != null ? totalElements.value : this.totalElements),
        totalPages: (totalPages != null ? totalPages.value : this.totalPages),
        number: (number != null ? number.value : this.number));
  }
}

@JsonSerializable(explicitToJson: true)
class ProductCard {
  ProductCard({
    required this.webshopId,
    required this.hqId,
    required this.title,
    this.specialDescription,
    this.salesUnitSize,
    this.unitPriceDescription,
    this.images,
    this.bonusStartDate,
    this.bonusEndDate,
    this.discountType,
    this.segmentType,
    this.promotionType,
    this.bonusMechanism,
    this.currentPrice,
    this.priceBeforeBonus,
    this.orderAvailabilityStatus,
    this.orderAvailabilityDescription,
    this.mainCategory,
    this.subCategory,
    this.brand,
    this.shopType,
    this.bonusPeriodDescription,
    this.availableOnline,
    this.isPreviouslyBought,
    this.descriptionHighlights,
    this.propertyIcons,
    this.nix18,
    required this.isStapelBonus,
    this.extraDescriptions,
    this.bonusSegmentId,
    this.bonusSegmentDescription,
    required this.isBonus,
    this.descriptionFull,
    required this.isOrderable,
    required this.isInfiniteBonus,
    required this.isSample,
    this.isBonusPrice,
    required this.isSponsored,
  });

  factory ProductCard.fromJson(Map<String, dynamic> json) =>
      _$ProductCardFromJson(json);

  @JsonKey(name: 'webshopId', includeIfNull: false)
  final num webshopId;
  @JsonKey(name: 'hqId', includeIfNull: false)
  final num hqId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'specialDescription', includeIfNull: false, defaultValue: '')
  final String? specialDescription;
  @JsonKey(name: 'salesUnitSize', includeIfNull: false, defaultValue: '')
  final String? salesUnitSize;
  @JsonKey(name: 'unitPriceDescription', includeIfNull: false, defaultValue: '')
  final String? unitPriceDescription;
  @JsonKey(name: 'images', includeIfNull: false, defaultValue: <Image>[])
  final List<Image>? images;
  @JsonKey(name: 'bonusStartDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusStartDate;
  @JsonKey(name: 'bonusEndDate', includeIfNull: false, toJson: _dateToJson)
  final DateTime? bonusEndDate;
  @JsonKey(name: 'discountType', includeIfNull: false, defaultValue: '')
  final String? discountType;
  @JsonKey(name: 'segmentType', includeIfNull: false, defaultValue: '')
  final String? segmentType;
  @JsonKey(name: 'promotionType', includeIfNull: false, defaultValue: '')
  final String? promotionType;
  @JsonKey(name: 'bonusMechanism', includeIfNull: false, defaultValue: '')
  final String? bonusMechanism;
  @JsonKey(name: 'currentPrice', includeIfNull: false)
  final double? currentPrice;
  @JsonKey(name: 'priceBeforeBonus', includeIfNull: false)
  final double? priceBeforeBonus;
  @JsonKey(
      name: 'orderAvailabilityStatus', includeIfNull: false, defaultValue: '')
  final String? orderAvailabilityStatus;
  @JsonKey(
      name: 'orderAvailabilityDescription',
      includeIfNull: false,
      defaultValue: '')
  final String? orderAvailabilityDescription;
  @JsonKey(name: 'mainCategory', includeIfNull: false, defaultValue: '')
  final String? mainCategory;
  @JsonKey(name: 'subCategory', includeIfNull: false, defaultValue: '')
  final String? subCategory;
  @JsonKey(name: 'brand', includeIfNull: false, defaultValue: '')
  final String? brand;
  @JsonKey(name: 'shopType', includeIfNull: false, defaultValue: '')
  final String? shopType;
  @JsonKey(
      name: 'bonusPeriodDescription', includeIfNull: false, defaultValue: '')
  final String? bonusPeriodDescription;
  @JsonKey(name: 'availableOnline', includeIfNull: false)
  final bool? availableOnline;
  @JsonKey(name: 'isPreviouslyBought', includeIfNull: false)
  final bool? isPreviouslyBought;
  @JsonKey(
      name: 'descriptionHighlights', includeIfNull: false, defaultValue: '')
  final String? descriptionHighlights;
  @JsonKey(
      name: 'propertyIcons', includeIfNull: false, defaultValue: <String>[])
  final List<String>? propertyIcons;
  @JsonKey(name: 'nix18', includeIfNull: false)
  final bool? nix18;
  @JsonKey(name: 'isStapelBonus', includeIfNull: false)
  final bool isStapelBonus;
  @JsonKey(
      name: 'extraDescriptions', includeIfNull: false, defaultValue: <String>[])
  final List<String>? extraDescriptions;
  @JsonKey(name: 'bonusSegmentId', includeIfNull: false)
  final num? bonusSegmentId;
  @JsonKey(
      name: 'bonusSegmentDescription', includeIfNull: false, defaultValue: '')
  final String? bonusSegmentDescription;
  @JsonKey(name: 'isBonus', includeIfNull: false)
  final bool isBonus;
  @JsonKey(name: 'descriptionFull', includeIfNull: false, defaultValue: '')
  final String? descriptionFull;
  @JsonKey(name: 'isOrderable', includeIfNull: false)
  final bool isOrderable;
  @JsonKey(name: 'isInfiniteBonus', includeIfNull: false)
  final bool isInfiniteBonus;
  @JsonKey(name: 'isSample', includeIfNull: false)
  final bool isSample;
  @JsonKey(name: 'isBonusPrice', includeIfNull: false)
  final bool? isBonusPrice;
  @JsonKey(name: 'isSponsored', includeIfNull: false)
  final bool isSponsored;
  static const fromJsonFactory = _$ProductCardFromJson;
  static const toJsonFactory = _$ProductCardToJson;
  Map<String, dynamic> toJson() => _$ProductCardToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductCard &&
            (identical(other.webshopId, webshopId) ||
                const DeepCollectionEquality()
                    .equals(other.webshopId, webshopId)) &&
            (identical(other.hqId, hqId) ||
                const DeepCollectionEquality().equals(other.hqId, hqId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.specialDescription, specialDescription) ||
                const DeepCollectionEquality()
                    .equals(other.specialDescription, specialDescription)) &&
            (identical(other.salesUnitSize, salesUnitSize) ||
                const DeepCollectionEquality()
                    .equals(other.salesUnitSize, salesUnitSize)) &&
            (identical(other.unitPriceDescription, unitPriceDescription) ||
                const DeepCollectionEquality().equals(
                    other.unitPriceDescription, unitPriceDescription)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.bonusStartDate, bonusStartDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusStartDate, bonusStartDate)) &&
            (identical(other.bonusEndDate, bonusEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.bonusEndDate, bonusEndDate)) &&
            (identical(other.discountType, discountType) ||
                const DeepCollectionEquality()
                    .equals(other.discountType, discountType)) &&
            (identical(other.segmentType, segmentType) ||
                const DeepCollectionEquality()
                    .equals(other.segmentType, segmentType)) &&
            (identical(other.promotionType, promotionType) ||
                const DeepCollectionEquality()
                    .equals(other.promotionType, promotionType)) &&
            (identical(other.bonusMechanism, bonusMechanism) ||
                const DeepCollectionEquality()
                    .equals(other.bonusMechanism, bonusMechanism)) &&
            (identical(other.currentPrice, currentPrice) ||
                const DeepCollectionEquality()
                    .equals(other.currentPrice, currentPrice)) &&
            (identical(other.priceBeforeBonus, priceBeforeBonus) ||
                const DeepCollectionEquality()
                    .equals(other.priceBeforeBonus, priceBeforeBonus)) &&
            (identical(other.orderAvailabilityStatus, orderAvailabilityStatus) ||
                const DeepCollectionEquality().equals(
                    other.orderAvailabilityStatus, orderAvailabilityStatus)) &&
            (identical(other.orderAvailabilityDescription, orderAvailabilityDescription) ||
                const DeepCollectionEquality().equals(
                    other.orderAvailabilityDescription,
                    orderAvailabilityDescription)) &&
            (identical(other.mainCategory, mainCategory) ||
                const DeepCollectionEquality()
                    .equals(other.mainCategory, mainCategory)) &&
            (identical(other.subCategory, subCategory) ||
                const DeepCollectionEquality()
                    .equals(other.subCategory, subCategory)) &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)) &&
            (identical(other.shopType, shopType) ||
                const DeepCollectionEquality()
                    .equals(other.shopType, shopType)) &&
            (identical(other.bonusPeriodDescription, bonusPeriodDescription) ||
                const DeepCollectionEquality().equals(other.bonusPeriodDescription, bonusPeriodDescription)) &&
            (identical(other.availableOnline, availableOnline) || const DeepCollectionEquality().equals(other.availableOnline, availableOnline)) &&
            (identical(other.isPreviouslyBought, isPreviouslyBought) || const DeepCollectionEquality().equals(other.isPreviouslyBought, isPreviouslyBought)) &&
            (identical(other.descriptionHighlights, descriptionHighlights) || const DeepCollectionEquality().equals(other.descriptionHighlights, descriptionHighlights)) &&
            (identical(other.propertyIcons, propertyIcons) || const DeepCollectionEquality().equals(other.propertyIcons, propertyIcons)) &&
            (identical(other.nix18, nix18) || const DeepCollectionEquality().equals(other.nix18, nix18)) &&
            (identical(other.isStapelBonus, isStapelBonus) || const DeepCollectionEquality().equals(other.isStapelBonus, isStapelBonus)) &&
            (identical(other.extraDescriptions, extraDescriptions) || const DeepCollectionEquality().equals(other.extraDescriptions, extraDescriptions)) &&
            (identical(other.bonusSegmentId, bonusSegmentId) || const DeepCollectionEquality().equals(other.bonusSegmentId, bonusSegmentId)) &&
            (identical(other.bonusSegmentDescription, bonusSegmentDescription) || const DeepCollectionEquality().equals(other.bonusSegmentDescription, bonusSegmentDescription)) &&
            (identical(other.isBonus, isBonus) || const DeepCollectionEquality().equals(other.isBonus, isBonus)) &&
            (identical(other.descriptionFull, descriptionFull) || const DeepCollectionEquality().equals(other.descriptionFull, descriptionFull)) &&
            (identical(other.isOrderable, isOrderable) || const DeepCollectionEquality().equals(other.isOrderable, isOrderable)) &&
            (identical(other.isInfiniteBonus, isInfiniteBonus) || const DeepCollectionEquality().equals(other.isInfiniteBonus, isInfiniteBonus)) &&
            (identical(other.isSample, isSample) || const DeepCollectionEquality().equals(other.isSample, isSample)) &&
            (identical(other.isBonusPrice, isBonusPrice) || const DeepCollectionEquality().equals(other.isBonusPrice, isBonusPrice)) &&
            (identical(other.isSponsored, isSponsored) || const DeepCollectionEquality().equals(other.isSponsored, isSponsored)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(webshopId) ^
      const DeepCollectionEquality().hash(hqId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(specialDescription) ^
      const DeepCollectionEquality().hash(salesUnitSize) ^
      const DeepCollectionEquality().hash(unitPriceDescription) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(bonusStartDate) ^
      const DeepCollectionEquality().hash(bonusEndDate) ^
      const DeepCollectionEquality().hash(discountType) ^
      const DeepCollectionEquality().hash(segmentType) ^
      const DeepCollectionEquality().hash(promotionType) ^
      const DeepCollectionEquality().hash(bonusMechanism) ^
      const DeepCollectionEquality().hash(currentPrice) ^
      const DeepCollectionEquality().hash(priceBeforeBonus) ^
      const DeepCollectionEquality().hash(orderAvailabilityStatus) ^
      const DeepCollectionEquality().hash(orderAvailabilityDescription) ^
      const DeepCollectionEquality().hash(mainCategory) ^
      const DeepCollectionEquality().hash(subCategory) ^
      const DeepCollectionEquality().hash(brand) ^
      const DeepCollectionEquality().hash(shopType) ^
      const DeepCollectionEquality().hash(bonusPeriodDescription) ^
      const DeepCollectionEquality().hash(availableOnline) ^
      const DeepCollectionEquality().hash(isPreviouslyBought) ^
      const DeepCollectionEquality().hash(descriptionHighlights) ^
      const DeepCollectionEquality().hash(propertyIcons) ^
      const DeepCollectionEquality().hash(nix18) ^
      const DeepCollectionEquality().hash(isStapelBonus) ^
      const DeepCollectionEquality().hash(extraDescriptions) ^
      const DeepCollectionEquality().hash(bonusSegmentId) ^
      const DeepCollectionEquality().hash(bonusSegmentDescription) ^
      const DeepCollectionEquality().hash(isBonus) ^
      const DeepCollectionEquality().hash(descriptionFull) ^
      const DeepCollectionEquality().hash(isOrderable) ^
      const DeepCollectionEquality().hash(isInfiniteBonus) ^
      const DeepCollectionEquality().hash(isSample) ^
      const DeepCollectionEquality().hash(isBonusPrice) ^
      const DeepCollectionEquality().hash(isSponsored) ^
      runtimeType.hashCode;
}

extension $ProductCardExtension on ProductCard {
  ProductCard copyWith(
      {num? webshopId,
      num? hqId,
      String? title,
      String? specialDescription,
      String? salesUnitSize,
      String? unitPriceDescription,
      List<Image>? images,
      DateTime? bonusStartDate,
      DateTime? bonusEndDate,
      String? discountType,
      String? segmentType,
      String? promotionType,
      String? bonusMechanism,
      double? currentPrice,
      double? priceBeforeBonus,
      String? orderAvailabilityStatus,
      String? orderAvailabilityDescription,
      String? mainCategory,
      String? subCategory,
      String? brand,
      String? shopType,
      String? bonusPeriodDescription,
      bool? availableOnline,
      bool? isPreviouslyBought,
      String? descriptionHighlights,
      List<String>? propertyIcons,
      bool? nix18,
      bool? isStapelBonus,
      List<String>? extraDescriptions,
      num? bonusSegmentId,
      String? bonusSegmentDescription,
      bool? isBonus,
      String? descriptionFull,
      bool? isOrderable,
      bool? isInfiniteBonus,
      bool? isSample,
      bool? isBonusPrice,
      bool? isSponsored}) {
    return ProductCard(
        webshopId: webshopId ?? this.webshopId,
        hqId: hqId ?? this.hqId,
        title: title ?? this.title,
        specialDescription: specialDescription ?? this.specialDescription,
        salesUnitSize: salesUnitSize ?? this.salesUnitSize,
        unitPriceDescription: unitPriceDescription ?? this.unitPriceDescription,
        images: images ?? this.images,
        bonusStartDate: bonusStartDate ?? this.bonusStartDate,
        bonusEndDate: bonusEndDate ?? this.bonusEndDate,
        discountType: discountType ?? this.discountType,
        segmentType: segmentType ?? this.segmentType,
        promotionType: promotionType ?? this.promotionType,
        bonusMechanism: bonusMechanism ?? this.bonusMechanism,
        currentPrice: currentPrice ?? this.currentPrice,
        priceBeforeBonus: priceBeforeBonus ?? this.priceBeforeBonus,
        orderAvailabilityStatus:
            orderAvailabilityStatus ?? this.orderAvailabilityStatus,
        orderAvailabilityDescription:
            orderAvailabilityDescription ?? this.orderAvailabilityDescription,
        mainCategory: mainCategory ?? this.mainCategory,
        subCategory: subCategory ?? this.subCategory,
        brand: brand ?? this.brand,
        shopType: shopType ?? this.shopType,
        bonusPeriodDescription:
            bonusPeriodDescription ?? this.bonusPeriodDescription,
        availableOnline: availableOnline ?? this.availableOnline,
        isPreviouslyBought: isPreviouslyBought ?? this.isPreviouslyBought,
        descriptionHighlights:
            descriptionHighlights ?? this.descriptionHighlights,
        propertyIcons: propertyIcons ?? this.propertyIcons,
        nix18: nix18 ?? this.nix18,
        isStapelBonus: isStapelBonus ?? this.isStapelBonus,
        extraDescriptions: extraDescriptions ?? this.extraDescriptions,
        bonusSegmentId: bonusSegmentId ?? this.bonusSegmentId,
        bonusSegmentDescription:
            bonusSegmentDescription ?? this.bonusSegmentDescription,
        isBonus: isBonus ?? this.isBonus,
        descriptionFull: descriptionFull ?? this.descriptionFull,
        isOrderable: isOrderable ?? this.isOrderable,
        isInfiniteBonus: isInfiniteBonus ?? this.isInfiniteBonus,
        isSample: isSample ?? this.isSample,
        isBonusPrice: isBonusPrice ?? this.isBonusPrice,
        isSponsored: isSponsored ?? this.isSponsored);
  }

  ProductCard copyWithWrapped(
      {Wrapped<num>? webshopId,
      Wrapped<num>? hqId,
      Wrapped<String>? title,
      Wrapped<String?>? specialDescription,
      Wrapped<String?>? salesUnitSize,
      Wrapped<String?>? unitPriceDescription,
      Wrapped<List<Image>?>? images,
      Wrapped<DateTime?>? bonusStartDate,
      Wrapped<DateTime?>? bonusEndDate,
      Wrapped<String?>? discountType,
      Wrapped<String?>? segmentType,
      Wrapped<String?>? promotionType,
      Wrapped<String?>? bonusMechanism,
      Wrapped<double?>? currentPrice,
      Wrapped<double?>? priceBeforeBonus,
      Wrapped<String?>? orderAvailabilityStatus,
      Wrapped<String?>? orderAvailabilityDescription,
      Wrapped<String?>? mainCategory,
      Wrapped<String?>? subCategory,
      Wrapped<String?>? brand,
      Wrapped<String?>? shopType,
      Wrapped<String?>? bonusPeriodDescription,
      Wrapped<bool?>? availableOnline,
      Wrapped<bool?>? isPreviouslyBought,
      Wrapped<String?>? descriptionHighlights,
      Wrapped<List<String>?>? propertyIcons,
      Wrapped<bool?>? nix18,
      Wrapped<bool>? isStapelBonus,
      Wrapped<List<String>?>? extraDescriptions,
      Wrapped<num?>? bonusSegmentId,
      Wrapped<String?>? bonusSegmentDescription,
      Wrapped<bool>? isBonus,
      Wrapped<String?>? descriptionFull,
      Wrapped<bool>? isOrderable,
      Wrapped<bool>? isInfiniteBonus,
      Wrapped<bool>? isSample,
      Wrapped<bool?>? isBonusPrice,
      Wrapped<bool>? isSponsored}) {
    return ProductCard(
        webshopId: (webshopId != null ? webshopId.value : this.webshopId),
        hqId: (hqId != null ? hqId.value : this.hqId),
        title: (title != null ? title.value : this.title),
        specialDescription: (specialDescription != null
            ? specialDescription.value
            : this.specialDescription),
        salesUnitSize:
            (salesUnitSize != null ? salesUnitSize.value : this.salesUnitSize),
        unitPriceDescription: (unitPriceDescription != null
            ? unitPriceDescription.value
            : this.unitPriceDescription),
        images: (images != null ? images.value : this.images),
        bonusStartDate: (bonusStartDate != null
            ? bonusStartDate.value
            : this.bonusStartDate),
        bonusEndDate:
            (bonusEndDate != null ? bonusEndDate.value : this.bonusEndDate),
        discountType:
            (discountType != null ? discountType.value : this.discountType),
        segmentType:
            (segmentType != null ? segmentType.value : this.segmentType),
        promotionType:
            (promotionType != null ? promotionType.value : this.promotionType),
        bonusMechanism: (bonusMechanism != null
            ? bonusMechanism.value
            : this.bonusMechanism),
        currentPrice:
            (currentPrice != null ? currentPrice.value : this.currentPrice),
        priceBeforeBonus: (priceBeforeBonus != null
            ? priceBeforeBonus.value
            : this.priceBeforeBonus),
        orderAvailabilityStatus: (orderAvailabilityStatus != null
            ? orderAvailabilityStatus.value
            : this.orderAvailabilityStatus),
        orderAvailabilityDescription: (orderAvailabilityDescription != null
            ? orderAvailabilityDescription.value
            : this.orderAvailabilityDescription),
        mainCategory:
            (mainCategory != null ? mainCategory.value : this.mainCategory),
        subCategory:
            (subCategory != null ? subCategory.value : this.subCategory),
        brand: (brand != null ? brand.value : this.brand),
        shopType: (shopType != null ? shopType.value : this.shopType),
        bonusPeriodDescription: (bonusPeriodDescription != null
            ? bonusPeriodDescription.value
            : this.bonusPeriodDescription),
        availableOnline: (availableOnline != null
            ? availableOnline.value
            : this.availableOnline),
        isPreviouslyBought: (isPreviouslyBought != null
            ? isPreviouslyBought.value
            : this.isPreviouslyBought),
        descriptionHighlights: (descriptionHighlights != null
            ? descriptionHighlights.value
            : this.descriptionHighlights),
        propertyIcons:
            (propertyIcons != null ? propertyIcons.value : this.propertyIcons),
        nix18: (nix18 != null ? nix18.value : this.nix18),
        isStapelBonus:
            (isStapelBonus != null ? isStapelBonus.value : this.isStapelBonus),
        extraDescriptions: (extraDescriptions != null
            ? extraDescriptions.value
            : this.extraDescriptions),
        bonusSegmentId: (bonusSegmentId != null
            ? bonusSegmentId.value
            : this.bonusSegmentId),
        bonusSegmentDescription: (bonusSegmentDescription != null
            ? bonusSegmentDescription.value
            : this.bonusSegmentDescription),
        isBonus: (isBonus != null ? isBonus.value : this.isBonus),
        descriptionFull: (descriptionFull != null
            ? descriptionFull.value
            : this.descriptionFull),
        isOrderable:
            (isOrderable != null ? isOrderable.value : this.isOrderable),
        isInfiniteBonus: (isInfiniteBonus != null
            ? isInfiniteBonus.value
            : this.isInfiniteBonus),
        isSample: (isSample != null ? isSample.value : this.isSample),
        isBonusPrice:
            (isBonusPrice != null ? isBonusPrice.value : this.isBonusPrice),
        isSponsored:
            (isSponsored != null ? isSponsored.value : this.isSponsored));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchLink {
  SearchLink({
    required this.href,
  });

  factory SearchLink.fromJson(Map<String, dynamic> json) =>
      _$SearchLinkFromJson(json);

  @JsonKey(name: 'href', includeIfNull: false, defaultValue: '')
  final String href;
  static const fromJsonFactory = _$SearchLinkFromJson;
  static const toJsonFactory = _$SearchLinkToJson;
  Map<String, dynamic> toJson() => _$SearchLinkToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchLink &&
            (identical(other.href, href) ||
                const DeepCollectionEquality().equals(other.href, href)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(href) ^ runtimeType.hashCode;
}

extension $SearchLinkExtension on SearchLink {
  SearchLink copyWith({String? href}) {
    return SearchLink(href: href ?? this.href);
  }

  SearchLink copyWithWrapped({Wrapped<String>? href}) {
    return SearchLink(href: (href != null ? href.value : this.href));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchLinks {
  SearchLinks({
    this.first,
    required this.current,
    this.next,
    this.prev,
    this.last,
  });

  factory SearchLinks.fromJson(Map<String, dynamic> json) =>
      _$SearchLinksFromJson(json);

  @JsonKey(name: 'first', includeIfNull: false)
  final SearchLink? first;
  @JsonKey(name: 'current', includeIfNull: false)
  final SearchLink current;
  @JsonKey(name: 'next', includeIfNull: false)
  final SearchLink? next;
  @JsonKey(name: 'prev', includeIfNull: false)
  final SearchLink? prev;
  @JsonKey(name: 'last', includeIfNull: false)
  final SearchLink? last;
  static const fromJsonFactory = _$SearchLinksFromJson;
  static const toJsonFactory = _$SearchLinksToJson;
  Map<String, dynamic> toJson() => _$SearchLinksToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchLinks &&
            (identical(other.first, first) ||
                const DeepCollectionEquality().equals(other.first, first)) &&
            (identical(other.current, current) ||
                const DeepCollectionEquality()
                    .equals(other.current, current)) &&
            (identical(other.next, next) ||
                const DeepCollectionEquality().equals(other.next, next)) &&
            (identical(other.prev, prev) ||
                const DeepCollectionEquality().equals(other.prev, prev)) &&
            (identical(other.last, last) ||
                const DeepCollectionEquality().equals(other.last, last)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(first) ^
      const DeepCollectionEquality().hash(current) ^
      const DeepCollectionEquality().hash(next) ^
      const DeepCollectionEquality().hash(prev) ^
      const DeepCollectionEquality().hash(last) ^
      runtimeType.hashCode;
}

extension $SearchLinksExtension on SearchLinks {
  SearchLinks copyWith(
      {SearchLink? first,
      SearchLink? current,
      SearchLink? next,
      SearchLink? prev,
      SearchLink? last}) {
    return SearchLinks(
        first: first ?? this.first,
        current: current ?? this.current,
        next: next ?? this.next,
        prev: prev ?? this.prev,
        last: last ?? this.last);
  }

  SearchLinks copyWithWrapped(
      {Wrapped<SearchLink?>? first,
      Wrapped<SearchLink>? current,
      Wrapped<SearchLink?>? next,
      Wrapped<SearchLink?>? prev,
      Wrapped<SearchLink?>? last}) {
    return SearchLinks(
        first: (first != null ? first.value : this.first),
        current: (current != null ? current.value : this.current),
        next: (next != null ? next.value : this.next),
        prev: (prev != null ? prev.value : this.prev),
        last: (last != null ? last.value : this.last));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchResponse {
  SearchResponse({
    required this.filters,
    required this.configuration,
    this.links,
    required this.page,
    required this.products,
  });

  factory SearchResponse.fromJson(Map<String, dynamic> json) =>
      _$SearchResponseFromJson(json);

  @JsonKey(name: 'filters', includeIfNull: false, defaultValue: <Filter>[])
  final List<Filter> filters;
  @JsonKey(name: 'configuration', includeIfNull: false)
  final FrontendConfiguration configuration;
  @JsonKey(name: 'links', includeIfNull: false)
  final SearchLinks? links;
  @JsonKey(name: 'page', includeIfNull: false)
  final Page page;
  @JsonKey(
      name: 'products', includeIfNull: false, defaultValue: <ProductCard>[])
  final List<ProductCard> products;
  static const fromJsonFactory = _$SearchResponseFromJson;
  static const toJsonFactory = _$SearchResponseToJson;
  Map<String, dynamic> toJson() => _$SearchResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchResponse &&
            (identical(other.filters, filters) ||
                const DeepCollectionEquality()
                    .equals(other.filters, filters)) &&
            (identical(other.configuration, configuration) ||
                const DeepCollectionEquality()
                    .equals(other.configuration, configuration)) &&
            (identical(other.links, links) ||
                const DeepCollectionEquality().equals(other.links, links)) &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)) &&
            (identical(other.products, products) ||
                const DeepCollectionEquality()
                    .equals(other.products, products)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(filters) ^
      const DeepCollectionEquality().hash(configuration) ^
      const DeepCollectionEquality().hash(links) ^
      const DeepCollectionEquality().hash(page) ^
      const DeepCollectionEquality().hash(products) ^
      runtimeType.hashCode;
}

extension $SearchResponseExtension on SearchResponse {
  SearchResponse copyWith(
      {List<Filter>? filters,
      FrontendConfiguration? configuration,
      SearchLinks? links,
      Page? page,
      List<ProductCard>? products}) {
    return SearchResponse(
        filters: filters ?? this.filters,
        configuration: configuration ?? this.configuration,
        links: links ?? this.links,
        page: page ?? this.page,
        products: products ?? this.products);
  }

  SearchResponse copyWithWrapped(
      {Wrapped<List<Filter>>? filters,
      Wrapped<FrontendConfiguration>? configuration,
      Wrapped<SearchLinks?>? links,
      Wrapped<Page>? page,
      Wrapped<List<ProductCard>>? products}) {
    return SearchResponse(
        filters: (filters != null ? filters.value : this.filters),
        configuration:
            (configuration != null ? configuration.value : this.configuration),
        links: (links != null ? links.value : this.links),
        page: (page != null ? page.value : this.page),
        products: (products != null ? products.value : this.products));
  }
}

@JsonSerializable(explicitToJson: true)
class SuggestionsResponse {
  SuggestionsResponse({
    this.id,
    required this.suggestions,
  });

  factory SuggestionsResponse.fromJson(Map<String, dynamic> json) =>
      _$SuggestionsResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'suggestions', includeIfNull: false, defaultValue: <String>[])
  final List<String> suggestions;
  static const fromJsonFactory = _$SuggestionsResponseFromJson;
  static const toJsonFactory = _$SuggestionsResponseToJson;
  Map<String, dynamic> toJson() => _$SuggestionsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SuggestionsResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.suggestions, suggestions) ||
                const DeepCollectionEquality()
                    .equals(other.suggestions, suggestions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(suggestions) ^
      runtimeType.hashCode;
}

extension $SuggestionsResponseExtension on SuggestionsResponse {
  SuggestionsResponse copyWith({String? id, List<String>? suggestions}) {
    return SuggestionsResponse(
        id: id ?? this.id, suggestions: suggestions ?? this.suggestions);
  }

  SuggestionsResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<List<String>>? suggestions}) {
    return SuggestionsResponse(
        id: (id != null ? id.value : this.id),
        suggestions:
            (suggestions != null ? suggestions.value : this.suggestions));
  }
}

String? v1GetSortOnToJson(enums.V1GetSortOn? v1GetSortOn) {
  return enums.$V1GetSortOnMap[v1GetSortOn];
}

enums.V1GetSortOn v1GetSortOnFromJson(
  Object? v1GetSortOn, [
  enums.V1GetSortOn? defaultValue,
]) {
  if (v1GetSortOn is String) {
    return enums.$V1GetSortOnMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == v1GetSortOn.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.V1GetSortOn.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1GetSortOnMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1GetSortOn.swaggerGeneratedUnknown;
}

List<String> v1GetSortOnListToJson(List<enums.V1GetSortOn>? v1GetSortOn) {
  if (v1GetSortOn == null) {
    return [];
  }

  return v1GetSortOn.map((e) => enums.$V1GetSortOnMap[e]!).toList();
}

List<enums.V1GetSortOn> v1GetSortOnListFromJson(
  List? v1GetSortOn, [
  List<enums.V1GetSortOn>? defaultValue,
]) {
  if (v1GetSortOn == null) {
    return defaultValue ?? [];
  }

  return v1GetSortOn.map((e) => v1GetSortOnFromJson(e.toString())).toList();
}

List<enums.V1GetSortOn>? v1GetSortOnNullableListFromJson(
  List? v1GetSortOn, [
  List<enums.V1GetSortOn>? defaultValue,
]) {
  if (v1GetSortOn == null) {
    return defaultValue;
  }

  return v1GetSortOn.map((e) => v1GetSortOnFromJson(e.toString())).toList();
}

String? v2GetSortOnToJson(enums.V2GetSortOn? v2GetSortOn) {
  return enums.$V2GetSortOnMap[v2GetSortOn];
}

enums.V2GetSortOn v2GetSortOnFromJson(
  Object? v2GetSortOn, [
  enums.V2GetSortOn? defaultValue,
]) {
  if (v2GetSortOn is String) {
    return enums.$V2GetSortOnMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == v2GetSortOn.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.V2GetSortOn.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V2GetSortOnMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V2GetSortOn.swaggerGeneratedUnknown;
}

List<String> v2GetSortOnListToJson(List<enums.V2GetSortOn>? v2GetSortOn) {
  if (v2GetSortOn == null) {
    return [];
  }

  return v2GetSortOn.map((e) => enums.$V2GetSortOnMap[e]!).toList();
}

List<enums.V2GetSortOn> v2GetSortOnListFromJson(
  List? v2GetSortOn, [
  List<enums.V2GetSortOn>? defaultValue,
]) {
  if (v2GetSortOn == null) {
    return defaultValue ?? [];
  }

  return v2GetSortOn.map((e) => v2GetSortOnFromJson(e.toString())).toList();
}

List<enums.V2GetSortOn>? v2GetSortOnNullableListFromJson(
  List? v2GetSortOn, [
  List<enums.V2GetSortOn>? defaultValue,
]) {
  if (v2GetSortOn == null) {
    return defaultValue;
  }

  return v2GetSortOn.map((e) => v2GetSortOnFromJson(e.toString())).toList();
}

String? filterTypeToJson(enums.FilterType? filterType) {
  return enums.$FilterTypeMap[filterType];
}

enums.FilterType filterTypeFromJson(
  Object? filterType, [
  enums.FilterType? defaultValue,
]) {
  if (filterType is String) {
    return enums.$FilterTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == filterType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.FilterType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$FilterTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.FilterType.swaggerGeneratedUnknown;
}

List<String> filterTypeListToJson(List<enums.FilterType>? filterType) {
  if (filterType == null) {
    return [];
  }

  return filterType.map((e) => enums.$FilterTypeMap[e]!).toList();
}

List<enums.FilterType> filterTypeListFromJson(
  List? filterType, [
  List<enums.FilterType>? defaultValue,
]) {
  if (filterType == null) {
    return defaultValue ?? [];
  }

  return filterType.map((e) => filterTypeFromJson(e.toString())).toList();
}

List<enums.FilterType>? filterTypeNullableListFromJson(
  List? filterType, [
  List<enums.FilterType>? defaultValue,
]) {
  if (filterType == null) {
    return defaultValue;
  }

  return filterType.map((e) => filterTypeFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
