// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'products_remote_data_source.swagger.chopper.dart';
part 'products_remote_data_source.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ProductsRemoteDataSource extends ChopperService {
  static ProductsRemoteDataSource create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ProductsRemoteDataSource(client);
    }

    final newClient = ChopperClient(
        services: [_$ProductsRemoteDataSource()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$ProductsRemoteDataSource(newClient);
  }

  ///Get product sub-categories
  ///@param X-Application
  ///@param id
  Future<chopper.Response<SubCategory>>
      v1ProductShelvesCategoriesIdSubCategoriesGet({
    String? xApplication,
    required num? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SubCategory, () => SubCategory.fromJsonFactory);

    return _v1ProductShelvesCategoriesIdSubCategoriesGet(
        xApplication: xApplication, id: id, cacheControl: cacheControl);
  }

  ///Get product sub-categories
  ///@param X-Application
  ///@param id
  @Get(path: '/v1/product-shelves/categories/{id}/sub-categories')
  Future<chopper.Response<SubCategory>>
      _v1ProductShelvesCategoriesIdSubCategoriesGet({
    @Header('X-Application') String? xApplication,
    @Path('id') required num? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get product categories (top level)
  ///@param X-Application
  Future<chopper.Response<List<ProductCategory>>>
      v1ProductShelvesCategoriesGet({
    String? xApplication,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProductCategory, () => ProductCategory.fromJsonFactory);

    return _v1ProductShelvesCategoriesGet(
        xApplication: xApplication, cacheControl: cacheControl);
  }

  ///Get product categories (top level)
  ///@param X-Application
  @Get(path: '/v1/product-shelves/categories')
  Future<chopper.Response<List<ProductCategory>>>
      _v1ProductShelvesCategoriesGet({
    @Header('X-Application') String? xApplication,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    this.height,
    this.width,
    this.url,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  @JsonKey(name: 'height', includeIfNull: false)
  final int? height;
  @JsonKey(name: 'width', includeIfNull: false)
  final int? width;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$ImageFromJson;
  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.height, height) ||
                const DeepCollectionEquality().equals(other.height, height)) &&
            (identical(other.width, width) ||
                const DeepCollectionEquality().equals(other.width, width)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(height) ^
      const DeepCollectionEquality().hash(width) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({int? height, int? width, String? url}) {
    return Image(
        height: height ?? this.height,
        width: width ?? this.width,
        url: url ?? this.url);
  }

  Image copyWithWrapped(
      {Wrapped<int?>? height, Wrapped<int?>? width, Wrapped<String?>? url}) {
    return Image(
        height: (height != null ? height.value : this.height),
        width: (width != null ? width.value : this.width),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class ProductCategory {
  ProductCategory({
    required this.id,
    this.name,
    required this.images,
    required this.nix18,
  });

  factory ProductCategory.fromJson(Map<String, dynamic> json) =>
      _$ProductCategoryFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'images', includeIfNull: false)
  final List<Image> images;
  @JsonKey(name: 'nix18', includeIfNull: false)
  final bool nix18;
  static const fromJsonFactory = _$ProductCategoryFromJson;
  static const toJsonFactory = _$ProductCategoryToJson;
  Map<String, dynamic> toJson() => _$ProductCategoryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductCategory &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.nix18, nix18) ||
                const DeepCollectionEquality().equals(other.nix18, nix18)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(nix18) ^
      runtimeType.hashCode;
}

extension $ProductCategoryExtension on ProductCategory {
  ProductCategory copyWith(
      {num? id, String? name, List<Image>? images, bool? nix18}) {
    return ProductCategory(
        id: id ?? this.id,
        name: name ?? this.name,
        images: images ?? this.images,
        nix18: nix18 ?? this.nix18);
  }

  ProductCategory copyWithWrapped(
      {Wrapped<num>? id,
      Wrapped<String?>? name,
      Wrapped<List<Image>>? images,
      Wrapped<bool>? nix18}) {
    return ProductCategory(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        images: (images != null ? images.value : this.images),
        nix18: (nix18 != null ? nix18.value : this.nix18));
  }
}

@JsonSerializable(explicitToJson: true)
class SubCategory {
  SubCategory({
    required this.parent,
    required this.children,
  });

  factory SubCategory.fromJson(Map<String, dynamic> json) =>
      _$SubCategoryFromJson(json);

  @JsonKey(name: 'parent', includeIfNull: false)
  final ProductCategory parent;
  @JsonKey(name: 'children', includeIfNull: false)
  final List<ProductCategory> children;
  static const fromJsonFactory = _$SubCategoryFromJson;
  static const toJsonFactory = _$SubCategoryToJson;
  Map<String, dynamic> toJson() => _$SubCategoryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubCategory &&
            (identical(other.parent, parent) ||
                const DeepCollectionEquality().equals(other.parent, parent)) &&
            (identical(other.children, children) ||
                const DeepCollectionEquality()
                    .equals(other.children, children)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(parent) ^
      const DeepCollectionEquality().hash(children) ^
      runtimeType.hashCode;
}

extension $SubCategoryExtension on SubCategory {
  SubCategory copyWith(
      {ProductCategory? parent, List<ProductCategory>? children}) {
    return SubCategory(
        parent: parent ?? this.parent, children: children ?? this.children);
  }

  SubCategory copyWithWrapped(
      {Wrapped<ProductCategory>? parent,
      Wrapped<List<ProductCategory>>? children}) {
    return SubCategory(
        parent: (parent != null ? parent.value : this.parent),
        children: (children != null ? children.value : this.children));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
