// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'purchase_service.enums.swagger.dart' as enums;
export 'purchase_service.enums.swagger.dart';

part 'purchase_service.swagger.chopper.dart';
part 'purchase_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PurchaseService extends ChopperService {
  static PurchaseService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PurchaseService(client);
    }

    final newClient = ChopperClient(
        services: [_$PurchaseService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$PurchaseService(newClient);
  }

  ///Purchase a TVOD product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-cus Customer identifier
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> customersCustomerIdPurchasePost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xClaimsSet,
    String? cacheControl,
    required Purchase? body,
  }) {
    return _customersCustomerIdPurchasePost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl,
        body: body);
  }

  ///Purchase a TVOD product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-cus Customer identifier
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  @Post(path: '/customers/{customerId}/purchase')
  Future<chopper.Response> _customersCustomerIdPurchasePost({
    @Path('customerId') required String? customerId,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Purchase? body,
  });

  ///Refreshes the entitlements for cpeId, faster delivery of the EMM, the OMW on the STB calls Traxis
  ///@param cpeId Customer-premises equipment identifier.
  Future<chopper.Response> refreshEntitlementsCpeIdPost({
    required String? cpeId,
    String? cacheControl,
  }) {
    return _refreshEntitlementsCpeIdPost(
        cpeId: cpeId, cacheControl: cacheControl);
  }

  ///Refreshes the entitlements for cpeId, faster delivery of the EMM, the OMW on the STB calls Traxis
  ///@param cpeId Customer-premises equipment identifier.
  @Post(
    path: '/refreshEntitlements/{cpeId}',
    optionalBody: true,
  )
  Future<chopper.Response> _refreshEntitlementsCpeIdPost({
    @Path('cpeId') required String? cpeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns UI stack information for existing device or proxy plug and play activation request to Akana
  ///@param cpeId Customer-premises equipment identifier.
  Future<chopper.Response<PlugAndPlayResponse>> plugAndPlayCpeIdPost({
    required String? cpeId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PlugAndPlayResponse, () => PlugAndPlayResponse.fromJsonFactory);

    return _plugAndPlayCpeIdPost(cpeId: cpeId, cacheControl: cacheControl);
  }

  ///Returns UI stack information for existing device or proxy plug and play activation request to Akana
  ///@param cpeId Customer-premises equipment identifier.
  @Post(
    path: '/plugAndPlay/{cpeId}',
    optionalBody: true,
  )
  Future<chopper.Response<PlugAndPlayResponse>> _plugAndPlayCpeIdPost({
    @Path('cpeId') required String? cpeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Purchase a TVOD product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-cus Customer identifier
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> v2CustomersCustomerIdPurchasePost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xClaimsSet,
    String? cacheControl,
    required Purchase? body,
  }) {
    return _v2CustomersCustomerIdPurchasePost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl,
        body: body);
  }

  ///Purchase a TVOD product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-cus Customer identifier
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  @Post(path: '/v2/customers/{customerId}/purchase')
  Future<chopper.Response> _v2CustomersCustomerIdPurchasePost({
    @Path('customerId') required String? customerId,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Purchase? body,
  });

  ///Provide entitlements list.
  ///@param customerId Identifier of a customer to return list of entitlements.
  ///@param enableDaypass If flag is enabled, day pass backward compatibility is disabled
  ///@param x-cus Customer identifier
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  ///@param X-Forwarded-For IP address to check if customer in home
  Future<chopper.Response<V2CustomerEntitlements>>
      v2CustomersCustomerIdEntitlementsGet({
    required String? customerId,
    bool? enableDaypass,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xClaimsSet,
    String? xForwardedFor,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        V2CustomerEntitlements, () => V2CustomerEntitlements.fromJsonFactory);

    return _v2CustomersCustomerIdEntitlementsGet(
        customerId: customerId,
        enableDaypass: enableDaypass,
        xCus: xCus,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        xForwardedFor: xForwardedFor,
        cacheControl: cacheControl);
  }

  ///Provide entitlements list.
  ///@param customerId Identifier of a customer to return list of entitlements.
  ///@param enableDaypass If flag is enabled, day pass backward compatibility is disabled
  ///@param x-cus Customer identifier
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  ///@param X-Forwarded-For IP address to check if customer in home
  @Get(path: '/v2/customers/{customerId}/entitlements')
  Future<chopper.Response<V2CustomerEntitlements>>
      _v2CustomersCustomerIdEntitlementsGet({
    @Path('customerId') required String? customerId,
    @Query('enableDaypass') bool? enableDaypass,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('X-Forwarded-For') String? xForwardedFor,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Purchase a PPV product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> v2CustomersCustomerIdPurchasesPpvPost({
    required String? customerId,
    String? xDev,
    String? xClaimsSet,
    String? cacheControl,
    required V2PayPerViewPurchase? body,
  }) {
    return _v2CustomersCustomerIdPurchasesPpvPost(
        customerId: customerId,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl,
        body: body);
  }

  ///Purchase a PPV product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  @Post(path: '/v2/customers/{customerId}/purchases/ppv')
  Future<chopper.Response> _v2CustomersCustomerIdPurchasesPpvPost({
    @Path('customerId') required String? customerId,
    @Header('x-dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
    @Body() required V2PayPerViewPurchase? body,
  });

  ///Purchase a DayPass product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> v2CustomersCustomerIdPurchasesDaypassPost({
    required String? customerId,
    String? xDev,
    String? xClaimsSet,
    String? cacheControl,
    required V2DayPassPurchase? body,
  }) {
    return _v2CustomersCustomerIdPurchasesDaypassPost(
        customerId: customerId,
        xDev: xDev,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl,
        body: body);
  }

  ///Purchase a DayPass product.
  ///@param customerId Identifier of a customer purchasing the specified product.
  ///@param x-dev Device identifier
  ///@param X-Claims-Set Encoded customer information
  @Post(path: '/v2/customers/{customerId}/purchases/daypass')
  Future<chopper.Response> _v2CustomersCustomerIdPurchasesDaypassPost({
    @Path('customerId') required String? customerId,
    @Header('x-dev') String? xDev,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
    @Body() required V2DayPassPurchase? body,
  });

  ///Updates a specific customer, their budget and entitlements.
  Future<chopper.Response> v3CustomersPut({
    String? cacheControl,
    required V3CustomerParams? body,
  }) {
    return _v3CustomersPut(cacheControl: cacheControl, body: body);
  }

  ///Updates a specific customer, their budget and entitlements.
  @Put(path: '/v3/customers')
  Future<chopper.Response> _v3CustomersPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required V3CustomerParams? body,
  });

  ///Creates a customer, their budget and entitlements.
  Future<chopper.Response> v3CustomersPost({
    String? cacheControl,
    required V3CustomerParams? body,
  }) {
    return _v3CustomersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a customer, their budget and entitlements.
  @Post(path: '/v3/customers')
  Future<chopper.Response> _v3CustomersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required V3CustomerParams? body,
  });

  ///Returns customer data to the CPS and the Potal.
  ///@param customerId The customer identifier for which the budget and entitlements are being set.
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response<V3Customer>> v3CustomersCustomerIdGet({
    required String? customerId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(V3Customer, () => V3Customer.fromJsonFactory);

    return _v3CustomersCustomerIdGet(
        customerId: customerId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Returns customer data to the CPS and the Potal.
  ///@param customerId The customer identifier for which the budget and entitlements are being set.
  ///@param X-Claims-Set Encoded customer information
  @Get(path: '/v3/customers/{customerId}')
  Future<chopper.Response<V3Customer>> _v3CustomersCustomerIdGet({
    @Path('customerId') required String? customerId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Deletes a specific customer and purge their history, budget and entitlements.
  ///@param customerId The customer identifier who is going to be deleted
  Future<chopper.Response> v3CustomersCustomerIdDelete({
    required String? customerId,
    String? cacheControl,
  }) {
    return _v3CustomersCustomerIdDelete(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Deletes a specific customer and purge their history, budget and entitlements.
  ///@param customerId The customer identifier who is going to be deleted
  @Delete(path: '/v3/customers/{customerId}')
  Future<chopper.Response> _v3CustomersCustomerIdDelete({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Changes the status of a customer to either active or inactive.
  ///@param customerId The customer identifier which is being activated or deactivated.
  Future<chopper.Response> v3CustomersCustomerIdStatusPut({
    required String? customerId,
    String? cacheControl,
    required enums.CustomerStatus? body,
  }) {
    return _v3CustomersCustomerIdStatusPut(
        customerId: customerId,
        cacheControl: cacheControl,
        body: enums.$CustomerStatusMap[body]?.toString());
  }

  ///Changes the status of a customer to either active or inactive.
  ///@param customerId The customer identifier which is being activated or deactivated.
  @Put(path: '/v3/customers/{customerId}/status')
  Future<chopper.Response> _v3CustomersCustomerIdStatusPut({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required dynamic body,
  });

  ///Returns customer purchase history.
  ///@param customerId The customer identifier for which the purchase history is to be returned.
  Future<chopper.Response<V3History>> v3CustomersCustomerIdHistoryGet({
    required String? customerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(V3History, () => V3History.fromJsonFactory);

    return _v3CustomersCustomerIdHistoryGet(
        customerId: customerId, cacheControl: cacheControl);
  }

  ///Returns customer purchase history.
  ///@param customerId The customer identifier for which the purchase history is to be returned.
  @Get(path: '/v3/customers/{customerId}/history')
  Future<chopper.Response<V3History>> _v3CustomersCustomerIdHistoryGet({
    @Path('customerId') required String? customerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates customer device for skip in-home check.
  ///@param customerId The customer identifier
  ///@param deviceId The customer device identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> v3CustomersCustomerIdDevicesDeviceIdPatch({
    required String? customerId,
    required String? deviceId,
    String? xClaimsSet,
    String? cacheControl,
    required V3DeviceSkipInHomeCheckUpdateParam? body,
  }) {
    return _v3CustomersCustomerIdDevicesDeviceIdPatch(
        customerId: customerId,
        deviceId: deviceId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl,
        body: body);
  }

  ///Updates customer device for skip in-home check.
  ///@param customerId The customer identifier
  ///@param deviceId The customer device identifier
  ///@param X-Claims-Set Encoded customer information
  @Patch(path: '/v3/customers/{customerId}/devices/{deviceId}')
  Future<chopper.Response> _v3CustomersCustomerIdDevicesDeviceIdPatch({
    @Path('customerId') required String? customerId,
    @Path('deviceId') required String? deviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
    @Body() required V3DeviceSkipInHomeCheckUpdateParam? body,
  });

  ///Check customer device for skip in-home check.
  ///@param customerId The customer identifier
  ///@param deviceId The customer device identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response<V3DeviceSkipInHomeCheck>>
      v3CustomersCustomerIdDevicesDeviceIdGet({
    required String? customerId,
    required String? deviceId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        V3DeviceSkipInHomeCheck, () => V3DeviceSkipInHomeCheck.fromJsonFactory);

    return _v3CustomersCustomerIdDevicesDeviceIdGet(
        customerId: customerId,
        deviceId: deviceId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Check customer device for skip in-home check.
  ///@param customerId The customer identifier
  ///@param deviceId The customer device identifier
  ///@param X-Claims-Set Encoded customer information
  @Get(path: '/v3/customers/{customerId}/devices/{deviceId}')
  Future<chopper.Response<V3DeviceSkipInHomeCheck>>
      _v3CustomersCustomerIdDevicesDeviceIdGet({
    @Path('customerId') required String? customerId,
    @Path('deviceId') required String? deviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Sends notification to refresh entitlements on the equipment
  ///@param customerId The customer identifier
  ///@param X-Claims-Set Encoded customer information
  Future<chopper.Response> v3CustomersCustomerIdRefreshCpePost({
    required String? customerId,
    String? xClaimsSet,
    String? cacheControl,
  }) {
    return _v3CustomersCustomerIdRefreshCpePost(
        customerId: customerId,
        xClaimsSet: xClaimsSet,
        cacheControl: cacheControl);
  }

  ///Sends notification to refresh entitlements on the equipment
  ///@param customerId The customer identifier
  ///@param X-Claims-Set Encoded customer information
  @Post(
    path: '/v3/customers/{customerId}/refreshCpe',
    optionalBody: true,
  )
  Future<chopper.Response> _v3CustomersCustomerIdRefreshCpePost({
    @Path('customerId') required String? customerId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Schedules TVOD and PPV purchases cleanup (triggered by cronjob - not intended to be run manually)
  Future<chopper.Response> adminTasksCleanupPurchasePost(
      {String? cacheControl}) {
    return _adminTasksCleanupPurchasePost(cacheControl: cacheControl);
  }

  ///Schedules TVOD and PPV purchases cleanup (triggered by cronjob - not intended to be run manually)
  @Post(
    path: '/admin/tasks/cleanup_purchase',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksCleanupPurchasePost(
      {@Header('Cache-Control') String? cacheControl});

  ///Schedules customer export tasks (triggered by cronjob - not intended to be run manually)
  Future<chopper.Response> adminTasksExportCustomerPost(
      {String? cacheControl}) {
    return _adminTasksExportCustomerPost(cacheControl: cacheControl);
  }

  ///Schedules customer export tasks (triggered by cronjob - not intended to be run manually)
  @Post(
    path: '/admin/tasks/export_customer',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksExportCustomerPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Schedules customer entitlements verification export tasks (triggered by cronjob - not intended to be run manually)
  Future<chopper.Response> adminTasksExportCustomerEntitlementVerificationPost(
      {String? cacheControl}) {
    return _adminTasksExportCustomerEntitlementVerificationPost(
        cacheControl: cacheControl);
  }

  ///Schedules customer entitlements verification export tasks (triggered by cronjob - not intended to be run manually)
  @Post(
    path: '/admin/tasks/export_customer_entitlement_verification',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksExportCustomerEntitlementVerificationPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Schedules TVOD purchase export tasks (triggered by cronjob - not intended to be run manually)
  ///@param start
  ///@param end
  Future<chopper.Response> adminTasksExportTvodPurchasePost({
    String? start,
    String? end,
    String? cacheControl,
  }) {
    return _adminTasksExportTvodPurchasePost(
        start: start, end: end, cacheControl: cacheControl);
  }

  ///Schedules TVOD purchase export tasks (triggered by cronjob - not intended to be run manually)
  ///@param start
  ///@param end
  @Post(
    path: '/admin/tasks/export_tvod_purchase',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksExportTvodPurchasePost({
    @Query('start') String? start,
    @Query('end') String? end,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Schedules PPV/PPN purchase export tasks (triggered by cronjob - not intended to be run manually)
  ///@param start
  ///@param end
  Future<chopper.Response> adminTasksExportPpvPurchasePost({
    String? start,
    String? end,
    String? cacheControl,
  }) {
    return _adminTasksExportPpvPurchasePost(
        start: start, end: end, cacheControl: cacheControl);
  }

  ///Schedules PPV/PPN purchase export tasks (triggered by cronjob - not intended to be run manually)
  ///@param start
  ///@param end
  @Post(
    path: '/admin/tasks/export_ppv_purchase',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksExportPpvPurchasePost({
    @Query('start') String? start,
    @Query('end') String? end,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Schedules TVOD synchronization export tasks (triggered by cronjob - not intended to be run manually)
  Future<chopper.Response> adminTasksExportTvodSyncPost(
      {String? cacheControl}) {
    return _adminTasksExportTvodSyncPost(cacheControl: cacheControl);
  }

  ///Schedules TVOD synchronization export tasks (triggered by cronjob - not intended to be run manually)
  @Post(
    path: '/admin/tasks/export_tvod_sync',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksExportTvodSyncPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Schedules Daypass purchase export tasks (triggered by cronjob - not intended to be run manually)
  ///@param start
  ///@param end
  Future<chopper.Response> adminTasksExportDaypassPurchasePost({
    String? start,
    String? end,
    String? cacheControl,
  }) {
    return _adminTasksExportDaypassPurchasePost(
        start: start, end: end, cacheControl: cacheControl);
  }

  ///Schedules Daypass purchase export tasks (triggered by cronjob - not intended to be run manually)
  ///@param start
  ///@param end
  @Post(
    path: '/admin/tasks/export_daypass_purchase',
    optionalBody: true,
  )
  Future<chopper.Response> _adminTasksExportDaypassPurchasePost({
    @Query('start') String? start,
    @Query('end') String? end,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Purchase {
  Purchase({
    required this.offerId,
    required this.price,
    required this.deviceId,
    required this.productId,
  });

  factory Purchase.fromJson(Map<String, dynamic> json) =>
      _$PurchaseFromJson(json);

  @JsonKey(name: 'offerId', includeIfNull: false, defaultValue: '')
  final String offerId;
  @JsonKey(name: 'price', includeIfNull: false)
  final double price;
  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String productId;
  static const fromJsonFactory = _$PurchaseFromJson;
  static const toJsonFactory = _$PurchaseToJson;
  Map<String, dynamic> toJson() => _$PurchaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Purchase &&
            (identical(other.offerId, offerId) ||
                const DeepCollectionEquality()
                    .equals(other.offerId, offerId)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(offerId) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(productId) ^
      runtimeType.hashCode;
}

extension $PurchaseExtension on Purchase {
  Purchase copyWith(
      {String? offerId, double? price, String? deviceId, String? productId}) {
    return Purchase(
        offerId: offerId ?? this.offerId,
        price: price ?? this.price,
        deviceId: deviceId ?? this.deviceId,
        productId: productId ?? this.productId);
  }

  Purchase copyWithWrapped(
      {Wrapped<String>? offerId,
      Wrapped<double>? price,
      Wrapped<String>? deviceId,
      Wrapped<String>? productId}) {
    return Purchase(
        offerId: (offerId != null ? offerId.value : this.offerId),
        price: (price != null ? price.value : this.price),
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        productId: (productId != null ? productId.value : this.productId));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({ErrorResponse$Error? error}) {
    return ErrorResponse(error: error ?? this.error);
  }

  ErrorResponse copyWithWrapped({Wrapped<ErrorResponse$Error?>? error}) {
    return ErrorResponse(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class V2CustomerEntitlements {
  V2CustomerEntitlements({
    this.entitlements,
    this.rentals,
    this.ppvs,
    this.features,
    this.homeScreenHint,
    this.isDeactivated,
    this.notInHome,
    this.token,
  });

  factory V2CustomerEntitlements.fromJson(Map<String, dynamic> json) =>
      _$V2CustomerEntitlementsFromJson(json);

  @JsonKey(
      name: 'entitlements', includeIfNull: false, defaultValue: <Entitlement>[])
  final List<Entitlement>? entitlements;
  @JsonKey(name: 'rentals', includeIfNull: false, defaultValue: <V2Rental>[])
  final List<V2Rental>? rentals;
  @JsonKey(name: 'ppvs', includeIfNull: false, defaultValue: <V2PayPerView>[])
  final List<V2PayPerView>? ppvs;
  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  @JsonKey(name: 'homeScreenHint', includeIfNull: false, defaultValue: '')
  final String? homeScreenHint;
  @JsonKey(name: 'isDeactivated', includeIfNull: false)
  final bool? isDeactivated;
  @JsonKey(name: 'notInHome', includeIfNull: false)
  final bool? notInHome;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$V2CustomerEntitlementsFromJson;
  static const toJsonFactory = _$V2CustomerEntitlementsToJson;
  Map<String, dynamic> toJson() => _$V2CustomerEntitlementsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V2CustomerEntitlements &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)) &&
            (identical(other.rentals, rentals) ||
                const DeepCollectionEquality()
                    .equals(other.rentals, rentals)) &&
            (identical(other.ppvs, ppvs) ||
                const DeepCollectionEquality().equals(other.ppvs, ppvs)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)) &&
            (identical(other.homeScreenHint, homeScreenHint) ||
                const DeepCollectionEquality()
                    .equals(other.homeScreenHint, homeScreenHint)) &&
            (identical(other.isDeactivated, isDeactivated) ||
                const DeepCollectionEquality()
                    .equals(other.isDeactivated, isDeactivated)) &&
            (identical(other.notInHome, notInHome) ||
                const DeepCollectionEquality()
                    .equals(other.notInHome, notInHome)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlements) ^
      const DeepCollectionEquality().hash(rentals) ^
      const DeepCollectionEquality().hash(ppvs) ^
      const DeepCollectionEquality().hash(features) ^
      const DeepCollectionEquality().hash(homeScreenHint) ^
      const DeepCollectionEquality().hash(isDeactivated) ^
      const DeepCollectionEquality().hash(notInHome) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $V2CustomerEntitlementsExtension on V2CustomerEntitlements {
  V2CustomerEntitlements copyWith(
      {List<Entitlement>? entitlements,
      List<V2Rental>? rentals,
      List<V2PayPerView>? ppvs,
      List<String>? features,
      String? homeScreenHint,
      bool? isDeactivated,
      bool? notInHome,
      String? token}) {
    return V2CustomerEntitlements(
        entitlements: entitlements ?? this.entitlements,
        rentals: rentals ?? this.rentals,
        ppvs: ppvs ?? this.ppvs,
        features: features ?? this.features,
        homeScreenHint: homeScreenHint ?? this.homeScreenHint,
        isDeactivated: isDeactivated ?? this.isDeactivated,
        notInHome: notInHome ?? this.notInHome,
        token: token ?? this.token);
  }

  V2CustomerEntitlements copyWithWrapped(
      {Wrapped<List<Entitlement>?>? entitlements,
      Wrapped<List<V2Rental>?>? rentals,
      Wrapped<List<V2PayPerView>?>? ppvs,
      Wrapped<List<String>?>? features,
      Wrapped<String?>? homeScreenHint,
      Wrapped<bool?>? isDeactivated,
      Wrapped<bool?>? notInHome,
      Wrapped<String?>? token}) {
    return V2CustomerEntitlements(
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements),
        rentals: (rentals != null ? rentals.value : this.rentals),
        ppvs: (ppvs != null ? ppvs.value : this.ppvs),
        features: (features != null ? features.value : this.features),
        homeScreenHint: (homeScreenHint != null
            ? homeScreenHint.value
            : this.homeScreenHint),
        isDeactivated:
            (isDeactivated != null ? isDeactivated.value : this.isDeactivated),
        notInHome: (notInHome != null ? notInHome.value : this.notInHome),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class Entitlement {
  Entitlement({
    required this.id,
    this.startDate,
    this.endDate,
    this.casIndicator,
  });

  factory Entitlement.fromJson(Map<String, dynamic> json) =>
      _$EntitlementFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  @JsonKey(name: 'casIndicator', includeIfNull: false)
  final int? casIndicator;
  static const fromJsonFactory = _$EntitlementFromJson;
  static const toJsonFactory = _$EntitlementToJson;
  Map<String, dynamic> toJson() => _$EntitlementToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Entitlement &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.casIndicator, casIndicator) ||
                const DeepCollectionEquality()
                    .equals(other.casIndicator, casIndicator)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(casIndicator) ^
      runtimeType.hashCode;
}

extension $EntitlementExtension on Entitlement {
  Entitlement copyWith(
      {String? id, DateTime? startDate, DateTime? endDate, int? casIndicator}) {
    return Entitlement(
        id: id ?? this.id,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        casIndicator: casIndicator ?? this.casIndicator);
  }

  Entitlement copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate,
      Wrapped<int?>? casIndicator}) {
    return Entitlement(
        id: (id != null ? id.value : this.id),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        casIndicator:
            (casIndicator != null ? casIndicator.value : this.casIndicator));
  }
}

@JsonSerializable(explicitToJson: true)
class V2Rental {
  V2Rental({
    required this.id,
    required this.startDate,
    required this.endDate,
  });

  factory V2Rental.fromJson(Map<String, dynamic> json) =>
      _$V2RentalFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime endDate;
  static const fromJsonFactory = _$V2RentalFromJson;
  static const toJsonFactory = _$V2RentalToJson;
  Map<String, dynamic> toJson() => _$V2RentalToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V2Rental &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality().equals(other.endDate, endDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      runtimeType.hashCode;
}

extension $V2RentalExtension on V2Rental {
  V2Rental copyWith({String? id, DateTime? startDate, DateTime? endDate}) {
    return V2Rental(
        id: id ?? this.id,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate);
  }

  V2Rental copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<DateTime>? startDate,
      Wrapped<DateTime>? endDate}) {
    return V2Rental(
        id: (id != null ? id.value : this.id),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate));
  }
}

@JsonSerializable(explicitToJson: true)
class V2PayPerViewPurchase {
  V2PayPerViewPurchase({
    required this.deviceId,
    required this.nagraELKProductId,
    required this.price,
    this.availabilityStart,
    required this.availabilityEnd,
    this.edsProductId,
    this.productId,
  });

  factory V2PayPerViewPurchase.fromJson(Map<String, dynamic> json) =>
      _$V2PayPerViewPurchaseFromJson(json);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  @JsonKey(name: 'nagraELKProductId', includeIfNull: false, defaultValue: '')
  final String nagraELKProductId;
  @JsonKey(name: 'price', includeIfNull: false)
  final double price;
  @JsonKey(name: 'availabilityStart', includeIfNull: false)
  final DateTime? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false)
  final DateTime availabilityEnd;
  @JsonKey(name: 'edsProductId', includeIfNull: false, defaultValue: '')
  final String? edsProductId;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String? productId;
  static const fromJsonFactory = _$V2PayPerViewPurchaseFromJson;
  static const toJsonFactory = _$V2PayPerViewPurchaseToJson;
  Map<String, dynamic> toJson() => _$V2PayPerViewPurchaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V2PayPerViewPurchase &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.nagraELKProductId, nagraELKProductId) ||
                const DeepCollectionEquality()
                    .equals(other.nagraELKProductId, nagraELKProductId)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.edsProductId, edsProductId) ||
                const DeepCollectionEquality()
                    .equals(other.edsProductId, edsProductId)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(nagraELKProductId) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(edsProductId) ^
      const DeepCollectionEquality().hash(productId) ^
      runtimeType.hashCode;
}

extension $V2PayPerViewPurchaseExtension on V2PayPerViewPurchase {
  V2PayPerViewPurchase copyWith(
      {String? deviceId,
      String? nagraELKProductId,
      double? price,
      DateTime? availabilityStart,
      DateTime? availabilityEnd,
      String? edsProductId,
      String? productId}) {
    return V2PayPerViewPurchase(
        deviceId: deviceId ?? this.deviceId,
        nagraELKProductId: nagraELKProductId ?? this.nagraELKProductId,
        price: price ?? this.price,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        edsProductId: edsProductId ?? this.edsProductId,
        productId: productId ?? this.productId);
  }

  V2PayPerViewPurchase copyWithWrapped(
      {Wrapped<String>? deviceId,
      Wrapped<String>? nagraELKProductId,
      Wrapped<double>? price,
      Wrapped<DateTime?>? availabilityStart,
      Wrapped<DateTime>? availabilityEnd,
      Wrapped<String?>? edsProductId,
      Wrapped<String?>? productId}) {
    return V2PayPerViewPurchase(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        nagraELKProductId: (nagraELKProductId != null
            ? nagraELKProductId.value
            : this.nagraELKProductId),
        price: (price != null ? price.value : this.price),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        edsProductId:
            (edsProductId != null ? edsProductId.value : this.edsProductId),
        productId: (productId != null ? productId.value : this.productId));
  }
}

@JsonSerializable(explicitToJson: true)
class V2DayPassPurchase {
  V2DayPassPurchase({
    required this.deviceId,
    required this.price,
    required this.linearProductDayPass,
  });

  factory V2DayPassPurchase.fromJson(Map<String, dynamic> json) =>
      _$V2DayPassPurchaseFromJson(json);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  @JsonKey(name: 'price', includeIfNull: false)
  final double price;
  @JsonKey(name: 'linearProductDayPass', includeIfNull: false, defaultValue: '')
  final String linearProductDayPass;
  static const fromJsonFactory = _$V2DayPassPurchaseFromJson;
  static const toJsonFactory = _$V2DayPassPurchaseToJson;
  Map<String, dynamic> toJson() => _$V2DayPassPurchaseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V2DayPassPurchase &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.linearProductDayPass, linearProductDayPass) ||
                const DeepCollectionEquality()
                    .equals(other.linearProductDayPass, linearProductDayPass)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(linearProductDayPass) ^
      runtimeType.hashCode;
}

extension $V2DayPassPurchaseExtension on V2DayPassPurchase {
  V2DayPassPurchase copyWith(
      {String? deviceId, double? price, String? linearProductDayPass}) {
    return V2DayPassPurchase(
        deviceId: deviceId ?? this.deviceId,
        price: price ?? this.price,
        linearProductDayPass:
            linearProductDayPass ?? this.linearProductDayPass);
  }

  V2DayPassPurchase copyWithWrapped(
      {Wrapped<String>? deviceId,
      Wrapped<double>? price,
      Wrapped<String>? linearProductDayPass}) {
    return V2DayPassPurchase(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        price: (price != null ? price.value : this.price),
        linearProductDayPass: (linearProductDayPass != null
            ? linearProductDayPass.value
            : this.linearProductDayPass));
  }
}

@JsonSerializable(explicitToJson: true)
class V2PayPerView {
  V2PayPerView({
    required this.id,
    required this.startDate,
    required this.endDate,
  });

  factory V2PayPerView.fromJson(Map<String, dynamic> json) =>
      _$V2PayPerViewFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime endDate;
  static const fromJsonFactory = _$V2PayPerViewFromJson;
  static const toJsonFactory = _$V2PayPerViewToJson;
  Map<String, dynamic> toJson() => _$V2PayPerViewToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V2PayPerView &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality().equals(other.endDate, endDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      runtimeType.hashCode;
}

extension $V2PayPerViewExtension on V2PayPerView {
  V2PayPerView copyWith({String? id, DateTime? startDate, DateTime? endDate}) {
    return V2PayPerView(
        id: id ?? this.id,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate);
  }

  V2PayPerView copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<DateTime>? startDate,
      Wrapped<DateTime>? endDate}) {
    return V2PayPerView(
        id: (id != null ? id.value : this.id),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate));
  }
}

@JsonSerializable(explicitToJson: true)
class V3Customer {
  V3Customer({
    required this.customerId,
    this.budgetLimit,
    this.budgetLimitResetDay,
    this.devices,
    required this.entitlements,
    required this.isDeactivated,
  });

  factory V3Customer.fromJson(Map<String, dynamic> json) =>
      _$V3CustomerFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'budgetLimit', includeIfNull: false)
  final double? budgetLimit;
  @JsonKey(name: 'budgetLimitResetDay', includeIfNull: false)
  final int? budgetLimitResetDay;
  @JsonKey(name: 'devices', includeIfNull: false, defaultValue: <V3Device>[])
  final List<V3Device>? devices;
  @JsonKey(
      name: 'entitlements', includeIfNull: false, defaultValue: <Entitlement>[])
  final List<Entitlement> entitlements;
  @JsonKey(name: 'isDeactivated', includeIfNull: false)
  final bool isDeactivated;
  static const fromJsonFactory = _$V3CustomerFromJson;
  static const toJsonFactory = _$V3CustomerToJson;
  Map<String, dynamic> toJson() => _$V3CustomerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3Customer &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.budgetLimit, budgetLimit) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimit, budgetLimit)) &&
            (identical(other.budgetLimitResetDay, budgetLimitResetDay) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimitResetDay, budgetLimitResetDay)) &&
            (identical(other.devices, devices) ||
                const DeepCollectionEquality()
                    .equals(other.devices, devices)) &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)) &&
            (identical(other.isDeactivated, isDeactivated) ||
                const DeepCollectionEquality()
                    .equals(other.isDeactivated, isDeactivated)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(budgetLimit) ^
      const DeepCollectionEquality().hash(budgetLimitResetDay) ^
      const DeepCollectionEquality().hash(devices) ^
      const DeepCollectionEquality().hash(entitlements) ^
      const DeepCollectionEquality().hash(isDeactivated) ^
      runtimeType.hashCode;
}

extension $V3CustomerExtension on V3Customer {
  V3Customer copyWith(
      {String? customerId,
      double? budgetLimit,
      int? budgetLimitResetDay,
      List<V3Device>? devices,
      List<Entitlement>? entitlements,
      bool? isDeactivated}) {
    return V3Customer(
        customerId: customerId ?? this.customerId,
        budgetLimit: budgetLimit ?? this.budgetLimit,
        budgetLimitResetDay: budgetLimitResetDay ?? this.budgetLimitResetDay,
        devices: devices ?? this.devices,
        entitlements: entitlements ?? this.entitlements,
        isDeactivated: isDeactivated ?? this.isDeactivated);
  }

  V3Customer copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<double?>? budgetLimit,
      Wrapped<int?>? budgetLimitResetDay,
      Wrapped<List<V3Device>?>? devices,
      Wrapped<List<Entitlement>>? entitlements,
      Wrapped<bool>? isDeactivated}) {
    return V3Customer(
        customerId: (customerId != null ? customerId.value : this.customerId),
        budgetLimit:
            (budgetLimit != null ? budgetLimit.value : this.budgetLimit),
        budgetLimitResetDay: (budgetLimitResetDay != null
            ? budgetLimitResetDay.value
            : this.budgetLimitResetDay),
        devices: (devices != null ? devices.value : this.devices),
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements),
        isDeactivated:
            (isDeactivated != null ? isDeactivated.value : this.isDeactivated));
  }
}

@JsonSerializable(explicitToJson: true)
class V3CustomerParams {
  V3CustomerParams({
    required this.customerId,
    this.budgetLimit,
    this.budgetLimitResetDay,
    this.devices,
    this.entitlements,
  });

  factory V3CustomerParams.fromJson(Map<String, dynamic> json) =>
      _$V3CustomerParamsFromJson(json);

  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'budgetLimit', includeIfNull: false)
  final double? budgetLimit;
  @JsonKey(name: 'budgetLimitResetDay', includeIfNull: false)
  final int? budgetLimitResetDay;
  @JsonKey(name: 'devices', includeIfNull: false, defaultValue: <V3Device>[])
  final List<V3Device>? devices;
  @JsonKey(
      name: 'entitlements',
      includeIfNull: false,
      defaultValue: <V3Entitlement>[])
  final List<V3Entitlement>? entitlements;
  static const fromJsonFactory = _$V3CustomerParamsFromJson;
  static const toJsonFactory = _$V3CustomerParamsToJson;
  Map<String, dynamic> toJson() => _$V3CustomerParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3CustomerParams &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.budgetLimit, budgetLimit) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimit, budgetLimit)) &&
            (identical(other.budgetLimitResetDay, budgetLimitResetDay) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimitResetDay, budgetLimitResetDay)) &&
            (identical(other.devices, devices) ||
                const DeepCollectionEquality()
                    .equals(other.devices, devices)) &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(budgetLimit) ^
      const DeepCollectionEquality().hash(budgetLimitResetDay) ^
      const DeepCollectionEquality().hash(devices) ^
      const DeepCollectionEquality().hash(entitlements) ^
      runtimeType.hashCode;
}

extension $V3CustomerParamsExtension on V3CustomerParams {
  V3CustomerParams copyWith(
      {String? customerId,
      double? budgetLimit,
      int? budgetLimitResetDay,
      List<V3Device>? devices,
      List<V3Entitlement>? entitlements}) {
    return V3CustomerParams(
        customerId: customerId ?? this.customerId,
        budgetLimit: budgetLimit ?? this.budgetLimit,
        budgetLimitResetDay: budgetLimitResetDay ?? this.budgetLimitResetDay,
        devices: devices ?? this.devices,
        entitlements: entitlements ?? this.entitlements);
  }

  V3CustomerParams copyWithWrapped(
      {Wrapped<String>? customerId,
      Wrapped<double?>? budgetLimit,
      Wrapped<int?>? budgetLimitResetDay,
      Wrapped<List<V3Device>?>? devices,
      Wrapped<List<V3Entitlement>?>? entitlements}) {
    return V3CustomerParams(
        customerId: (customerId != null ? customerId.value : this.customerId),
        budgetLimit:
            (budgetLimit != null ? budgetLimit.value : this.budgetLimit),
        budgetLimitResetDay: (budgetLimitResetDay != null
            ? budgetLimitResetDay.value
            : this.budgetLimitResetDay),
        devices: (devices != null ? devices.value : this.devices),
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements));
  }
}

@JsonSerializable(explicitToJson: true)
class V3Entitlement {
  V3Entitlement({
    required this.id,
    this.startDate,
    this.endDate,
    this.casIndicator,
  });

  factory V3Entitlement.fromJson(Map<String, dynamic> json) =>
      _$V3EntitlementFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  @JsonKey(name: 'casIndicator', includeIfNull: false)
  final int? casIndicator;
  static const fromJsonFactory = _$V3EntitlementFromJson;
  static const toJsonFactory = _$V3EntitlementToJson;
  Map<String, dynamic> toJson() => _$V3EntitlementToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3Entitlement &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.casIndicator, casIndicator) ||
                const DeepCollectionEquality()
                    .equals(other.casIndicator, casIndicator)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(casIndicator) ^
      runtimeType.hashCode;
}

extension $V3EntitlementExtension on V3Entitlement {
  V3Entitlement copyWith(
      {String? id, DateTime? startDate, DateTime? endDate, int? casIndicator}) {
    return V3Entitlement(
        id: id ?? this.id,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        casIndicator: casIndicator ?? this.casIndicator);
  }

  V3Entitlement copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate,
      Wrapped<int?>? casIndicator}) {
    return V3Entitlement(
        id: (id != null ? id.value : this.id),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        casIndicator:
            (casIndicator != null ? casIndicator.value : this.casIndicator));
  }
}

@JsonSerializable(explicitToJson: true)
class V3Device {
  V3Device({
    required this.extSerialNum,
    required this.smartCardId,
    required this.serialNumber,
  });

  factory V3Device.fromJson(Map<String, dynamic> json) =>
      _$V3DeviceFromJson(json);

  @JsonKey(name: 'extSerialNum', includeIfNull: false, defaultValue: '')
  final String extSerialNum;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String serialNumber;
  static const fromJsonFactory = _$V3DeviceFromJson;
  static const toJsonFactory = _$V3DeviceToJson;
  Map<String, dynamic> toJson() => _$V3DeviceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3Device &&
            (identical(other.extSerialNum, extSerialNum) ||
                const DeepCollectionEquality()
                    .equals(other.extSerialNum, extSerialNum)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(extSerialNum) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      runtimeType.hashCode;
}

extension $V3DeviceExtension on V3Device {
  V3Device copyWith(
      {String? extSerialNum, String? smartCardId, String? serialNumber}) {
    return V3Device(
        extSerialNum: extSerialNum ?? this.extSerialNum,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber);
  }

  V3Device copyWithWrapped(
      {Wrapped<String>? extSerialNum,
      Wrapped<String>? smartCardId,
      Wrapped<String>? serialNumber}) {
    return V3Device(
        extSerialNum:
            (extSerialNum != null ? extSerialNum.value : this.extSerialNum),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber));
  }
}

@JsonSerializable(explicitToJson: true)
class V3DeviceSkipInHomeCheckUpdateParam {
  V3DeviceSkipInHomeCheckUpdateParam({
    required this.skipInHomeCheck,
  });

  factory V3DeviceSkipInHomeCheckUpdateParam.fromJson(
          Map<String, dynamic> json) =>
      _$V3DeviceSkipInHomeCheckUpdateParamFromJson(json);

  @JsonKey(name: 'skipInHomeCheck', includeIfNull: false)
  final bool skipInHomeCheck;
  static const fromJsonFactory = _$V3DeviceSkipInHomeCheckUpdateParamFromJson;
  static const toJsonFactory = _$V3DeviceSkipInHomeCheckUpdateParamToJson;
  Map<String, dynamic> toJson() =>
      _$V3DeviceSkipInHomeCheckUpdateParamToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3DeviceSkipInHomeCheckUpdateParam &&
            (identical(other.skipInHomeCheck, skipInHomeCheck) ||
                const DeepCollectionEquality()
                    .equals(other.skipInHomeCheck, skipInHomeCheck)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(skipInHomeCheck) ^
      runtimeType.hashCode;
}

extension $V3DeviceSkipInHomeCheckUpdateParamExtension
    on V3DeviceSkipInHomeCheckUpdateParam {
  V3DeviceSkipInHomeCheckUpdateParam copyWith({bool? skipInHomeCheck}) {
    return V3DeviceSkipInHomeCheckUpdateParam(
        skipInHomeCheck: skipInHomeCheck ?? this.skipInHomeCheck);
  }

  V3DeviceSkipInHomeCheckUpdateParam copyWithWrapped(
      {Wrapped<bool>? skipInHomeCheck}) {
    return V3DeviceSkipInHomeCheckUpdateParam(
        skipInHomeCheck: (skipInHomeCheck != null
            ? skipInHomeCheck.value
            : this.skipInHomeCheck));
  }
}

@JsonSerializable(explicitToJson: true)
class V3DeviceSkipInHomeCheck {
  V3DeviceSkipInHomeCheck({
    required this.skipInHomeCheck,
  });

  factory V3DeviceSkipInHomeCheck.fromJson(Map<String, dynamic> json) =>
      _$V3DeviceSkipInHomeCheckFromJson(json);

  @JsonKey(name: 'skipInHomeCheck', includeIfNull: false)
  final bool skipInHomeCheck;
  static const fromJsonFactory = _$V3DeviceSkipInHomeCheckFromJson;
  static const toJsonFactory = _$V3DeviceSkipInHomeCheckToJson;
  Map<String, dynamic> toJson() => _$V3DeviceSkipInHomeCheckToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3DeviceSkipInHomeCheck &&
            (identical(other.skipInHomeCheck, skipInHomeCheck) ||
                const DeepCollectionEquality()
                    .equals(other.skipInHomeCheck, skipInHomeCheck)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(skipInHomeCheck) ^
      runtimeType.hashCode;
}

extension $V3DeviceSkipInHomeCheckExtension on V3DeviceSkipInHomeCheck {
  V3DeviceSkipInHomeCheck copyWith({bool? skipInHomeCheck}) {
    return V3DeviceSkipInHomeCheck(
        skipInHomeCheck: skipInHomeCheck ?? this.skipInHomeCheck);
  }

  V3DeviceSkipInHomeCheck copyWithWrapped({Wrapped<bool>? skipInHomeCheck}) {
    return V3DeviceSkipInHomeCheck(
        skipInHomeCheck: (skipInHomeCheck != null
            ? skipInHomeCheck.value
            : this.skipInHomeCheck));
  }
}

@JsonSerializable(explicitToJson: true)
class V3History {
  V3History({
    required this.lastResetDateTime,
    required this.customerId,
    this.budgetLimit,
    required this.budgetLimitResetDay,
    required this.budgetUsed,
    required this.isDeactivated,
    this.purchaseHistory,
  });

  factory V3History.fromJson(Map<String, dynamic> json) =>
      _$V3HistoryFromJson(json);

  @JsonKey(name: 'lastResetDateTime', includeIfNull: false)
  final DateTime lastResetDateTime;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String customerId;
  @JsonKey(name: 'budgetLimit', includeIfNull: false)
  final double? budgetLimit;
  @JsonKey(name: 'budgetLimitResetDay', includeIfNull: false)
  final int budgetLimitResetDay;
  @JsonKey(name: 'budgetUsed', includeIfNull: false)
  final double budgetUsed;
  @JsonKey(name: 'isDeactivated', includeIfNull: false)
  final bool isDeactivated;
  @JsonKey(
      name: 'purchaseHistory',
      includeIfNull: false,
      defaultValue: <V3HistoryEntry>[])
  final List<V3HistoryEntry>? purchaseHistory;
  static const fromJsonFactory = _$V3HistoryFromJson;
  static const toJsonFactory = _$V3HistoryToJson;
  Map<String, dynamic> toJson() => _$V3HistoryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3History &&
            (identical(other.lastResetDateTime, lastResetDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastResetDateTime, lastResetDateTime)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)) &&
            (identical(other.budgetLimit, budgetLimit) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimit, budgetLimit)) &&
            (identical(other.budgetLimitResetDay, budgetLimitResetDay) ||
                const DeepCollectionEquality()
                    .equals(other.budgetLimitResetDay, budgetLimitResetDay)) &&
            (identical(other.budgetUsed, budgetUsed) ||
                const DeepCollectionEquality()
                    .equals(other.budgetUsed, budgetUsed)) &&
            (identical(other.isDeactivated, isDeactivated) ||
                const DeepCollectionEquality()
                    .equals(other.isDeactivated, isDeactivated)) &&
            (identical(other.purchaseHistory, purchaseHistory) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseHistory, purchaseHistory)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastResetDateTime) ^
      const DeepCollectionEquality().hash(customerId) ^
      const DeepCollectionEquality().hash(budgetLimit) ^
      const DeepCollectionEquality().hash(budgetLimitResetDay) ^
      const DeepCollectionEquality().hash(budgetUsed) ^
      const DeepCollectionEquality().hash(isDeactivated) ^
      const DeepCollectionEquality().hash(purchaseHistory) ^
      runtimeType.hashCode;
}

extension $V3HistoryExtension on V3History {
  V3History copyWith(
      {DateTime? lastResetDateTime,
      String? customerId,
      double? budgetLimit,
      int? budgetLimitResetDay,
      double? budgetUsed,
      bool? isDeactivated,
      List<V3HistoryEntry>? purchaseHistory}) {
    return V3History(
        lastResetDateTime: lastResetDateTime ?? this.lastResetDateTime,
        customerId: customerId ?? this.customerId,
        budgetLimit: budgetLimit ?? this.budgetLimit,
        budgetLimitResetDay: budgetLimitResetDay ?? this.budgetLimitResetDay,
        budgetUsed: budgetUsed ?? this.budgetUsed,
        isDeactivated: isDeactivated ?? this.isDeactivated,
        purchaseHistory: purchaseHistory ?? this.purchaseHistory);
  }

  V3History copyWithWrapped(
      {Wrapped<DateTime>? lastResetDateTime,
      Wrapped<String>? customerId,
      Wrapped<double?>? budgetLimit,
      Wrapped<int>? budgetLimitResetDay,
      Wrapped<double>? budgetUsed,
      Wrapped<bool>? isDeactivated,
      Wrapped<List<V3HistoryEntry>?>? purchaseHistory}) {
    return V3History(
        lastResetDateTime: (lastResetDateTime != null
            ? lastResetDateTime.value
            : this.lastResetDateTime),
        customerId: (customerId != null ? customerId.value : this.customerId),
        budgetLimit:
            (budgetLimit != null ? budgetLimit.value : this.budgetLimit),
        budgetLimitResetDay: (budgetLimitResetDay != null
            ? budgetLimitResetDay.value
            : this.budgetLimitResetDay),
        budgetUsed: (budgetUsed != null ? budgetUsed.value : this.budgetUsed),
        isDeactivated:
            (isDeactivated != null ? isDeactivated.value : this.isDeactivated),
        purchaseHistory: (purchaseHistory != null
            ? purchaseHistory.value
            : this.purchaseHistory));
  }
}

@JsonSerializable(explicitToJson: true)
class V3HistoryEntry {
  V3HistoryEntry({
    required this.deviceId,
    required this.smartCardId,
    this.serialNumber,
    required this.productId,
    required this.price,
    required this.purchaseDateTime,
    required this.entitlementEnd,
  });

  factory V3HistoryEntry.fromJson(Map<String, dynamic> json) =>
      _$V3HistoryEntryFromJson(json);

  @JsonKey(name: 'deviceId', includeIfNull: false, defaultValue: '')
  final String deviceId;
  @JsonKey(name: 'smartCardId', includeIfNull: false, defaultValue: '')
  final String smartCardId;
  @JsonKey(name: 'serialNumber', includeIfNull: false, defaultValue: '')
  final String? serialNumber;
  @JsonKey(name: 'productId', includeIfNull: false, defaultValue: '')
  final String productId;
  @JsonKey(name: 'price', includeIfNull: false)
  final double price;
  @JsonKey(name: 'purchaseDateTime', includeIfNull: false)
  final DateTime purchaseDateTime;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false)
  final DateTime entitlementEnd;
  static const fromJsonFactory = _$V3HistoryEntryFromJson;
  static const toJsonFactory = _$V3HistoryEntryToJson;
  Map<String, dynamic> toJson() => _$V3HistoryEntryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is V3HistoryEntry &&
            (identical(other.deviceId, deviceId) ||
                const DeepCollectionEquality()
                    .equals(other.deviceId, deviceId)) &&
            (identical(other.smartCardId, smartCardId) ||
                const DeepCollectionEquality()
                    .equals(other.smartCardId, smartCardId)) &&
            (identical(other.serialNumber, serialNumber) ||
                const DeepCollectionEquality()
                    .equals(other.serialNumber, serialNumber)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.purchaseDateTime, purchaseDateTime) ||
                const DeepCollectionEquality()
                    .equals(other.purchaseDateTime, purchaseDateTime)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceId) ^
      const DeepCollectionEquality().hash(smartCardId) ^
      const DeepCollectionEquality().hash(serialNumber) ^
      const DeepCollectionEquality().hash(productId) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(purchaseDateTime) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      runtimeType.hashCode;
}

extension $V3HistoryEntryExtension on V3HistoryEntry {
  V3HistoryEntry copyWith(
      {String? deviceId,
      String? smartCardId,
      String? serialNumber,
      String? productId,
      double? price,
      DateTime? purchaseDateTime,
      DateTime? entitlementEnd}) {
    return V3HistoryEntry(
        deviceId: deviceId ?? this.deviceId,
        smartCardId: smartCardId ?? this.smartCardId,
        serialNumber: serialNumber ?? this.serialNumber,
        productId: productId ?? this.productId,
        price: price ?? this.price,
        purchaseDateTime: purchaseDateTime ?? this.purchaseDateTime,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd);
  }

  V3HistoryEntry copyWithWrapped(
      {Wrapped<String>? deviceId,
      Wrapped<String>? smartCardId,
      Wrapped<String?>? serialNumber,
      Wrapped<String>? productId,
      Wrapped<double>? price,
      Wrapped<DateTime>? purchaseDateTime,
      Wrapped<DateTime>? entitlementEnd}) {
    return V3HistoryEntry(
        deviceId: (deviceId != null ? deviceId.value : this.deviceId),
        smartCardId:
            (smartCardId != null ? smartCardId.value : this.smartCardId),
        serialNumber:
            (serialNumber != null ? serialNumber.value : this.serialNumber),
        productId: (productId != null ? productId.value : this.productId),
        price: (price != null ? price.value : this.price),
        purchaseDateTime: (purchaseDateTime != null
            ? purchaseDateTime.value
            : this.purchaseDateTime),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd));
  }
}

@JsonSerializable(explicitToJson: true)
class PlugAndPlayResponse {
  PlugAndPlayResponse({
    required this.stack,
  });

  factory PlugAndPlayResponse.fromJson(Map<String, dynamic> json) =>
      _$PlugAndPlayResponseFromJson(json);

  @JsonKey(name: 'stack', includeIfNull: false, defaultValue: '')
  final String stack;
  static const fromJsonFactory = _$PlugAndPlayResponseFromJson;
  static const toJsonFactory = _$PlugAndPlayResponseToJson;
  Map<String, dynamic> toJson() => _$PlugAndPlayResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PlugAndPlayResponse &&
            (identical(other.stack, stack) ||
                const DeepCollectionEquality().equals(other.stack, stack)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(stack) ^ runtimeType.hashCode;
}

extension $PlugAndPlayResponseExtension on PlugAndPlayResponse {
  PlugAndPlayResponse copyWith({String? stack}) {
    return PlugAndPlayResponse(stack: stack ?? this.stack);
  }

  PlugAndPlayResponse copyWithWrapped({Wrapped<String>? stack}) {
    return PlugAndPlayResponse(
        stack: (stack != null ? stack.value : this.stack));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    this.httpStatusCode,
    this.statusCode,
    this.message,
    this.details,
    this.correlationId,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int? httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;
  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      String? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        correlationId: correlationId ?? this.correlationId);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int?>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String?>? message,
      Wrapped<String?>? details,
      Wrapped<String?>? correlationId}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

String? customerStatusToJson(enums.CustomerStatus? customerStatus) {
  return enums.$CustomerStatusMap[customerStatus];
}

enums.CustomerStatus customerStatusFromJson(
  Object? customerStatus, [
  enums.CustomerStatus? defaultValue,
]) {
  if (customerStatus is String) {
    return enums.$CustomerStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == customerStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomerStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomerStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomerStatus.swaggerGeneratedUnknown;
}

List<String> customerStatusListToJson(
    List<enums.CustomerStatus>? customerStatus) {
  if (customerStatus == null) {
    return [];
  }

  return customerStatus.map((e) => enums.$CustomerStatusMap[e]!).toList();
}

List<enums.CustomerStatus> customerStatusListFromJson(
  List? customerStatus, [
  List<enums.CustomerStatus>? defaultValue,
]) {
  if (customerStatus == null) {
    return defaultValue ?? [];
  }

  return customerStatus
      .map((e) => customerStatusFromJson(e.toString()))
      .toList();
}

List<enums.CustomerStatus>? customerStatusNullableListFromJson(
  List? customerStatus, [
  List<enums.CustomerStatus>? defaultValue,
]) {
  if (customerStatus == null) {
    return defaultValue;
  }

  return customerStatus
      .map((e) => customerStatusFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
