// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'session_manager.swagger.chopper.dart';
part 'session_manager.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class SessionManager extends ChopperService {
  static SessionManager create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$SessionManager(client);
    }

    final newClient = ChopperClient(
        services: [_$SessionManager()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$SessionManager(newClient);
  }

  ///Provide the license
  ///@param ContentId DRM ContentId. It should be extracted from the maniest LA_URL.
  ///@param x-drm-schemeId Id (guid) of the drm system. Possible values are:   <ul>     <li>9a04f079-9840-4286-ab92-e65be0885f95 - Playready</li>     <li>edef8ba9-79d6-4ace-a3c8-27dcd51d21ed - Widevine</li>     <li>94ce86fb-07ff-4f43-adb8-93d2fa968ca2 - Fairplay</li>   </ul>
  ///@param deviceName DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service. When empty the deviceName should be provided instead.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param keyId is required for Fairplay only
  ///@param x-cus CustomerId for which the session should be created. It should contain country code e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  Future<chopper.Response<String>> licensePost({
    required String? contentId,
    String? xDrmSchemeId,
    String? deviceName,
    String? xStreamingToken,
    String? keyId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? cacheControl,
    required Object? body,
  }) {
    return _licensePost(
        contentId: contentId,
        xDrmSchemeId: xDrmSchemeId,
        deviceName: deviceName,
        xStreamingToken: xStreamingToken,
        keyId: keyId,
        xCus: xCus,
        xDev: xDev,
        cacheControl: cacheControl,
        body: body);
  }

  ///Provide the license
  ///@param ContentId DRM ContentId. It should be extracted from the maniest LA_URL.
  ///@param x-drm-schemeId Id (guid) of the drm system. Possible values are:   <ul>     <li>9a04f079-9840-4286-ab92-e65be0885f95 - Playready</li>     <li>edef8ba9-79d6-4ace-a3c8-27dcd51d21ed - Widevine</li>     <li>94ce86fb-07ff-4f43-adb8-93d2fa968ca2 - Fairplay</li>   </ul>
  ///@param deviceName DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service. When empty the deviceName should be provided instead.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  ///@param keyId is required for Fairplay only
  ///@param x-cus CustomerId for which the session should be created. It should contain country code e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  @Post(path: '/license')
  Future<chopper.Response<String>> _licensePost({
    @Query('ContentId') required String? contentId,
    @Header('x-drm-schemeId') String? xDrmSchemeId,
    @Header('deviceName') String? deviceName,
    @Header('x-streaming-token') String? xStreamingToken,
    @Query('keyId') String? keyId,
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Object? body,
  });

  ///Refresh the streaming token
  ///@param x-cus CustomerId for which the session should be created. It should contain country code e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  Future<chopper.Response> licenseTokenPost({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xStreamingToken,
    String? cacheControl,
  }) {
    return _licenseTokenPost(
        xCus: xCus,
        xDev: xDev,
        xStreamingToken: xStreamingToken,
        cacheControl: cacheControl);
  }

  ///Refresh the streaming token
  ///@param x-cus CustomerId for which the session should be created. It should contain country code e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  @Post(
    path: '/license/token',
    optionalBody: true,
  )
  Future<chopper.Response> _licenseTokenPost({
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-streaming-token') String? xStreamingToken,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete the session
  ///@param x-cus CustomerId for which the session should be created. It should contain country code e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  Future<chopper.Response> licenseTokenDelete({
    String? xCus = 'X-Cus',
    String? xDev,
    String? xStreamingToken,
    String? cacheControl,
  }) {
    return _licenseTokenDelete(
        xCus: xCus,
        xDev: xDev,
        xStreamingToken: xStreamingToken,
        cacheControl: cacheControl);
  }

  ///Delete the session
  ///@param x-cus CustomerId for which the session should be created. It should contain country code e.g.: abcdabcd-abcd-1234-1234-0987654321ed_nl
  ///@param x-dev HTTP header containing a device id. It is set only for STB devices.
  ///@param x-streaming-token Streaming token obtain during session creation. It authorizes the content identified by ContentId.
  @Delete(path: '/license/token')
  Future<chopper.Response> _licenseTokenDelete({
    @Header('x-cus') String? xCus = 'X-Cus',
    @Header('x-dev') String? xDev,
    @Header('x-streaming-token') String? xStreamingToken,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;
  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
