// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'session_service.enums.swagger.dart' as enums;
export 'session_service.enums.swagger.dart';

part 'session_service.swagger.chopper.dart';
part 'session_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class SessionService extends ChopperService {
  static SessionService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$SessionService(client);
    }

    final newClient = ChopperClient(
        services: [_$SessionService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$SessionService(newClient);
  }

  ///Returns Playready license for STB.
  ///@param
  ///@param
  ///@param CrmId Customer id.
  ///@param AccountId Account Id.
  ///@param ContentId Content Id.
  ///@param DeviceID Device Id.
  ///@param SubContentType SubContent Type.
  ///@param body SOAP AcquireLicense body. Unmodified it is sent to playready endpoint in irdeto-rrm.
  Future<chopper.Response> customplayreadyRightsmanagerAsmxPost({
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    required String? crmId,
    required String? accountId,
    required String? contentId,
    required String? deviceID,
    required String? subContentType,
    required String? body,
    String? cacheControl,
  }) {
    return _customplayreadyRightsmanagerAsmxPost(
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        crmId: crmId,
        accountId: accountId,
        contentId: contentId,
        deviceID: deviceID,
        subContentType: subContentType,
        body: body,
        cacheControl: cacheControl);
  }

  ///Returns Playready license for STB.
  ///@param
  ///@param
  ///@param CrmId Customer id.
  ///@param AccountId Account Id.
  ///@param ContentId Content Id.
  ///@param DeviceID Device Id.
  ///@param SubContentType SubContent Type.
  ///@param body SOAP AcquireLicense body. Unmodified it is sent to playready endpoint in irdeto-rrm.
  @Post(path: '/customplayready/rightsmanager.asmx')
  Future<chopper.Response> _customplayreadyRightsmanagerAsmxPost({
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Query('CrmId') required String? crmId,
    @Query('AccountId') required String? accountId,
    @Query('ContentId') required String? contentId,
    @Query('DeviceID') required String? deviceID,
    @Query('SubContentType') required String? subContentType,
    @Body() required String? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Resolve content id to the channel, start_time and end_time.
  ///@param body Xml request body.
  Future<chopper.Response<TsbResolveContentReply>>
      vsppAdapterTsbResolveContentPost({
    TsbResolveContentRequest? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TsbResolveContentRequest,
        () => TsbResolveContentRequest.fromJsonFactory);
    generatedMapping.putIfAbsent(
        TsbResolveContentReply, () => TsbResolveContentReply.fromJsonFactory);

    return _vsppAdapterTsbResolveContentPost(
        body: body, cacheControl: cacheControl);
  }

  ///Resolve content id to the channel, start_time and end_time.
  ///@param body Xml request body.
  @Post(path: '/vspp-adapter/tsb_resolve_content')
  Future<chopper.Response<TsbResolveContentReply>>
      _vsppAdapterTsbResolveContentPost({
    @Body() TsbResolveContentRequest? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get thumbnail service url for CPE.
  ///@param customerId Customer ID.
  ///@param recordingId Recording ID in a form of Traxis Event's CRID+IMI.
  Future<chopper.Response<LocalRecordingResponse>>
      sessionCustomersCustomerIdLocalRecordingsRecordingIdPost({
    required String? customerId,
    required String? recordingId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LocalRecordingResponse, () => LocalRecordingResponse.fromJsonFactory);

    return _sessionCustomersCustomerIdLocalRecordingsRecordingIdPost(
        customerId: customerId,
        recordingId: recordingId,
        cacheControl: cacheControl);
  }

  ///Get thumbnail service url for CPE.
  ///@param customerId Customer ID.
  ///@param recordingId Recording ID in a form of Traxis Event's CRID+IMI.
  @Post(
    path: '/session/customers/{customerId}/local_recordings/{recordingId}',
    optionalBody: true,
  )
  Future<chopper.Response<LocalRecordingResponse>>
      _sessionCustomersCustomerIdLocalRecordingsRecordingIdPost({
    @Path('customerId') required String? customerId,
    @Path('recordingId') required String? recordingId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///It creates session for nDVR recording.
  ///@param customerId
  ///@param recordingId Id of the Event used to schedule recording (CRID+IMI).
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<RecordingResponse>>
      sessionCustomersCustomerIdRecordingsRecordingIdPost({
    required String? customerId,
    required String? recordingId,
    String? xDev,
    String? userAgent,
    String? abrType,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingResponse, () => RecordingResponse.fromJsonFactory);

    return _sessionCustomersCustomerIdRecordingsRecordingIdPost(
        customerId: customerId,
        recordingId: recordingId,
        xDev: xDev,
        userAgent: userAgent,
        abrType: abrType,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///It creates session for nDVR recording.
  ///@param customerId
  ///@param recordingId Id of the Event used to schedule recording (CRID+IMI).
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Post(
    path: '/session/customers/{customerId}/recordings/{recordingId}',
    optionalBody: true,
  )
  Future<chopper.Response<RecordingResponse>>
      _sessionCustomersCustomerIdRecordingsRecordingIdPost({
    @Path('customerId') required String? customerId,
    @Path('recordingId') required String? recordingId,
    @Header('X-Dev') String? xDev,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create replay session for STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<ReplaySessionResponse>>
      sessionCpesCpeIdReplayEventsEventIdPost({
    required String? cpeId,
    required String? eventId,
    String? userAgent,
    String? abrType,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplaySessionResponse, () => ReplaySessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdReplayEventsEventIdPost(
        cpeId: cpeId,
        eventId: eventId,
        userAgent: userAgent,
        abrType: abrType,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Create replay session for STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Post(
    path: '/session/cpes/{cpeId}/replay/events/{eventId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReplaySessionResponse>>
      _sessionCpesCpeIdReplayEventsEventIdPost({
    @Path('cpeId') required String? cpeId,
    @Path('eventId') required String? eventId,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete replay session for STB
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the session in Traxis.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<DeleteSessionResponse>>
      sessionCpesCpeIdReplaySessionsSessionIdDelete({
    required String? cpeId,
    required String? sessionId,
    required int? sessionEndCode,
    String? additionalInfo,
    required String? timeOffset,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeleteSessionResponse, () => DeleteSessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdReplaySessionsSessionIdDelete(
        cpeId: cpeId,
        sessionId: sessionId,
        sessionEndCode: sessionEndCode,
        additionalInfo: additionalInfo,
        timeOffset: timeOffset,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Delete replay session for STB
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the session in Traxis.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3
  ///@param
  ///@param
  ///@param
  ///@param
  @Delete(path: '/session/cpes/{cpeId}/replay/sessions/{sessionId}')
  Future<chopper.Response<DeleteSessionResponse>>
      _sessionCpesCpeIdReplaySessionsSessionIdDelete({
    @Path('cpeId') required String? cpeId,
    @Path('sessionId') required String? sessionId,
    @Query('sessionEndCode') required int? sessionEndCode,
    @Query('additionalInfo') String? additionalInfo,
    @Query('timeOffset') required String? timeOffset,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create replay session for HZN-GO (OESP).
  ///@param customerId Id of the customer
  ///@param assetId Crid of the asset taken from offers.alternativeIdentifiers from MAG
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<ReplaySessionOespResponse>>
      sessionCustomersCustomerIdReplayAssetsAssetIdPost({
    required String? customerId,
    required String? assetId,
    String? userAgent,
    required String? abrType,
    String? profileId,
    String? language,
    String? sessionMode,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ReplaySessionOespResponse,
        () => ReplaySessionOespResponse.fromJsonFactory);

    return _sessionCustomersCustomerIdReplayAssetsAssetIdPost(
        customerId: customerId,
        assetId: assetId,
        userAgent: userAgent,
        abrType: abrType,
        profileId: profileId,
        language: language,
        sessionMode: sessionMode,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl);
  }

  ///Create replay session for HZN-GO (OESP).
  ///@param customerId Id of the customer
  ///@param assetId Crid of the asset taken from offers.alternativeIdentifiers from MAG
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Post(
    path: '/session/customers/{customerId}/replay/assets/{assetId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReplaySessionOespResponse>>
      _sessionCustomersCustomerIdReplayAssetsAssetIdPost({
    @Path('customerId') required String? customerId,
    @Path('assetId') required String? assetId,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') required String? abrType,
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Query('sessionMode') String? sessionMode,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create session to replay from external resource.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<ReplayExternalResponse>>
      sessionCpesCpeIdReplayExternalEventsEventIdPost({
    required String? cpeId,
    required String? eventId,
    String? sessionMode,
    String? userAgent,
    String? abrType,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReplayExternalResponse, () => ReplayExternalResponse.fromJsonFactory);

    return _sessionCpesCpeIdReplayExternalEventsEventIdPost(
        cpeId: cpeId,
        eventId: eventId,
        sessionMode: sessionMode,
        userAgent: userAgent,
        abrType: abrType,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Create session to replay from external resource.
  ///@param cpeId Identification of the customer's CPE.
  ///@param eventId CRID+IMI of the event - provided by the client apps.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Post(
    path: '/session/cpes/{cpeId}/replay_external/events/{eventId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReplayExternalResponse>>
      _sessionCpesCpeIdReplayExternalEventsEventIdPost({
    @Path('cpeId') required String? cpeId,
    @Path('eventId') required String? eventId,
    @Query('sessionMode') String? sessionMode,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Playback from the review buffer.
  ///@param channelId ID of a channel
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE' to view the Live streaming of the channel.
  ///@param source Additional parameter to drive the selection of the thumbnail source
  ///@param
  ///@param
  Future<chopper.Response<ReviewBufferResponse>>
      sessionV1ChannelsChannelIdPost({
    required String? channelId,
    required String? startTime,
    String? source,
    String? userAgent,
    String? abrType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ReviewBufferResponse, () => ReviewBufferResponse.fromJsonFactory);

    return _sessionV1ChannelsChannelIdPost(
        channelId: channelId,
        startTime: startTime,
        source: source,
        userAgent: userAgent,
        abrType: abrType,
        cacheControl: cacheControl);
  }

  ///Playback from the review buffer.
  ///@param channelId ID of a channel
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE' to view the Live streaming of the channel.
  ///@param source Additional parameter to drive the selection of the thumbnail source
  ///@param
  ///@param
  @Post(
    path: '/session/v1/channels/{channelId}',
    optionalBody: true,
  )
  Future<chopper.Response<ReviewBufferResponse>>
      _sessionV1ChannelsChannelIdPost({
    @Path('channelId') required String? channelId,
    @Query('startTime') required String? startTime,
    @Query('source') String? source,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create VoD session to replay on STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param contentId CRID+IMI of the content (instance id from vod-service) - provided by the client apps. e.g.: crid://e2e-si.lgi.com/597-titanic,imi:597-titanic-stb
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<VodSessionResponse>>
      sessionCpesCpeIdVodContentsContentIdPost({
    required String? cpeId,
    required String? contentId,
    String? userAgent,
    String? abrType,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        VodSessionResponse, () => VodSessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdVodContentsContentIdPost(
        cpeId: cpeId,
        contentId: contentId,
        userAgent: userAgent,
        abrType: abrType,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Create VoD session to replay on STB.
  ///@param cpeId Identification of the customer's CPE.
  ///@param contentId CRID+IMI of the content (instance id from vod-service) - provided by the client apps. e.g.: crid://e2e-si.lgi.com/597-titanic,imi:597-titanic-stb
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Post(
    path: '/session/cpes/{cpeId}/vod/contents/{contentId}',
    optionalBody: true,
  )
  Future<chopper.Response<VodSessionResponse>>
      _sessionCpesCpeIdVodContentsContentIdPost({
    @Path('cpeId') required String? cpeId,
    @Path('contentId') required String? contentId,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete VoD session.
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the VoD session returned during creation.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<DeleteSessionResponse>>
      sessionCpesCpeIdVodSessionsSessionIdDelete({
    required String? cpeId,
    required String? sessionId,
    required int? sessionEndCode,
    String? additionalInfo,
    required String? timeOffset,
    String? xDev,
    String? xCus = 'X-Cus',
    String? profileId,
    String? language,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeleteSessionResponse, () => DeleteSessionResponse.fromJsonFactory);

    return _sessionCpesCpeIdVodSessionsSessionIdDelete(
        cpeId: cpeId,
        sessionId: sessionId,
        sessionEndCode: sessionEndCode,
        additionalInfo: additionalInfo,
        timeOffset: timeOffset,
        xDev: xDev,
        xCus: xCus,
        profileId: profileId,
        language: language,
        cacheControl: cacheControl);
  }

  ///Delete VoD session.
  ///@param cpeId Identification of the customer's CPE.
  ///@param sessionId Identification of the VoD session returned during creation.
  ///@param sessionEndCode Code for the reason of session deletion. <a href="https://wikiprojects.upc.biz/display/SPARK/Session+Service+Use+cases#SessionServiceUsecases-Usecase:DeletesessiononHZN-4">Delete session on HZN-4</a>
  ///@param additionalInfo Additional information send to the service when delete a session. Right now used (required) only for sessionEndCode=8 and it specify how much of the content was with droppped quality from UHD. The value should be > 0.0 and <= 1.0
  ///@param timeOffset Time shall be provided as an NPT value conform RFC 2326. Only npt-sec and npt-hhmmss are allowed. Examples e.g.: 1320.003 or 20 or 01:05:35.3
  ///@param
  ///@param
  ///@param
  ///@param
  @Delete(path: '/session/cpes/{cpeId}/vod/sessions/{sessionId}')
  Future<chopper.Response<DeleteSessionResponse>>
      _sessionCpesCpeIdVodSessionsSessionIdDelete({
    @Path('cpeId') required String? cpeId,
    @Path('sessionId') required String? sessionId,
    @Query('sessionEndCode') required int? sessionEndCode,
    @Query('additionalInfo') String? additionalInfo,
    @Query('timeOffset') required String? timeOffset,
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create URL to the manifest to play VOD content on HZ-GO.
  ///@param customerId Identification of the customer.
  ///@param crid Alternative identifier (crid) of the content. Crid with Imi for specific content is also accepted.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  Future<chopper.Response<VodSessionForHznGoResponse>>
      sessionCustomersCustomerIdVodContentsCridPost({
    required String? customerId,
    required String? crid,
    String? userAgent,
    String? abrType,
    String? profileId,
    String? language,
    String? sessionMode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(VodSessionForHznGoResponse,
        () => VodSessionForHznGoResponse.fromJsonFactory);

    return _sessionCustomersCustomerIdVodContentsCridPost(
        customerId: customerId,
        crid: crid,
        userAgent: userAgent,
        abrType: abrType,
        profileId: profileId,
        language: language,
        sessionMode: sessionMode,
        cacheControl: cacheControl);
  }

  ///Create URL to the manifest to play VOD content on HZ-GO.
  ///@param customerId Identification of the customer.
  ///@param crid Alternative identifier (crid) of the content. Crid with Imi for specific content is also accepted.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param sessionMode Optional parameter controlling the session mode. Could be online (default), offline - for the offline view of the content or limited for non-OBO provisioned customers.
  @Post(
    path: '/session/customers/{customerId}/vod/contents/{crid}',
    optionalBody: true,
  )
  Future<chopper.Response<VodSessionForHznGoResponse>>
      _sessionCustomersCustomerIdVodContentsCridPost({
    @Path('customerId') required String? customerId,
    @Path('crid') required String? crid,
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Query('profileId') String? profileId,
    @Query('language') String? language,
    @Query('sessionMode') String? sessionMode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify if the requesting client is authorized to access the asset.
  ///@param StbId The client device for which the authorization is checked.
  ///@param AssetId Identifies the asset for which authorization is checked.
  Future<chopper.Response<AuthorizedForAssetResponse>>
      sessionAuthorizationAssetsGet({
    required String? stbId,
    required String? assetId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AuthorizedForAssetResponse,
        () => AuthorizedForAssetResponse.fromJsonFactory);

    return _sessionAuthorizationAssetsGet(
        stbId: stbId, assetId: assetId, cacheControl: cacheControl);
  }

  ///Verify if the requesting client is authorized to access the asset.
  ///@param StbId The client device for which the authorization is checked.
  ///@param AssetId Identifies the asset for which authorization is checked.
  @Get(path: '/session/authorization/assets')
  Future<chopper.Response<AuthorizedForAssetResponse>>
      _sessionAuthorizationAssetsGet({
    @Query('StbId') required String? stbId,
    @Query('AssetId') required String? assetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify if the requesting client is authorized to access the recording.
  ///@param CustomerId The customer ID for which the authorization is checked.
  ///@param RecordingId Identifies the resource for which authorization is checked.
  Future<chopper.Response<AuthorizedForAssetResponse>>
      sessionAuthorizationRecordingsGet({
    required String? customerId,
    required String? recordingId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AuthorizedForAssetResponse,
        () => AuthorizedForAssetResponse.fromJsonFactory);

    return _sessionAuthorizationRecordingsGet(
        customerId: customerId,
        recordingId: recordingId,
        cacheControl: cacheControl);
  }

  ///Verify if the requesting client is authorized to access the recording.
  ///@param CustomerId The customer ID for which the authorization is checked.
  ///@param RecordingId Identifies the resource for which authorization is checked.
  @Get(path: '/session/authorization/recordings')
  Future<chopper.Response<AuthorizedForAssetResponse>>
      _sessionAuthorizationRecordingsGet({
    @Query('CustomerId') required String? customerId,
    @Query('RecordingId') required String? recordingId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify if the requesting client is authorized to access the channel.
  ///@param StbId The client device for which the authorization is checked.
  ///@param ChannelId Identifies the channel for which authorization is checked.
  Future<chopper.Response<AuthorizedForChannelResponse>>
      sessionAuthorizationChannelsGet({
    required String? stbId,
    required String? channelId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AuthorizedForChannelResponse,
        () => AuthorizedForChannelResponse.fromJsonFactory);

    return _sessionAuthorizationChannelsGet(
        stbId: stbId, channelId: channelId, cacheControl: cacheControl);
  }

  ///Verify if the requesting client is authorized to access the channel.
  ///@param StbId The client device for which the authorization is checked.
  ///@param ChannelId Identifies the channel for which authorization is checked.
  @Get(path: '/session/authorization/channels')
  Future<chopper.Response<AuthorizedForChannelResponse>>
      _sessionAuthorizationChannelsGet({
    @Query('StbId') required String? stbId,
    @Query('ChannelId') required String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create replay session for Perseus.
  ///@param eventId Event for which the session should be created. Accepts both ~~2F and // encodings.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param x-dev Id of the STB devices. It is not set for the mobile/web clients.
  Future<chopper.Response<ReplayPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersCustomerIdReplayPost({
    required String? eventId,
    required String? abrType,
    required String? customerId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? xDrmDeviceId,
    String? xClaimsSet,
    String? xProfileId,
    String? xUiLanguage,
    String? xDev,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ReplayPerseusSessionResponse,
        () => ReplayPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersCustomerIdReplayPost(
        eventId: eventId,
        abrType: abrType,
        customerId: customerId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        xDrmDeviceId: xDrmDeviceId,
        xClaimsSet: xClaimsSet,
        xProfileId: xProfileId,
        xUiLanguage: xUiLanguage,
        xDev: xDev,
        cacheControl: cacheControl);
  }

  ///Create replay session for Perseus.
  ///@param eventId Event for which the session should be created. Accepts both ~~2F and // encodings.
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  ///@param x-dev Id of the STB devices. It is not set for the mobile/web clients.
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{customerId}/replay',
    optionalBody: true,
  )
  Future<chopper.Response<ReplayPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersCustomerIdReplayPost({
    @Query('eventId') required String? eventId,
    @Query('abrType') required String? abrType,
    @Path('customerId') required String? customerId,
    @Path('deviceFamily') required String? deviceFamily,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent') String? userAgent,
    @Header('X-Drm-Device-Id') String? xDrmDeviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('x-profile-id') String? xProfileId,
    @Header('x-ui-language') String? xUiLanguage,
    @Header('x-dev') String? xDev,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create VOD session for Perseus.
  ///@param contentId Id of the Content for which the session is created.<br> <b>Hollow:</b> Content -> contentId. Example: crid:~~2F~~2Fperf.e2e-si.lgi.com~~2F76203-12-years-a-slave,imi:76203-12-years-a-slave-stb
  ///@param customerId CustomerId for which the session should be created. It should contain country code
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<VodPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersCustomerIdVodPost({
    required String? contentId,
    required String? customerId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    required String? abrType,
    String? xDrmDeviceId,
    String? xClaimsSet,
    String? xProfileId,
    String? xUiLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(VodPerseusSessionResponse,
        () => VodPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersCustomerIdVodPost(
        contentId: contentId,
        customerId: customerId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        xClaimsSet: xClaimsSet,
        xProfileId: xProfileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl);
  }

  ///Create VOD session for Perseus.
  ///@param contentId Id of the Content for which the session is created.<br> <b>Hollow:</b> Content -> contentId. Example: crid:~~2F~~2Fperf.e2e-si.lgi.com~~2F76203-12-years-a-slave,imi:76203-12-years-a-slave-stb
  ///@param customerId CustomerId for which the session should be created. It should contain country code
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{customerId}/vod',
    optionalBody: true,
  )
  Future<chopper.Response<VodPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersCustomerIdVodPost({
    @Query('contentId') required String? contentId,
    @Path('customerId') required String? customerId,
    @Path('deviceFamily') required String? deviceFamily,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent') String? userAgent,
    @Query('abrType') required String? abrType,
    @Header('X-Drm-Device-Id') String? xDrmDeviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('x-profile-id') String? xProfileId,
    @Header('x-ui-language') String? xUiLanguage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create nDVR session
  ///@param recordingId Id of the recording for which the session is created. It should be take from recording-management-service.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<RecordingPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersCustomerIdRecordingPost({
    required String? recordingId,
    required String? customerId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? abrType,
    String? xDrmDeviceId,
    String? xClaimsSet,
    String? profileId,
    String? xUiLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(RecordingPerseusSessionResponse,
        () => RecordingPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersCustomerIdRecordingPost(
        recordingId: recordingId,
        customerId: customerId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        xClaimsSet: xClaimsSet,
        profileId: profileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl);
  }

  ///Create nDVR session
  ///@param recordingId Id of the recording for which the session is created. It should be take from recording-management-service.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{customerId}/recording',
    optionalBody: true,
  )
  Future<chopper.Response<RecordingPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersCustomerIdRecordingPost({
    @Query('recordingId') required String? recordingId,
    @Path('customerId') required String? customerId,
    @Path('deviceFamily') required String? deviceFamily,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('X-Entitlements-Token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent') String? userAgent,
    @Query('abrType') String? abrType,
    @Header('X-Drm-Device-Id') String? xDrmDeviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Query('profileId') String? profileId,
    @Header('x-ui-language') String? xUiLanguage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create session for review buffer.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE'
  ///@param source Additional parameter to drive the selection of the thumbnail source
  ///@param customerId CustomerId for which the session should be created. It should contain country code
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<ReviewBufferPerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersCustomerIdReviewBufferPost({
    required String? channelId,
    required String? startTime,
    String? source,
    required String? customerId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    required String? abrType,
    String? xDrmDeviceId,
    String? xClaimsSet,
    String? xProfileId,
    String? xUiLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ReviewBufferPerseusSessionResponse,
        () => ReviewBufferPerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersCustomerIdReviewBufferPost(
        channelId: channelId,
        startTime: startTime,
        source: source,
        customerId: customerId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        abrType: abrType,
        xDrmDeviceId: xDrmDeviceId,
        xClaimsSet: xClaimsSet,
        xProfileId: xProfileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl);
  }

  ///Create session for review buffer.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param startTime Past time ('YYYY-MM-DDThh:mm:ssZ') for time-shift service or 'LIVE'
  ///@param source Additional parameter to drive the selection of the thumbnail source
  ///@param customerId CustomerId for which the session should be created. It should contain country code
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param abrType AbrType query parameter is used to identify device profile. Currently, expected value for this parameter is Orion-HLS, Orion-HSS, Orion-Replay-HSS, Orion-DASH, Orion-DASH-PR, Orion-Replay-DASH, Orion-Replay-DASH-PR but this is configurable per namespaces.
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{customerId}/reviewBuffer',
    optionalBody: true,
  )
  Future<chopper.Response<ReviewBufferPerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersCustomerIdReviewBufferPost({
    @Query('channelId') required String? channelId,
    @Query('startTime') required String? startTime,
    @Query('source') String? source,
    @Path('customerId') required String? customerId,
    @Path('deviceFamily') required String? deviceFamily,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent') String? userAgent,
    @Query('abrType') required String? abrType,
    @Header('X-Drm-Device-Id') String? xDrmDeviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('x-profile-id') String? xProfileId,
    @Header('x-ui-language') String? xUiLanguage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create a live session.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param customerId CustomerId for which the session should be created. It should contain country code
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  Future<chopper.Response<LivePerseusSessionResponse>>
      sessionV2DeviceFamilyCustomersCustomerIdLivePost({
    required String? channelId,
    required String? customerId,
    required String? deviceFamily,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? userAgent,
    String? xDrmDeviceId,
    String? xClaimsSet,
    String? xProfileId,
    String? xUiLanguage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(LivePerseusSessionResponse,
        () => LivePerseusSessionResponse.fromJsonFactory);

    return _sessionV2DeviceFamilyCustomersCustomerIdLivePost(
        channelId: channelId,
        customerId: customerId,
        deviceFamily: deviceFamily,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        userAgent: userAgent,
        xDrmDeviceId: xDrmDeviceId,
        xClaimsSet: xClaimsSet,
        xProfileId: xProfileId,
        xUiLanguage: xUiLanguage,
        cacheControl: cacheControl);
  }

  ///Create a live session.
  ///@param channelId Id of the Chanel for which the session is created.<br> <b>Hollow:</b> Channel -> channelId. Example: 0149
  ///@param customerId CustomerId for which the session should be created. It should contain country code
  ///@param
  ///@param
  ///@param
  ///@param x-entitlements-token Entitlements token
  ///@param
  ///@param X-Drm-Device-Id DRM Device Id registered in personalization service. It is obtain from the Irdeto RRM X-Irdeto-DrmDeviceId and is verified agains the claim from personalization service.
  ///@param X-Claims-Set Encoded customer information
  ///@param x-profile-id Id of the profile.
  ///@param x-ui-language UI language, 2 letter country code according to ISO639-1 (not validated by the service)
  @Post(
    path: '/session/v2/{deviceFamily}/customers/{customerId}/live',
    optionalBody: true,
  )
  Future<chopper.Response<LivePerseusSessionResponse>>
      _sessionV2DeviceFamilyCustomersCustomerIdLivePost({
    @Query('channelId') required String? channelId,
    @Path('customerId') required String? customerId,
    @Path('deviceFamily') required String? deviceFamily,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('User-Agent') String? userAgent,
    @Header('X-Drm-Device-Id') String? xDrmDeviceId,
    @Header('X-Claims-Set') String? xClaimsSet,
    @Header('x-profile-id') String? xProfileId,
    @Header('x-ui-language') String? xUiLanguage,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;
  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewBufferResponse {
  ReviewBufferResponse({
    required this.url,
    required this.latency,
    this.thumbnailServiceUrl,
  });

  factory ReviewBufferResponse.fromJson(Map<String, dynamic> json) =>
      _$ReviewBufferResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'latency', includeIfNull: false)
  final num latency;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  static const fromJsonFactory = _$ReviewBufferResponseFromJson;
  static const toJsonFactory = _$ReviewBufferResponseToJson;
  Map<String, dynamic> toJson() => _$ReviewBufferResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewBufferResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.latency, latency) ||
                const DeepCollectionEquality()
                    .equals(other.latency, latency)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(latency) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      runtimeType.hashCode;
}

extension $ReviewBufferResponseExtension on ReviewBufferResponse {
  ReviewBufferResponse copyWith(
      {String? url, num? latency, String? thumbnailServiceUrl}) {
    return ReviewBufferResponse(
        url: url ?? this.url,
        latency: latency ?? this.latency,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl);
  }

  ReviewBufferResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<num>? latency,
      Wrapped<String?>? thumbnailServiceUrl}) {
    return ReviewBufferResponse(
        url: (url != null ? url.value : this.url),
        latency: (latency != null ? latency.value : this.latency),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayExternalResponse {
  ReplayExternalResponse({
    this.replayId,
  });

  factory ReplayExternalResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayExternalResponseFromJson(json);

  @JsonKey(name: 'replayId', includeIfNull: false, defaultValue: '')
  final String? replayId;
  static const fromJsonFactory = _$ReplayExternalResponseFromJson;
  static const toJsonFactory = _$ReplayExternalResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayExternalResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayExternalResponse &&
            (identical(other.replayId, replayId) ||
                const DeepCollectionEquality()
                    .equals(other.replayId, replayId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayId) ^ runtimeType.hashCode;
}

extension $ReplayExternalResponseExtension on ReplayExternalResponse {
  ReplayExternalResponse copyWith({String? replayId}) {
    return ReplayExternalResponse(replayId: replayId ?? this.replayId);
  }

  ReplayExternalResponse copyWithWrapped({Wrapped<String?>? replayId}) {
    return ReplayExternalResponse(
        replayId: (replayId != null ? replayId.value : this.replayId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplaySessionResponse {
  ReplaySessionResponse({
    required this.url,
    this.sessionId,
    this.prePaddingTime,
    this.postPaddingTime,
    required this.trickPlayControl,
    this.thumbnailServiceUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
  });

  factory ReplaySessionResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplaySessionResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String? sessionId;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final num? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final num? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  static const fromJsonFactory = _$ReplaySessionResponseFromJson;
  static const toJsonFactory = _$ReplaySessionResponseToJson;
  Map<String, dynamic> toJson() => _$ReplaySessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplaySessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(sessionId) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      runtimeType.hashCode;
}

extension $ReplaySessionResponseExtension on ReplaySessionResponse {
  ReplaySessionResponse copyWith(
      {String? url,
      String? sessionId,
      num? prePaddingTime,
      num? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? thumbnailServiceUrl,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime}) {
    return ReplaySessionResponse(
        url: url ?? this.url,
        sessionId: sessionId ?? this.sessionId,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime);
  }

  ReplaySessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? sessionId,
      Wrapped<num?>? prePaddingTime,
      Wrapped<num?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime}) {
    return ReplaySessionResponse(
        url: (url != null ? url.value : this.url),
        sessionId: (sessionId != null ? sessionId.value : this.sessionId),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplaySessionOespResponse {
  ReplaySessionOespResponse({
    required this.url,
    this.prePaddingTime,
    this.postPaddingTime,
    this.trickPlayControl,
    this.contentLocator,
    this.protectionKey,
    this.drmScheme,
    this.thumbnailServiceUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
  });

  factory ReplaySessionOespResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplaySessionOespResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final num? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final num? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? trickPlayControl;
  @JsonKey(name: 'contentLocator', includeIfNull: false, defaultValue: '')
  final String? contentLocator;
  @JsonKey(name: 'protectionKey', includeIfNull: false, defaultValue: '')
  final String? protectionKey;
  @JsonKey(name: 'drmScheme', includeIfNull: false, defaultValue: '')
  final String? drmScheme;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(
      name: 'eventSessionStartTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionEndTime;
  static const fromJsonFactory = _$ReplaySessionOespResponseFromJson;
  static const toJsonFactory = _$ReplaySessionOespResponseToJson;
  Map<String, dynamic> toJson() => _$ReplaySessionOespResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplaySessionOespResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.contentLocator, contentLocator) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocator, contentLocator)) &&
            (identical(other.protectionKey, protectionKey) ||
                const DeepCollectionEquality()
                    .equals(other.protectionKey, protectionKey)) &&
            (identical(other.drmScheme, drmScheme) ||
                const DeepCollectionEquality()
                    .equals(other.drmScheme, drmScheme)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(contentLocator) ^
      const DeepCollectionEquality().hash(protectionKey) ^
      const DeepCollectionEquality().hash(drmScheme) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      runtimeType.hashCode;
}

extension $ReplaySessionOespResponseExtension on ReplaySessionOespResponse {
  ReplaySessionOespResponse copyWith(
      {String? url,
      num? prePaddingTime,
      num? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? contentLocator,
      String? protectionKey,
      String? drmScheme,
      String? thumbnailServiceUrl,
      String? eventSessionStartTime,
      String? eventSessionEndTime}) {
    return ReplaySessionOespResponse(
        url: url ?? this.url,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        contentLocator: contentLocator ?? this.contentLocator,
        protectionKey: protectionKey ?? this.protectionKey,
        drmScheme: drmScheme ?? this.drmScheme,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime);
  }

  ReplaySessionOespResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<num?>? prePaddingTime,
      Wrapped<num?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>?>? trickPlayControl,
      Wrapped<String?>? contentLocator,
      Wrapped<String?>? protectionKey,
      Wrapped<String?>? drmScheme,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? eventSessionStartTime,
      Wrapped<String?>? eventSessionEndTime}) {
    return ReplaySessionOespResponse(
        url: (url != null ? url.value : this.url),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        contentLocator: (contentLocator != null
            ? contentLocator.value
            : this.contentLocator),
        protectionKey:
            (protectionKey != null ? protectionKey.value : this.protectionKey),
        drmScheme: (drmScheme != null ? drmScheme.value : this.drmScheme),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ReplayPerseusSessionResponse {
  ReplayPerseusSessionResponse({
    required this.url,
    this.prePaddingTime,
    this.postPaddingTime,
    required this.trickPlayControl,
    this.thumbnailServiceUrl,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.drmContentId,
  });

  factory ReplayPerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$ReplayPerseusSessionResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$ReplayPerseusSessionResponseFromJson;
  static const toJsonFactory = _$ReplayPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() => _$ReplayPerseusSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReplayPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $ReplayPerseusSessionResponseExtension
    on ReplayPerseusSessionResponse {
  ReplayPerseusSessionResponse copyWith(
      {String? url,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? thumbnailServiceUrl,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime,
      String? drmContentId}) {
    return ReplayPerseusSessionResponse(
        url: url ?? this.url,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  ReplayPerseusSessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime,
      Wrapped<String?>? drmContentId}) {
    return ReplayPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class VodPerseusSessionResponse {
  VodPerseusSessionResponse({
    this.url,
    this.thumbnailServiceUrl,
    this.drmContentId,
  });

  factory VodPerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$VodPerseusSessionResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$VodPerseusSessionResponseFromJson;
  static const toJsonFactory = _$VodPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() => _$VodPerseusSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $VodPerseusSessionResponseExtension on VodPerseusSessionResponse {
  VodPerseusSessionResponse copyWith(
      {String? url, String? thumbnailServiceUrl, String? drmContentId}) {
    return VodPerseusSessionResponse(
        url: url ?? this.url,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  VodPerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? drmContentId}) {
    return VodPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingResponse {
  RecordingResponse({
    this.url,
    this.prePaddingTime,
    this.postPaddingTime,
    this.trickPlayControl,
    this.thumbnailServiceUrl,
    this.contentLocator,
    this.protectionKey,
    this.drmScheme,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.drmContentId,
  });

  factory RecordingResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final num? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final num? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? trickPlayControl;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'contentLocator', includeIfNull: false, defaultValue: '')
  final String? contentLocator;
  @JsonKey(name: 'protectionKey', includeIfNull: false, defaultValue: '')
  final String? protectionKey;
  @JsonKey(name: 'drmScheme', includeIfNull: false, defaultValue: '')
  final String? drmScheme;
  @JsonKey(
      name: 'eventSessionStartTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false, defaultValue: '')
  final String? eventSessionEndTime;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$RecordingResponseFromJson;
  static const toJsonFactory = _$RecordingResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.contentLocator, contentLocator) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocator, contentLocator)) &&
            (identical(other.protectionKey, protectionKey) ||
                const DeepCollectionEquality()
                    .equals(other.protectionKey, protectionKey)) &&
            (identical(other.drmScheme, drmScheme) ||
                const DeepCollectionEquality()
                    .equals(other.drmScheme, drmScheme)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(contentLocator) ^
      const DeepCollectionEquality().hash(protectionKey) ^
      const DeepCollectionEquality().hash(drmScheme) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $RecordingResponseExtension on RecordingResponse {
  RecordingResponse copyWith(
      {String? url,
      num? prePaddingTime,
      num? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? thumbnailServiceUrl,
      String? contentLocator,
      String? protectionKey,
      String? drmScheme,
      String? eventSessionStartTime,
      String? eventSessionEndTime,
      String? drmContentId}) {
    return RecordingResponse(
        url: url ?? this.url,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        contentLocator: contentLocator ?? this.contentLocator,
        protectionKey: protectionKey ?? this.protectionKey,
        drmScheme: drmScheme ?? this.drmScheme,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  RecordingResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<num?>? prePaddingTime,
      Wrapped<num?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>?>? trickPlayControl,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? contentLocator,
      Wrapped<String?>? protectionKey,
      Wrapped<String?>? drmScheme,
      Wrapped<String?>? eventSessionStartTime,
      Wrapped<String?>? eventSessionEndTime,
      Wrapped<String?>? drmContentId}) {
    return RecordingResponse(
        url: (url != null ? url.value : this.url),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        contentLocator: (contentLocator != null
            ? contentLocator.value
            : this.contentLocator),
        protectionKey:
            (protectionKey != null ? protectionKey.value : this.protectionKey),
        drmScheme: (drmScheme != null ? drmScheme.value : this.drmScheme),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingPerseusSessionResponse {
  RecordingPerseusSessionResponse({
    this.url,
    this.eventSessionStartTime,
    this.eventSessionEndTime,
    this.thumbnailServiceUrl,
    this.prePaddingTime,
    this.postPaddingTime,
    this.trickPlayControl,
    this.drmContentId,
  });

  factory RecordingPerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingPerseusSessionResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'eventSessionStartTime', includeIfNull: false)
  final DateTime? eventSessionStartTime;
  @JsonKey(name: 'eventSessionEndTime', includeIfNull: false)
  final DateTime? eventSessionEndTime;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false)
  final int? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false)
  final int? postPaddingTime;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl>? trickPlayControl;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$RecordingPerseusSessionResponseFromJson;
  static const toJsonFactory = _$RecordingPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingPerseusSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.eventSessionStartTime, eventSessionStartTime) ||
                const DeepCollectionEquality().equals(
                    other.eventSessionStartTime, eventSessionStartTime)) &&
            (identical(other.eventSessionEndTime, eventSessionEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.eventSessionEndTime, eventSessionEndTime)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(eventSessionStartTime) ^
      const DeepCollectionEquality().hash(eventSessionEndTime) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $RecordingPerseusSessionResponseExtension
    on RecordingPerseusSessionResponse {
  RecordingPerseusSessionResponse copyWith(
      {String? url,
      DateTime? eventSessionStartTime,
      DateTime? eventSessionEndTime,
      String? thumbnailServiceUrl,
      int? prePaddingTime,
      int? postPaddingTime,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? drmContentId}) {
    return RecordingPerseusSessionResponse(
        url: url ?? this.url,
        eventSessionStartTime:
            eventSessionStartTime ?? this.eventSessionStartTime,
        eventSessionEndTime: eventSessionEndTime ?? this.eventSessionEndTime,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  RecordingPerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<DateTime?>? eventSessionStartTime,
      Wrapped<DateTime?>? eventSessionEndTime,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<int?>? prePaddingTime,
      Wrapped<int?>? postPaddingTime,
      Wrapped<List<enums.TrickPlayControl>?>? trickPlayControl,
      Wrapped<String?>? drmContentId}) {
    return RecordingPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        eventSessionStartTime: (eventSessionStartTime != null
            ? eventSessionStartTime.value
            : this.eventSessionStartTime),
        eventSessionEndTime: (eventSessionEndTime != null
            ? eventSessionEndTime.value
            : this.eventSessionEndTime),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class ReviewBufferPerseusSessionResponse {
  ReviewBufferPerseusSessionResponse({
    this.url,
    this.thumbnailServiceUrl,
    this.drmContentId,
  });

  factory ReviewBufferPerseusSessionResponse.fromJson(
          Map<String, dynamic> json) =>
      _$ReviewBufferPerseusSessionResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$ReviewBufferPerseusSessionResponseFromJson;
  static const toJsonFactory = _$ReviewBufferPerseusSessionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$ReviewBufferPerseusSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ReviewBufferPerseusSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(drmContentId) ^
      runtimeType.hashCode;
}

extension $ReviewBufferPerseusSessionResponseExtension
    on ReviewBufferPerseusSessionResponse {
  ReviewBufferPerseusSessionResponse copyWith(
      {String? url, String? thumbnailServiceUrl, String? drmContentId}) {
    return ReviewBufferPerseusSessionResponse(
        url: url ?? this.url,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        drmContentId: drmContentId ?? this.drmContentId);
  }

  ReviewBufferPerseusSessionResponse copyWithWrapped(
      {Wrapped<String?>? url,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? drmContentId}) {
    return ReviewBufferPerseusSessionResponse(
        url: (url != null ? url.value : this.url),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class LivePerseusSessionResponse {
  LivePerseusSessionResponse({
    this.drmContentId,
  });

  factory LivePerseusSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$LivePerseusSessionResponseFromJson(json);

  @JsonKey(name: 'drmContentId', includeIfNull: false)
  final String? drmContentId;
  static const fromJsonFactory = _$LivePerseusSessionResponseFromJson;
  static const toJsonFactory = _$LivePerseusSessionResponseToJson;
  Map<String, dynamic> toJson() => _$LivePerseusSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LivePerseusSessionResponse &&
            (identical(other.drmContentId, drmContentId) ||
                const DeepCollectionEquality()
                    .equals(other.drmContentId, drmContentId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(drmContentId) ^ runtimeType.hashCode;
}

extension $LivePerseusSessionResponseExtension on LivePerseusSessionResponse {
  LivePerseusSessionResponse copyWith({String? drmContentId}) {
    return LivePerseusSessionResponse(
        drmContentId: drmContentId ?? this.drmContentId);
  }

  LivePerseusSessionResponse copyWithWrapped({Wrapped<String?>? drmContentId}) {
    return LivePerseusSessionResponse(
        drmContentId:
            (drmContentId != null ? drmContentId.value : this.drmContentId));
  }
}

@JsonSerializable(explicitToJson: true)
class XStreamingHeaders {
  XStreamingHeaders();

  factory XStreamingHeaders.fromJson(Map<String, dynamic> json) =>
      _$XStreamingHeadersFromJson(json);

  static const fromJsonFactory = _$XStreamingHeadersFromJson;
  static const toJsonFactory = _$XStreamingHeadersToJson;
  Map<String, dynamic> toJson() => _$XStreamingHeadersToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class VodSessionResponse {
  VodSessionResponse({
    required this.url,
    this.sessionId,
    this.contentId,
    required this.trickPlayControl,
    this.thumbnailServiceUrl,
  });

  factory VodSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$VodSessionResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String? sessionId;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String? contentId;
  @JsonKey(
    name: 'trickPlayControl',
    includeIfNull: false,
    toJson: trickPlayControlListToJson,
    fromJson: trickPlayControlListFromJson,
  )
  final List<enums.TrickPlayControl> trickPlayControl;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  static const fromJsonFactory = _$VodSessionResponseFromJson;
  static const toJsonFactory = _$VodSessionResponseToJson;
  Map<String, dynamic> toJson() => _$VodSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodSessionResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(sessionId) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      runtimeType.hashCode;
}

extension $VodSessionResponseExtension on VodSessionResponse {
  VodSessionResponse copyWith(
      {String? url,
      String? sessionId,
      String? contentId,
      List<enums.TrickPlayControl>? trickPlayControl,
      String? thumbnailServiceUrl}) {
    return VodSessionResponse(
        url: url ?? this.url,
        sessionId: sessionId ?? this.sessionId,
        contentId: contentId ?? this.contentId,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl);
  }

  VodSessionResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? sessionId,
      Wrapped<String?>? contentId,
      Wrapped<List<enums.TrickPlayControl>>? trickPlayControl,
      Wrapped<String?>? thumbnailServiceUrl}) {
    return VodSessionResponse(
        url: (url != null ? url.value : this.url),
        sessionId: (sessionId != null ? sessionId.value : this.sessionId),
        contentId: (contentId != null ? contentId.value : this.contentId),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class VodSessionForHznGoResponse {
  VodSessionForHznGoResponse({
    required this.url,
    this.thumbnailServiceUrl,
    this.contentLocator,
    this.protectionKey,
    this.drmScheme,
  });

  factory VodSessionForHznGoResponse.fromJson(Map<String, dynamic> json) =>
      _$VodSessionForHznGoResponseFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'contentLocator', includeIfNull: false, defaultValue: '')
  final String? contentLocator;
  @JsonKey(name: 'protectionKey', includeIfNull: false, defaultValue: '')
  final String? protectionKey;
  @JsonKey(name: 'drmScheme', includeIfNull: false, defaultValue: '')
  final String? drmScheme;
  static const fromJsonFactory = _$VodSessionForHznGoResponseFromJson;
  static const toJsonFactory = _$VodSessionForHznGoResponseToJson;
  Map<String, dynamic> toJson() => _$VodSessionForHznGoResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodSessionForHznGoResponse &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.contentLocator, contentLocator) ||
                const DeepCollectionEquality()
                    .equals(other.contentLocator, contentLocator)) &&
            (identical(other.protectionKey, protectionKey) ||
                const DeepCollectionEquality()
                    .equals(other.protectionKey, protectionKey)) &&
            (identical(other.drmScheme, drmScheme) ||
                const DeepCollectionEquality()
                    .equals(other.drmScheme, drmScheme)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(contentLocator) ^
      const DeepCollectionEquality().hash(protectionKey) ^
      const DeepCollectionEquality().hash(drmScheme) ^
      runtimeType.hashCode;
}

extension $VodSessionForHznGoResponseExtension on VodSessionForHznGoResponse {
  VodSessionForHznGoResponse copyWith(
      {String? url,
      String? thumbnailServiceUrl,
      String? contentLocator,
      String? protectionKey,
      String? drmScheme}) {
    return VodSessionForHznGoResponse(
        url: url ?? this.url,
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        contentLocator: contentLocator ?? this.contentLocator,
        protectionKey: protectionKey ?? this.protectionKey,
        drmScheme: drmScheme ?? this.drmScheme);
  }

  VodSessionForHznGoResponse copyWithWrapped(
      {Wrapped<String>? url,
      Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? contentLocator,
      Wrapped<String?>? protectionKey,
      Wrapped<String?>? drmScheme}) {
    return VodSessionForHznGoResponse(
        url: (url != null ? url.value : this.url),
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        contentLocator: (contentLocator != null
            ? contentLocator.value
            : this.contentLocator),
        protectionKey:
            (protectionKey != null ? protectionKey.value : this.protectionKey),
        drmScheme: (drmScheme != null ? drmScheme.value : this.drmScheme));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteSessionResponse {
  DeleteSessionResponse({
    required this.status,
    required this.sessionId,
  });

  factory DeleteSessionResponse.fromJson(Map<String, dynamic> json) =>
      _$DeleteSessionResponseFromJson(json);

  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String status;
  @JsonKey(name: 'sessionId', includeIfNull: false, defaultValue: '')
  final String sessionId;
  static const fromJsonFactory = _$DeleteSessionResponseFromJson;
  static const toJsonFactory = _$DeleteSessionResponseToJson;
  Map<String, dynamic> toJson() => _$DeleteSessionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteSessionResponse &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.sessionId, sessionId) ||
                const DeepCollectionEquality()
                    .equals(other.sessionId, sessionId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(sessionId) ^
      runtimeType.hashCode;
}

extension $DeleteSessionResponseExtension on DeleteSessionResponse {
  DeleteSessionResponse copyWith({String? status, String? sessionId}) {
    return DeleteSessionResponse(
        status: status ?? this.status, sessionId: sessionId ?? this.sessionId);
  }

  DeleteSessionResponse copyWithWrapped(
      {Wrapped<String>? status, Wrapped<String>? sessionId}) {
    return DeleteSessionResponse(
        status: (status != null ? status.value : this.status),
        sessionId: (sessionId != null ? sessionId.value : this.sessionId));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizedForChannelResponse {
  AuthorizedForChannelResponse({
    this.authorizedChannels,
    this.entitlementTimeout,
    this.customerId,
  });

  factory AuthorizedForChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$AuthorizedForChannelResponseFromJson(json);

  @JsonKey(
      name: 'authorizedChannels',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? authorizedChannels;
  @JsonKey(name: 'entitlementTimeout', includeIfNull: false, defaultValue: '')
  final String? entitlementTimeout;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  static const fromJsonFactory = _$AuthorizedForChannelResponseFromJson;
  static const toJsonFactory = _$AuthorizedForChannelResponseToJson;
  Map<String, dynamic> toJson() => _$AuthorizedForChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizedForChannelResponse &&
            (identical(other.authorizedChannels, authorizedChannels) ||
                const DeepCollectionEquality()
                    .equals(other.authorizedChannels, authorizedChannels)) &&
            (identical(other.entitlementTimeout, entitlementTimeout) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementTimeout, entitlementTimeout)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorizedChannels) ^
      const DeepCollectionEquality().hash(entitlementTimeout) ^
      const DeepCollectionEquality().hash(customerId) ^
      runtimeType.hashCode;
}

extension $AuthorizedForChannelResponseExtension
    on AuthorizedForChannelResponse {
  AuthorizedForChannelResponse copyWith(
      {List<String>? authorizedChannels,
      String? entitlementTimeout,
      String? customerId}) {
    return AuthorizedForChannelResponse(
        authorizedChannels: authorizedChannels ?? this.authorizedChannels,
        entitlementTimeout: entitlementTimeout ?? this.entitlementTimeout,
        customerId: customerId ?? this.customerId);
  }

  AuthorizedForChannelResponse copyWithWrapped(
      {Wrapped<List<String>?>? authorizedChannels,
      Wrapped<String?>? entitlementTimeout,
      Wrapped<String?>? customerId}) {
    return AuthorizedForChannelResponse(
        authorizedChannels: (authorizedChannels != null
            ? authorizedChannels.value
            : this.authorizedChannels),
        entitlementTimeout: (entitlementTimeout != null
            ? entitlementTimeout.value
            : this.entitlementTimeout),
        customerId: (customerId != null ? customerId.value : this.customerId));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizedForAssetResponse {
  AuthorizedForAssetResponse({
    this.entitlementId,
    this.entitlementTimeout,
    this.customerId,
  });

  factory AuthorizedForAssetResponse.fromJson(Map<String, dynamic> json) =>
      _$AuthorizedForAssetResponseFromJson(json);

  @JsonKey(name: 'entitlementId', includeIfNull: false, defaultValue: '')
  final String? entitlementId;
  @JsonKey(name: 'entitlementTimeout', includeIfNull: false, defaultValue: '')
  final String? entitlementTimeout;
  @JsonKey(name: 'customerId', includeIfNull: false, defaultValue: '')
  final String? customerId;
  static const fromJsonFactory = _$AuthorizedForAssetResponseFromJson;
  static const toJsonFactory = _$AuthorizedForAssetResponseToJson;
  Map<String, dynamic> toJson() => _$AuthorizedForAssetResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizedForAssetResponse &&
            (identical(other.entitlementId, entitlementId) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementId, entitlementId)) &&
            (identical(other.entitlementTimeout, entitlementTimeout) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementTimeout, entitlementTimeout)) &&
            (identical(other.customerId, customerId) ||
                const DeepCollectionEquality()
                    .equals(other.customerId, customerId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entitlementId) ^
      const DeepCollectionEquality().hash(entitlementTimeout) ^
      const DeepCollectionEquality().hash(customerId) ^
      runtimeType.hashCode;
}

extension $AuthorizedForAssetResponseExtension on AuthorizedForAssetResponse {
  AuthorizedForAssetResponse copyWith(
      {String? entitlementId, String? entitlementTimeout, String? customerId}) {
    return AuthorizedForAssetResponse(
        entitlementId: entitlementId ?? this.entitlementId,
        entitlementTimeout: entitlementTimeout ?? this.entitlementTimeout,
        customerId: customerId ?? this.customerId);
  }

  AuthorizedForAssetResponse copyWithWrapped(
      {Wrapped<String?>? entitlementId,
      Wrapped<String?>? entitlementTimeout,
      Wrapped<String?>? customerId}) {
    return AuthorizedForAssetResponse(
        entitlementId:
            (entitlementId != null ? entitlementId.value : this.entitlementId),
        entitlementTimeout: (entitlementTimeout != null
            ? entitlementTimeout.value
            : this.entitlementTimeout),
        customerId: (customerId != null ? customerId.value : this.customerId));
  }
}

@JsonSerializable(explicitToJson: true)
class LocalRecordingResponse {
  LocalRecordingResponse({
    this.thumbnailServiceUrl,
    this.prePaddingTime,
    this.postPaddingTime,
  });

  factory LocalRecordingResponse.fromJson(Map<String, dynamic> json) =>
      _$LocalRecordingResponseFromJson(json);

  @JsonKey(name: 'thumbnailServiceUrl', includeIfNull: false, defaultValue: '')
  final String? thumbnailServiceUrl;
  @JsonKey(name: 'prePaddingTime', includeIfNull: false, defaultValue: '')
  final String? prePaddingTime;
  @JsonKey(name: 'postPaddingTime', includeIfNull: false, defaultValue: '')
  final String? postPaddingTime;
  static const fromJsonFactory = _$LocalRecordingResponseFromJson;
  static const toJsonFactory = _$LocalRecordingResponseToJson;
  Map<String, dynamic> toJson() => _$LocalRecordingResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalRecordingResponse &&
            (identical(other.thumbnailServiceUrl, thumbnailServiceUrl) ||
                const DeepCollectionEquality()
                    .equals(other.thumbnailServiceUrl, thumbnailServiceUrl)) &&
            (identical(other.prePaddingTime, prePaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingTime, prePaddingTime)) &&
            (identical(other.postPaddingTime, postPaddingTime) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingTime, postPaddingTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(thumbnailServiceUrl) ^
      const DeepCollectionEquality().hash(prePaddingTime) ^
      const DeepCollectionEquality().hash(postPaddingTime) ^
      runtimeType.hashCode;
}

extension $LocalRecordingResponseExtension on LocalRecordingResponse {
  LocalRecordingResponse copyWith(
      {String? thumbnailServiceUrl,
      String? prePaddingTime,
      String? postPaddingTime}) {
    return LocalRecordingResponse(
        thumbnailServiceUrl: thumbnailServiceUrl ?? this.thumbnailServiceUrl,
        prePaddingTime: prePaddingTime ?? this.prePaddingTime,
        postPaddingTime: postPaddingTime ?? this.postPaddingTime);
  }

  LocalRecordingResponse copyWithWrapped(
      {Wrapped<String?>? thumbnailServiceUrl,
      Wrapped<String?>? prePaddingTime,
      Wrapped<String?>? postPaddingTime}) {
    return LocalRecordingResponse(
        thumbnailServiceUrl: (thumbnailServiceUrl != null
            ? thumbnailServiceUrl.value
            : this.thumbnailServiceUrl),
        prePaddingTime: (prePaddingTime != null
            ? prePaddingTime.value
            : this.prePaddingTime),
        postPaddingTime: (postPaddingTime != null
            ? postPaddingTime.value
            : this.postPaddingTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ResolveAttributes {
  ResolveAttributes({
    this.assetId,
    this.type,
  });

  factory ResolveAttributes.fromJson(Map<String, dynamic> json) =>
      _$ResolveAttributesFromJson(json);

  @JsonKey(name: 'asset_id', includeIfNull: false, defaultValue: '')
  final String? assetId;
  @JsonKey(name: 'type', includeIfNull: false)
  final int? type;
  static const fromJsonFactory = _$ResolveAttributesFromJson;
  static const toJsonFactory = _$ResolveAttributesToJson;
  Map<String, dynamic> toJson() => _$ResolveAttributesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ResolveAttributes &&
            (identical(other.assetId, assetId) ||
                const DeepCollectionEquality()
                    .equals(other.assetId, assetId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(assetId) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $ResolveAttributesExtension on ResolveAttributes {
  ResolveAttributes copyWith({String? assetId, int? type}) {
    return ResolveAttributes(
        assetId: assetId ?? this.assetId, type: type ?? this.type);
  }

  ResolveAttributes copyWithWrapped(
      {Wrapped<String?>? assetId, Wrapped<int?>? type}) {
    return ResolveAttributes(
        assetId: (assetId != null ? assetId.value : this.assetId),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class TsbResolveContentRequest {
  TsbResolveContentRequest({
    this.resolveAttributes,
  });

  factory TsbResolveContentRequest.fromJson(Map<String, dynamic> json) =>
      _$TsbResolveContentRequestFromJson(json);

  @JsonKey(name: 'resolve_attributes', includeIfNull: false)
  final ResolveAttributes? resolveAttributes;
  static const fromJsonFactory = _$TsbResolveContentRequestFromJson;
  static const toJsonFactory = _$TsbResolveContentRequestToJson;
  Map<String, dynamic> toJson() => _$TsbResolveContentRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TsbResolveContentRequest &&
            (identical(other.resolveAttributes, resolveAttributes) ||
                const DeepCollectionEquality()
                    .equals(other.resolveAttributes, resolveAttributes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(resolveAttributes) ^
      runtimeType.hashCode;
}

extension $TsbResolveContentRequestExtension on TsbResolveContentRequest {
  TsbResolveContentRequest copyWith({ResolveAttributes? resolveAttributes}) {
    return TsbResolveContentRequest(
        resolveAttributes: resolveAttributes ?? this.resolveAttributes);
  }

  TsbResolveContentRequest copyWithWrapped(
      {Wrapped<ResolveAttributes?>? resolveAttributes}) {
    return TsbResolveContentRequest(
        resolveAttributes: (resolveAttributes != null
            ? resolveAttributes.value
            : this.resolveAttributes));
  }
}

@JsonSerializable(explicitToJson: true)
class TsbResolveContentReply {
  TsbResolveContentReply({
    this.resolveAttributes,
    this.tsbPlayoutInfo,
    this.expirationTime,
  });

  factory TsbResolveContentReply.fromJson(Map<String, dynamic> json) =>
      _$TsbResolveContentReplyFromJson(json);

  @JsonKey(name: 'resolve_attributes', includeIfNull: false)
  final ResolveAttributes? resolveAttributes;
  @JsonKey(name: 'tsb_playout_info', includeIfNull: false)
  final TsbResolveContentReply$TsbPlayoutInfo? tsbPlayoutInfo;
  @JsonKey(name: 'expiration_time', includeIfNull: false, defaultValue: '')
  final String? expirationTime;
  static const fromJsonFactory = _$TsbResolveContentReplyFromJson;
  static const toJsonFactory = _$TsbResolveContentReplyToJson;
  Map<String, dynamic> toJson() => _$TsbResolveContentReplyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TsbResolveContentReply &&
            (identical(other.resolveAttributes, resolveAttributes) ||
                const DeepCollectionEquality()
                    .equals(other.resolveAttributes, resolveAttributes)) &&
            (identical(other.tsbPlayoutInfo, tsbPlayoutInfo) ||
                const DeepCollectionEquality()
                    .equals(other.tsbPlayoutInfo, tsbPlayoutInfo)) &&
            (identical(other.expirationTime, expirationTime) ||
                const DeepCollectionEquality()
                    .equals(other.expirationTime, expirationTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(resolveAttributes) ^
      const DeepCollectionEquality().hash(tsbPlayoutInfo) ^
      const DeepCollectionEquality().hash(expirationTime) ^
      runtimeType.hashCode;
}

extension $TsbResolveContentReplyExtension on TsbResolveContentReply {
  TsbResolveContentReply copyWith(
      {ResolveAttributes? resolveAttributes,
      TsbResolveContentReply$TsbPlayoutInfo? tsbPlayoutInfo,
      String? expirationTime}) {
    return TsbResolveContentReply(
        resolveAttributes: resolveAttributes ?? this.resolveAttributes,
        tsbPlayoutInfo: tsbPlayoutInfo ?? this.tsbPlayoutInfo,
        expirationTime: expirationTime ?? this.expirationTime);
  }

  TsbResolveContentReply copyWithWrapped(
      {Wrapped<ResolveAttributes?>? resolveAttributes,
      Wrapped<TsbResolveContentReply$TsbPlayoutInfo?>? tsbPlayoutInfo,
      Wrapped<String?>? expirationTime}) {
    return TsbResolveContentReply(
        resolveAttributes: (resolveAttributes != null
            ? resolveAttributes.value
            : this.resolveAttributes),
        tsbPlayoutInfo: (tsbPlayoutInfo != null
            ? tsbPlayoutInfo.value
            : this.tsbPlayoutInfo),
        expirationTime: (expirationTime != null
            ? expirationTime.value
            : this.expirationTime));
  }
}

@JsonSerializable(explicitToJson: true)
class TsbResolveContentReply$TsbPlayoutInfo {
  TsbResolveContentReply$TsbPlayoutInfo({
    this.channelName,
    this.endTime,
    this.startTime,
  });

  factory TsbResolveContentReply$TsbPlayoutInfo.fromJson(
          Map<String, dynamic> json) =>
      _$TsbResolveContentReply$TsbPlayoutInfoFromJson(json);

  @JsonKey(name: 'channel_name', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'end_time', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'start_time', includeIfNull: false, defaultValue: '')
  final String? startTime;
  static const fromJsonFactory =
      _$TsbResolveContentReply$TsbPlayoutInfoFromJson;
  static const toJsonFactory = _$TsbResolveContentReply$TsbPlayoutInfoToJson;
  Map<String, dynamic> toJson() =>
      _$TsbResolveContentReply$TsbPlayoutInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TsbResolveContentReply$TsbPlayoutInfo &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(startTime) ^
      runtimeType.hashCode;
}

extension $TsbResolveContentReply$TsbPlayoutInfoExtension
    on TsbResolveContentReply$TsbPlayoutInfo {
  TsbResolveContentReply$TsbPlayoutInfo copyWith(
      {String? channelName, String? endTime, String? startTime}) {
    return TsbResolveContentReply$TsbPlayoutInfo(
        channelName: channelName ?? this.channelName,
        endTime: endTime ?? this.endTime,
        startTime: startTime ?? this.startTime);
  }

  TsbResolveContentReply$TsbPlayoutInfo copyWithWrapped(
      {Wrapped<String?>? channelName,
      Wrapped<String?>? endTime,
      Wrapped<String?>? startTime}) {
    return TsbResolveContentReply$TsbPlayoutInfo(
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        endTime: (endTime != null ? endTime.value : this.endTime),
        startTime: (startTime != null ? startTime.value : this.startTime));
  }
}

String? trickPlayControlToJson(enums.TrickPlayControl? trickPlayControl) {
  return enums.$TrickPlayControlMap[trickPlayControl];
}

enums.TrickPlayControl trickPlayControlFromJson(
  Object? trickPlayControl, [
  enums.TrickPlayControl? defaultValue,
]) {
  if (trickPlayControl is String) {
    return enums.$TrickPlayControlMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == trickPlayControl.toLowerCase(),
            orElse: () => const MapEntry(
                enums.TrickPlayControl.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TrickPlayControlMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.TrickPlayControl.swaggerGeneratedUnknown;
}

List<String> trickPlayControlListToJson(
    List<enums.TrickPlayControl>? trickPlayControl) {
  if (trickPlayControl == null) {
    return [];
  }

  return trickPlayControl.map((e) => enums.$TrickPlayControlMap[e]!).toList();
}

List<enums.TrickPlayControl> trickPlayControlListFromJson(
  List? trickPlayControl, [
  List<enums.TrickPlayControl>? defaultValue,
]) {
  if (trickPlayControl == null) {
    return defaultValue ?? [];
  }

  return trickPlayControl
      .map((e) => trickPlayControlFromJson(e.toString()))
      .toList();
}

List<enums.TrickPlayControl>? trickPlayControlNullableListFromJson(
  List? trickPlayControl, [
  List<enums.TrickPlayControl>? defaultValue,
]) {
  if (trickPlayControl == null) {
    return defaultValue;
  }

  return trickPlayControl
      .map((e) => trickPlayControlFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
