// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'settings_as.enums.swagger.dart' as enums;
export 'settings_as.enums.swagger.dart';

part 'settings_as.swagger.chopper.dart';
part 'settings_as.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class SettingsAs extends ChopperService {
  static SettingsAs create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$SettingsAs(client);
    }

    final newClient = ChopperClient(
        services: [_$SettingsAs()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$SettingsAs(newClient);
  }

  ///Gets specified setting value.
  ///@param key Setting key. `*` to get all settings' values.
  Future<chopper.Response> getSettingKeyGet({
    required Object? key,
    String? cacheControl,
  }) {
    return _getSettingKeyGet(key: key, cacheControl: cacheControl);
  }

  ///Gets specified setting value.
  ///@param key Setting key. `*` to get all settings' values.
  @Get(path: '/getSetting/{key}')
  Future<chopper.Response> _getSettingKeyGet({
    @Path('key') required Object? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Sets specified setting value.
  ///@param key Setting key.
  Future<chopper.Response> setSettingKeyPut({
    required enums.Key? key,
    String? cacheControl,
    required Value? body,
  }) {
    return _setSettingKeyPut(
        key: enums.$KeyMap[key]?.toString(),
        cacheControl: cacheControl,
        body: body);
  }

  ///Sets specified setting value.
  ///@param key Setting key.
  @Put(path: '/setSetting/{key}')
  Future<chopper.Response> _setSettingKeyPut({
    @Path('key') required String? key,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Value? body,
  });

  ///Resets specified setting to its default value.
  ///@param key Setting key.
  Future<chopper.Response<Value>> resetSettingKeyPut({
    required enums.Key? key,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Value, () => Value.fromJsonFactory);

    return _resetSettingKeyPut(
        key: enums.$KeyMap[key]?.toString(), cacheControl: cacheControl);
  }

  ///Resets specified setting to its default value.
  ///@param key Setting key.
  @Put(
    path: '/resetSetting/{key}',
    optionalBody: true,
  )
  Future<chopper.Response<Value>> _resetSettingKeyPut({
    @Path('key') required String? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Gets specified setting value from the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  Future<chopper.Response<RemoteValue>> getRemoteSettingKeyGet({
    required enums.RemoteKey? key,
    required String? cpeId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RemoteValue, () => RemoteValue.fromJsonFactory);

    return _getRemoteSettingKeyGet(
        key: enums.$RemoteKeyMap[key]?.toString(),
        cpeId: cpeId,
        cacheControl: cacheControl);
  }

  ///Gets specified setting value from the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  @Get(path: '/getRemoteSetting/{key}')
  Future<chopper.Response<RemoteValue>> _getRemoteSettingKeyGet({
    @Path('key') required String? key,
    @Query('cpeId') required String? cpeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Sets specified setting value of the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  Future<chopper.Response> setRemoteSettingKeyPut({
    required enums.RemoteKey? key,
    required String? cpeId,
    String? cacheControl,
    required RemoteValue? body,
  }) {
    return _setRemoteSettingKeyPut(
        key: enums.$RemoteKeyMap[key]?.toString(),
        cpeId: cpeId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Sets specified setting value of the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  @Put(path: '/setRemoteSetting/{key}')
  Future<chopper.Response> _setRemoteSettingKeyPut({
    @Path('key') required String? key,
    @Query('cpeId') required String? cpeId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required RemoteValue? body,
  });

  ///Gets specified settings' values.
  Future<chopper.Response<Settings>> getSettingsPut({
    String? cacheControl,
    required List<enums.Key>? body,
  }) {
    generatedMapping.putIfAbsent(Settings, () => Settings.fromJsonFactory);

    return _getSettingsPut(
        cacheControl: cacheControl, body: keyListToJson(body));
  }

  ///Gets specified settings' values.
  @Put(path: '/getSettings')
  Future<chopper.Response<Settings>> _getSettingsPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required dynamic body,
  });

  ///Sets specified settings.
  Future<chopper.Response> setSettingsPut({
    String? cacheControl,
    required Settings? body,
  }) {
    return _setSettingsPut(cacheControl: cacheControl, body: body);
  }

  ///Sets specified settings.
  @Put(path: '/setSettings')
  Future<chopper.Response> _setSettingsPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Settings? body,
  });

  ///Settings change event.
  ///@param key Setting key.
  Future<chopper.Response<OnChangeEvent>> settingChangeKeyGet({
    required Object? key,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        OnChangeEvent, () => OnChangeEvent.fromJsonFactory);

    return _settingChangeKeyGet(key: key, cacheControl: cacheControl);
  }

  ///Settings change event.
  ///@param key Setting key.
  @Get(path: '/settingChange/{key}')
  Future<chopper.Response<OnChangeEvent>> _settingChangeKeyGet({
    @Path('key') required Object? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Profile switch changes applied event.
  ///
  Future<chopper.Response> profileSwitchChangesAppliedGet(
      {String? cacheControl}) {
    return _profileSwitchChangesAppliedGet(cacheControl: cacheControl);
  }

  ///Profile switch changes applied event.
  ///
  @Get(path: '/profileSwitchChangesApplied')
  Future<chopper.Response> _profileSwitchChangesAppliedGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Service ready for operation event.
  Future<chopper.Response> readyGet({String? cacheControl}) {
    return _readyGet(cacheControl: cacheControl);
  }

  ///Service ready for operation event.
  @Get(path: '/ready')
  Future<chopper.Response> _readyGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class Any {
  Any();

  factory Any.fromJson(Map<String, dynamic> json) => _$AnyFromJson(json);

  static const fromJsonFactory = _$AnyFromJson;
  static const toJsonFactory = _$AnyToJson;
  Map<String, dynamic> toJson() => _$AnyToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.message,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({String? message}) {
    return ErrorResponse(message: message ?? this.message);
  }

  ErrorResponse copyWithWrapped({Wrapped<String>? message}) {
    return ErrorResponse(
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class OnChangeEvent {
  OnChangeEvent({
    required this.key,
    this.newValue,
    this.oldValue,
  });

  factory OnChangeEvent.fromJson(Map<String, dynamic> json) =>
      _$OnChangeEventFromJson(json);

  @JsonKey(
    name: 'key',
    includeIfNull: false,
    toJson: keyToJson,
    fromJson: keyFromJson,
  )
  final enums.Key key;
  @JsonKey(name: 'newValue', includeIfNull: false)
  final Value? newValue;
  @JsonKey(name: 'oldValue', includeIfNull: false)
  final Value? oldValue;
  static const fromJsonFactory = _$OnChangeEventFromJson;
  static const toJsonFactory = _$OnChangeEventToJson;
  Map<String, dynamic> toJson() => _$OnChangeEventToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OnChangeEvent &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.newValue, newValue) ||
                const DeepCollectionEquality()
                    .equals(other.newValue, newValue)) &&
            (identical(other.oldValue, oldValue) ||
                const DeepCollectionEquality()
                    .equals(other.oldValue, oldValue)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(newValue) ^
      const DeepCollectionEquality().hash(oldValue) ^
      runtimeType.hashCode;
}

extension $OnChangeEventExtension on OnChangeEvent {
  OnChangeEvent copyWith({enums.Key? key, Value? newValue, Value? oldValue}) {
    return OnChangeEvent(
        key: key ?? this.key,
        newValue: newValue ?? this.newValue,
        oldValue: oldValue ?? this.oldValue);
  }

  OnChangeEvent copyWithWrapped(
      {Wrapped<enums.Key>? key,
      Wrapped<Value?>? newValue,
      Wrapped<Value?>? oldValue}) {
    return OnChangeEvent(
        key: (key != null ? key.value : this.key),
        newValue: (newValue != null ? newValue.value : this.newValue),
        oldValue: (oldValue != null ? oldValue.value : this.oldValue));
  }
}

@JsonSerializable(explicitToJson: true)
class Value {
  Value();

  factory Value.fromJson(Map<String, dynamic> json) => _$ValueFromJson(json);

  static const fromJsonFactory = _$ValueFromJson;
  static const toJsonFactory = _$ValueToJson;
  Map<String, dynamic> toJson() => _$ValueToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class RemoteValue {
  RemoteValue();

  factory RemoteValue.fromJson(Map<String, dynamic> json) =>
      _$RemoteValueFromJson(json);

  static const fromJsonFactory = _$RemoteValueFromJson;
  static const toJsonFactory = _$RemoteValueToJson;
  Map<String, dynamic> toJson() => _$RemoteValueToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class Settings {
  Settings({
    this.cpe16by9Handling,
    this.cpe4by3Handling,
    this.cpeAdsOptInShownForRelease,
    this.cpeAppSubscriptions,
    this.cpeAskPurchasePin,
    this.cpeAskRecPlayPin,
    this.cpeAspectRatio,
    this.cpeAudioDelayDD,
    this.cpeAudioDelayPCM,
    this.cpeAudioDolbyDigital,
    this.cpeAudioDolbyDigitalMode,
    this.cpeAutoStandby,
    this.cpeAutoTvStartup,
    this.cpeCcAnalogService,
    this.cpeCcDigitalService,
    this.cpeCcsMessages,
    this.cpeCountry,
    this.cpeDefaultProfileId,
    this.cpeDefaultPvrStb,
    this.cpeDisplayedStandByMessageCount,
    this.cpeEnableCEC,
    this.cpeFactoryResetState,
    this.cpeFactoryResetType,
    this.cpeFriendlyName,
    this.cpeFtiState,
    this.cpeHdmiColorOutput,
    this.cpeHdmiDeviceInfo,
    this.cpeHdmiResolution,
    this.cpeIsAlexaLinked,
    this.cpeIsSilentDowngrade,
    this.cpeLastUsedBrandedScreenKey,
    this.cpeLastUseNetflix,
    this.cpeLockedApps,
    this.cpeMatchFrameRate,
    this.cpeNetflixRailCache,
    this.cpeNetflixToken,
    this.cpeNetflixVdid,
    this.cpeOneTouchViewTurnOffPolicy,
    this.cpePowerCheck,
    this.cpePowerSource,
    this.cpePrimaryVideoOutput,
    this.cpeQuicksetPairedDevicesInfo,
    this.cpeRcuUpgradeStatus,
    this.cpeRebootReason,
    this.cpeRecordPaddingAfter,
    this.cpeRecordPaddingBefore,
    this.cpeShowColdStandByMessage,
    this.cpeShowReplayOptInMessage,
    this.cpeSlowStandByCyclesCount,
    this.cpeSpeedTestResults,
    this.cpeStandByMode,
    this.cpeUiTestTools,
    this.cpeUpgradeStatus,
    this.cpeUseHighContrastUI,
    this.cpeVolume,
    this.cpeWifiClientEnabled,
    this.cpeWifiClientPass,
    this.cpeWifiClientSsid,
    this.cpeXaBrokerUrl,
    this.customerA2aHgoOptIn,
    this.customerA2aStbOptIn,
    this.customerAdsOptIn,
    this.customerAppsOptIn,
    this.customerAutoDeleteFunction,
    this.customerCityId,
    this.customerCustomerId,
    this.customerDefaultHhStb,
    this.customerDeleteRecordingReminder,
    this.customerIsAdultPinUsed,
    this.customerIsFtiPassed,
    this.customerIsSuspended,
    this.customerPersonalSuggestions,
    this.customerRecordingRetentionPeriod,
    this.customerReplayOptIn,
    this.customerReplayOptInTime,
    this.customerZipCode,
    this.profileAccessibleViews,
    this.profileAgeLock,
    this.profileAudioDescription,
    this.profileAudioLang,
    this.profileOnScreenKeyboardMode,
    this.profileOsdLang,
    this.profileRecentlyListenedRadios,
    this.profileRecentlyUsedAppsItems,
    this.profileRecentlyUsedSettingsItems,
    this.profileSignLanguage,
    this.profileSubControl,
    this.profileSubHardOfHearing,
    this.profileSubLang,
    this.profileSurfFavoriteChannels,
    this.profileTextToSpeech,
    this.profileTextToSpeechSpeed,
    this.profileTextToSpeechVoice,
    this.profileTextToSpeechVolume,
    this.profileTipsAndTricks,
  });

  factory Settings.fromJson(Map<String, dynamic> json) =>
      _$SettingsFromJson(json);

  @JsonKey(
    name: 'cpe.16by9Handling',
    includeIfNull: false,
    toJson: cpe16by9HandlingToJson,
    fromJson: cpe16by9HandlingFromJson,
  )
  final enums.Cpe16by9Handling? cpe16by9Handling;
  @JsonKey(
    name: 'cpe.4by3Handling',
    includeIfNull: false,
    toJson: cpe4by3HandlingToJson,
    fromJson: cpe4by3HandlingFromJson,
  )
  final enums.Cpe4by3Handling? cpe4by3Handling;
  @JsonKey(name: 'cpe.adsOptInShownForRelease', includeIfNull: false)
  final String? cpeAdsOptInShownForRelease;
  @JsonKey(name: 'cpe.appSubscriptions', includeIfNull: false)
  final CpeAppSubscriptions? cpeAppSubscriptions;
  @JsonKey(name: 'cpe.askPurchasePin', includeIfNull: false)
  final bool? cpeAskPurchasePin;
  @JsonKey(name: 'cpe.askRecPlayPin', includeIfNull: false)
  final bool? cpeAskRecPlayPin;
  @JsonKey(
    name: 'cpe.aspectRatio',
    includeIfNull: false,
    toJson: cpeAspectRatioToJson,
    fromJson: cpeAspectRatioFromJson,
  )
  final enums.CpeAspectRatio? cpeAspectRatio;
  @JsonKey(name: 'cpe.audioDelayDD', includeIfNull: false)
  final int? cpeAudioDelayDD;
  @JsonKey(name: 'cpe.audioDelayPCM', includeIfNull: false)
  final int? cpeAudioDelayPCM;
  @JsonKey(name: 'cpe.audioDolbyDigital', includeIfNull: false)
  final bool? cpeAudioDolbyDigital;
  @JsonKey(
    name: 'cpe.audioDolbyDigitalMode',
    includeIfNull: false,
    toJson: cpeAudioDolbyDigitalModeToJson,
    fromJson: cpeAudioDolbyDigitalModeFromJson,
  )
  final enums.CpeAudioDolbyDigitalMode? cpeAudioDolbyDigitalMode;
  @JsonKey(
    name: 'cpe.autoStandby',
    includeIfNull: false,
    toJson: cpeAutoStandbyToJson,
    fromJson: cpeAutoStandbyFromJson,
  )
  final enums.CpeAutoStandby? cpeAutoStandby;
  @JsonKey(name: 'cpe.autoTvStartup', includeIfNull: false)
  final bool? cpeAutoTvStartup;
  @JsonKey(
    name: 'cpe.ccAnalogService',
    includeIfNull: false,
    toJson: cpeCcAnalogServiceToJson,
    fromJson: cpeCcAnalogServiceFromJson,
  )
  final enums.CpeCcAnalogService? cpeCcAnalogService;
  @JsonKey(
    name: 'cpe.ccDigitalService',
    includeIfNull: false,
    toJson: cpeCcDigitalServiceToJson,
    fromJson: cpeCcDigitalServiceFromJson,
  )
  final enums.CpeCcDigitalService? cpeCcDigitalService;
  @JsonKey(name: 'cpe.ccsMessages', includeIfNull: false)
  final CpeCcsMessages? cpeCcsMessages;
  @JsonKey(name: 'cpe.country', includeIfNull: false)
  final String? cpeCountry;
  @JsonKey(name: 'cpe.defaultProfileId', includeIfNull: false)
  final String? cpeDefaultProfileId;
  @JsonKey(name: 'cpe.defaultPvrStb', includeIfNull: false)
  final String? cpeDefaultPvrStb;
  @JsonKey(name: 'cpe.displayedStandByMessageCount', includeIfNull: false)
  final int? cpeDisplayedStandByMessageCount;
  @JsonKey(name: 'cpe.enableCEC', includeIfNull: false)
  final bool? cpeEnableCEC;
  @JsonKey(
    name: 'cpe.factoryResetState',
    includeIfNull: false,
    toJson: cpeFactoryResetStateToJson,
    fromJson: cpeFactoryResetStateFromJson,
  )
  final enums.CpeFactoryResetState? cpeFactoryResetState;
  @JsonKey(
    name: 'cpe.factoryResetType',
    includeIfNull: false,
    toJson: cpeFactoryResetTypeToJson,
    fromJson: cpeFactoryResetTypeFromJson,
  )
  final enums.CpeFactoryResetType? cpeFactoryResetType;
  @JsonKey(name: 'cpe.friendlyName', includeIfNull: false)
  final String? cpeFriendlyName;
  @JsonKey(
    name: 'cpe.ftiState',
    includeIfNull: false,
    toJson: cpeFtiStateToJson,
    fromJson: cpeFtiStateFromJson,
  )
  final enums.CpeFtiState? cpeFtiState;
  @JsonKey(
    name: 'cpe.hdmiColorOutput',
    includeIfNull: false,
    toJson: cpeHdmiColorOutputToJson,
    fromJson: cpeHdmiColorOutputFromJson,
  )
  final enums.CpeHdmiColorOutput? cpeHdmiColorOutput;
  @JsonKey(name: 'cpe.hdmiDeviceInfo', includeIfNull: false)
  final CpeHdmiDeviceInfo? cpeHdmiDeviceInfo;
  @JsonKey(
    name: 'cpe.hdmiResolution',
    includeIfNull: false,
    toJson: cpeHdmiResolutionToJson,
    fromJson: cpeHdmiResolutionFromJson,
  )
  final enums.CpeHdmiResolution? cpeHdmiResolution;
  @JsonKey(name: 'cpe.isAlexaLinked', includeIfNull: false)
  final bool? cpeIsAlexaLinked;
  @JsonKey(name: 'cpe.isSilentDowngrade', includeIfNull: false)
  final bool? cpeIsSilentDowngrade;
  @JsonKey(name: 'cpe.lastUsedBrandedScreenKey', includeIfNull: false)
  final String? cpeLastUsedBrandedScreenKey;
  @JsonKey(name: 'cpe.lastUseNetflix', includeIfNull: false)
  final num? cpeLastUseNetflix;
  @JsonKey(name: 'cpe.lockedApps', includeIfNull: false)
  final CpeLockedApps? cpeLockedApps;
  @JsonKey(name: 'cpe.matchFrameRate', includeIfNull: false)
  final bool? cpeMatchFrameRate;
  @JsonKey(name: 'cpe.netflixRailCache', includeIfNull: false)
  final String? cpeNetflixRailCache;
  @JsonKey(name: 'cpe.netflixToken', includeIfNull: false)
  final String? cpeNetflixToken;
  @JsonKey(name: 'cpe.netflixVdid', includeIfNull: false)
  final String? cpeNetflixVdid;
  @JsonKey(name: 'cpe.oneTouchViewTurnOffPolicy', includeIfNull: false)
  final bool? cpeOneTouchViewTurnOffPolicy;
  @JsonKey(
    name: 'cpe.powerCheck',
    includeIfNull: false,
    toJson: cpePowerCheckToJson,
    fromJson: cpePowerCheckFromJson,
  )
  final enums.CpePowerCheck? cpePowerCheck;
  @JsonKey(
    name: 'cpe.powerSource',
    includeIfNull: false,
    toJson: cpePowerSourceToJson,
    fromJson: cpePowerSourceFromJson,
  )
  final enums.CpePowerSource? cpePowerSource;
  @JsonKey(
    name: 'cpe.primaryVideoOutput',
    includeIfNull: false,
    toJson: cpePrimaryVideoOutputToJson,
    fromJson: cpePrimaryVideoOutputFromJson,
  )
  final enums.CpePrimaryVideoOutput? cpePrimaryVideoOutput;
  @JsonKey(name: 'cpe.quicksetPairedDevicesInfo', includeIfNull: false)
  final CpeQuicksetPairedDevicesInfo? cpeQuicksetPairedDevicesInfo;
  @JsonKey(
    name: 'cpe.rcuUpgradeStatus',
    includeIfNull: false,
    toJson: cpeRcuUpgradeStatusToJson,
    fromJson: cpeRcuUpgradeStatusFromJson,
  )
  final enums.CpeRcuUpgradeStatus? cpeRcuUpgradeStatus;
  @JsonKey(name: 'cpe.rebootReason', includeIfNull: false)
  final CpeRebootReason? cpeRebootReason;
  @JsonKey(
    name: 'cpe.recordPaddingAfter',
    includeIfNull: false,
    toJson: cpeRecordPaddingAfterToJson,
    fromJson: cpeRecordPaddingAfterFromJson,
  )
  final enums.CpeRecordPaddingAfter? cpeRecordPaddingAfter;
  @JsonKey(
    name: 'cpe.recordPaddingBefore',
    includeIfNull: false,
    toJson: cpeRecordPaddingBeforeToJson,
    fromJson: cpeRecordPaddingBeforeFromJson,
  )
  final enums.CpeRecordPaddingBefore? cpeRecordPaddingBefore;
  @JsonKey(name: 'cpe.showColdStandByMessage', includeIfNull: false)
  final bool? cpeShowColdStandByMessage;
  @JsonKey(name: 'cpe.showReplayOptInMessage', includeIfNull: false)
  final bool? cpeShowReplayOptInMessage;
  @JsonKey(name: 'cpe.slowStandByCyclesCount', includeIfNull: false)
  final int? cpeSlowStandByCyclesCount;
  @JsonKey(name: 'cpe.speedTestResults', includeIfNull: false)
  final CpeSpeedTestResults? cpeSpeedTestResults;
  @JsonKey(
    name: 'cpe.standByMode',
    includeIfNull: false,
    toJson: cpeStandByModeToJson,
    fromJson: cpeStandByModeFromJson,
  )
  final enums.CpeStandByMode? cpeStandByMode;
  @JsonKey(name: 'cpe.uiTestTools', includeIfNull: false)
  final bool? cpeUiTestTools;
  @JsonKey(
    name: 'cpe.upgradeStatus',
    includeIfNull: false,
    toJson: cpeUpgradeStatusToJson,
    fromJson: cpeUpgradeStatusFromJson,
  )
  final enums.CpeUpgradeStatus? cpeUpgradeStatus;
  @JsonKey(name: 'cpe.useHighContrastUI', includeIfNull: false)
  final bool? cpeUseHighContrastUI;
  @JsonKey(name: 'cpe.volume', includeIfNull: false)
  final num? cpeVolume;
  @JsonKey(name: 'cpe.wifiClientEnabled', includeIfNull: false)
  final bool? cpeWifiClientEnabled;
  @JsonKey(name: 'cpe.wifiClientPass', includeIfNull: false)
  final String? cpeWifiClientPass;
  @JsonKey(name: 'cpe.wifiClientSsid', includeIfNull: false)
  final String? cpeWifiClientSsid;
  @JsonKey(name: 'cpe.xaBrokerUrl', includeIfNull: false)
  final String? cpeXaBrokerUrl;
  @JsonKey(name: 'customer.a2aHgoOptIn', includeIfNull: false)
  final bool? customerA2aHgoOptIn;
  @JsonKey(name: 'customer.a2aStbOptIn', includeIfNull: false)
  final bool? customerA2aStbOptIn;
  @JsonKey(name: 'customer.adsOptIn', includeIfNull: false)
  final bool? customerAdsOptIn;
  @JsonKey(name: 'customer.appsOptIn', includeIfNull: false)
  final bool? customerAppsOptIn;
  @JsonKey(name: 'customer.autoDeleteFunction', includeIfNull: false)
  final bool? customerAutoDeleteFunction;
  @JsonKey(name: 'customer.cityId', includeIfNull: false)
  final String? customerCityId;
  @JsonKey(name: 'customer.customerId', includeIfNull: false)
  final String? customerCustomerId;
  @JsonKey(name: 'customer.defaultHhStb', includeIfNull: false)
  final String? customerDefaultHhStb;
  @JsonKey(name: 'customer.deleteRecordingReminder', includeIfNull: false)
  final bool? customerDeleteRecordingReminder;
  @JsonKey(name: 'customer.isAdultPinUsed', includeIfNull: false)
  final bool? customerIsAdultPinUsed;
  @JsonKey(name: 'customer.isFtiPassed', includeIfNull: false)
  final bool? customerIsFtiPassed;
  @JsonKey(name: 'customer.isSuspended', includeIfNull: false)
  final bool? customerIsSuspended;
  @JsonKey(name: 'customer.personalSuggestions', includeIfNull: false)
  final bool? customerPersonalSuggestions;
  @JsonKey(
    name: 'customer.recordingRetentionPeriod',
    includeIfNull: false,
    toJson: customerRecordingRetentionPeriodToJson,
    fromJson: customerRecordingRetentionPeriodFromJson,
  )
  final enums.CustomerRecordingRetentionPeriod?
      customerRecordingRetentionPeriod;
  @JsonKey(name: 'customer.replayOptIn', includeIfNull: false)
  final bool? customerReplayOptIn;
  @JsonKey(name: 'customer.replayOptInTime', includeIfNull: false)
  final num? customerReplayOptInTime;
  @JsonKey(name: 'customer.zipCode', includeIfNull: false)
  final String? customerZipCode;
  @JsonKey(name: 'profile.accessibleViews', includeIfNull: false)
  final ProfileAccessibleViews? profileAccessibleViews;
  @JsonKey(
    name: 'profile.ageLock',
    includeIfNull: false,
    toJson: profileAgeLockToJson,
    fromJson: profileAgeLockFromJson,
  )
  final enums.ProfileAgeLock? profileAgeLock;
  @JsonKey(name: 'profile.audioDescription', includeIfNull: false)
  final bool? profileAudioDescription;
  @JsonKey(
    name: 'profile.audioLang',
    includeIfNull: false,
    toJson: profileAudioLangToJson,
    fromJson: profileAudioLangFromJson,
  )
  final enums.ProfileAudioLang? profileAudioLang;
  @JsonKey(
    name: 'profile.onScreenKeyboardMode',
    includeIfNull: false,
    toJson: profileOnScreenKeyboardModeToJson,
    fromJson: profileOnScreenKeyboardModeFromJson,
  )
  final enums.ProfileOnScreenKeyboardMode? profileOnScreenKeyboardMode;
  @JsonKey(
    name: 'profile.osdLang',
    includeIfNull: false,
    toJson: profileOsdLangToJson,
    fromJson: profileOsdLangFromJson,
  )
  final enums.ProfileOsdLang? profileOsdLang;
  @JsonKey(name: 'profile.recentlyListenedRadios', includeIfNull: false)
  final ProfileRecentlyListenedRadios? profileRecentlyListenedRadios;
  @JsonKey(name: 'profile.recentlyUsedAppsItems', includeIfNull: false)
  final ProfileRecentlyUsedAppsItems? profileRecentlyUsedAppsItems;
  @JsonKey(name: 'profile.recentlyUsedSettingsItems', includeIfNull: false)
  final ProfileRecentlyUsedSettingsItems? profileRecentlyUsedSettingsItems;
  @JsonKey(name: 'profile.signLanguage', includeIfNull: false)
  final bool? profileSignLanguage;
  @JsonKey(name: 'profile.subControl', includeIfNull: false)
  final bool? profileSubControl;
  @JsonKey(name: 'profile.subHardOfHearing', includeIfNull: false)
  final bool? profileSubHardOfHearing;
  @JsonKey(
    name: 'profile.subLang',
    includeIfNull: false,
    toJson: profileSubLangToJson,
    fromJson: profileSubLangFromJson,
  )
  final enums.ProfileSubLang? profileSubLang;
  @JsonKey(name: 'profile.surfFavoriteChannels', includeIfNull: false)
  final bool? profileSurfFavoriteChannels;
  @JsonKey(name: 'profile.textToSpeech', includeIfNull: false)
  final bool? profileTextToSpeech;
  @JsonKey(
    name: 'profile.textToSpeechSpeed',
    includeIfNull: false,
    toJson: profileTextToSpeechSpeedToJson,
    fromJson: profileTextToSpeechSpeedFromJson,
  )
  final enums.ProfileTextToSpeechSpeed? profileTextToSpeechSpeed;
  @JsonKey(name: 'profile.textToSpeechVoice', includeIfNull: false)
  final ProfileTextToSpeechVoice? profileTextToSpeechVoice;
  @JsonKey(
    name: 'profile.textToSpeechVolume',
    includeIfNull: false,
    toJson: profileTextToSpeechVolumeToJson,
    fromJson: profileTextToSpeechVolumeFromJson,
  )
  final enums.ProfileTextToSpeechVolume? profileTextToSpeechVolume;
  @JsonKey(name: 'profile.tipsAndTricks', includeIfNull: false)
  final ProfileTipsAndTricks? profileTipsAndTricks;
  static const fromJsonFactory = _$SettingsFromJson;
  static const toJsonFactory = _$SettingsToJson;
  Map<String, dynamic> toJson() => _$SettingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Settings &&
            (identical(other.cpe16by9Handling, cpe16by9Handling) ||
                const DeepCollectionEquality()
                    .equals(other.cpe16by9Handling, cpe16by9Handling)) &&
            (identical(other.cpe4by3Handling, cpe4by3Handling) ||
                const DeepCollectionEquality()
                    .equals(other.cpe4by3Handling, cpe4by3Handling)) &&
            (identical(other.cpeAdsOptInShownForRelease, cpeAdsOptInShownForRelease) ||
                const DeepCollectionEquality().equals(
                    other.cpeAdsOptInShownForRelease,
                    cpeAdsOptInShownForRelease)) &&
            (identical(other.cpeAppSubscriptions, cpeAppSubscriptions) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAppSubscriptions, cpeAppSubscriptions)) &&
            (identical(other.cpeAskPurchasePin, cpeAskPurchasePin) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAskPurchasePin, cpeAskPurchasePin)) &&
            (identical(other.cpeAskRecPlayPin, cpeAskRecPlayPin) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAskRecPlayPin, cpeAskRecPlayPin)) &&
            (identical(other.cpeAspectRatio, cpeAspectRatio) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAspectRatio, cpeAspectRatio)) &&
            (identical(other.cpeAudioDelayDD, cpeAudioDelayDD) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAudioDelayDD, cpeAudioDelayDD)) &&
            (identical(other.cpeAudioDelayPCM, cpeAudioDelayPCM) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAudioDelayPCM, cpeAudioDelayPCM)) &&
            (identical(other.cpeAudioDolbyDigital, cpeAudioDolbyDigital) ||
                const DeepCollectionEquality().equals(
                    other.cpeAudioDolbyDigital, cpeAudioDolbyDigital)) &&
            (identical(other.cpeAudioDolbyDigitalMode, cpeAudioDolbyDigitalMode) ||
                const DeepCollectionEquality().equals(
                    other.cpeAudioDolbyDigitalMode,
                    cpeAudioDolbyDigitalMode)) &&
            (identical(other.cpeAutoStandby, cpeAutoStandby) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAutoStandby, cpeAutoStandby)) &&
            (identical(other.cpeAutoTvStartup, cpeAutoTvStartup) ||
                const DeepCollectionEquality()
                    .equals(other.cpeAutoTvStartup, cpeAutoTvStartup)) &&
            (identical(other.cpeCcAnalogService, cpeCcAnalogService) ||
                const DeepCollectionEquality()
                    .equals(other.cpeCcAnalogService, cpeCcAnalogService)) &&
            (identical(other.cpeCcDigitalService, cpeCcDigitalService) ||
                const DeepCollectionEquality()
                    .equals(other.cpeCcDigitalService, cpeCcDigitalService)) &&
            (identical(other.cpeCcsMessages, cpeCcsMessages) ||
                const DeepCollectionEquality().equals(other.cpeCcsMessages, cpeCcsMessages)) &&
            (identical(other.cpeCountry, cpeCountry) || const DeepCollectionEquality().equals(other.cpeCountry, cpeCountry)) &&
            (identical(other.cpeDefaultProfileId, cpeDefaultProfileId) || const DeepCollectionEquality().equals(other.cpeDefaultProfileId, cpeDefaultProfileId)) &&
            (identical(other.cpeDefaultPvrStb, cpeDefaultPvrStb) || const DeepCollectionEquality().equals(other.cpeDefaultPvrStb, cpeDefaultPvrStb)) &&
            (identical(other.cpeDisplayedStandByMessageCount, cpeDisplayedStandByMessageCount) || const DeepCollectionEquality().equals(other.cpeDisplayedStandByMessageCount, cpeDisplayedStandByMessageCount)) &&
            (identical(other.cpeEnableCEC, cpeEnableCEC) || const DeepCollectionEquality().equals(other.cpeEnableCEC, cpeEnableCEC)) &&
            (identical(other.cpeFactoryResetState, cpeFactoryResetState) || const DeepCollectionEquality().equals(other.cpeFactoryResetState, cpeFactoryResetState)) &&
            (identical(other.cpeFactoryResetType, cpeFactoryResetType) || const DeepCollectionEquality().equals(other.cpeFactoryResetType, cpeFactoryResetType)) &&
            (identical(other.cpeFriendlyName, cpeFriendlyName) || const DeepCollectionEquality().equals(other.cpeFriendlyName, cpeFriendlyName)) &&
            (identical(other.cpeFtiState, cpeFtiState) || const DeepCollectionEquality().equals(other.cpeFtiState, cpeFtiState)) &&
            (identical(other.cpeHdmiColorOutput, cpeHdmiColorOutput) || const DeepCollectionEquality().equals(other.cpeHdmiColorOutput, cpeHdmiColorOutput)) &&
            (identical(other.cpeHdmiDeviceInfo, cpeHdmiDeviceInfo) || const DeepCollectionEquality().equals(other.cpeHdmiDeviceInfo, cpeHdmiDeviceInfo)) &&
            (identical(other.cpeHdmiResolution, cpeHdmiResolution) || const DeepCollectionEquality().equals(other.cpeHdmiResolution, cpeHdmiResolution)) &&
            (identical(other.cpeIsAlexaLinked, cpeIsAlexaLinked) || const DeepCollectionEquality().equals(other.cpeIsAlexaLinked, cpeIsAlexaLinked)) &&
            (identical(other.cpeIsSilentDowngrade, cpeIsSilentDowngrade) || const DeepCollectionEquality().equals(other.cpeIsSilentDowngrade, cpeIsSilentDowngrade)) &&
            (identical(other.cpeLastUsedBrandedScreenKey, cpeLastUsedBrandedScreenKey) || const DeepCollectionEquality().equals(other.cpeLastUsedBrandedScreenKey, cpeLastUsedBrandedScreenKey)) &&
            (identical(other.cpeLastUseNetflix, cpeLastUseNetflix) || const DeepCollectionEquality().equals(other.cpeLastUseNetflix, cpeLastUseNetflix)) &&
            (identical(other.cpeLockedApps, cpeLockedApps) || const DeepCollectionEquality().equals(other.cpeLockedApps, cpeLockedApps)) &&
            (identical(other.cpeMatchFrameRate, cpeMatchFrameRate) || const DeepCollectionEquality().equals(other.cpeMatchFrameRate, cpeMatchFrameRate)) &&
            (identical(other.cpeNetflixRailCache, cpeNetflixRailCache) || const DeepCollectionEquality().equals(other.cpeNetflixRailCache, cpeNetflixRailCache)) &&
            (identical(other.cpeNetflixToken, cpeNetflixToken) || const DeepCollectionEquality().equals(other.cpeNetflixToken, cpeNetflixToken)) &&
            (identical(other.cpeNetflixVdid, cpeNetflixVdid) || const DeepCollectionEquality().equals(other.cpeNetflixVdid, cpeNetflixVdid)) &&
            (identical(other.cpeOneTouchViewTurnOffPolicy, cpeOneTouchViewTurnOffPolicy) || const DeepCollectionEquality().equals(other.cpeOneTouchViewTurnOffPolicy, cpeOneTouchViewTurnOffPolicy)) &&
            (identical(other.cpePowerCheck, cpePowerCheck) || const DeepCollectionEquality().equals(other.cpePowerCheck, cpePowerCheck)) &&
            (identical(other.cpePowerSource, cpePowerSource) || const DeepCollectionEquality().equals(other.cpePowerSource, cpePowerSource)) &&
            (identical(other.cpePrimaryVideoOutput, cpePrimaryVideoOutput) || const DeepCollectionEquality().equals(other.cpePrimaryVideoOutput, cpePrimaryVideoOutput)) &&
            (identical(other.cpeQuicksetPairedDevicesInfo, cpeQuicksetPairedDevicesInfo) || const DeepCollectionEquality().equals(other.cpeQuicksetPairedDevicesInfo, cpeQuicksetPairedDevicesInfo)) &&
            (identical(other.cpeRcuUpgradeStatus, cpeRcuUpgradeStatus) || const DeepCollectionEquality().equals(other.cpeRcuUpgradeStatus, cpeRcuUpgradeStatus)) &&
            (identical(other.cpeRebootReason, cpeRebootReason) || const DeepCollectionEquality().equals(other.cpeRebootReason, cpeRebootReason)) &&
            (identical(other.cpeRecordPaddingAfter, cpeRecordPaddingAfter) || const DeepCollectionEquality().equals(other.cpeRecordPaddingAfter, cpeRecordPaddingAfter)) &&
            (identical(other.cpeRecordPaddingBefore, cpeRecordPaddingBefore) || const DeepCollectionEquality().equals(other.cpeRecordPaddingBefore, cpeRecordPaddingBefore)) &&
            (identical(other.cpeShowColdStandByMessage, cpeShowColdStandByMessage) || const DeepCollectionEquality().equals(other.cpeShowColdStandByMessage, cpeShowColdStandByMessage)) &&
            (identical(other.cpeShowReplayOptInMessage, cpeShowReplayOptInMessage) || const DeepCollectionEquality().equals(other.cpeShowReplayOptInMessage, cpeShowReplayOptInMessage)) &&
            (identical(other.cpeSlowStandByCyclesCount, cpeSlowStandByCyclesCount) || const DeepCollectionEquality().equals(other.cpeSlowStandByCyclesCount, cpeSlowStandByCyclesCount)) &&
            (identical(other.cpeSpeedTestResults, cpeSpeedTestResults) || const DeepCollectionEquality().equals(other.cpeSpeedTestResults, cpeSpeedTestResults)) &&
            (identical(other.cpeStandByMode, cpeStandByMode) || const DeepCollectionEquality().equals(other.cpeStandByMode, cpeStandByMode)) &&
            (identical(other.cpeUiTestTools, cpeUiTestTools) || const DeepCollectionEquality().equals(other.cpeUiTestTools, cpeUiTestTools)) &&
            (identical(other.cpeUpgradeStatus, cpeUpgradeStatus) || const DeepCollectionEquality().equals(other.cpeUpgradeStatus, cpeUpgradeStatus)) &&
            (identical(other.cpeUseHighContrastUI, cpeUseHighContrastUI) || const DeepCollectionEquality().equals(other.cpeUseHighContrastUI, cpeUseHighContrastUI)) &&
            (identical(other.cpeVolume, cpeVolume) || const DeepCollectionEquality().equals(other.cpeVolume, cpeVolume)) &&
            (identical(other.cpeWifiClientEnabled, cpeWifiClientEnabled) || const DeepCollectionEquality().equals(other.cpeWifiClientEnabled, cpeWifiClientEnabled)) &&
            (identical(other.cpeWifiClientPass, cpeWifiClientPass) || const DeepCollectionEquality().equals(other.cpeWifiClientPass, cpeWifiClientPass)) &&
            (identical(other.cpeWifiClientSsid, cpeWifiClientSsid) || const DeepCollectionEquality().equals(other.cpeWifiClientSsid, cpeWifiClientSsid)) &&
            (identical(other.cpeXaBrokerUrl, cpeXaBrokerUrl) || const DeepCollectionEquality().equals(other.cpeXaBrokerUrl, cpeXaBrokerUrl)) &&
            (identical(other.customerA2aHgoOptIn, customerA2aHgoOptIn) || const DeepCollectionEquality().equals(other.customerA2aHgoOptIn, customerA2aHgoOptIn)) &&
            (identical(other.customerA2aStbOptIn, customerA2aStbOptIn) || const DeepCollectionEquality().equals(other.customerA2aStbOptIn, customerA2aStbOptIn)) &&
            (identical(other.customerAdsOptIn, customerAdsOptIn) || const DeepCollectionEquality().equals(other.customerAdsOptIn, customerAdsOptIn)) &&
            (identical(other.customerAppsOptIn, customerAppsOptIn) || const DeepCollectionEquality().equals(other.customerAppsOptIn, customerAppsOptIn)) &&
            (identical(other.customerAutoDeleteFunction, customerAutoDeleteFunction) || const DeepCollectionEquality().equals(other.customerAutoDeleteFunction, customerAutoDeleteFunction)) &&
            (identical(other.customerCityId, customerCityId) || const DeepCollectionEquality().equals(other.customerCityId, customerCityId)) &&
            (identical(other.customerCustomerId, customerCustomerId) || const DeepCollectionEquality().equals(other.customerCustomerId, customerCustomerId)) &&
            (identical(other.customerDefaultHhStb, customerDefaultHhStb) || const DeepCollectionEquality().equals(other.customerDefaultHhStb, customerDefaultHhStb)) &&
            (identical(other.customerDeleteRecordingReminder, customerDeleteRecordingReminder) || const DeepCollectionEquality().equals(other.customerDeleteRecordingReminder, customerDeleteRecordingReminder)) &&
            (identical(other.customerIsAdultPinUsed, customerIsAdultPinUsed) || const DeepCollectionEquality().equals(other.customerIsAdultPinUsed, customerIsAdultPinUsed)) &&
            (identical(other.customerIsFtiPassed, customerIsFtiPassed) || const DeepCollectionEquality().equals(other.customerIsFtiPassed, customerIsFtiPassed)) &&
            (identical(other.customerIsSuspended, customerIsSuspended) || const DeepCollectionEquality().equals(other.customerIsSuspended, customerIsSuspended)) &&
            (identical(other.customerPersonalSuggestions, customerPersonalSuggestions) || const DeepCollectionEquality().equals(other.customerPersonalSuggestions, customerPersonalSuggestions)) &&
            (identical(other.customerRecordingRetentionPeriod, customerRecordingRetentionPeriod) || const DeepCollectionEquality().equals(other.customerRecordingRetentionPeriod, customerRecordingRetentionPeriod)) &&
            (identical(other.customerReplayOptIn, customerReplayOptIn) || const DeepCollectionEquality().equals(other.customerReplayOptIn, customerReplayOptIn)) &&
            (identical(other.customerReplayOptInTime, customerReplayOptInTime) || const DeepCollectionEquality().equals(other.customerReplayOptInTime, customerReplayOptInTime)) &&
            (identical(other.customerZipCode, customerZipCode) || const DeepCollectionEquality().equals(other.customerZipCode, customerZipCode)) &&
            (identical(other.profileAccessibleViews, profileAccessibleViews) || const DeepCollectionEquality().equals(other.profileAccessibleViews, profileAccessibleViews)) &&
            (identical(other.profileAgeLock, profileAgeLock) || const DeepCollectionEquality().equals(other.profileAgeLock, profileAgeLock)) &&
            (identical(other.profileAudioDescription, profileAudioDescription) || const DeepCollectionEquality().equals(other.profileAudioDescription, profileAudioDescription)) &&
            (identical(other.profileAudioLang, profileAudioLang) || const DeepCollectionEquality().equals(other.profileAudioLang, profileAudioLang)) &&
            (identical(other.profileOnScreenKeyboardMode, profileOnScreenKeyboardMode) || const DeepCollectionEquality().equals(other.profileOnScreenKeyboardMode, profileOnScreenKeyboardMode)) &&
            (identical(other.profileOsdLang, profileOsdLang) || const DeepCollectionEquality().equals(other.profileOsdLang, profileOsdLang)) &&
            (identical(other.profileRecentlyListenedRadios, profileRecentlyListenedRadios) || const DeepCollectionEquality().equals(other.profileRecentlyListenedRadios, profileRecentlyListenedRadios)) &&
            (identical(other.profileRecentlyUsedAppsItems, profileRecentlyUsedAppsItems) || const DeepCollectionEquality().equals(other.profileRecentlyUsedAppsItems, profileRecentlyUsedAppsItems)) &&
            (identical(other.profileRecentlyUsedSettingsItems, profileRecentlyUsedSettingsItems) || const DeepCollectionEquality().equals(other.profileRecentlyUsedSettingsItems, profileRecentlyUsedSettingsItems)) &&
            (identical(other.profileSignLanguage, profileSignLanguage) || const DeepCollectionEquality().equals(other.profileSignLanguage, profileSignLanguage)) &&
            (identical(other.profileSubControl, profileSubControl) || const DeepCollectionEquality().equals(other.profileSubControl, profileSubControl)) &&
            (identical(other.profileSubHardOfHearing, profileSubHardOfHearing) || const DeepCollectionEquality().equals(other.profileSubHardOfHearing, profileSubHardOfHearing)) &&
            (identical(other.profileSubLang, profileSubLang) || const DeepCollectionEquality().equals(other.profileSubLang, profileSubLang)) &&
            (identical(other.profileSurfFavoriteChannels, profileSurfFavoriteChannels) || const DeepCollectionEquality().equals(other.profileSurfFavoriteChannels, profileSurfFavoriteChannels)) &&
            (identical(other.profileTextToSpeech, profileTextToSpeech) || const DeepCollectionEquality().equals(other.profileTextToSpeech, profileTextToSpeech)) &&
            (identical(other.profileTextToSpeechSpeed, profileTextToSpeechSpeed) || const DeepCollectionEquality().equals(other.profileTextToSpeechSpeed, profileTextToSpeechSpeed)) &&
            (identical(other.profileTextToSpeechVoice, profileTextToSpeechVoice) || const DeepCollectionEquality().equals(other.profileTextToSpeechVoice, profileTextToSpeechVoice)) &&
            (identical(other.profileTextToSpeechVolume, profileTextToSpeechVolume) || const DeepCollectionEquality().equals(other.profileTextToSpeechVolume, profileTextToSpeechVolume)) &&
            (identical(other.profileTipsAndTricks, profileTipsAndTricks) || const DeepCollectionEquality().equals(other.profileTipsAndTricks, profileTipsAndTricks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(cpe16by9Handling) ^
      const DeepCollectionEquality().hash(cpe4by3Handling) ^
      const DeepCollectionEquality().hash(cpeAdsOptInShownForRelease) ^
      const DeepCollectionEquality().hash(cpeAppSubscriptions) ^
      const DeepCollectionEquality().hash(cpeAskPurchasePin) ^
      const DeepCollectionEquality().hash(cpeAskRecPlayPin) ^
      const DeepCollectionEquality().hash(cpeAspectRatio) ^
      const DeepCollectionEquality().hash(cpeAudioDelayDD) ^
      const DeepCollectionEquality().hash(cpeAudioDelayPCM) ^
      const DeepCollectionEquality().hash(cpeAudioDolbyDigital) ^
      const DeepCollectionEquality().hash(cpeAudioDolbyDigitalMode) ^
      const DeepCollectionEquality().hash(cpeAutoStandby) ^
      const DeepCollectionEquality().hash(cpeAutoTvStartup) ^
      const DeepCollectionEquality().hash(cpeCcAnalogService) ^
      const DeepCollectionEquality().hash(cpeCcDigitalService) ^
      const DeepCollectionEquality().hash(cpeCcsMessages) ^
      const DeepCollectionEquality().hash(cpeCountry) ^
      const DeepCollectionEquality().hash(cpeDefaultProfileId) ^
      const DeepCollectionEquality().hash(cpeDefaultPvrStb) ^
      const DeepCollectionEquality().hash(cpeDisplayedStandByMessageCount) ^
      const DeepCollectionEquality().hash(cpeEnableCEC) ^
      const DeepCollectionEquality().hash(cpeFactoryResetState) ^
      const DeepCollectionEquality().hash(cpeFactoryResetType) ^
      const DeepCollectionEquality().hash(cpeFriendlyName) ^
      const DeepCollectionEquality().hash(cpeFtiState) ^
      const DeepCollectionEquality().hash(cpeHdmiColorOutput) ^
      const DeepCollectionEquality().hash(cpeHdmiDeviceInfo) ^
      const DeepCollectionEquality().hash(cpeHdmiResolution) ^
      const DeepCollectionEquality().hash(cpeIsAlexaLinked) ^
      const DeepCollectionEquality().hash(cpeIsSilentDowngrade) ^
      const DeepCollectionEquality().hash(cpeLastUsedBrandedScreenKey) ^
      const DeepCollectionEquality().hash(cpeLastUseNetflix) ^
      const DeepCollectionEquality().hash(cpeLockedApps) ^
      const DeepCollectionEquality().hash(cpeMatchFrameRate) ^
      const DeepCollectionEquality().hash(cpeNetflixRailCache) ^
      const DeepCollectionEquality().hash(cpeNetflixToken) ^
      const DeepCollectionEquality().hash(cpeNetflixVdid) ^
      const DeepCollectionEquality().hash(cpeOneTouchViewTurnOffPolicy) ^
      const DeepCollectionEquality().hash(cpePowerCheck) ^
      const DeepCollectionEquality().hash(cpePowerSource) ^
      const DeepCollectionEquality().hash(cpePrimaryVideoOutput) ^
      const DeepCollectionEquality().hash(cpeQuicksetPairedDevicesInfo) ^
      const DeepCollectionEquality().hash(cpeRcuUpgradeStatus) ^
      const DeepCollectionEquality().hash(cpeRebootReason) ^
      const DeepCollectionEquality().hash(cpeRecordPaddingAfter) ^
      const DeepCollectionEquality().hash(cpeRecordPaddingBefore) ^
      const DeepCollectionEquality().hash(cpeShowColdStandByMessage) ^
      const DeepCollectionEquality().hash(cpeShowReplayOptInMessage) ^
      const DeepCollectionEquality().hash(cpeSlowStandByCyclesCount) ^
      const DeepCollectionEquality().hash(cpeSpeedTestResults) ^
      const DeepCollectionEquality().hash(cpeStandByMode) ^
      const DeepCollectionEquality().hash(cpeUiTestTools) ^
      const DeepCollectionEquality().hash(cpeUpgradeStatus) ^
      const DeepCollectionEquality().hash(cpeUseHighContrastUI) ^
      const DeepCollectionEquality().hash(cpeVolume) ^
      const DeepCollectionEquality().hash(cpeWifiClientEnabled) ^
      const DeepCollectionEquality().hash(cpeWifiClientPass) ^
      const DeepCollectionEquality().hash(cpeWifiClientSsid) ^
      const DeepCollectionEquality().hash(cpeXaBrokerUrl) ^
      const DeepCollectionEquality().hash(customerA2aHgoOptIn) ^
      const DeepCollectionEquality().hash(customerA2aStbOptIn) ^
      const DeepCollectionEquality().hash(customerAdsOptIn) ^
      const DeepCollectionEquality().hash(customerAppsOptIn) ^
      const DeepCollectionEquality().hash(customerAutoDeleteFunction) ^
      const DeepCollectionEquality().hash(customerCityId) ^
      const DeepCollectionEquality().hash(customerCustomerId) ^
      const DeepCollectionEquality().hash(customerDefaultHhStb) ^
      const DeepCollectionEquality().hash(customerDeleteRecordingReminder) ^
      const DeepCollectionEquality().hash(customerIsAdultPinUsed) ^
      const DeepCollectionEquality().hash(customerIsFtiPassed) ^
      const DeepCollectionEquality().hash(customerIsSuspended) ^
      const DeepCollectionEquality().hash(customerPersonalSuggestions) ^
      const DeepCollectionEquality().hash(customerRecordingRetentionPeriod) ^
      const DeepCollectionEquality().hash(customerReplayOptIn) ^
      const DeepCollectionEquality().hash(customerReplayOptInTime) ^
      const DeepCollectionEquality().hash(customerZipCode) ^
      const DeepCollectionEquality().hash(profileAccessibleViews) ^
      const DeepCollectionEquality().hash(profileAgeLock) ^
      const DeepCollectionEquality().hash(profileAudioDescription) ^
      const DeepCollectionEquality().hash(profileAudioLang) ^
      const DeepCollectionEquality().hash(profileOnScreenKeyboardMode) ^
      const DeepCollectionEquality().hash(profileOsdLang) ^
      const DeepCollectionEquality().hash(profileRecentlyListenedRadios) ^
      const DeepCollectionEquality().hash(profileRecentlyUsedAppsItems) ^
      const DeepCollectionEquality().hash(profileRecentlyUsedSettingsItems) ^
      const DeepCollectionEquality().hash(profileSignLanguage) ^
      const DeepCollectionEquality().hash(profileSubControl) ^
      const DeepCollectionEquality().hash(profileSubHardOfHearing) ^
      const DeepCollectionEquality().hash(profileSubLang) ^
      const DeepCollectionEquality().hash(profileSurfFavoriteChannels) ^
      const DeepCollectionEquality().hash(profileTextToSpeech) ^
      const DeepCollectionEquality().hash(profileTextToSpeechSpeed) ^
      const DeepCollectionEquality().hash(profileTextToSpeechVoice) ^
      const DeepCollectionEquality().hash(profileTextToSpeechVolume) ^
      const DeepCollectionEquality().hash(profileTipsAndTricks) ^
      runtimeType.hashCode;
}

extension $SettingsExtension on Settings {
  Settings copyWith(
      {enums.Cpe16by9Handling? cpe16by9Handling,
      enums.Cpe4by3Handling? cpe4by3Handling,
      String? cpeAdsOptInShownForRelease,
      CpeAppSubscriptions? cpeAppSubscriptions,
      bool? cpeAskPurchasePin,
      bool? cpeAskRecPlayPin,
      enums.CpeAspectRatio? cpeAspectRatio,
      int? cpeAudioDelayDD,
      int? cpeAudioDelayPCM,
      bool? cpeAudioDolbyDigital,
      enums.CpeAudioDolbyDigitalMode? cpeAudioDolbyDigitalMode,
      enums.CpeAutoStandby? cpeAutoStandby,
      bool? cpeAutoTvStartup,
      enums.CpeCcAnalogService? cpeCcAnalogService,
      enums.CpeCcDigitalService? cpeCcDigitalService,
      CpeCcsMessages? cpeCcsMessages,
      String? cpeCountry,
      String? cpeDefaultProfileId,
      String? cpeDefaultPvrStb,
      int? cpeDisplayedStandByMessageCount,
      bool? cpeEnableCEC,
      enums.CpeFactoryResetState? cpeFactoryResetState,
      enums.CpeFactoryResetType? cpeFactoryResetType,
      String? cpeFriendlyName,
      enums.CpeFtiState? cpeFtiState,
      enums.CpeHdmiColorOutput? cpeHdmiColorOutput,
      CpeHdmiDeviceInfo? cpeHdmiDeviceInfo,
      enums.CpeHdmiResolution? cpeHdmiResolution,
      bool? cpeIsAlexaLinked,
      bool? cpeIsSilentDowngrade,
      String? cpeLastUsedBrandedScreenKey,
      num? cpeLastUseNetflix,
      CpeLockedApps? cpeLockedApps,
      bool? cpeMatchFrameRate,
      String? cpeNetflixRailCache,
      String? cpeNetflixToken,
      String? cpeNetflixVdid,
      bool? cpeOneTouchViewTurnOffPolicy,
      enums.CpePowerCheck? cpePowerCheck,
      enums.CpePowerSource? cpePowerSource,
      enums.CpePrimaryVideoOutput? cpePrimaryVideoOutput,
      CpeQuicksetPairedDevicesInfo? cpeQuicksetPairedDevicesInfo,
      enums.CpeRcuUpgradeStatus? cpeRcuUpgradeStatus,
      CpeRebootReason? cpeRebootReason,
      enums.CpeRecordPaddingAfter? cpeRecordPaddingAfter,
      enums.CpeRecordPaddingBefore? cpeRecordPaddingBefore,
      bool? cpeShowColdStandByMessage,
      bool? cpeShowReplayOptInMessage,
      int? cpeSlowStandByCyclesCount,
      CpeSpeedTestResults? cpeSpeedTestResults,
      enums.CpeStandByMode? cpeStandByMode,
      bool? cpeUiTestTools,
      enums.CpeUpgradeStatus? cpeUpgradeStatus,
      bool? cpeUseHighContrastUI,
      num? cpeVolume,
      bool? cpeWifiClientEnabled,
      String? cpeWifiClientPass,
      String? cpeWifiClientSsid,
      String? cpeXaBrokerUrl,
      bool? customerA2aHgoOptIn,
      bool? customerA2aStbOptIn,
      bool? customerAdsOptIn,
      bool? customerAppsOptIn,
      bool? customerAutoDeleteFunction,
      String? customerCityId,
      String? customerCustomerId,
      String? customerDefaultHhStb,
      bool? customerDeleteRecordingReminder,
      bool? customerIsAdultPinUsed,
      bool? customerIsFtiPassed,
      bool? customerIsSuspended,
      bool? customerPersonalSuggestions,
      enums.CustomerRecordingRetentionPeriod? customerRecordingRetentionPeriod,
      bool? customerReplayOptIn,
      num? customerReplayOptInTime,
      String? customerZipCode,
      ProfileAccessibleViews? profileAccessibleViews,
      enums.ProfileAgeLock? profileAgeLock,
      bool? profileAudioDescription,
      enums.ProfileAudioLang? profileAudioLang,
      enums.ProfileOnScreenKeyboardMode? profileOnScreenKeyboardMode,
      enums.ProfileOsdLang? profileOsdLang,
      ProfileRecentlyListenedRadios? profileRecentlyListenedRadios,
      ProfileRecentlyUsedAppsItems? profileRecentlyUsedAppsItems,
      ProfileRecentlyUsedSettingsItems? profileRecentlyUsedSettingsItems,
      bool? profileSignLanguage,
      bool? profileSubControl,
      bool? profileSubHardOfHearing,
      enums.ProfileSubLang? profileSubLang,
      bool? profileSurfFavoriteChannels,
      bool? profileTextToSpeech,
      enums.ProfileTextToSpeechSpeed? profileTextToSpeechSpeed,
      ProfileTextToSpeechVoice? profileTextToSpeechVoice,
      enums.ProfileTextToSpeechVolume? profileTextToSpeechVolume,
      ProfileTipsAndTricks? profileTipsAndTricks}) {
    return Settings(
        cpe16by9Handling: cpe16by9Handling ?? this.cpe16by9Handling,
        cpe4by3Handling: cpe4by3Handling ?? this.cpe4by3Handling,
        cpeAdsOptInShownForRelease:
            cpeAdsOptInShownForRelease ?? this.cpeAdsOptInShownForRelease,
        cpeAppSubscriptions: cpeAppSubscriptions ?? this.cpeAppSubscriptions,
        cpeAskPurchasePin: cpeAskPurchasePin ?? this.cpeAskPurchasePin,
        cpeAskRecPlayPin: cpeAskRecPlayPin ?? this.cpeAskRecPlayPin,
        cpeAspectRatio: cpeAspectRatio ?? this.cpeAspectRatio,
        cpeAudioDelayDD: cpeAudioDelayDD ?? this.cpeAudioDelayDD,
        cpeAudioDelayPCM: cpeAudioDelayPCM ?? this.cpeAudioDelayPCM,
        cpeAudioDolbyDigital: cpeAudioDolbyDigital ?? this.cpeAudioDolbyDigital,
        cpeAudioDolbyDigitalMode:
            cpeAudioDolbyDigitalMode ?? this.cpeAudioDolbyDigitalMode,
        cpeAutoStandby: cpeAutoStandby ?? this.cpeAutoStandby,
        cpeAutoTvStartup: cpeAutoTvStartup ?? this.cpeAutoTvStartup,
        cpeCcAnalogService: cpeCcAnalogService ?? this.cpeCcAnalogService,
        cpeCcDigitalService: cpeCcDigitalService ?? this.cpeCcDigitalService,
        cpeCcsMessages: cpeCcsMessages ?? this.cpeCcsMessages,
        cpeCountry: cpeCountry ?? this.cpeCountry,
        cpeDefaultProfileId: cpeDefaultProfileId ?? this.cpeDefaultProfileId,
        cpeDefaultPvrStb: cpeDefaultPvrStb ?? this.cpeDefaultPvrStb,
        cpeDisplayedStandByMessageCount: cpeDisplayedStandByMessageCount ??
            this.cpeDisplayedStandByMessageCount,
        cpeEnableCEC: cpeEnableCEC ?? this.cpeEnableCEC,
        cpeFactoryResetState: cpeFactoryResetState ?? this.cpeFactoryResetState,
        cpeFactoryResetType: cpeFactoryResetType ?? this.cpeFactoryResetType,
        cpeFriendlyName: cpeFriendlyName ?? this.cpeFriendlyName,
        cpeFtiState: cpeFtiState ?? this.cpeFtiState,
        cpeHdmiColorOutput: cpeHdmiColorOutput ?? this.cpeHdmiColorOutput,
        cpeHdmiDeviceInfo: cpeHdmiDeviceInfo ?? this.cpeHdmiDeviceInfo,
        cpeHdmiResolution: cpeHdmiResolution ?? this.cpeHdmiResolution,
        cpeIsAlexaLinked: cpeIsAlexaLinked ?? this.cpeIsAlexaLinked,
        cpeIsSilentDowngrade: cpeIsSilentDowngrade ?? this.cpeIsSilentDowngrade,
        cpeLastUsedBrandedScreenKey:
            cpeLastUsedBrandedScreenKey ?? this.cpeLastUsedBrandedScreenKey,
        cpeLastUseNetflix: cpeLastUseNetflix ?? this.cpeLastUseNetflix,
        cpeLockedApps: cpeLockedApps ?? this.cpeLockedApps,
        cpeMatchFrameRate: cpeMatchFrameRate ?? this.cpeMatchFrameRate,
        cpeNetflixRailCache: cpeNetflixRailCache ?? this.cpeNetflixRailCache,
        cpeNetflixToken: cpeNetflixToken ?? this.cpeNetflixToken,
        cpeNetflixVdid: cpeNetflixVdid ?? this.cpeNetflixVdid,
        cpeOneTouchViewTurnOffPolicy:
            cpeOneTouchViewTurnOffPolicy ?? this.cpeOneTouchViewTurnOffPolicy,
        cpePowerCheck: cpePowerCheck ?? this.cpePowerCheck,
        cpePowerSource: cpePowerSource ?? this.cpePowerSource,
        cpePrimaryVideoOutput:
            cpePrimaryVideoOutput ?? this.cpePrimaryVideoOutput,
        cpeQuicksetPairedDevicesInfo:
            cpeQuicksetPairedDevicesInfo ?? this.cpeQuicksetPairedDevicesInfo,
        cpeRcuUpgradeStatus: cpeRcuUpgradeStatus ?? this.cpeRcuUpgradeStatus,
        cpeRebootReason: cpeRebootReason ?? this.cpeRebootReason,
        cpeRecordPaddingAfter:
            cpeRecordPaddingAfter ?? this.cpeRecordPaddingAfter,
        cpeRecordPaddingBefore:
            cpeRecordPaddingBefore ?? this.cpeRecordPaddingBefore,
        cpeShowColdStandByMessage:
            cpeShowColdStandByMessage ?? this.cpeShowColdStandByMessage,
        cpeShowReplayOptInMessage:
            cpeShowReplayOptInMessage ?? this.cpeShowReplayOptInMessage,
        cpeSlowStandByCyclesCount:
            cpeSlowStandByCyclesCount ?? this.cpeSlowStandByCyclesCount,
        cpeSpeedTestResults: cpeSpeedTestResults ?? this.cpeSpeedTestResults,
        cpeStandByMode: cpeStandByMode ?? this.cpeStandByMode,
        cpeUiTestTools: cpeUiTestTools ?? this.cpeUiTestTools,
        cpeUpgradeStatus: cpeUpgradeStatus ?? this.cpeUpgradeStatus,
        cpeUseHighContrastUI: cpeUseHighContrastUI ?? this.cpeUseHighContrastUI,
        cpeVolume: cpeVolume ?? this.cpeVolume,
        cpeWifiClientEnabled: cpeWifiClientEnabled ?? this.cpeWifiClientEnabled,
        cpeWifiClientPass: cpeWifiClientPass ?? this.cpeWifiClientPass,
        cpeWifiClientSsid: cpeWifiClientSsid ?? this.cpeWifiClientSsid,
        cpeXaBrokerUrl: cpeXaBrokerUrl ?? this.cpeXaBrokerUrl,
        customerA2aHgoOptIn: customerA2aHgoOptIn ?? this.customerA2aHgoOptIn,
        customerA2aStbOptIn: customerA2aStbOptIn ?? this.customerA2aStbOptIn,
        customerAdsOptIn: customerAdsOptIn ?? this.customerAdsOptIn,
        customerAppsOptIn: customerAppsOptIn ?? this.customerAppsOptIn,
        customerAutoDeleteFunction:
            customerAutoDeleteFunction ?? this.customerAutoDeleteFunction,
        customerCityId: customerCityId ?? this.customerCityId,
        customerCustomerId: customerCustomerId ?? this.customerCustomerId,
        customerDefaultHhStb: customerDefaultHhStb ?? this.customerDefaultHhStb,
        customerDeleteRecordingReminder: customerDeleteRecordingReminder ??
            this.customerDeleteRecordingReminder,
        customerIsAdultPinUsed:
            customerIsAdultPinUsed ?? this.customerIsAdultPinUsed,
        customerIsFtiPassed: customerIsFtiPassed ?? this.customerIsFtiPassed,
        customerIsSuspended: customerIsSuspended ?? this.customerIsSuspended,
        customerPersonalSuggestions:
            customerPersonalSuggestions ?? this.customerPersonalSuggestions,
        customerRecordingRetentionPeriod: customerRecordingRetentionPeriod ??
            this.customerRecordingRetentionPeriod,
        customerReplayOptIn: customerReplayOptIn ?? this.customerReplayOptIn,
        customerReplayOptInTime:
            customerReplayOptInTime ?? this.customerReplayOptInTime,
        customerZipCode: customerZipCode ?? this.customerZipCode,
        profileAccessibleViews:
            profileAccessibleViews ?? this.profileAccessibleViews,
        profileAgeLock: profileAgeLock ?? this.profileAgeLock,
        profileAudioDescription:
            profileAudioDescription ?? this.profileAudioDescription,
        profileAudioLang: profileAudioLang ?? this.profileAudioLang,
        profileOnScreenKeyboardMode:
            profileOnScreenKeyboardMode ?? this.profileOnScreenKeyboardMode,
        profileOsdLang: profileOsdLang ?? this.profileOsdLang,
        profileRecentlyListenedRadios:
            profileRecentlyListenedRadios ?? this.profileRecentlyListenedRadios,
        profileRecentlyUsedAppsItems:
            profileRecentlyUsedAppsItems ?? this.profileRecentlyUsedAppsItems,
        profileRecentlyUsedSettingsItems: profileRecentlyUsedSettingsItems ??
            this.profileRecentlyUsedSettingsItems,
        profileSignLanguage: profileSignLanguage ?? this.profileSignLanguage,
        profileSubControl: profileSubControl ?? this.profileSubControl,
        profileSubHardOfHearing:
            profileSubHardOfHearing ?? this.profileSubHardOfHearing,
        profileSubLang: profileSubLang ?? this.profileSubLang,
        profileSurfFavoriteChannels:
            profileSurfFavoriteChannels ?? this.profileSurfFavoriteChannels,
        profileTextToSpeech: profileTextToSpeech ?? this.profileTextToSpeech,
        profileTextToSpeechSpeed:
            profileTextToSpeechSpeed ?? this.profileTextToSpeechSpeed,
        profileTextToSpeechVoice:
            profileTextToSpeechVoice ?? this.profileTextToSpeechVoice,
        profileTextToSpeechVolume:
            profileTextToSpeechVolume ?? this.profileTextToSpeechVolume,
        profileTipsAndTricks:
            profileTipsAndTricks ?? this.profileTipsAndTricks);
  }

  Settings copyWithWrapped(
      {Wrapped<enums.Cpe16by9Handling?>? cpe16by9Handling,
      Wrapped<enums.Cpe4by3Handling?>? cpe4by3Handling,
      Wrapped<String?>? cpeAdsOptInShownForRelease,
      Wrapped<CpeAppSubscriptions?>? cpeAppSubscriptions,
      Wrapped<bool?>? cpeAskPurchasePin,
      Wrapped<bool?>? cpeAskRecPlayPin,
      Wrapped<enums.CpeAspectRatio?>? cpeAspectRatio,
      Wrapped<int?>? cpeAudioDelayDD,
      Wrapped<int?>? cpeAudioDelayPCM,
      Wrapped<bool?>? cpeAudioDolbyDigital,
      Wrapped<enums.CpeAudioDolbyDigitalMode?>? cpeAudioDolbyDigitalMode,
      Wrapped<enums.CpeAutoStandby?>? cpeAutoStandby,
      Wrapped<bool?>? cpeAutoTvStartup,
      Wrapped<enums.CpeCcAnalogService?>? cpeCcAnalogService,
      Wrapped<enums.CpeCcDigitalService?>? cpeCcDigitalService,
      Wrapped<CpeCcsMessages?>? cpeCcsMessages,
      Wrapped<String?>? cpeCountry,
      Wrapped<String?>? cpeDefaultProfileId,
      Wrapped<String?>? cpeDefaultPvrStb,
      Wrapped<int?>? cpeDisplayedStandByMessageCount,
      Wrapped<bool?>? cpeEnableCEC,
      Wrapped<enums.CpeFactoryResetState?>? cpeFactoryResetState,
      Wrapped<enums.CpeFactoryResetType?>? cpeFactoryResetType,
      Wrapped<String?>? cpeFriendlyName,
      Wrapped<enums.CpeFtiState?>? cpeFtiState,
      Wrapped<enums.CpeHdmiColorOutput?>? cpeHdmiColorOutput,
      Wrapped<CpeHdmiDeviceInfo?>? cpeHdmiDeviceInfo,
      Wrapped<enums.CpeHdmiResolution?>? cpeHdmiResolution,
      Wrapped<bool?>? cpeIsAlexaLinked,
      Wrapped<bool?>? cpeIsSilentDowngrade,
      Wrapped<String?>? cpeLastUsedBrandedScreenKey,
      Wrapped<num?>? cpeLastUseNetflix,
      Wrapped<CpeLockedApps?>? cpeLockedApps,
      Wrapped<bool?>? cpeMatchFrameRate,
      Wrapped<String?>? cpeNetflixRailCache,
      Wrapped<String?>? cpeNetflixToken,
      Wrapped<String?>? cpeNetflixVdid,
      Wrapped<bool?>? cpeOneTouchViewTurnOffPolicy,
      Wrapped<enums.CpePowerCheck?>? cpePowerCheck,
      Wrapped<enums.CpePowerSource?>? cpePowerSource,
      Wrapped<enums.CpePrimaryVideoOutput?>? cpePrimaryVideoOutput,
      Wrapped<CpeQuicksetPairedDevicesInfo?>? cpeQuicksetPairedDevicesInfo,
      Wrapped<enums.CpeRcuUpgradeStatus?>? cpeRcuUpgradeStatus,
      Wrapped<CpeRebootReason?>? cpeRebootReason,
      Wrapped<enums.CpeRecordPaddingAfter?>? cpeRecordPaddingAfter,
      Wrapped<enums.CpeRecordPaddingBefore?>? cpeRecordPaddingBefore,
      Wrapped<bool?>? cpeShowColdStandByMessage,
      Wrapped<bool?>? cpeShowReplayOptInMessage,
      Wrapped<int?>? cpeSlowStandByCyclesCount,
      Wrapped<CpeSpeedTestResults?>? cpeSpeedTestResults,
      Wrapped<enums.CpeStandByMode?>? cpeStandByMode,
      Wrapped<bool?>? cpeUiTestTools,
      Wrapped<enums.CpeUpgradeStatus?>? cpeUpgradeStatus,
      Wrapped<bool?>? cpeUseHighContrastUI,
      Wrapped<num?>? cpeVolume,
      Wrapped<bool?>? cpeWifiClientEnabled,
      Wrapped<String?>? cpeWifiClientPass,
      Wrapped<String?>? cpeWifiClientSsid,
      Wrapped<String?>? cpeXaBrokerUrl,
      Wrapped<bool?>? customerA2aHgoOptIn,
      Wrapped<bool?>? customerA2aStbOptIn,
      Wrapped<bool?>? customerAdsOptIn,
      Wrapped<bool?>? customerAppsOptIn,
      Wrapped<bool?>? customerAutoDeleteFunction,
      Wrapped<String?>? customerCityId,
      Wrapped<String?>? customerCustomerId,
      Wrapped<String?>? customerDefaultHhStb,
      Wrapped<bool?>? customerDeleteRecordingReminder,
      Wrapped<bool?>? customerIsAdultPinUsed,
      Wrapped<bool?>? customerIsFtiPassed,
      Wrapped<bool?>? customerIsSuspended,
      Wrapped<bool?>? customerPersonalSuggestions,
      Wrapped<enums.CustomerRecordingRetentionPeriod?>?
          customerRecordingRetentionPeriod,
      Wrapped<bool?>? customerReplayOptIn,
      Wrapped<num?>? customerReplayOptInTime,
      Wrapped<String?>? customerZipCode,
      Wrapped<ProfileAccessibleViews?>? profileAccessibleViews,
      Wrapped<enums.ProfileAgeLock?>? profileAgeLock,
      Wrapped<bool?>? profileAudioDescription,
      Wrapped<enums.ProfileAudioLang?>? profileAudioLang,
      Wrapped<enums.ProfileOnScreenKeyboardMode?>? profileOnScreenKeyboardMode,
      Wrapped<enums.ProfileOsdLang?>? profileOsdLang,
      Wrapped<ProfileRecentlyListenedRadios?>? profileRecentlyListenedRadios,
      Wrapped<ProfileRecentlyUsedAppsItems?>? profileRecentlyUsedAppsItems,
      Wrapped<ProfileRecentlyUsedSettingsItems?>?
          profileRecentlyUsedSettingsItems,
      Wrapped<bool?>? profileSignLanguage,
      Wrapped<bool?>? profileSubControl,
      Wrapped<bool?>? profileSubHardOfHearing,
      Wrapped<enums.ProfileSubLang?>? profileSubLang,
      Wrapped<bool?>? profileSurfFavoriteChannels,
      Wrapped<bool?>? profileTextToSpeech,
      Wrapped<enums.ProfileTextToSpeechSpeed?>? profileTextToSpeechSpeed,
      Wrapped<ProfileTextToSpeechVoice?>? profileTextToSpeechVoice,
      Wrapped<enums.ProfileTextToSpeechVolume?>? profileTextToSpeechVolume,
      Wrapped<ProfileTipsAndTricks?>? profileTipsAndTricks}) {
    return Settings(
        cpe16by9Handling: (cpe16by9Handling != null
            ? cpe16by9Handling.value
            : this.cpe16by9Handling),
        cpe4by3Handling: (cpe4by3Handling != null
            ? cpe4by3Handling.value
            : this.cpe4by3Handling),
        cpeAdsOptInShownForRelease: (cpeAdsOptInShownForRelease != null
            ? cpeAdsOptInShownForRelease.value
            : this.cpeAdsOptInShownForRelease),
        cpeAppSubscriptions: (cpeAppSubscriptions != null
            ? cpeAppSubscriptions.value
            : this.cpeAppSubscriptions),
        cpeAskPurchasePin: (cpeAskPurchasePin != null
            ? cpeAskPurchasePin.value
            : this.cpeAskPurchasePin),
        cpeAskRecPlayPin: (cpeAskRecPlayPin != null
            ? cpeAskRecPlayPin.value
            : this.cpeAskRecPlayPin),
        cpeAspectRatio: (cpeAspectRatio != null
            ? cpeAspectRatio.value
            : this.cpeAspectRatio),
        cpeAudioDelayDD: (cpeAudioDelayDD != null
            ? cpeAudioDelayDD.value
            : this.cpeAudioDelayDD),
        cpeAudioDelayPCM: (cpeAudioDelayPCM != null
            ? cpeAudioDelayPCM.value
            : this.cpeAudioDelayPCM),
        cpeAudioDolbyDigital: (cpeAudioDolbyDigital != null
            ? cpeAudioDolbyDigital.value
            : this.cpeAudioDolbyDigital),
        cpeAudioDolbyDigitalMode: (cpeAudioDolbyDigitalMode != null
            ? cpeAudioDolbyDigitalMode.value
            : this.cpeAudioDolbyDigitalMode),
        cpeAutoStandby: (cpeAutoStandby != null
            ? cpeAutoStandby.value
            : this.cpeAutoStandby),
        cpeAutoTvStartup: (cpeAutoTvStartup != null
            ? cpeAutoTvStartup.value
            : this.cpeAutoTvStartup),
        cpeCcAnalogService: (cpeCcAnalogService != null
            ? cpeCcAnalogService.value
            : this.cpeCcAnalogService),
        cpeCcDigitalService: (cpeCcDigitalService != null
            ? cpeCcDigitalService.value
            : this.cpeCcDigitalService),
        cpeCcsMessages: (cpeCcsMessages != null
            ? cpeCcsMessages.value
            : this.cpeCcsMessages),
        cpeCountry: (cpeCountry != null ? cpeCountry.value : this.cpeCountry),
        cpeDefaultProfileId: (cpeDefaultProfileId != null
            ? cpeDefaultProfileId.value
            : this.cpeDefaultProfileId),
        cpeDefaultPvrStb: (cpeDefaultPvrStb != null
            ? cpeDefaultPvrStb.value
            : this.cpeDefaultPvrStb),
        cpeDisplayedStandByMessageCount:
            (cpeDisplayedStandByMessageCount != null
                ? cpeDisplayedStandByMessageCount.value
                : this.cpeDisplayedStandByMessageCount),
        cpeEnableCEC:
            (cpeEnableCEC != null ? cpeEnableCEC.value : this.cpeEnableCEC),
        cpeFactoryResetState: (cpeFactoryResetState != null
            ? cpeFactoryResetState.value
            : this.cpeFactoryResetState),
        cpeFactoryResetType: (cpeFactoryResetType != null
            ? cpeFactoryResetType.value
            : this.cpeFactoryResetType),
        cpeFriendlyName: (cpeFriendlyName != null
            ? cpeFriendlyName.value
            : this.cpeFriendlyName),
        cpeFtiState:
            (cpeFtiState != null ? cpeFtiState.value : this.cpeFtiState),
        cpeHdmiColorOutput: (cpeHdmiColorOutput != null
            ? cpeHdmiColorOutput.value
            : this.cpeHdmiColorOutput),
        cpeHdmiDeviceInfo: (cpeHdmiDeviceInfo != null
            ? cpeHdmiDeviceInfo.value
            : this.cpeHdmiDeviceInfo),
        cpeHdmiResolution: (cpeHdmiResolution != null
            ? cpeHdmiResolution.value
            : this.cpeHdmiResolution),
        cpeIsAlexaLinked: (cpeIsAlexaLinked != null
            ? cpeIsAlexaLinked.value
            : this.cpeIsAlexaLinked),
        cpeIsSilentDowngrade: (cpeIsSilentDowngrade != null
            ? cpeIsSilentDowngrade.value
            : this.cpeIsSilentDowngrade),
        cpeLastUsedBrandedScreenKey: (cpeLastUsedBrandedScreenKey != null
            ? cpeLastUsedBrandedScreenKey.value
            : this.cpeLastUsedBrandedScreenKey),
        cpeLastUseNetflix: (cpeLastUseNetflix != null
            ? cpeLastUseNetflix.value
            : this.cpeLastUseNetflix),
        cpeLockedApps:
            (cpeLockedApps != null ? cpeLockedApps.value : this.cpeLockedApps),
        cpeMatchFrameRate: (cpeMatchFrameRate != null
            ? cpeMatchFrameRate.value
            : this.cpeMatchFrameRate),
        cpeNetflixRailCache: (cpeNetflixRailCache != null
            ? cpeNetflixRailCache.value
            : this.cpeNetflixRailCache),
        cpeNetflixToken: (cpeNetflixToken != null
            ? cpeNetflixToken.value
            : this.cpeNetflixToken),
        cpeNetflixVdid: (cpeNetflixVdid != null
            ? cpeNetflixVdid.value
            : this.cpeNetflixVdid),
        cpeOneTouchViewTurnOffPolicy: (cpeOneTouchViewTurnOffPolicy != null
            ? cpeOneTouchViewTurnOffPolicy.value
            : this.cpeOneTouchViewTurnOffPolicy),
        cpePowerCheck:
            (cpePowerCheck != null ? cpePowerCheck.value : this.cpePowerCheck),
        cpePowerSource: (cpePowerSource != null
            ? cpePowerSource.value
            : this.cpePowerSource),
        cpePrimaryVideoOutput: (cpePrimaryVideoOutput != null
            ? cpePrimaryVideoOutput.value
            : this.cpePrimaryVideoOutput),
        cpeQuicksetPairedDevicesInfo: (cpeQuicksetPairedDevicesInfo != null
            ? cpeQuicksetPairedDevicesInfo.value
            : this.cpeQuicksetPairedDevicesInfo),
        cpeRcuUpgradeStatus: (cpeRcuUpgradeStatus != null
            ? cpeRcuUpgradeStatus.value
            : this.cpeRcuUpgradeStatus),
        cpeRebootReason: (cpeRebootReason != null
            ? cpeRebootReason.value
            : this.cpeRebootReason),
        cpeRecordPaddingAfter: (cpeRecordPaddingAfter != null
            ? cpeRecordPaddingAfter.value
            : this.cpeRecordPaddingAfter),
        cpeRecordPaddingBefore: (cpeRecordPaddingBefore != null
            ? cpeRecordPaddingBefore.value
            : this.cpeRecordPaddingBefore),
        cpeShowColdStandByMessage: (cpeShowColdStandByMessage != null ? cpeShowColdStandByMessage.value : this.cpeShowColdStandByMessage),
        cpeShowReplayOptInMessage: (cpeShowReplayOptInMessage != null ? cpeShowReplayOptInMessage.value : this.cpeShowReplayOptInMessage),
        cpeSlowStandByCyclesCount: (cpeSlowStandByCyclesCount != null ? cpeSlowStandByCyclesCount.value : this.cpeSlowStandByCyclesCount),
        cpeSpeedTestResults: (cpeSpeedTestResults != null ? cpeSpeedTestResults.value : this.cpeSpeedTestResults),
        cpeStandByMode: (cpeStandByMode != null ? cpeStandByMode.value : this.cpeStandByMode),
        cpeUiTestTools: (cpeUiTestTools != null ? cpeUiTestTools.value : this.cpeUiTestTools),
        cpeUpgradeStatus: (cpeUpgradeStatus != null ? cpeUpgradeStatus.value : this.cpeUpgradeStatus),
        cpeUseHighContrastUI: (cpeUseHighContrastUI != null ? cpeUseHighContrastUI.value : this.cpeUseHighContrastUI),
        cpeVolume: (cpeVolume != null ? cpeVolume.value : this.cpeVolume),
        cpeWifiClientEnabled: (cpeWifiClientEnabled != null ? cpeWifiClientEnabled.value : this.cpeWifiClientEnabled),
        cpeWifiClientPass: (cpeWifiClientPass != null ? cpeWifiClientPass.value : this.cpeWifiClientPass),
        cpeWifiClientSsid: (cpeWifiClientSsid != null ? cpeWifiClientSsid.value : this.cpeWifiClientSsid),
        cpeXaBrokerUrl: (cpeXaBrokerUrl != null ? cpeXaBrokerUrl.value : this.cpeXaBrokerUrl),
        customerA2aHgoOptIn: (customerA2aHgoOptIn != null ? customerA2aHgoOptIn.value : this.customerA2aHgoOptIn),
        customerA2aStbOptIn: (customerA2aStbOptIn != null ? customerA2aStbOptIn.value : this.customerA2aStbOptIn),
        customerAdsOptIn: (customerAdsOptIn != null ? customerAdsOptIn.value : this.customerAdsOptIn),
        customerAppsOptIn: (customerAppsOptIn != null ? customerAppsOptIn.value : this.customerAppsOptIn),
        customerAutoDeleteFunction: (customerAutoDeleteFunction != null ? customerAutoDeleteFunction.value : this.customerAutoDeleteFunction),
        customerCityId: (customerCityId != null ? customerCityId.value : this.customerCityId),
        customerCustomerId: (customerCustomerId != null ? customerCustomerId.value : this.customerCustomerId),
        customerDefaultHhStb: (customerDefaultHhStb != null ? customerDefaultHhStb.value : this.customerDefaultHhStb),
        customerDeleteRecordingReminder: (customerDeleteRecordingReminder != null ? customerDeleteRecordingReminder.value : this.customerDeleteRecordingReminder),
        customerIsAdultPinUsed: (customerIsAdultPinUsed != null ? customerIsAdultPinUsed.value : this.customerIsAdultPinUsed),
        customerIsFtiPassed: (customerIsFtiPassed != null ? customerIsFtiPassed.value : this.customerIsFtiPassed),
        customerIsSuspended: (customerIsSuspended != null ? customerIsSuspended.value : this.customerIsSuspended),
        customerPersonalSuggestions: (customerPersonalSuggestions != null ? customerPersonalSuggestions.value : this.customerPersonalSuggestions),
        customerRecordingRetentionPeriod: (customerRecordingRetentionPeriod != null ? customerRecordingRetentionPeriod.value : this.customerRecordingRetentionPeriod),
        customerReplayOptIn: (customerReplayOptIn != null ? customerReplayOptIn.value : this.customerReplayOptIn),
        customerReplayOptInTime: (customerReplayOptInTime != null ? customerReplayOptInTime.value : this.customerReplayOptInTime),
        customerZipCode: (customerZipCode != null ? customerZipCode.value : this.customerZipCode),
        profileAccessibleViews: (profileAccessibleViews != null ? profileAccessibleViews.value : this.profileAccessibleViews),
        profileAgeLock: (profileAgeLock != null ? profileAgeLock.value : this.profileAgeLock),
        profileAudioDescription: (profileAudioDescription != null ? profileAudioDescription.value : this.profileAudioDescription),
        profileAudioLang: (profileAudioLang != null ? profileAudioLang.value : this.profileAudioLang),
        profileOnScreenKeyboardMode: (profileOnScreenKeyboardMode != null ? profileOnScreenKeyboardMode.value : this.profileOnScreenKeyboardMode),
        profileOsdLang: (profileOsdLang != null ? profileOsdLang.value : this.profileOsdLang),
        profileRecentlyListenedRadios: (profileRecentlyListenedRadios != null ? profileRecentlyListenedRadios.value : this.profileRecentlyListenedRadios),
        profileRecentlyUsedAppsItems: (profileRecentlyUsedAppsItems != null ? profileRecentlyUsedAppsItems.value : this.profileRecentlyUsedAppsItems),
        profileRecentlyUsedSettingsItems: (profileRecentlyUsedSettingsItems != null ? profileRecentlyUsedSettingsItems.value : this.profileRecentlyUsedSettingsItems),
        profileSignLanguage: (profileSignLanguage != null ? profileSignLanguage.value : this.profileSignLanguage),
        profileSubControl: (profileSubControl != null ? profileSubControl.value : this.profileSubControl),
        profileSubHardOfHearing: (profileSubHardOfHearing != null ? profileSubHardOfHearing.value : this.profileSubHardOfHearing),
        profileSubLang: (profileSubLang != null ? profileSubLang.value : this.profileSubLang),
        profileSurfFavoriteChannels: (profileSurfFavoriteChannels != null ? profileSurfFavoriteChannels.value : this.profileSurfFavoriteChannels),
        profileTextToSpeech: (profileTextToSpeech != null ? profileTextToSpeech.value : this.profileTextToSpeech),
        profileTextToSpeechSpeed: (profileTextToSpeechSpeed != null ? profileTextToSpeechSpeed.value : this.profileTextToSpeechSpeed),
        profileTextToSpeechVoice: (profileTextToSpeechVoice != null ? profileTextToSpeechVoice.value : this.profileTextToSpeechVoice),
        profileTextToSpeechVolume: (profileTextToSpeechVolume != null ? profileTextToSpeechVolume.value : this.profileTextToSpeechVolume),
        profileTipsAndTricks: (profileTipsAndTricks != null ? profileTipsAndTricks.value : this.profileTipsAndTricks));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeAppSubscriptions {
  CpeAppSubscriptions();

  factory CpeAppSubscriptions.fromJson(Map<String, dynamic> json) =>
      _$CpeAppSubscriptionsFromJson(json);

  static const fromJsonFactory = _$CpeAppSubscriptionsFromJson;
  static const toJsonFactory = _$CpeAppSubscriptionsToJson;
  Map<String, dynamic> toJson() => _$CpeAppSubscriptionsToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

typedef CpeCcsMessages = List<Object>;

@JsonSerializable(explicitToJson: true)
class CpeHdmiDeviceInfo {
  CpeHdmiDeviceInfo({
    this.maxSupportedResolution,
  });

  factory CpeHdmiDeviceInfo.fromJson(Map<String, dynamic> json) =>
      _$CpeHdmiDeviceInfoFromJson(json);

  @JsonKey(
      name: 'maxSupportedResolution', includeIfNull: false, defaultValue: '')
  final String? maxSupportedResolution;
  static const fromJsonFactory = _$CpeHdmiDeviceInfoFromJson;
  static const toJsonFactory = _$CpeHdmiDeviceInfoToJson;
  Map<String, dynamic> toJson() => _$CpeHdmiDeviceInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeHdmiDeviceInfo &&
            (identical(other.maxSupportedResolution, maxSupportedResolution) ||
                const DeepCollectionEquality().equals(
                    other.maxSupportedResolution, maxSupportedResolution)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(maxSupportedResolution) ^
      runtimeType.hashCode;
}

extension $CpeHdmiDeviceInfoExtension on CpeHdmiDeviceInfo {
  CpeHdmiDeviceInfo copyWith({String? maxSupportedResolution}) {
    return CpeHdmiDeviceInfo(
        maxSupportedResolution:
            maxSupportedResolution ?? this.maxSupportedResolution);
  }

  CpeHdmiDeviceInfo copyWithWrapped(
      {Wrapped<String?>? maxSupportedResolution}) {
    return CpeHdmiDeviceInfo(
        maxSupportedResolution: (maxSupportedResolution != null
            ? maxSupportedResolution.value
            : this.maxSupportedResolution));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeLastUseNetflix {
  CpeLastUseNetflix();

  factory CpeLastUseNetflix.fromJson(Map<String, dynamic> json) =>
      _$CpeLastUseNetflixFromJson(json);

  static const fromJsonFactory = _$CpeLastUseNetflixFromJson;
  static const toJsonFactory = _$CpeLastUseNetflixToJson;
  Map<String, dynamic> toJson() => _$CpeLastUseNetflixToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

typedef CpeLockedApps = List<Object>;

@JsonSerializable(explicitToJson: true)
class CpeQuicksetPairedDevicesInfo {
  CpeQuicksetPairedDevicesInfo({
    required this.physicalAddress,
    required this.edid,
    required this.volumeLock,
    this.volumeLockMethod,
    required this.tv,
    required this.amp,
    this.stats,
  });

  factory CpeQuicksetPairedDevicesInfo.fromJson(Map<String, dynamic> json) =>
      _$CpeQuicksetPairedDevicesInfoFromJson(json);

  @JsonKey(name: 'physicalAddress', includeIfNull: false, defaultValue: '')
  final String physicalAddress;
  @JsonKey(name: 'edid', includeIfNull: false, defaultValue: '')
  final String edid;
  @JsonKey(name: 'volumeLock', includeIfNull: false)
  final int volumeLock;
  @JsonKey(name: 'volumeLockMethod', includeIfNull: false, defaultValue: '')
  final String? volumeLockMethod;
  @JsonKey(name: 'tv', includeIfNull: false)
  final CpeQuicksetPairedDevicesInfo$Tv tv;
  @JsonKey(name: 'amp', includeIfNull: false)
  final CpeQuicksetPairedDevicesInfo$Amp amp;
  @JsonKey(name: 'stats', includeIfNull: false)
  final CpeQuicksetPairedDevicesInfo$Stats? stats;
  static const fromJsonFactory = _$CpeQuicksetPairedDevicesInfoFromJson;
  static const toJsonFactory = _$CpeQuicksetPairedDevicesInfoToJson;
  Map<String, dynamic> toJson() => _$CpeQuicksetPairedDevicesInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeQuicksetPairedDevicesInfo &&
            (identical(other.physicalAddress, physicalAddress) ||
                const DeepCollectionEquality()
                    .equals(other.physicalAddress, physicalAddress)) &&
            (identical(other.edid, edid) ||
                const DeepCollectionEquality().equals(other.edid, edid)) &&
            (identical(other.volumeLock, volumeLock) ||
                const DeepCollectionEquality()
                    .equals(other.volumeLock, volumeLock)) &&
            (identical(other.volumeLockMethod, volumeLockMethod) ||
                const DeepCollectionEquality()
                    .equals(other.volumeLockMethod, volumeLockMethod)) &&
            (identical(other.tv, tv) ||
                const DeepCollectionEquality().equals(other.tv, tv)) &&
            (identical(other.amp, amp) ||
                const DeepCollectionEquality().equals(other.amp, amp)) &&
            (identical(other.stats, stats) ||
                const DeepCollectionEquality().equals(other.stats, stats)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(physicalAddress) ^
      const DeepCollectionEquality().hash(edid) ^
      const DeepCollectionEquality().hash(volumeLock) ^
      const DeepCollectionEquality().hash(volumeLockMethod) ^
      const DeepCollectionEquality().hash(tv) ^
      const DeepCollectionEquality().hash(amp) ^
      const DeepCollectionEquality().hash(stats) ^
      runtimeType.hashCode;
}

extension $CpeQuicksetPairedDevicesInfoExtension
    on CpeQuicksetPairedDevicesInfo {
  CpeQuicksetPairedDevicesInfo copyWith(
      {String? physicalAddress,
      String? edid,
      int? volumeLock,
      String? volumeLockMethod,
      CpeQuicksetPairedDevicesInfo$Tv? tv,
      CpeQuicksetPairedDevicesInfo$Amp? amp,
      CpeQuicksetPairedDevicesInfo$Stats? stats}) {
    return CpeQuicksetPairedDevicesInfo(
        physicalAddress: physicalAddress ?? this.physicalAddress,
        edid: edid ?? this.edid,
        volumeLock: volumeLock ?? this.volumeLock,
        volumeLockMethod: volumeLockMethod ?? this.volumeLockMethod,
        tv: tv ?? this.tv,
        amp: amp ?? this.amp,
        stats: stats ?? this.stats);
  }

  CpeQuicksetPairedDevicesInfo copyWithWrapped(
      {Wrapped<String>? physicalAddress,
      Wrapped<String>? edid,
      Wrapped<int>? volumeLock,
      Wrapped<String?>? volumeLockMethod,
      Wrapped<CpeQuicksetPairedDevicesInfo$Tv>? tv,
      Wrapped<CpeQuicksetPairedDevicesInfo$Amp>? amp,
      Wrapped<CpeQuicksetPairedDevicesInfo$Stats?>? stats}) {
    return CpeQuicksetPairedDevicesInfo(
        physicalAddress: (physicalAddress != null
            ? physicalAddress.value
            : this.physicalAddress),
        edid: (edid != null ? edid.value : this.edid),
        volumeLock: (volumeLock != null ? volumeLock.value : this.volumeLock),
        volumeLockMethod: (volumeLockMethod != null
            ? volumeLockMethod.value
            : this.volumeLockMethod),
        tv: (tv != null ? tv.value : this.tv),
        amp: (amp != null ? amp.value : this.amp),
        stats: (stats != null ? stats.value : this.stats));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeRebootReason {
  CpeRebootReason({
    required this.reason,
    required this.ts,
  });

  factory CpeRebootReason.fromJson(Map<String, dynamic> json) =>
      _$CpeRebootReasonFromJson(json);

  @JsonKey(name: 'reason', includeIfNull: false, defaultValue: '')
  final String reason;
  @JsonKey(name: 'ts', includeIfNull: false)
  final double ts;
  static const fromJsonFactory = _$CpeRebootReasonFromJson;
  static const toJsonFactory = _$CpeRebootReasonToJson;
  Map<String, dynamic> toJson() => _$CpeRebootReasonToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeRebootReason &&
            (identical(other.reason, reason) ||
                const DeepCollectionEquality().equals(other.reason, reason)) &&
            (identical(other.ts, ts) ||
                const DeepCollectionEquality().equals(other.ts, ts)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(reason) ^
      const DeepCollectionEquality().hash(ts) ^
      runtimeType.hashCode;
}

extension $CpeRebootReasonExtension on CpeRebootReason {
  CpeRebootReason copyWith({String? reason, double? ts}) {
    return CpeRebootReason(reason: reason ?? this.reason, ts: ts ?? this.ts);
  }

  CpeRebootReason copyWithWrapped(
      {Wrapped<String>? reason, Wrapped<double>? ts}) {
    return CpeRebootReason(
        reason: (reason != null ? reason.value : this.reason),
        ts: (ts != null ? ts.value : this.ts));
  }
}

typedef CpeSpeedTestResults = List<CpeSpeedTestResults$Item>;

@JsonSerializable(explicitToJson: true)
class CpeSpeedTestResults$Item {
  CpeSpeedTestResults$Item({
    this.timestamp,
    this.interface,
    this.downstreamBitrate,
    this.upstreamBitrate,
  });

  factory CpeSpeedTestResults$Item.fromJson(Map<String, dynamic> json) =>
      _$CpeSpeedTestResults$ItemFromJson(json);

  @JsonKey(name: 'timestamp', includeIfNull: false)
  final double? timestamp;
  @JsonKey(name: 'interface', includeIfNull: false, defaultValue: '')
  final String? interface;
  @JsonKey(name: 'downstreamBitrate', includeIfNull: false)
  final double? downstreamBitrate;
  @JsonKey(name: 'upstreamBitrate', includeIfNull: false)
  final double? upstreamBitrate;
  static const fromJsonFactory = _$CpeSpeedTestResults$ItemFromJson;
  static const toJsonFactory = _$CpeSpeedTestResults$ItemToJson;
  Map<String, dynamic> toJson() => _$CpeSpeedTestResults$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeSpeedTestResults$Item &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.interface, interface) ||
                const DeepCollectionEquality()
                    .equals(other.interface, interface)) &&
            (identical(other.downstreamBitrate, downstreamBitrate) ||
                const DeepCollectionEquality()
                    .equals(other.downstreamBitrate, downstreamBitrate)) &&
            (identical(other.upstreamBitrate, upstreamBitrate) ||
                const DeepCollectionEquality()
                    .equals(other.upstreamBitrate, upstreamBitrate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(interface) ^
      const DeepCollectionEquality().hash(downstreamBitrate) ^
      const DeepCollectionEquality().hash(upstreamBitrate) ^
      runtimeType.hashCode;
}

extension $CpeSpeedTestResults$ItemExtension on CpeSpeedTestResults$Item {
  CpeSpeedTestResults$Item copyWith(
      {double? timestamp,
      String? interface,
      double? downstreamBitrate,
      double? upstreamBitrate}) {
    return CpeSpeedTestResults$Item(
        timestamp: timestamp ?? this.timestamp,
        interface: interface ?? this.interface,
        downstreamBitrate: downstreamBitrate ?? this.downstreamBitrate,
        upstreamBitrate: upstreamBitrate ?? this.upstreamBitrate);
  }

  CpeSpeedTestResults$Item copyWithWrapped(
      {Wrapped<double?>? timestamp,
      Wrapped<String?>? interface,
      Wrapped<double?>? downstreamBitrate,
      Wrapped<double?>? upstreamBitrate}) {
    return CpeSpeedTestResults$Item(
        timestamp: (timestamp != null ? timestamp.value : this.timestamp),
        interface: (interface != null ? interface.value : this.interface),
        downstreamBitrate: (downstreamBitrate != null
            ? downstreamBitrate.value
            : this.downstreamBitrate),
        upstreamBitrate: (upstreamBitrate != null
            ? upstreamBitrate.value
            : this.upstreamBitrate));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeVolume {
  CpeVolume();

  factory CpeVolume.fromJson(Map<String, dynamic> json) =>
      _$CpeVolumeFromJson(json);

  static const fromJsonFactory = _$CpeVolumeFromJson;
  static const toJsonFactory = _$CpeVolumeToJson;
  Map<String, dynamic> toJson() => _$CpeVolumeToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class CustomerReplayOptInTime {
  CustomerReplayOptInTime();

  factory CustomerReplayOptInTime.fromJson(Map<String, dynamic> json) =>
      _$CustomerReplayOptInTimeFromJson(json);

  static const fromJsonFactory = _$CustomerReplayOptInTimeFromJson;
  static const toJsonFactory = _$CustomerReplayOptInTimeToJson;
  Map<String, dynamic> toJson() => _$CustomerReplayOptInTimeToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

typedef ProfileAccessibleViews = List<Object>;

typedef ProfileRecentlyListenedRadios = List<Object>;
typedef ProfileRecentlyUsedAppsItems = List<Object>;
typedef ProfileRecentlyUsedSettingsItems = List<Object>;

@JsonSerializable(explicitToJson: true)
class ProfileTextToSpeechVoice {
  ProfileTextToSpeechVoice();

  factory ProfileTextToSpeechVoice.fromJson(Map<String, dynamic> json) =>
      _$ProfileTextToSpeechVoiceFromJson(json);

  static const fromJsonFactory = _$ProfileTextToSpeechVoiceFromJson;
  static const toJsonFactory = _$ProfileTextToSpeechVoiceToJson;
  Map<String, dynamic> toJson() => _$ProfileTextToSpeechVoiceToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class ProfileTipsAndTricks {
  ProfileTipsAndTricks({
    required this.ids,
    required this.timestamps,
    this.counters,
  });

  factory ProfileTipsAndTricks.fromJson(Map<String, dynamic> json) =>
      _$ProfileTipsAndTricksFromJson(json);

  @JsonKey(name: 'ids', includeIfNull: false, defaultValue: <String>[])
  final List<String> ids;
  @JsonKey(name: 'timestamps', includeIfNull: false, defaultValue: <double>[])
  final List<double> timestamps;
  @JsonKey(name: 'counters', includeIfNull: false)
  final Map<String, dynamic>? counters;
  static const fromJsonFactory = _$ProfileTipsAndTricksFromJson;
  static const toJsonFactory = _$ProfileTipsAndTricksToJson;
  Map<String, dynamic> toJson() => _$ProfileTipsAndTricksToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProfileTipsAndTricks &&
            (identical(other.ids, ids) ||
                const DeepCollectionEquality().equals(other.ids, ids)) &&
            (identical(other.timestamps, timestamps) ||
                const DeepCollectionEquality()
                    .equals(other.timestamps, timestamps)) &&
            (identical(other.counters, counters) ||
                const DeepCollectionEquality()
                    .equals(other.counters, counters)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ids) ^
      const DeepCollectionEquality().hash(timestamps) ^
      const DeepCollectionEquality().hash(counters) ^
      runtimeType.hashCode;
}

extension $ProfileTipsAndTricksExtension on ProfileTipsAndTricks {
  ProfileTipsAndTricks copyWith(
      {List<String>? ids,
      List<double>? timestamps,
      Map<String, dynamic>? counters}) {
    return ProfileTipsAndTricks(
        ids: ids ?? this.ids,
        timestamps: timestamps ?? this.timestamps,
        counters: counters ?? this.counters);
  }

  ProfileTipsAndTricks copyWithWrapped(
      {Wrapped<List<String>>? ids,
      Wrapped<List<double>>? timestamps,
      Wrapped<Map<String, dynamic>?>? counters}) {
    return ProfileTipsAndTricks(
        ids: (ids != null ? ids.value : this.ids),
        timestamps: (timestamps != null ? timestamps.value : this.timestamps),
        counters: (counters != null ? counters.value : this.counters));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeQuicksetPairedDevicesInfo$Tv {
  CpeQuicksetPairedDevicesInfo$Tv({
    required this.brand,
    required this.model,
    required this.vendorId,
    required this.osd,
    required this.codeset,
    this.codesetBlob,
    required this.discreteCodeset,
    this.discreteCodesetBlob,
    required this.controlRule,
    required this.cecCmdDataPowerOn,
    required this.cecCmdDataPowerOff,
    required this.cecCmdDataInputSelect,
    required this.isPaired,
    required this.pairingMethod,
  });

  factory CpeQuicksetPairedDevicesInfo$Tv.fromJson(Map<String, dynamic> json) =>
      _$CpeQuicksetPairedDevicesInfo$TvFromJson(json);

  @JsonKey(name: 'brand', includeIfNull: false, defaultValue: '')
  final String brand;
  @JsonKey(name: 'model', includeIfNull: false, defaultValue: '')
  final String model;
  @JsonKey(name: 'vendorId', includeIfNull: false, defaultValue: '')
  final String vendorId;
  @JsonKey(name: 'osd', includeIfNull: false, defaultValue: '')
  final String osd;
  @JsonKey(name: 'codeset', includeIfNull: false, defaultValue: '')
  final String codeset;
  @JsonKey(name: 'codesetBlob', includeIfNull: false, defaultValue: '')
  final String? codesetBlob;
  @JsonKey(name: 'discreteCodeset', includeIfNull: false, defaultValue: '')
  final String discreteCodeset;
  @JsonKey(name: 'discreteCodesetBlob', includeIfNull: false, defaultValue: '')
  final String? discreteCodesetBlob;
  @JsonKey(name: 'controlRule', includeIfNull: false, defaultValue: '')
  final String controlRule;
  @JsonKey(name: 'cecCmdDataPowerOn', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOn;
  @JsonKey(name: 'cecCmdDataPowerOff', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOff;
  @JsonKey(
      name: 'cecCmdDataInputSelect', includeIfNull: false, defaultValue: '')
  final String cecCmdDataInputSelect;
  @JsonKey(name: 'isPaired', includeIfNull: false)
  final bool isPaired;
  @JsonKey(name: 'pairingMethod', includeIfNull: false, defaultValue: '')
  final String pairingMethod;
  static const fromJsonFactory = _$CpeQuicksetPairedDevicesInfo$TvFromJson;
  static const toJsonFactory = _$CpeQuicksetPairedDevicesInfo$TvToJson;
  Map<String, dynamic> toJson() =>
      _$CpeQuicksetPairedDevicesInfo$TvToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeQuicksetPairedDevicesInfo$Tv &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)) &&
            (identical(other.model, model) ||
                const DeepCollectionEquality().equals(other.model, model)) &&
            (identical(other.vendorId, vendorId) ||
                const DeepCollectionEquality()
                    .equals(other.vendorId, vendorId)) &&
            (identical(other.osd, osd) ||
                const DeepCollectionEquality().equals(other.osd, osd)) &&
            (identical(other.codeset, codeset) ||
                const DeepCollectionEquality()
                    .equals(other.codeset, codeset)) &&
            (identical(other.codesetBlob, codesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.codesetBlob, codesetBlob)) &&
            (identical(other.discreteCodeset, discreteCodeset) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodeset, discreteCodeset)) &&
            (identical(other.discreteCodesetBlob, discreteCodesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodesetBlob, discreteCodesetBlob)) &&
            (identical(other.controlRule, controlRule) ||
                const DeepCollectionEquality()
                    .equals(other.controlRule, controlRule)) &&
            (identical(other.cecCmdDataPowerOn, cecCmdDataPowerOn) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOn, cecCmdDataPowerOn)) &&
            (identical(other.cecCmdDataPowerOff, cecCmdDataPowerOff) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOff, cecCmdDataPowerOff)) &&
            (identical(other.cecCmdDataInputSelect, cecCmdDataInputSelect) ||
                const DeepCollectionEquality().equals(
                    other.cecCmdDataInputSelect, cecCmdDataInputSelect)) &&
            (identical(other.isPaired, isPaired) ||
                const DeepCollectionEquality()
                    .equals(other.isPaired, isPaired)) &&
            (identical(other.pairingMethod, pairingMethod) ||
                const DeepCollectionEquality()
                    .equals(other.pairingMethod, pairingMethod)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(brand) ^
      const DeepCollectionEquality().hash(model) ^
      const DeepCollectionEquality().hash(vendorId) ^
      const DeepCollectionEquality().hash(osd) ^
      const DeepCollectionEquality().hash(codeset) ^
      const DeepCollectionEquality().hash(codesetBlob) ^
      const DeepCollectionEquality().hash(discreteCodeset) ^
      const DeepCollectionEquality().hash(discreteCodesetBlob) ^
      const DeepCollectionEquality().hash(controlRule) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOn) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOff) ^
      const DeepCollectionEquality().hash(cecCmdDataInputSelect) ^
      const DeepCollectionEquality().hash(isPaired) ^
      const DeepCollectionEquality().hash(pairingMethod) ^
      runtimeType.hashCode;
}

extension $CpeQuicksetPairedDevicesInfo$TvExtension
    on CpeQuicksetPairedDevicesInfo$Tv {
  CpeQuicksetPairedDevicesInfo$Tv copyWith(
      {String? brand,
      String? model,
      String? vendorId,
      String? osd,
      String? codeset,
      String? codesetBlob,
      String? discreteCodeset,
      String? discreteCodesetBlob,
      String? controlRule,
      String? cecCmdDataPowerOn,
      String? cecCmdDataPowerOff,
      String? cecCmdDataInputSelect,
      bool? isPaired,
      String? pairingMethod}) {
    return CpeQuicksetPairedDevicesInfo$Tv(
        brand: brand ?? this.brand,
        model: model ?? this.model,
        vendorId: vendorId ?? this.vendorId,
        osd: osd ?? this.osd,
        codeset: codeset ?? this.codeset,
        codesetBlob: codesetBlob ?? this.codesetBlob,
        discreteCodeset: discreteCodeset ?? this.discreteCodeset,
        discreteCodesetBlob: discreteCodesetBlob ?? this.discreteCodesetBlob,
        controlRule: controlRule ?? this.controlRule,
        cecCmdDataPowerOn: cecCmdDataPowerOn ?? this.cecCmdDataPowerOn,
        cecCmdDataPowerOff: cecCmdDataPowerOff ?? this.cecCmdDataPowerOff,
        cecCmdDataInputSelect:
            cecCmdDataInputSelect ?? this.cecCmdDataInputSelect,
        isPaired: isPaired ?? this.isPaired,
        pairingMethod: pairingMethod ?? this.pairingMethod);
  }

  CpeQuicksetPairedDevicesInfo$Tv copyWithWrapped(
      {Wrapped<String>? brand,
      Wrapped<String>? model,
      Wrapped<String>? vendorId,
      Wrapped<String>? osd,
      Wrapped<String>? codeset,
      Wrapped<String?>? codesetBlob,
      Wrapped<String>? discreteCodeset,
      Wrapped<String?>? discreteCodesetBlob,
      Wrapped<String>? controlRule,
      Wrapped<String>? cecCmdDataPowerOn,
      Wrapped<String>? cecCmdDataPowerOff,
      Wrapped<String>? cecCmdDataInputSelect,
      Wrapped<bool>? isPaired,
      Wrapped<String>? pairingMethod}) {
    return CpeQuicksetPairedDevicesInfo$Tv(
        brand: (brand != null ? brand.value : this.brand),
        model: (model != null ? model.value : this.model),
        vendorId: (vendorId != null ? vendorId.value : this.vendorId),
        osd: (osd != null ? osd.value : this.osd),
        codeset: (codeset != null ? codeset.value : this.codeset),
        codesetBlob:
            (codesetBlob != null ? codesetBlob.value : this.codesetBlob),
        discreteCodeset: (discreteCodeset != null
            ? discreteCodeset.value
            : this.discreteCodeset),
        discreteCodesetBlob: (discreteCodesetBlob != null
            ? discreteCodesetBlob.value
            : this.discreteCodesetBlob),
        controlRule:
            (controlRule != null ? controlRule.value : this.controlRule),
        cecCmdDataPowerOn: (cecCmdDataPowerOn != null
            ? cecCmdDataPowerOn.value
            : this.cecCmdDataPowerOn),
        cecCmdDataPowerOff: (cecCmdDataPowerOff != null
            ? cecCmdDataPowerOff.value
            : this.cecCmdDataPowerOff),
        cecCmdDataInputSelect: (cecCmdDataInputSelect != null
            ? cecCmdDataInputSelect.value
            : this.cecCmdDataInputSelect),
        isPaired: (isPaired != null ? isPaired.value : this.isPaired),
        pairingMethod:
            (pairingMethod != null ? pairingMethod.value : this.pairingMethod));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeQuicksetPairedDevicesInfo$Amp {
  CpeQuicksetPairedDevicesInfo$Amp({
    required this.brand,
    required this.model,
    required this.vendorId,
    required this.osd,
    required this.codeset,
    this.codesetBlob,
    required this.discreteCodeset,
    this.discreteCodesetBlob,
    required this.controlRule,
    required this.cecCmdDataPowerOn,
    required this.cecCmdDataPowerOff,
    required this.cecCmdDataInputSelect,
    required this.isPaired,
    required this.pairingMethod,
  });

  factory CpeQuicksetPairedDevicesInfo$Amp.fromJson(
          Map<String, dynamic> json) =>
      _$CpeQuicksetPairedDevicesInfo$AmpFromJson(json);

  @JsonKey(name: 'brand', includeIfNull: false, defaultValue: '')
  final String brand;
  @JsonKey(name: 'model', includeIfNull: false, defaultValue: '')
  final String model;
  @JsonKey(name: 'vendorId', includeIfNull: false, defaultValue: '')
  final String vendorId;
  @JsonKey(name: 'osd', includeIfNull: false, defaultValue: '')
  final String osd;
  @JsonKey(name: 'codeset', includeIfNull: false, defaultValue: '')
  final String codeset;
  @JsonKey(name: 'codesetBlob', includeIfNull: false, defaultValue: '')
  final String? codesetBlob;
  @JsonKey(name: 'discreteCodeset', includeIfNull: false, defaultValue: '')
  final String discreteCodeset;
  @JsonKey(name: 'discreteCodesetBlob', includeIfNull: false, defaultValue: '')
  final String? discreteCodesetBlob;
  @JsonKey(name: 'controlRule', includeIfNull: false, defaultValue: '')
  final String controlRule;
  @JsonKey(name: 'cecCmdDataPowerOn', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOn;
  @JsonKey(name: 'cecCmdDataPowerOff', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOff;
  @JsonKey(
      name: 'cecCmdDataInputSelect', includeIfNull: false, defaultValue: '')
  final String cecCmdDataInputSelect;
  @JsonKey(name: 'isPaired', includeIfNull: false)
  final bool isPaired;
  @JsonKey(name: 'pairingMethod', includeIfNull: false, defaultValue: '')
  final String pairingMethod;
  static const fromJsonFactory = _$CpeQuicksetPairedDevicesInfo$AmpFromJson;
  static const toJsonFactory = _$CpeQuicksetPairedDevicesInfo$AmpToJson;
  Map<String, dynamic> toJson() =>
      _$CpeQuicksetPairedDevicesInfo$AmpToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeQuicksetPairedDevicesInfo$Amp &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)) &&
            (identical(other.model, model) ||
                const DeepCollectionEquality().equals(other.model, model)) &&
            (identical(other.vendorId, vendorId) ||
                const DeepCollectionEquality()
                    .equals(other.vendorId, vendorId)) &&
            (identical(other.osd, osd) ||
                const DeepCollectionEquality().equals(other.osd, osd)) &&
            (identical(other.codeset, codeset) ||
                const DeepCollectionEquality()
                    .equals(other.codeset, codeset)) &&
            (identical(other.codesetBlob, codesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.codesetBlob, codesetBlob)) &&
            (identical(other.discreteCodeset, discreteCodeset) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodeset, discreteCodeset)) &&
            (identical(other.discreteCodesetBlob, discreteCodesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodesetBlob, discreteCodesetBlob)) &&
            (identical(other.controlRule, controlRule) ||
                const DeepCollectionEquality()
                    .equals(other.controlRule, controlRule)) &&
            (identical(other.cecCmdDataPowerOn, cecCmdDataPowerOn) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOn, cecCmdDataPowerOn)) &&
            (identical(other.cecCmdDataPowerOff, cecCmdDataPowerOff) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOff, cecCmdDataPowerOff)) &&
            (identical(other.cecCmdDataInputSelect, cecCmdDataInputSelect) ||
                const DeepCollectionEquality().equals(
                    other.cecCmdDataInputSelect, cecCmdDataInputSelect)) &&
            (identical(other.isPaired, isPaired) ||
                const DeepCollectionEquality()
                    .equals(other.isPaired, isPaired)) &&
            (identical(other.pairingMethod, pairingMethod) ||
                const DeepCollectionEquality()
                    .equals(other.pairingMethod, pairingMethod)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(brand) ^
      const DeepCollectionEquality().hash(model) ^
      const DeepCollectionEquality().hash(vendorId) ^
      const DeepCollectionEquality().hash(osd) ^
      const DeepCollectionEquality().hash(codeset) ^
      const DeepCollectionEquality().hash(codesetBlob) ^
      const DeepCollectionEquality().hash(discreteCodeset) ^
      const DeepCollectionEquality().hash(discreteCodesetBlob) ^
      const DeepCollectionEquality().hash(controlRule) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOn) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOff) ^
      const DeepCollectionEquality().hash(cecCmdDataInputSelect) ^
      const DeepCollectionEquality().hash(isPaired) ^
      const DeepCollectionEquality().hash(pairingMethod) ^
      runtimeType.hashCode;
}

extension $CpeQuicksetPairedDevicesInfo$AmpExtension
    on CpeQuicksetPairedDevicesInfo$Amp {
  CpeQuicksetPairedDevicesInfo$Amp copyWith(
      {String? brand,
      String? model,
      String? vendorId,
      String? osd,
      String? codeset,
      String? codesetBlob,
      String? discreteCodeset,
      String? discreteCodesetBlob,
      String? controlRule,
      String? cecCmdDataPowerOn,
      String? cecCmdDataPowerOff,
      String? cecCmdDataInputSelect,
      bool? isPaired,
      String? pairingMethod}) {
    return CpeQuicksetPairedDevicesInfo$Amp(
        brand: brand ?? this.brand,
        model: model ?? this.model,
        vendorId: vendorId ?? this.vendorId,
        osd: osd ?? this.osd,
        codeset: codeset ?? this.codeset,
        codesetBlob: codesetBlob ?? this.codesetBlob,
        discreteCodeset: discreteCodeset ?? this.discreteCodeset,
        discreteCodesetBlob: discreteCodesetBlob ?? this.discreteCodesetBlob,
        controlRule: controlRule ?? this.controlRule,
        cecCmdDataPowerOn: cecCmdDataPowerOn ?? this.cecCmdDataPowerOn,
        cecCmdDataPowerOff: cecCmdDataPowerOff ?? this.cecCmdDataPowerOff,
        cecCmdDataInputSelect:
            cecCmdDataInputSelect ?? this.cecCmdDataInputSelect,
        isPaired: isPaired ?? this.isPaired,
        pairingMethod: pairingMethod ?? this.pairingMethod);
  }

  CpeQuicksetPairedDevicesInfo$Amp copyWithWrapped(
      {Wrapped<String>? brand,
      Wrapped<String>? model,
      Wrapped<String>? vendorId,
      Wrapped<String>? osd,
      Wrapped<String>? codeset,
      Wrapped<String?>? codesetBlob,
      Wrapped<String>? discreteCodeset,
      Wrapped<String?>? discreteCodesetBlob,
      Wrapped<String>? controlRule,
      Wrapped<String>? cecCmdDataPowerOn,
      Wrapped<String>? cecCmdDataPowerOff,
      Wrapped<String>? cecCmdDataInputSelect,
      Wrapped<bool>? isPaired,
      Wrapped<String>? pairingMethod}) {
    return CpeQuicksetPairedDevicesInfo$Amp(
        brand: (brand != null ? brand.value : this.brand),
        model: (model != null ? model.value : this.model),
        vendorId: (vendorId != null ? vendorId.value : this.vendorId),
        osd: (osd != null ? osd.value : this.osd),
        codeset: (codeset != null ? codeset.value : this.codeset),
        codesetBlob:
            (codesetBlob != null ? codesetBlob.value : this.codesetBlob),
        discreteCodeset: (discreteCodeset != null
            ? discreteCodeset.value
            : this.discreteCodeset),
        discreteCodesetBlob: (discreteCodesetBlob != null
            ? discreteCodesetBlob.value
            : this.discreteCodesetBlob),
        controlRule:
            (controlRule != null ? controlRule.value : this.controlRule),
        cecCmdDataPowerOn: (cecCmdDataPowerOn != null
            ? cecCmdDataPowerOn.value
            : this.cecCmdDataPowerOn),
        cecCmdDataPowerOff: (cecCmdDataPowerOff != null
            ? cecCmdDataPowerOff.value
            : this.cecCmdDataPowerOff),
        cecCmdDataInputSelect: (cecCmdDataInputSelect != null
            ? cecCmdDataInputSelect.value
            : this.cecCmdDataInputSelect),
        isPaired: (isPaired != null ? isPaired.value : this.isPaired),
        pairingMethod:
            (pairingMethod != null ? pairingMethod.value : this.pairingMethod));
  }
}

@JsonSerializable(explicitToJson: true)
class CpeQuicksetPairedDevicesInfo$Stats {
  CpeQuicksetPairedDevicesInfo$Stats({
    required this.edidDiscoveryCount,
    required this.cecDiscoveryCount,
    required this.createSessionCount,
    required this.autoLookupCount,
    required this.getPickCount,
    required this.getControlRuleCount,
  });

  factory CpeQuicksetPairedDevicesInfo$Stats.fromJson(
          Map<String, dynamic> json) =>
      _$CpeQuicksetPairedDevicesInfo$StatsFromJson(json);

  @JsonKey(name: 'edidDiscoveryCount', includeIfNull: false)
  final int edidDiscoveryCount;
  @JsonKey(name: 'cecDiscoveryCount', includeIfNull: false)
  final int cecDiscoveryCount;
  @JsonKey(name: 'createSessionCount', includeIfNull: false)
  final int createSessionCount;
  @JsonKey(name: 'autoLookupCount', includeIfNull: false)
  final int autoLookupCount;
  @JsonKey(name: 'getPickCount', includeIfNull: false)
  final int getPickCount;
  @JsonKey(name: 'getControlRuleCount', includeIfNull: false)
  final int getControlRuleCount;
  static const fromJsonFactory = _$CpeQuicksetPairedDevicesInfo$StatsFromJson;
  static const toJsonFactory = _$CpeQuicksetPairedDevicesInfo$StatsToJson;
  Map<String, dynamic> toJson() =>
      _$CpeQuicksetPairedDevicesInfo$StatsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CpeQuicksetPairedDevicesInfo$Stats &&
            (identical(other.edidDiscoveryCount, edidDiscoveryCount) ||
                const DeepCollectionEquality()
                    .equals(other.edidDiscoveryCount, edidDiscoveryCount)) &&
            (identical(other.cecDiscoveryCount, cecDiscoveryCount) ||
                const DeepCollectionEquality()
                    .equals(other.cecDiscoveryCount, cecDiscoveryCount)) &&
            (identical(other.createSessionCount, createSessionCount) ||
                const DeepCollectionEquality()
                    .equals(other.createSessionCount, createSessionCount)) &&
            (identical(other.autoLookupCount, autoLookupCount) ||
                const DeepCollectionEquality()
                    .equals(other.autoLookupCount, autoLookupCount)) &&
            (identical(other.getPickCount, getPickCount) ||
                const DeepCollectionEquality()
                    .equals(other.getPickCount, getPickCount)) &&
            (identical(other.getControlRuleCount, getControlRuleCount) ||
                const DeepCollectionEquality()
                    .equals(other.getControlRuleCount, getControlRuleCount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(edidDiscoveryCount) ^
      const DeepCollectionEquality().hash(cecDiscoveryCount) ^
      const DeepCollectionEquality().hash(createSessionCount) ^
      const DeepCollectionEquality().hash(autoLookupCount) ^
      const DeepCollectionEquality().hash(getPickCount) ^
      const DeepCollectionEquality().hash(getControlRuleCount) ^
      runtimeType.hashCode;
}

extension $CpeQuicksetPairedDevicesInfo$StatsExtension
    on CpeQuicksetPairedDevicesInfo$Stats {
  CpeQuicksetPairedDevicesInfo$Stats copyWith(
      {int? edidDiscoveryCount,
      int? cecDiscoveryCount,
      int? createSessionCount,
      int? autoLookupCount,
      int? getPickCount,
      int? getControlRuleCount}) {
    return CpeQuicksetPairedDevicesInfo$Stats(
        edidDiscoveryCount: edidDiscoveryCount ?? this.edidDiscoveryCount,
        cecDiscoveryCount: cecDiscoveryCount ?? this.cecDiscoveryCount,
        createSessionCount: createSessionCount ?? this.createSessionCount,
        autoLookupCount: autoLookupCount ?? this.autoLookupCount,
        getPickCount: getPickCount ?? this.getPickCount,
        getControlRuleCount: getControlRuleCount ?? this.getControlRuleCount);
  }

  CpeQuicksetPairedDevicesInfo$Stats copyWithWrapped(
      {Wrapped<int>? edidDiscoveryCount,
      Wrapped<int>? cecDiscoveryCount,
      Wrapped<int>? createSessionCount,
      Wrapped<int>? autoLookupCount,
      Wrapped<int>? getPickCount,
      Wrapped<int>? getControlRuleCount}) {
    return CpeQuicksetPairedDevicesInfo$Stats(
        edidDiscoveryCount: (edidDiscoveryCount != null
            ? edidDiscoveryCount.value
            : this.edidDiscoveryCount),
        cecDiscoveryCount: (cecDiscoveryCount != null
            ? cecDiscoveryCount.value
            : this.cecDiscoveryCount),
        createSessionCount: (createSessionCount != null
            ? createSessionCount.value
            : this.createSessionCount),
        autoLookupCount: (autoLookupCount != null
            ? autoLookupCount.value
            : this.autoLookupCount),
        getPickCount:
            (getPickCount != null ? getPickCount.value : this.getPickCount),
        getControlRuleCount: (getControlRuleCount != null
            ? getControlRuleCount.value
            : this.getControlRuleCount));
  }
}

String? keyToJson(enums.Key? key) {
  return enums.$KeyMap[key];
}

enums.Key keyFromJson(
  Object? key, [
  enums.Key? defaultValue,
]) {
  if (key is String) {
    return enums.$KeyMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == key.toLowerCase(),
            orElse: () => const MapEntry(enums.Key.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$KeyMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.Key.swaggerGeneratedUnknown;
}

List<String> keyListToJson(List<enums.Key>? key) {
  if (key == null) {
    return [];
  }

  return key.map((e) => enums.$KeyMap[e]!).toList();
}

List<enums.Key> keyListFromJson(
  List? key, [
  List<enums.Key>? defaultValue,
]) {
  if (key == null) {
    return defaultValue ?? [];
  }

  return key.map((e) => keyFromJson(e.toString())).toList();
}

List<enums.Key>? keyNullableListFromJson(
  List? key, [
  List<enums.Key>? defaultValue,
]) {
  if (key == null) {
    return defaultValue;
  }

  return key.map((e) => keyFromJson(e.toString())).toList();
}

String? remoteKeyToJson(enums.RemoteKey? remoteKey) {
  return enums.$RemoteKeyMap[remoteKey];
}

enums.RemoteKey remoteKeyFromJson(
  Object? remoteKey, [
  enums.RemoteKey? defaultValue,
]) {
  if (remoteKey is String) {
    return enums.$RemoteKeyMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == remoteKey.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.RemoteKey.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RemoteKeyMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RemoteKey.swaggerGeneratedUnknown;
}

List<String> remoteKeyListToJson(List<enums.RemoteKey>? remoteKey) {
  if (remoteKey == null) {
    return [];
  }

  return remoteKey.map((e) => enums.$RemoteKeyMap[e]!).toList();
}

List<enums.RemoteKey> remoteKeyListFromJson(
  List? remoteKey, [
  List<enums.RemoteKey>? defaultValue,
]) {
  if (remoteKey == null) {
    return defaultValue ?? [];
  }

  return remoteKey.map((e) => remoteKeyFromJson(e.toString())).toList();
}

List<enums.RemoteKey>? remoteKeyNullableListFromJson(
  List? remoteKey, [
  List<enums.RemoteKey>? defaultValue,
]) {
  if (remoteKey == null) {
    return defaultValue;
  }

  return remoteKey.map((e) => remoteKeyFromJson(e.toString())).toList();
}

String? cpe16by9HandlingToJson(enums.Cpe16by9Handling? cpe16by9Handling) {
  return enums.$Cpe16by9HandlingMap[cpe16by9Handling];
}

enums.Cpe16by9Handling cpe16by9HandlingFromJson(
  Object? cpe16by9Handling, [
  enums.Cpe16by9Handling? defaultValue,
]) {
  if (cpe16by9Handling is String) {
    return enums.$Cpe16by9HandlingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpe16by9Handling.toLowerCase(),
            orElse: () => const MapEntry(
                enums.Cpe16by9Handling.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$Cpe16by9HandlingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.Cpe16by9Handling.swaggerGeneratedUnknown;
}

List<String> cpe16by9HandlingListToJson(
    List<enums.Cpe16by9Handling>? cpe16by9Handling) {
  if (cpe16by9Handling == null) {
    return [];
  }

  return cpe16by9Handling.map((e) => enums.$Cpe16by9HandlingMap[e]!).toList();
}

List<enums.Cpe16by9Handling> cpe16by9HandlingListFromJson(
  List? cpe16by9Handling, [
  List<enums.Cpe16by9Handling>? defaultValue,
]) {
  if (cpe16by9Handling == null) {
    return defaultValue ?? [];
  }

  return cpe16by9Handling
      .map((e) => cpe16by9HandlingFromJson(e.toString()))
      .toList();
}

List<enums.Cpe16by9Handling>? cpe16by9HandlingNullableListFromJson(
  List? cpe16by9Handling, [
  List<enums.Cpe16by9Handling>? defaultValue,
]) {
  if (cpe16by9Handling == null) {
    return defaultValue;
  }

  return cpe16by9Handling
      .map((e) => cpe16by9HandlingFromJson(e.toString()))
      .toList();
}

String? cpe4by3HandlingToJson(enums.Cpe4by3Handling? cpe4by3Handling) {
  return enums.$Cpe4by3HandlingMap[cpe4by3Handling];
}

enums.Cpe4by3Handling cpe4by3HandlingFromJson(
  Object? cpe4by3Handling, [
  enums.Cpe4by3Handling? defaultValue,
]) {
  if (cpe4by3Handling is String) {
    return enums.$Cpe4by3HandlingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpe4by3Handling.toLowerCase(),
            orElse: () => const MapEntry(
                enums.Cpe4by3Handling.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$Cpe4by3HandlingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.Cpe4by3Handling.swaggerGeneratedUnknown;
}

List<String> cpe4by3HandlingListToJson(
    List<enums.Cpe4by3Handling>? cpe4by3Handling) {
  if (cpe4by3Handling == null) {
    return [];
  }

  return cpe4by3Handling.map((e) => enums.$Cpe4by3HandlingMap[e]!).toList();
}

List<enums.Cpe4by3Handling> cpe4by3HandlingListFromJson(
  List? cpe4by3Handling, [
  List<enums.Cpe4by3Handling>? defaultValue,
]) {
  if (cpe4by3Handling == null) {
    return defaultValue ?? [];
  }

  return cpe4by3Handling
      .map((e) => cpe4by3HandlingFromJson(e.toString()))
      .toList();
}

List<enums.Cpe4by3Handling>? cpe4by3HandlingNullableListFromJson(
  List? cpe4by3Handling, [
  List<enums.Cpe4by3Handling>? defaultValue,
]) {
  if (cpe4by3Handling == null) {
    return defaultValue;
  }

  return cpe4by3Handling
      .map((e) => cpe4by3HandlingFromJson(e.toString()))
      .toList();
}

String? cpeAspectRatioToJson(enums.CpeAspectRatio? cpeAspectRatio) {
  return enums.$CpeAspectRatioMap[cpeAspectRatio];
}

enums.CpeAspectRatio cpeAspectRatioFromJson(
  Object? cpeAspectRatio, [
  enums.CpeAspectRatio? defaultValue,
]) {
  if (cpeAspectRatio is String) {
    return enums.$CpeAspectRatioMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeAspectRatio.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeAspectRatio.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeAspectRatioMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeAspectRatio.swaggerGeneratedUnknown;
}

List<String> cpeAspectRatioListToJson(
    List<enums.CpeAspectRatio>? cpeAspectRatio) {
  if (cpeAspectRatio == null) {
    return [];
  }

  return cpeAspectRatio.map((e) => enums.$CpeAspectRatioMap[e]!).toList();
}

List<enums.CpeAspectRatio> cpeAspectRatioListFromJson(
  List? cpeAspectRatio, [
  List<enums.CpeAspectRatio>? defaultValue,
]) {
  if (cpeAspectRatio == null) {
    return defaultValue ?? [];
  }

  return cpeAspectRatio
      .map((e) => cpeAspectRatioFromJson(e.toString()))
      .toList();
}

List<enums.CpeAspectRatio>? cpeAspectRatioNullableListFromJson(
  List? cpeAspectRatio, [
  List<enums.CpeAspectRatio>? defaultValue,
]) {
  if (cpeAspectRatio == null) {
    return defaultValue;
  }

  return cpeAspectRatio
      .map((e) => cpeAspectRatioFromJson(e.toString()))
      .toList();
}

String? cpeAudioDolbyDigitalModeToJson(
    enums.CpeAudioDolbyDigitalMode? cpeAudioDolbyDigitalMode) {
  return enums.$CpeAudioDolbyDigitalModeMap[cpeAudioDolbyDigitalMode];
}

enums.CpeAudioDolbyDigitalMode cpeAudioDolbyDigitalModeFromJson(
  Object? cpeAudioDolbyDigitalMode, [
  enums.CpeAudioDolbyDigitalMode? defaultValue,
]) {
  if (cpeAudioDolbyDigitalMode is String) {
    return enums.$CpeAudioDolbyDigitalModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpeAudioDolbyDigitalMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeAudioDolbyDigitalMode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeAudioDolbyDigitalModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeAudioDolbyDigitalMode.swaggerGeneratedUnknown;
}

List<String> cpeAudioDolbyDigitalModeListToJson(
    List<enums.CpeAudioDolbyDigitalMode>? cpeAudioDolbyDigitalMode) {
  if (cpeAudioDolbyDigitalMode == null) {
    return [];
  }

  return cpeAudioDolbyDigitalMode
      .map((e) => enums.$CpeAudioDolbyDigitalModeMap[e]!)
      .toList();
}

List<enums.CpeAudioDolbyDigitalMode> cpeAudioDolbyDigitalModeListFromJson(
  List? cpeAudioDolbyDigitalMode, [
  List<enums.CpeAudioDolbyDigitalMode>? defaultValue,
]) {
  if (cpeAudioDolbyDigitalMode == null) {
    return defaultValue ?? [];
  }

  return cpeAudioDolbyDigitalMode
      .map((e) => cpeAudioDolbyDigitalModeFromJson(e.toString()))
      .toList();
}

List<enums.CpeAudioDolbyDigitalMode>?
    cpeAudioDolbyDigitalModeNullableListFromJson(
  List? cpeAudioDolbyDigitalMode, [
  List<enums.CpeAudioDolbyDigitalMode>? defaultValue,
]) {
  if (cpeAudioDolbyDigitalMode == null) {
    return defaultValue;
  }

  return cpeAudioDolbyDigitalMode
      .map((e) => cpeAudioDolbyDigitalModeFromJson(e.toString()))
      .toList();
}

int? cpeAutoStandbyToJson(enums.CpeAutoStandby? cpeAutoStandby) {
  return enums.$CpeAutoStandbyMap[cpeAutoStandby];
}

enums.CpeAutoStandby cpeAutoStandbyFromJson(
  Object? cpeAutoStandby, [
  enums.CpeAutoStandby? defaultValue,
]) {
  if (cpeAutoStandby is int) {
    return enums.$CpeAutoStandbyMap.entries
        .firstWhere((element) => element.value == cpeAutoStandby,
            orElse: () =>
                const MapEntry(enums.CpeAutoStandby.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeAutoStandbyMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeAutoStandby.swaggerGeneratedUnknown;
}

List<int> cpeAutoStandbyListToJson(List<enums.CpeAutoStandby>? cpeAutoStandby) {
  if (cpeAutoStandby == null) {
    return [];
  }

  return cpeAutoStandby.map((e) => enums.$CpeAutoStandbyMap[e]!).toList();
}

List<enums.CpeAutoStandby> cpeAutoStandbyListFromJson(
  List? cpeAutoStandby, [
  List<enums.CpeAutoStandby>? defaultValue,
]) {
  if (cpeAutoStandby == null) {
    return defaultValue ?? [];
  }

  return cpeAutoStandby
      .map((e) => cpeAutoStandbyFromJson(e.toString()))
      .toList();
}

List<enums.CpeAutoStandby>? cpeAutoStandbyNullableListFromJson(
  List? cpeAutoStandby, [
  List<enums.CpeAutoStandby>? defaultValue,
]) {
  if (cpeAutoStandby == null) {
    return defaultValue;
  }

  return cpeAutoStandby
      .map((e) => cpeAutoStandbyFromJson(e.toString()))
      .toList();
}

String? cpeCcAnalogServiceToJson(enums.CpeCcAnalogService? cpeCcAnalogService) {
  return enums.$CpeCcAnalogServiceMap[cpeCcAnalogService];
}

enums.CpeCcAnalogService cpeCcAnalogServiceFromJson(
  Object? cpeCcAnalogService, [
  enums.CpeCcAnalogService? defaultValue,
]) {
  if (cpeCcAnalogService is String) {
    return enums.$CpeCcAnalogServiceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeCcAnalogService.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeCcAnalogService.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeCcAnalogServiceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeCcAnalogService.swaggerGeneratedUnknown;
}

List<String> cpeCcAnalogServiceListToJson(
    List<enums.CpeCcAnalogService>? cpeCcAnalogService) {
  if (cpeCcAnalogService == null) {
    return [];
  }

  return cpeCcAnalogService
      .map((e) => enums.$CpeCcAnalogServiceMap[e]!)
      .toList();
}

List<enums.CpeCcAnalogService> cpeCcAnalogServiceListFromJson(
  List? cpeCcAnalogService, [
  List<enums.CpeCcAnalogService>? defaultValue,
]) {
  if (cpeCcAnalogService == null) {
    return defaultValue ?? [];
  }

  return cpeCcAnalogService
      .map((e) => cpeCcAnalogServiceFromJson(e.toString()))
      .toList();
}

List<enums.CpeCcAnalogService>? cpeCcAnalogServiceNullableListFromJson(
  List? cpeCcAnalogService, [
  List<enums.CpeCcAnalogService>? defaultValue,
]) {
  if (cpeCcAnalogService == null) {
    return defaultValue;
  }

  return cpeCcAnalogService
      .map((e) => cpeCcAnalogServiceFromJson(e.toString()))
      .toList();
}

String? cpeCcDigitalServiceToJson(
    enums.CpeCcDigitalService? cpeCcDigitalService) {
  return enums.$CpeCcDigitalServiceMap[cpeCcDigitalService];
}

enums.CpeCcDigitalService cpeCcDigitalServiceFromJson(
  Object? cpeCcDigitalService, [
  enums.CpeCcDigitalService? defaultValue,
]) {
  if (cpeCcDigitalService is String) {
    return enums.$CpeCcDigitalServiceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpeCcDigitalService.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeCcDigitalService.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeCcDigitalServiceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeCcDigitalService.swaggerGeneratedUnknown;
}

List<String> cpeCcDigitalServiceListToJson(
    List<enums.CpeCcDigitalService>? cpeCcDigitalService) {
  if (cpeCcDigitalService == null) {
    return [];
  }

  return cpeCcDigitalService
      .map((e) => enums.$CpeCcDigitalServiceMap[e]!)
      .toList();
}

List<enums.CpeCcDigitalService> cpeCcDigitalServiceListFromJson(
  List? cpeCcDigitalService, [
  List<enums.CpeCcDigitalService>? defaultValue,
]) {
  if (cpeCcDigitalService == null) {
    return defaultValue ?? [];
  }

  return cpeCcDigitalService
      .map((e) => cpeCcDigitalServiceFromJson(e.toString()))
      .toList();
}

List<enums.CpeCcDigitalService>? cpeCcDigitalServiceNullableListFromJson(
  List? cpeCcDigitalService, [
  List<enums.CpeCcDigitalService>? defaultValue,
]) {
  if (cpeCcDigitalService == null) {
    return defaultValue;
  }

  return cpeCcDigitalService
      .map((e) => cpeCcDigitalServiceFromJson(e.toString()))
      .toList();
}

String? cpeFactoryResetStateToJson(
    enums.CpeFactoryResetState? cpeFactoryResetState) {
  return enums.$CpeFactoryResetStateMap[cpeFactoryResetState];
}

enums.CpeFactoryResetState cpeFactoryResetStateFromJson(
  Object? cpeFactoryResetState, [
  enums.CpeFactoryResetState? defaultValue,
]) {
  if (cpeFactoryResetState is String) {
    return enums.$CpeFactoryResetStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpeFactoryResetState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeFactoryResetState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeFactoryResetStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeFactoryResetState.swaggerGeneratedUnknown;
}

List<String> cpeFactoryResetStateListToJson(
    List<enums.CpeFactoryResetState>? cpeFactoryResetState) {
  if (cpeFactoryResetState == null) {
    return [];
  }

  return cpeFactoryResetState
      .map((e) => enums.$CpeFactoryResetStateMap[e]!)
      .toList();
}

List<enums.CpeFactoryResetState> cpeFactoryResetStateListFromJson(
  List? cpeFactoryResetState, [
  List<enums.CpeFactoryResetState>? defaultValue,
]) {
  if (cpeFactoryResetState == null) {
    return defaultValue ?? [];
  }

  return cpeFactoryResetState
      .map((e) => cpeFactoryResetStateFromJson(e.toString()))
      .toList();
}

List<enums.CpeFactoryResetState>? cpeFactoryResetStateNullableListFromJson(
  List? cpeFactoryResetState, [
  List<enums.CpeFactoryResetState>? defaultValue,
]) {
  if (cpeFactoryResetState == null) {
    return defaultValue;
  }

  return cpeFactoryResetState
      .map((e) => cpeFactoryResetStateFromJson(e.toString()))
      .toList();
}

String? cpeFactoryResetTypeToJson(
    enums.CpeFactoryResetType? cpeFactoryResetType) {
  return enums.$CpeFactoryResetTypeMap[cpeFactoryResetType];
}

enums.CpeFactoryResetType cpeFactoryResetTypeFromJson(
  Object? cpeFactoryResetType, [
  enums.CpeFactoryResetType? defaultValue,
]) {
  if (cpeFactoryResetType is String) {
    return enums.$CpeFactoryResetTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpeFactoryResetType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeFactoryResetType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeFactoryResetTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeFactoryResetType.swaggerGeneratedUnknown;
}

List<String> cpeFactoryResetTypeListToJson(
    List<enums.CpeFactoryResetType>? cpeFactoryResetType) {
  if (cpeFactoryResetType == null) {
    return [];
  }

  return cpeFactoryResetType
      .map((e) => enums.$CpeFactoryResetTypeMap[e]!)
      .toList();
}

List<enums.CpeFactoryResetType> cpeFactoryResetTypeListFromJson(
  List? cpeFactoryResetType, [
  List<enums.CpeFactoryResetType>? defaultValue,
]) {
  if (cpeFactoryResetType == null) {
    return defaultValue ?? [];
  }

  return cpeFactoryResetType
      .map((e) => cpeFactoryResetTypeFromJson(e.toString()))
      .toList();
}

List<enums.CpeFactoryResetType>? cpeFactoryResetTypeNullableListFromJson(
  List? cpeFactoryResetType, [
  List<enums.CpeFactoryResetType>? defaultValue,
]) {
  if (cpeFactoryResetType == null) {
    return defaultValue;
  }

  return cpeFactoryResetType
      .map((e) => cpeFactoryResetTypeFromJson(e.toString()))
      .toList();
}

String? cpeFtiStateToJson(enums.CpeFtiState? cpeFtiState) {
  return enums.$CpeFtiStateMap[cpeFtiState];
}

enums.CpeFtiState cpeFtiStateFromJson(
  Object? cpeFtiState, [
  enums.CpeFtiState? defaultValue,
]) {
  if (cpeFtiState is String) {
    return enums.$CpeFtiStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeFtiState.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.CpeFtiState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeFtiStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeFtiState.swaggerGeneratedUnknown;
}

List<String> cpeFtiStateListToJson(List<enums.CpeFtiState>? cpeFtiState) {
  if (cpeFtiState == null) {
    return [];
  }

  return cpeFtiState.map((e) => enums.$CpeFtiStateMap[e]!).toList();
}

List<enums.CpeFtiState> cpeFtiStateListFromJson(
  List? cpeFtiState, [
  List<enums.CpeFtiState>? defaultValue,
]) {
  if (cpeFtiState == null) {
    return defaultValue ?? [];
  }

  return cpeFtiState.map((e) => cpeFtiStateFromJson(e.toString())).toList();
}

List<enums.CpeFtiState>? cpeFtiStateNullableListFromJson(
  List? cpeFtiState, [
  List<enums.CpeFtiState>? defaultValue,
]) {
  if (cpeFtiState == null) {
    return defaultValue;
  }

  return cpeFtiState.map((e) => cpeFtiStateFromJson(e.toString())).toList();
}

String? cpeHdmiColorOutputToJson(enums.CpeHdmiColorOutput? cpeHdmiColorOutput) {
  return enums.$CpeHdmiColorOutputMap[cpeHdmiColorOutput];
}

enums.CpeHdmiColorOutput cpeHdmiColorOutputFromJson(
  Object? cpeHdmiColorOutput, [
  enums.CpeHdmiColorOutput? defaultValue,
]) {
  if (cpeHdmiColorOutput is String) {
    return enums.$CpeHdmiColorOutputMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeHdmiColorOutput.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeHdmiColorOutput.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeHdmiColorOutputMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeHdmiColorOutput.swaggerGeneratedUnknown;
}

List<String> cpeHdmiColorOutputListToJson(
    List<enums.CpeHdmiColorOutput>? cpeHdmiColorOutput) {
  if (cpeHdmiColorOutput == null) {
    return [];
  }

  return cpeHdmiColorOutput
      .map((e) => enums.$CpeHdmiColorOutputMap[e]!)
      .toList();
}

List<enums.CpeHdmiColorOutput> cpeHdmiColorOutputListFromJson(
  List? cpeHdmiColorOutput, [
  List<enums.CpeHdmiColorOutput>? defaultValue,
]) {
  if (cpeHdmiColorOutput == null) {
    return defaultValue ?? [];
  }

  return cpeHdmiColorOutput
      .map((e) => cpeHdmiColorOutputFromJson(e.toString()))
      .toList();
}

List<enums.CpeHdmiColorOutput>? cpeHdmiColorOutputNullableListFromJson(
  List? cpeHdmiColorOutput, [
  List<enums.CpeHdmiColorOutput>? defaultValue,
]) {
  if (cpeHdmiColorOutput == null) {
    return defaultValue;
  }

  return cpeHdmiColorOutput
      .map((e) => cpeHdmiColorOutputFromJson(e.toString()))
      .toList();
}

String? cpeHdmiResolutionToJson(enums.CpeHdmiResolution? cpeHdmiResolution) {
  return enums.$CpeHdmiResolutionMap[cpeHdmiResolution];
}

enums.CpeHdmiResolution cpeHdmiResolutionFromJson(
  Object? cpeHdmiResolution, [
  enums.CpeHdmiResolution? defaultValue,
]) {
  if (cpeHdmiResolution is String) {
    return enums.$CpeHdmiResolutionMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeHdmiResolution.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeHdmiResolution.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeHdmiResolutionMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeHdmiResolution.swaggerGeneratedUnknown;
}

List<String> cpeHdmiResolutionListToJson(
    List<enums.CpeHdmiResolution>? cpeHdmiResolution) {
  if (cpeHdmiResolution == null) {
    return [];
  }

  return cpeHdmiResolution.map((e) => enums.$CpeHdmiResolutionMap[e]!).toList();
}

List<enums.CpeHdmiResolution> cpeHdmiResolutionListFromJson(
  List? cpeHdmiResolution, [
  List<enums.CpeHdmiResolution>? defaultValue,
]) {
  if (cpeHdmiResolution == null) {
    return defaultValue ?? [];
  }

  return cpeHdmiResolution
      .map((e) => cpeHdmiResolutionFromJson(e.toString()))
      .toList();
}

List<enums.CpeHdmiResolution>? cpeHdmiResolutionNullableListFromJson(
  List? cpeHdmiResolution, [
  List<enums.CpeHdmiResolution>? defaultValue,
]) {
  if (cpeHdmiResolution == null) {
    return defaultValue;
  }

  return cpeHdmiResolution
      .map((e) => cpeHdmiResolutionFromJson(e.toString()))
      .toList();
}

String? cpePowerCheckToJson(enums.CpePowerCheck? cpePowerCheck) {
  return enums.$CpePowerCheckMap[cpePowerCheck];
}

enums.CpePowerCheck cpePowerCheckFromJson(
  Object? cpePowerCheck, [
  enums.CpePowerCheck? defaultValue,
]) {
  if (cpePowerCheck is String) {
    return enums.$CpePowerCheckMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpePowerCheck.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.CpePowerCheck.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpePowerCheckMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpePowerCheck.swaggerGeneratedUnknown;
}

List<String> cpePowerCheckListToJson(List<enums.CpePowerCheck>? cpePowerCheck) {
  if (cpePowerCheck == null) {
    return [];
  }

  return cpePowerCheck.map((e) => enums.$CpePowerCheckMap[e]!).toList();
}

List<enums.CpePowerCheck> cpePowerCheckListFromJson(
  List? cpePowerCheck, [
  List<enums.CpePowerCheck>? defaultValue,
]) {
  if (cpePowerCheck == null) {
    return defaultValue ?? [];
  }

  return cpePowerCheck.map((e) => cpePowerCheckFromJson(e.toString())).toList();
}

List<enums.CpePowerCheck>? cpePowerCheckNullableListFromJson(
  List? cpePowerCheck, [
  List<enums.CpePowerCheck>? defaultValue,
]) {
  if (cpePowerCheck == null) {
    return defaultValue;
  }

  return cpePowerCheck.map((e) => cpePowerCheckFromJson(e.toString())).toList();
}

String? cpePowerSourceToJson(enums.CpePowerSource? cpePowerSource) {
  return enums.$CpePowerSourceMap[cpePowerSource];
}

enums.CpePowerSource cpePowerSourceFromJson(
  Object? cpePowerSource, [
  enums.CpePowerSource? defaultValue,
]) {
  if (cpePowerSource is String) {
    return enums.$CpePowerSourceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpePowerSource.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpePowerSource.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpePowerSourceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpePowerSource.swaggerGeneratedUnknown;
}

List<String> cpePowerSourceListToJson(
    List<enums.CpePowerSource>? cpePowerSource) {
  if (cpePowerSource == null) {
    return [];
  }

  return cpePowerSource.map((e) => enums.$CpePowerSourceMap[e]!).toList();
}

List<enums.CpePowerSource> cpePowerSourceListFromJson(
  List? cpePowerSource, [
  List<enums.CpePowerSource>? defaultValue,
]) {
  if (cpePowerSource == null) {
    return defaultValue ?? [];
  }

  return cpePowerSource
      .map((e) => cpePowerSourceFromJson(e.toString()))
      .toList();
}

List<enums.CpePowerSource>? cpePowerSourceNullableListFromJson(
  List? cpePowerSource, [
  List<enums.CpePowerSource>? defaultValue,
]) {
  if (cpePowerSource == null) {
    return defaultValue;
  }

  return cpePowerSource
      .map((e) => cpePowerSourceFromJson(e.toString()))
      .toList();
}

String? cpePrimaryVideoOutputToJson(
    enums.CpePrimaryVideoOutput? cpePrimaryVideoOutput) {
  return enums.$CpePrimaryVideoOutputMap[cpePrimaryVideoOutput];
}

enums.CpePrimaryVideoOutput cpePrimaryVideoOutputFromJson(
  Object? cpePrimaryVideoOutput, [
  enums.CpePrimaryVideoOutput? defaultValue,
]) {
  if (cpePrimaryVideoOutput is String) {
    return enums.$CpePrimaryVideoOutputMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpePrimaryVideoOutput.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpePrimaryVideoOutput.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpePrimaryVideoOutputMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpePrimaryVideoOutput.swaggerGeneratedUnknown;
}

List<String> cpePrimaryVideoOutputListToJson(
    List<enums.CpePrimaryVideoOutput>? cpePrimaryVideoOutput) {
  if (cpePrimaryVideoOutput == null) {
    return [];
  }

  return cpePrimaryVideoOutput
      .map((e) => enums.$CpePrimaryVideoOutputMap[e]!)
      .toList();
}

List<enums.CpePrimaryVideoOutput> cpePrimaryVideoOutputListFromJson(
  List? cpePrimaryVideoOutput, [
  List<enums.CpePrimaryVideoOutput>? defaultValue,
]) {
  if (cpePrimaryVideoOutput == null) {
    return defaultValue ?? [];
  }

  return cpePrimaryVideoOutput
      .map((e) => cpePrimaryVideoOutputFromJson(e.toString()))
      .toList();
}

List<enums.CpePrimaryVideoOutput>? cpePrimaryVideoOutputNullableListFromJson(
  List? cpePrimaryVideoOutput, [
  List<enums.CpePrimaryVideoOutput>? defaultValue,
]) {
  if (cpePrimaryVideoOutput == null) {
    return defaultValue;
  }

  return cpePrimaryVideoOutput
      .map((e) => cpePrimaryVideoOutputFromJson(e.toString()))
      .toList();
}

String? cpeRcuUpgradeStatusToJson(
    enums.CpeRcuUpgradeStatus? cpeRcuUpgradeStatus) {
  return enums.$CpeRcuUpgradeStatusMap[cpeRcuUpgradeStatus];
}

enums.CpeRcuUpgradeStatus cpeRcuUpgradeStatusFromJson(
  Object? cpeRcuUpgradeStatus, [
  enums.CpeRcuUpgradeStatus? defaultValue,
]) {
  if (cpeRcuUpgradeStatus is String) {
    return enums.$CpeRcuUpgradeStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                cpeRcuUpgradeStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeRcuUpgradeStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeRcuUpgradeStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeRcuUpgradeStatus.swaggerGeneratedUnknown;
}

List<String> cpeRcuUpgradeStatusListToJson(
    List<enums.CpeRcuUpgradeStatus>? cpeRcuUpgradeStatus) {
  if (cpeRcuUpgradeStatus == null) {
    return [];
  }

  return cpeRcuUpgradeStatus
      .map((e) => enums.$CpeRcuUpgradeStatusMap[e]!)
      .toList();
}

List<enums.CpeRcuUpgradeStatus> cpeRcuUpgradeStatusListFromJson(
  List? cpeRcuUpgradeStatus, [
  List<enums.CpeRcuUpgradeStatus>? defaultValue,
]) {
  if (cpeRcuUpgradeStatus == null) {
    return defaultValue ?? [];
  }

  return cpeRcuUpgradeStatus
      .map((e) => cpeRcuUpgradeStatusFromJson(e.toString()))
      .toList();
}

List<enums.CpeRcuUpgradeStatus>? cpeRcuUpgradeStatusNullableListFromJson(
  List? cpeRcuUpgradeStatus, [
  List<enums.CpeRcuUpgradeStatus>? defaultValue,
]) {
  if (cpeRcuUpgradeStatus == null) {
    return defaultValue;
  }

  return cpeRcuUpgradeStatus
      .map((e) => cpeRcuUpgradeStatusFromJson(e.toString()))
      .toList();
}

int? cpeRecordPaddingAfterToJson(
    enums.CpeRecordPaddingAfter? cpeRecordPaddingAfter) {
  return enums.$CpeRecordPaddingAfterMap[cpeRecordPaddingAfter];
}

enums.CpeRecordPaddingAfter cpeRecordPaddingAfterFromJson(
  Object? cpeRecordPaddingAfter, [
  enums.CpeRecordPaddingAfter? defaultValue,
]) {
  if (cpeRecordPaddingAfter is int) {
    return enums.$CpeRecordPaddingAfterMap.entries
        .firstWhere((element) => element.value == cpeRecordPaddingAfter,
            orElse: () => const MapEntry(
                enums.CpeRecordPaddingAfter.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeRecordPaddingAfterMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeRecordPaddingAfter.swaggerGeneratedUnknown;
}

List<int> cpeRecordPaddingAfterListToJson(
    List<enums.CpeRecordPaddingAfter>? cpeRecordPaddingAfter) {
  if (cpeRecordPaddingAfter == null) {
    return [];
  }

  return cpeRecordPaddingAfter
      .map((e) => enums.$CpeRecordPaddingAfterMap[e]!)
      .toList();
}

List<enums.CpeRecordPaddingAfter> cpeRecordPaddingAfterListFromJson(
  List? cpeRecordPaddingAfter, [
  List<enums.CpeRecordPaddingAfter>? defaultValue,
]) {
  if (cpeRecordPaddingAfter == null) {
    return defaultValue ?? [];
  }

  return cpeRecordPaddingAfter
      .map((e) => cpeRecordPaddingAfterFromJson(e.toString()))
      .toList();
}

List<enums.CpeRecordPaddingAfter>? cpeRecordPaddingAfterNullableListFromJson(
  List? cpeRecordPaddingAfter, [
  List<enums.CpeRecordPaddingAfter>? defaultValue,
]) {
  if (cpeRecordPaddingAfter == null) {
    return defaultValue;
  }

  return cpeRecordPaddingAfter
      .map((e) => cpeRecordPaddingAfterFromJson(e.toString()))
      .toList();
}

int? cpeRecordPaddingBeforeToJson(
    enums.CpeRecordPaddingBefore? cpeRecordPaddingBefore) {
  return enums.$CpeRecordPaddingBeforeMap[cpeRecordPaddingBefore];
}

enums.CpeRecordPaddingBefore cpeRecordPaddingBeforeFromJson(
  Object? cpeRecordPaddingBefore, [
  enums.CpeRecordPaddingBefore? defaultValue,
]) {
  if (cpeRecordPaddingBefore is int) {
    return enums.$CpeRecordPaddingBeforeMap.entries
        .firstWhere((element) => element.value == cpeRecordPaddingBefore,
            orElse: () => const MapEntry(
                enums.CpeRecordPaddingBefore.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeRecordPaddingBeforeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeRecordPaddingBefore.swaggerGeneratedUnknown;
}

List<int> cpeRecordPaddingBeforeListToJson(
    List<enums.CpeRecordPaddingBefore>? cpeRecordPaddingBefore) {
  if (cpeRecordPaddingBefore == null) {
    return [];
  }

  return cpeRecordPaddingBefore
      .map((e) => enums.$CpeRecordPaddingBeforeMap[e]!)
      .toList();
}

List<enums.CpeRecordPaddingBefore> cpeRecordPaddingBeforeListFromJson(
  List? cpeRecordPaddingBefore, [
  List<enums.CpeRecordPaddingBefore>? defaultValue,
]) {
  if (cpeRecordPaddingBefore == null) {
    return defaultValue ?? [];
  }

  return cpeRecordPaddingBefore
      .map((e) => cpeRecordPaddingBeforeFromJson(e.toString()))
      .toList();
}

List<enums.CpeRecordPaddingBefore>? cpeRecordPaddingBeforeNullableListFromJson(
  List? cpeRecordPaddingBefore, [
  List<enums.CpeRecordPaddingBefore>? defaultValue,
]) {
  if (cpeRecordPaddingBefore == null) {
    return defaultValue;
  }

  return cpeRecordPaddingBefore
      .map((e) => cpeRecordPaddingBeforeFromJson(e.toString()))
      .toList();
}

String? cpeStandByModeToJson(enums.CpeStandByMode? cpeStandByMode) {
  return enums.$CpeStandByModeMap[cpeStandByMode];
}

enums.CpeStandByMode cpeStandByModeFromJson(
  Object? cpeStandByMode, [
  enums.CpeStandByMode? defaultValue,
]) {
  if (cpeStandByMode is String) {
    return enums.$CpeStandByModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeStandByMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeStandByMode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeStandByModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeStandByMode.swaggerGeneratedUnknown;
}

List<String> cpeStandByModeListToJson(
    List<enums.CpeStandByMode>? cpeStandByMode) {
  if (cpeStandByMode == null) {
    return [];
  }

  return cpeStandByMode.map((e) => enums.$CpeStandByModeMap[e]!).toList();
}

List<enums.CpeStandByMode> cpeStandByModeListFromJson(
  List? cpeStandByMode, [
  List<enums.CpeStandByMode>? defaultValue,
]) {
  if (cpeStandByMode == null) {
    return defaultValue ?? [];
  }

  return cpeStandByMode
      .map((e) => cpeStandByModeFromJson(e.toString()))
      .toList();
}

List<enums.CpeStandByMode>? cpeStandByModeNullableListFromJson(
  List? cpeStandByMode, [
  List<enums.CpeStandByMode>? defaultValue,
]) {
  if (cpeStandByMode == null) {
    return defaultValue;
  }

  return cpeStandByMode
      .map((e) => cpeStandByModeFromJson(e.toString()))
      .toList();
}

String? cpeUpgradeStatusToJson(enums.CpeUpgradeStatus? cpeUpgradeStatus) {
  return enums.$CpeUpgradeStatusMap[cpeUpgradeStatus];
}

enums.CpeUpgradeStatus cpeUpgradeStatusFromJson(
  Object? cpeUpgradeStatus, [
  enums.CpeUpgradeStatus? defaultValue,
]) {
  if (cpeUpgradeStatus is String) {
    return enums.$CpeUpgradeStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == cpeUpgradeStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CpeUpgradeStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CpeUpgradeStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CpeUpgradeStatus.swaggerGeneratedUnknown;
}

List<String> cpeUpgradeStatusListToJson(
    List<enums.CpeUpgradeStatus>? cpeUpgradeStatus) {
  if (cpeUpgradeStatus == null) {
    return [];
  }

  return cpeUpgradeStatus.map((e) => enums.$CpeUpgradeStatusMap[e]!).toList();
}

List<enums.CpeUpgradeStatus> cpeUpgradeStatusListFromJson(
  List? cpeUpgradeStatus, [
  List<enums.CpeUpgradeStatus>? defaultValue,
]) {
  if (cpeUpgradeStatus == null) {
    return defaultValue ?? [];
  }

  return cpeUpgradeStatus
      .map((e) => cpeUpgradeStatusFromJson(e.toString()))
      .toList();
}

List<enums.CpeUpgradeStatus>? cpeUpgradeStatusNullableListFromJson(
  List? cpeUpgradeStatus, [
  List<enums.CpeUpgradeStatus>? defaultValue,
]) {
  if (cpeUpgradeStatus == null) {
    return defaultValue;
  }

  return cpeUpgradeStatus
      .map((e) => cpeUpgradeStatusFromJson(e.toString()))
      .toList();
}

int? customerRecordingRetentionPeriodToJson(
    enums.CustomerRecordingRetentionPeriod? customerRecordingRetentionPeriod) {
  return enums
      .$CustomerRecordingRetentionPeriodMap[customerRecordingRetentionPeriod];
}

enums.CustomerRecordingRetentionPeriod customerRecordingRetentionPeriodFromJson(
  Object? customerRecordingRetentionPeriod, [
  enums.CustomerRecordingRetentionPeriod? defaultValue,
]) {
  if (customerRecordingRetentionPeriod is int) {
    return enums.$CustomerRecordingRetentionPeriodMap.entries
        .firstWhere(
            (element) => element.value == customerRecordingRetentionPeriod,
            orElse: () => const MapEntry(
                enums.CustomerRecordingRetentionPeriod.swaggerGeneratedUnknown,
                0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomerRecordingRetentionPeriodMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomerRecordingRetentionPeriod.swaggerGeneratedUnknown;
}

List<int> customerRecordingRetentionPeriodListToJson(
    List<enums.CustomerRecordingRetentionPeriod>?
        customerRecordingRetentionPeriod) {
  if (customerRecordingRetentionPeriod == null) {
    return [];
  }

  return customerRecordingRetentionPeriod
      .map((e) => enums.$CustomerRecordingRetentionPeriodMap[e]!)
      .toList();
}

List<enums.CustomerRecordingRetentionPeriod>
    customerRecordingRetentionPeriodListFromJson(
  List? customerRecordingRetentionPeriod, [
  List<enums.CustomerRecordingRetentionPeriod>? defaultValue,
]) {
  if (customerRecordingRetentionPeriod == null) {
    return defaultValue ?? [];
  }

  return customerRecordingRetentionPeriod
      .map((e) => customerRecordingRetentionPeriodFromJson(e.toString()))
      .toList();
}

List<enums.CustomerRecordingRetentionPeriod>?
    customerRecordingRetentionPeriodNullableListFromJson(
  List? customerRecordingRetentionPeriod, [
  List<enums.CustomerRecordingRetentionPeriod>? defaultValue,
]) {
  if (customerRecordingRetentionPeriod == null) {
    return defaultValue;
  }

  return customerRecordingRetentionPeriod
      .map((e) => customerRecordingRetentionPeriodFromJson(e.toString()))
      .toList();
}

int? profileAgeLockToJson(enums.ProfileAgeLock? profileAgeLock) {
  return enums.$ProfileAgeLockMap[profileAgeLock];
}

enums.ProfileAgeLock profileAgeLockFromJson(
  Object? profileAgeLock, [
  enums.ProfileAgeLock? defaultValue,
]) {
  if (profileAgeLock is int) {
    return enums.$ProfileAgeLockMap.entries
        .firstWhere((element) => element.value == profileAgeLock,
            orElse: () =>
                const MapEntry(enums.ProfileAgeLock.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileAgeLockMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileAgeLock.swaggerGeneratedUnknown;
}

List<int> profileAgeLockListToJson(List<enums.ProfileAgeLock>? profileAgeLock) {
  if (profileAgeLock == null) {
    return [];
  }

  return profileAgeLock.map((e) => enums.$ProfileAgeLockMap[e]!).toList();
}

List<enums.ProfileAgeLock> profileAgeLockListFromJson(
  List? profileAgeLock, [
  List<enums.ProfileAgeLock>? defaultValue,
]) {
  if (profileAgeLock == null) {
    return defaultValue ?? [];
  }

  return profileAgeLock
      .map((e) => profileAgeLockFromJson(e.toString()))
      .toList();
}

List<enums.ProfileAgeLock>? profileAgeLockNullableListFromJson(
  List? profileAgeLock, [
  List<enums.ProfileAgeLock>? defaultValue,
]) {
  if (profileAgeLock == null) {
    return defaultValue;
  }

  return profileAgeLock
      .map((e) => profileAgeLockFromJson(e.toString()))
      .toList();
}

String? profileAudioLangToJson(enums.ProfileAudioLang? profileAudioLang) {
  return enums.$ProfileAudioLangMap[profileAudioLang];
}

enums.ProfileAudioLang profileAudioLangFromJson(
  Object? profileAudioLang, [
  enums.ProfileAudioLang? defaultValue,
]) {
  if (profileAudioLang is String) {
    return enums.$ProfileAudioLangMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == profileAudioLang.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfileAudioLang.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileAudioLangMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileAudioLang.swaggerGeneratedUnknown;
}

List<String> profileAudioLangListToJson(
    List<enums.ProfileAudioLang>? profileAudioLang) {
  if (profileAudioLang == null) {
    return [];
  }

  return profileAudioLang.map((e) => enums.$ProfileAudioLangMap[e]!).toList();
}

List<enums.ProfileAudioLang> profileAudioLangListFromJson(
  List? profileAudioLang, [
  List<enums.ProfileAudioLang>? defaultValue,
]) {
  if (profileAudioLang == null) {
    return defaultValue ?? [];
  }

  return profileAudioLang
      .map((e) => profileAudioLangFromJson(e.toString()))
      .toList();
}

List<enums.ProfileAudioLang>? profileAudioLangNullableListFromJson(
  List? profileAudioLang, [
  List<enums.ProfileAudioLang>? defaultValue,
]) {
  if (profileAudioLang == null) {
    return defaultValue;
  }

  return profileAudioLang
      .map((e) => profileAudioLangFromJson(e.toString()))
      .toList();
}

String? profileOnScreenKeyboardModeToJson(
    enums.ProfileOnScreenKeyboardMode? profileOnScreenKeyboardMode) {
  return enums.$ProfileOnScreenKeyboardModeMap[profileOnScreenKeyboardMode];
}

enums.ProfileOnScreenKeyboardMode profileOnScreenKeyboardModeFromJson(
  Object? profileOnScreenKeyboardMode, [
  enums.ProfileOnScreenKeyboardMode? defaultValue,
]) {
  if (profileOnScreenKeyboardMode is String) {
    return enums.$ProfileOnScreenKeyboardModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                profileOnScreenKeyboardMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfileOnScreenKeyboardMode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileOnScreenKeyboardModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileOnScreenKeyboardMode.swaggerGeneratedUnknown;
}

List<String> profileOnScreenKeyboardModeListToJson(
    List<enums.ProfileOnScreenKeyboardMode>? profileOnScreenKeyboardMode) {
  if (profileOnScreenKeyboardMode == null) {
    return [];
  }

  return profileOnScreenKeyboardMode
      .map((e) => enums.$ProfileOnScreenKeyboardModeMap[e]!)
      .toList();
}

List<enums.ProfileOnScreenKeyboardMode> profileOnScreenKeyboardModeListFromJson(
  List? profileOnScreenKeyboardMode, [
  List<enums.ProfileOnScreenKeyboardMode>? defaultValue,
]) {
  if (profileOnScreenKeyboardMode == null) {
    return defaultValue ?? [];
  }

  return profileOnScreenKeyboardMode
      .map((e) => profileOnScreenKeyboardModeFromJson(e.toString()))
      .toList();
}

List<enums.ProfileOnScreenKeyboardMode>?
    profileOnScreenKeyboardModeNullableListFromJson(
  List? profileOnScreenKeyboardMode, [
  List<enums.ProfileOnScreenKeyboardMode>? defaultValue,
]) {
  if (profileOnScreenKeyboardMode == null) {
    return defaultValue;
  }

  return profileOnScreenKeyboardMode
      .map((e) => profileOnScreenKeyboardModeFromJson(e.toString()))
      .toList();
}

String? profileOsdLangToJson(enums.ProfileOsdLang? profileOsdLang) {
  return enums.$ProfileOsdLangMap[profileOsdLang];
}

enums.ProfileOsdLang profileOsdLangFromJson(
  Object? profileOsdLang, [
  enums.ProfileOsdLang? defaultValue,
]) {
  if (profileOsdLang is String) {
    return enums.$ProfileOsdLangMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == profileOsdLang.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfileOsdLang.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileOsdLangMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileOsdLang.swaggerGeneratedUnknown;
}

List<String> profileOsdLangListToJson(
    List<enums.ProfileOsdLang>? profileOsdLang) {
  if (profileOsdLang == null) {
    return [];
  }

  return profileOsdLang.map((e) => enums.$ProfileOsdLangMap[e]!).toList();
}

List<enums.ProfileOsdLang> profileOsdLangListFromJson(
  List? profileOsdLang, [
  List<enums.ProfileOsdLang>? defaultValue,
]) {
  if (profileOsdLang == null) {
    return defaultValue ?? [];
  }

  return profileOsdLang
      .map((e) => profileOsdLangFromJson(e.toString()))
      .toList();
}

List<enums.ProfileOsdLang>? profileOsdLangNullableListFromJson(
  List? profileOsdLang, [
  List<enums.ProfileOsdLang>? defaultValue,
]) {
  if (profileOsdLang == null) {
    return defaultValue;
  }

  return profileOsdLang
      .map((e) => profileOsdLangFromJson(e.toString()))
      .toList();
}

String? profileSubLangToJson(enums.ProfileSubLang? profileSubLang) {
  return enums.$ProfileSubLangMap[profileSubLang];
}

enums.ProfileSubLang profileSubLangFromJson(
  Object? profileSubLang, [
  enums.ProfileSubLang? defaultValue,
]) {
  if (profileSubLang is String) {
    return enums.$ProfileSubLangMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == profileSubLang.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfileSubLang.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileSubLangMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileSubLang.swaggerGeneratedUnknown;
}

List<String> profileSubLangListToJson(
    List<enums.ProfileSubLang>? profileSubLang) {
  if (profileSubLang == null) {
    return [];
  }

  return profileSubLang.map((e) => enums.$ProfileSubLangMap[e]!).toList();
}

List<enums.ProfileSubLang> profileSubLangListFromJson(
  List? profileSubLang, [
  List<enums.ProfileSubLang>? defaultValue,
]) {
  if (profileSubLang == null) {
    return defaultValue ?? [];
  }

  return profileSubLang
      .map((e) => profileSubLangFromJson(e.toString()))
      .toList();
}

List<enums.ProfileSubLang>? profileSubLangNullableListFromJson(
  List? profileSubLang, [
  List<enums.ProfileSubLang>? defaultValue,
]) {
  if (profileSubLang == null) {
    return defaultValue;
  }

  return profileSubLang
      .map((e) => profileSubLangFromJson(e.toString()))
      .toList();
}

String? profileTextToSpeechSpeedToJson(
    enums.ProfileTextToSpeechSpeed? profileTextToSpeechSpeed) {
  return enums.$ProfileTextToSpeechSpeedMap[profileTextToSpeechSpeed];
}

enums.ProfileTextToSpeechSpeed profileTextToSpeechSpeedFromJson(
  Object? profileTextToSpeechSpeed, [
  enums.ProfileTextToSpeechSpeed? defaultValue,
]) {
  if (profileTextToSpeechSpeed is String) {
    return enums.$ProfileTextToSpeechSpeedMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                profileTextToSpeechSpeed.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfileTextToSpeechSpeed.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileTextToSpeechSpeedMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileTextToSpeechSpeed.swaggerGeneratedUnknown;
}

List<String> profileTextToSpeechSpeedListToJson(
    List<enums.ProfileTextToSpeechSpeed>? profileTextToSpeechSpeed) {
  if (profileTextToSpeechSpeed == null) {
    return [];
  }

  return profileTextToSpeechSpeed
      .map((e) => enums.$ProfileTextToSpeechSpeedMap[e]!)
      .toList();
}

List<enums.ProfileTextToSpeechSpeed> profileTextToSpeechSpeedListFromJson(
  List? profileTextToSpeechSpeed, [
  List<enums.ProfileTextToSpeechSpeed>? defaultValue,
]) {
  if (profileTextToSpeechSpeed == null) {
    return defaultValue ?? [];
  }

  return profileTextToSpeechSpeed
      .map((e) => profileTextToSpeechSpeedFromJson(e.toString()))
      .toList();
}

List<enums.ProfileTextToSpeechSpeed>?
    profileTextToSpeechSpeedNullableListFromJson(
  List? profileTextToSpeechSpeed, [
  List<enums.ProfileTextToSpeechSpeed>? defaultValue,
]) {
  if (profileTextToSpeechSpeed == null) {
    return defaultValue;
  }

  return profileTextToSpeechSpeed
      .map((e) => profileTextToSpeechSpeedFromJson(e.toString()))
      .toList();
}

String? profileTextToSpeechVolumeToJson(
    enums.ProfileTextToSpeechVolume? profileTextToSpeechVolume) {
  return enums.$ProfileTextToSpeechVolumeMap[profileTextToSpeechVolume];
}

enums.ProfileTextToSpeechVolume profileTextToSpeechVolumeFromJson(
  Object? profileTextToSpeechVolume, [
  enums.ProfileTextToSpeechVolume? defaultValue,
]) {
  if (profileTextToSpeechVolume is String) {
    return enums.$ProfileTextToSpeechVolumeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                profileTextToSpeechVolume.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ProfileTextToSpeechVolume.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ProfileTextToSpeechVolumeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ProfileTextToSpeechVolume.swaggerGeneratedUnknown;
}

List<String> profileTextToSpeechVolumeListToJson(
    List<enums.ProfileTextToSpeechVolume>? profileTextToSpeechVolume) {
  if (profileTextToSpeechVolume == null) {
    return [];
  }

  return profileTextToSpeechVolume
      .map((e) => enums.$ProfileTextToSpeechVolumeMap[e]!)
      .toList();
}

List<enums.ProfileTextToSpeechVolume> profileTextToSpeechVolumeListFromJson(
  List? profileTextToSpeechVolume, [
  List<enums.ProfileTextToSpeechVolume>? defaultValue,
]) {
  if (profileTextToSpeechVolume == null) {
    return defaultValue ?? [];
  }

  return profileTextToSpeechVolume
      .map((e) => profileTextToSpeechVolumeFromJson(e.toString()))
      .toList();
}

List<enums.ProfileTextToSpeechVolume>?
    profileTextToSpeechVolumeNullableListFromJson(
  List? profileTextToSpeechVolume, [
  List<enums.ProfileTextToSpeechVolume>? defaultValue,
]) {
  if (profileTextToSpeechVolume == null) {
    return defaultValue;
  }

  return profileTextToSpeechVolume
      .map((e) => profileTextToSpeechVolumeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
