// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'taxonomy_swagger.enums.swagger.dart' as enums;
export 'taxonomy_swagger.enums.swagger.dart';

part 'taxonomy_swagger.swagger.chopper.dart';
part 'taxonomy_swagger.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class TaxonomySwagger extends ChopperService {
  static TaxonomySwagger create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$TaxonomySwagger(client);
    }

    final newClient = ChopperClient(
        services: [_$TaxonomySwagger()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$TaxonomySwagger(newClient);
  }

  ///taxonomy elements
  ///@param appCode Application code
  ///@param id Node ID
  ///@param include Include type (direction): [children, parents]
  ///@param products Indicate if product IDs should be listed too
  ///@param depth Depth of the response: less than 0 - infinite, 0 - the node itself, 1 - with direct associates, ...
  Future<chopper.Response<List<TaxonomyV3>>> v3TaxonomyByNodeGet({
    enums.V3TaxonomyByNodeGetAppCode? appCode,
    required num? id,
    enums.V3TaxonomyByNodeGetInclude? include,
    bool? products,
    int? depth,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TaxonomyV3, () => TaxonomyV3.fromJsonFactory);

    return _v3TaxonomyByNodeGet(
        appCode: enums.$V3TaxonomyByNodeGetAppCodeMap[appCode]?.toString(),
        id: id,
        include: enums.$V3TaxonomyByNodeGetIncludeMap[include]?.toString(),
        products: products,
        depth: depth,
        cacheControl: cacheControl);
  }

  ///taxonomy elements
  ///@param appCode Application code
  ///@param id Node ID
  ///@param include Include type (direction): [children, parents]
  ///@param products Indicate if product IDs should be listed too
  ///@param depth Depth of the response: less than 0 - infinite, 0 - the node itself, 1 - with direct associates, ...
  @Get(path: '/v3/taxonomy/byNode')
  Future<chopper.Response<List<TaxonomyV3>>> _v3TaxonomyByNodeGet({
    @Query('appCode') String? appCode,
    @Query('id') required num? id,
    @Query('include') String? include,
    @Query('products') bool? products,
    @Query('depth') int? depth,
    @Header('Cache-Control') String? cacheControl,
  });

  ///taxonomy by product
  ///@param appCode Application code
  ///@param id Product ID (a.k.a. webshopId)
  ///@param include Include type (direction): [children, parents]
  ///@param products Indicate if product IDs should be listed too
  ///@param depth Depth of the response: less than zero - infinite, 0 - the node itself, 1 - with direct associates, ...
  Future<chopper.Response<List<TaxonomyV3>>> v3TaxonomyByProductGet({
    enums.V3TaxonomyByProductGetAppCode? appCode,
    required num? id,
    enums.V3TaxonomyByProductGetInclude? include,
    bool? products,
    int? depth,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TaxonomyV3, () => TaxonomyV3.fromJsonFactory);

    return _v3TaxonomyByProductGet(
        appCode: enums.$V3TaxonomyByProductGetAppCodeMap[appCode]?.toString(),
        id: id,
        include: enums.$V3TaxonomyByProductGetIncludeMap[include]?.toString(),
        products: products,
        depth: depth,
        cacheControl: cacheControl);
  }

  ///taxonomy by product
  ///@param appCode Application code
  ///@param id Product ID (a.k.a. webshopId)
  ///@param include Include type (direction): [children, parents]
  ///@param products Indicate if product IDs should be listed too
  ///@param depth Depth of the response: less than zero - infinite, 0 - the node itself, 1 - with direct associates, ...
  @Get(path: '/v3/taxonomy/byProduct')
  Future<chopper.Response<List<TaxonomyV3>>> _v3TaxonomyByProductGet({
    @Query('appCode') String? appCode,
    @Query('id') required num? id,
    @Query('include') String? include,
    @Query('products') bool? products,
    @Query('depth') int? depth,
    @Header('Cache-Control') String? cacheControl,
  });

  ///sort productIds
  ///@param appCode Application code
  Future<chopper.Response<List<ProductSort>>> v3TaxonomySortPost({
    enums.V3TaxonomySortPostAppCode? appCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProductSort, () => ProductSort.fromJsonFactory);

    return _v3TaxonomySortPost(
        appCode: enums.$V3TaxonomySortPostAppCodeMap[appCode]?.toString(),
        cacheControl: cacheControl);
  }

  ///sort productIds
  ///@param appCode Application code
  @Post(path: '/v3/taxonomy/sort')
  Future<chopper.Response<List<ProductSort>>> _v3TaxonomySortPost({
    @Query('appCode') String? appCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///level 1 taxonomies
  ///@param appCode Application code
  Future<chopper.Response<List<TaxonomyV3>>> v3TaxonomyTopLevelGet({
    enums.V3TaxonomyTopLevelGetAppCode? appCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TaxonomyV3, () => TaxonomyV3.fromJsonFactory);

    return _v3TaxonomyTopLevelGet(
        appCode: enums.$V3TaxonomyTopLevelGetAppCodeMap[appCode]?.toString(),
        cacheControl: cacheControl);
  }

  ///level 1 taxonomies
  ///@param appCode Application code
  @Get(path: '/v3/taxonomy/topLevel')
  Future<chopper.Response<List<TaxonomyV3>>> _v3TaxonomyTopLevelGet({
    @Query('appCode') String? appCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///taxonomy by product
  ///@param appCode Application code
  ///@param productId Product ID (a.k.a. webshopId)
  ///@param fields Fields to fields.
  ///@param children Depth of the children in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct children, ...
  ///@param parents Depth of the parents in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct parents, ...
  Future<chopper.Response<Nodes>> v4TaxonomyNodesGet({
    enums.V4TaxonomyNodesGetAppCode? appCode,
    required num? productId,
    enums.V4TaxonomyNodesGetFields? fields,
    int? children,
    int? parents,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Nodes, () => Nodes.fromJsonFactory);

    return _v4TaxonomyNodesGet(
        appCode: enums.$V4TaxonomyNodesGetAppCodeMap[appCode]?.toString(),
        productId: productId,
        fields: enums.$V4TaxonomyNodesGetFieldsMap[fields]?.toString(),
        children: children,
        parents: parents,
        cacheControl: cacheControl);
  }

  ///taxonomy by product
  ///@param appCode Application code
  ///@param productId Product ID (a.k.a. webshopId)
  ///@param fields Fields to fields.
  ///@param children Depth of the children in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct children, ...
  ///@param parents Depth of the parents in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct parents, ...
  @Get(path: '/v4/taxonomy/nodes')
  Future<chopper.Response<Nodes>> _v4TaxonomyNodesGet({
    @Query('appCode') String? appCode,
    @Query('productId') required num? productId,
    @Query('fields') String? fields,
    @Query('children') int? children,
    @Query('parents') int? parents,
    @Header('Cache-Control') String? cacheControl,
  });

  ///sort products
  ///@param appCode Application code
  Future<chopper.Response<List<ProductSort>>> v4TaxonomyNodesSortPost({
    enums.V4TaxonomyNodesSortPostAppCode? appCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProductSort, () => ProductSort.fromJsonFactory);

    return _v4TaxonomyNodesSortPost(
        appCode: enums.$V4TaxonomyNodesSortPostAppCodeMap[appCode]?.toString(),
        cacheControl: cacheControl);
  }

  ///sort products
  ///@param appCode Application code
  @Post(path: '/v4/taxonomy/nodes/sort')
  Future<chopper.Response<List<ProductSort>>> _v4TaxonomyNodesSortPost({
    @Query('appCode') String? appCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///level 1 taxonomies
  ///@param appCode Application code
  Future<chopper.Response<Nodes>> v4TaxonomyNodesTopLevelGet({
    enums.V4TaxonomyNodesTopLevelGetAppCode? appCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Nodes, () => Nodes.fromJsonFactory);

    return _v4TaxonomyNodesTopLevelGet(
        appCode:
            enums.$V4TaxonomyNodesTopLevelGetAppCodeMap[appCode]?.toString(),
        cacheControl: cacheControl);
  }

  ///level 1 taxonomies
  ///@param appCode Application code
  @Get(path: '/v4/taxonomy/nodes/top-level')
  Future<chopper.Response<Nodes>> _v4TaxonomyNodesTopLevelGet({
    @Query('appCode') String? appCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///taxonomy elements
  ///@param appCode Application code
  ///@param id Node ID: use the value -1 as placeholder for the root node.
  ///@param fields Fields to fields.
  ///@param children Depth of the children in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct children, ...
  ///@param parents Depth of the parents in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct parents, ...
  Future<chopper.Response<Nodes>> v4TaxonomyNodesIdGet({
    enums.V4TaxonomyNodesIdGetAppCode? appCode,
    required num? id,
    enums.V4TaxonomyNodesIdGetFields? fields,
    int? children,
    int? parents,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Nodes, () => Nodes.fromJsonFactory);

    return _v4TaxonomyNodesIdGet(
        appCode: enums.$V4TaxonomyNodesIdGetAppCodeMap[appCode]?.toString(),
        id: id,
        fields: enums.$V4TaxonomyNodesIdGetFieldsMap[fields]?.toString(),
        children: children,
        parents: parents,
        cacheControl: cacheControl);
  }

  ///taxonomy elements
  ///@param appCode Application code
  ///@param id Node ID: use the value -1 as placeholder for the root node.
  ///@param fields Fields to fields.
  ///@param children Depth of the children in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct children, ...
  ///@param parents Depth of the parents in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct parents, ...
  @Get(path: '/v4/taxonomy/nodes/{id}')
  Future<chopper.Response<Nodes>> _v4TaxonomyNodesIdGet({
    @Query('appCode') String? appCode,
    @Path('id') required num? id,
    @Query('fields') String? fields,
    @Query('children') int? children,
    @Query('parents') int? parents,
    @Header('Cache-Control') String? cacheControl,
  });

  ///taxonomy elements
  ///@param appCode Application code
  ///@param slugifiedName Slugified node name
  ///@param fields Fields to fields.
  ///@param children Depth of the children in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct children, ...
  ///@param parents Depth of the parents in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct parents, ...
  Future<chopper.Response<Nodes>> v4TaxonomyNodesSlugifiedNameGet({
    enums.V4TaxonomyNodesSlugifiedNameGetAppCode? appCode,
    required String? slugifiedName,
    enums.V4TaxonomyNodesSlugifiedNameGetFields? fields,
    int? children,
    int? parents,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Nodes, () => Nodes.fromJsonFactory);

    return _v4TaxonomyNodesSlugifiedNameGet(
        appCode: enums.$V4TaxonomyNodesSlugifiedNameGetAppCodeMap[appCode]
            ?.toString(),
        slugifiedName: slugifiedName,
        fields:
            enums.$V4TaxonomyNodesSlugifiedNameGetFieldsMap[fields]?.toString(),
        children: children,
        parents: parents,
        cacheControl: cacheControl);
  }

  ///taxonomy elements
  ///@param appCode Application code
  ///@param slugifiedName Slugified node name
  ///@param fields Fields to fields.
  ///@param children Depth of the children in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct children, ...
  ///@param parents Depth of the parents in the response: less than 0 - infinite, 0 - the node itself, 1 - with direct parents, ...
  @Get(path: '/v4/taxonomy/nodes/{slugifiedName}')
  Future<chopper.Response<Nodes>> _v4TaxonomyNodesSlugifiedNameGet({
    @Query('appCode') String? appCode,
    @Path('slugifiedName') required String? slugifiedName,
    @Query('fields') String? fields,
    @Query('children') int? children,
    @Query('parents') int? parents,
    @Header('Cache-Control') String? cacheControl,
  });

  ///paths from root for a product
  ///@param appCode Application code
  ///@param productIds Product IDs (a.k.a. webshopIds)
  Future<chopper.Response<List<PathsV4>>> v4TaxonomyPathsFromRootGet({
    enums.V4TaxonomyPathsFromRootGetAppCode? appCode,
    required List<int>? productIds,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PathsV4, () => PathsV4.fromJsonFactory);

    return _v4TaxonomyPathsFromRootGet(
        appCode:
            enums.$V4TaxonomyPathsFromRootGetAppCodeMap[appCode]?.toString(),
        productIds: productIds,
        cacheControl: cacheControl);
  }

  ///paths from root for a product
  ///@param appCode Application code
  ///@param productIds Product IDs (a.k.a. webshopIds)
  @Get(path: '/v4/taxonomy/paths-from-root')
  Future<chopper.Response<List<PathsV4>>> _v4TaxonomyPathsFromRootGet({
    @Query('appCode') String? appCode,
    @Query('productIds') required List<int>? productIds,
    @Header('Cache-Control') String? cacheControl,
  });

  ///level 1 taxonomies
  ///@param application Application code
  Future<chopper.Response<Nodes>> v5TaxonomyNodesTopLevelGet({
    enums.V5TaxonomyNodesTopLevelGetApplication? application,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Nodes, () => Nodes.fromJsonFactory);

    return _v5TaxonomyNodesTopLevelGet(
        application: enums
            .$V5TaxonomyNodesTopLevelGetApplicationMap[application]
            ?.toString(),
        cacheControl: cacheControl);
  }

  ///level 1 taxonomies
  ///@param application Application code
  @Get(path: '/v5/taxonomy/nodes/top-level')
  Future<chopper.Response<Nodes>> _v5TaxonomyNodesTopLevelGet({
    @Query('application') String? application,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    required this.height,
    required this.url,
    required this.width,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  @JsonKey(name: 'height', includeIfNull: false)
  final int height;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'width', includeIfNull: false)
  final int width;
  static const fromJsonFactory = _$ImageFromJson;
  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.height, height) ||
                const DeepCollectionEquality().equals(other.height, height)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.width, width) ||
                const DeepCollectionEquality().equals(other.width, width)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(height) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(width) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({int? height, String? url, int? width}) {
    return Image(
        height: height ?? this.height,
        url: url ?? this.url,
        width: width ?? this.width);
  }

  Image copyWithWrapped(
      {Wrapped<int>? height, Wrapped<String>? url, Wrapped<int>? width}) {
    return Image(
        height: (height != null ? height.value : this.height),
        url: (url != null ? url.value : this.url),
        width: (width != null ? width.value : this.width));
  }
}

@JsonSerializable(explicitToJson: true)
class Nodes {
  Nodes({
    required this.nodes,
  });

  factory Nodes.fromJson(Map<String, dynamic> json) => _$NodesFromJson(json);

  @JsonKey(name: 'nodes', includeIfNull: false, defaultValue: <TaxonomyV5>[])
  final List<TaxonomyV5> nodes;
  static const fromJsonFactory = _$NodesFromJson;
  static const toJsonFactory = _$NodesToJson;
  Map<String, dynamic> toJson() => _$NodesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Nodes &&
            (identical(other.nodes, nodes) ||
                const DeepCollectionEquality().equals(other.nodes, nodes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nodes) ^ runtimeType.hashCode;
}

extension $NodesExtension on Nodes {
  Nodes copyWith({List<TaxonomyV5>? nodes}) {
    return Nodes(nodes: nodes ?? this.nodes);
  }

  Nodes copyWithWrapped({Wrapped<List<TaxonomyV5>>? nodes}) {
    return Nodes(nodes: (nodes != null ? nodes.value : this.nodes));
  }
}

@JsonSerializable(explicitToJson: true)
class PathsV4 {
  PathsV4({
    required this.paths,
    required this.productId,
  });

  factory PathsV4.fromJson(Map<String, dynamic> json) =>
      _$PathsV4FromJson(json);

  @JsonKey(
      name: 'paths', includeIfNull: false, defaultValue: <List<TaxonomyV4>>[])
  final List<List<TaxonomyV4>> paths;
  @JsonKey(name: 'productId', includeIfNull: false)
  final num productId;
  static const fromJsonFactory = _$PathsV4FromJson;
  static const toJsonFactory = _$PathsV4ToJson;
  Map<String, dynamic> toJson() => _$PathsV4ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PathsV4 &&
            (identical(other.paths, paths) ||
                const DeepCollectionEquality().equals(other.paths, paths)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(paths) ^
      const DeepCollectionEquality().hash(productId) ^
      runtimeType.hashCode;
}

extension $PathsV4Extension on PathsV4 {
  PathsV4 copyWith({List<List<TaxonomyV4>>? paths, num? productId}) {
    return PathsV4(
        paths: paths ?? this.paths, productId: productId ?? this.productId);
  }

  PathsV4 copyWithWrapped(
      {Wrapped<List<List<TaxonomyV4>>>? paths, Wrapped<num>? productId}) {
    return PathsV4(
        paths: (paths != null ? paths.value : this.paths),
        productId: (productId != null ? productId.value : this.productId));
  }
}

@JsonSerializable(explicitToJson: true)
class ProductSort {
  ProductSort({
    this.nodeId,
    this.nodeName,
    required this.productId,
  });

  factory ProductSort.fromJson(Map<String, dynamic> json) =>
      _$ProductSortFromJson(json);

  @JsonKey(name: 'nodeId', includeIfNull: false)
  final num? nodeId;
  @JsonKey(name: 'nodeName', includeIfNull: false, defaultValue: '')
  final String? nodeName;
  @JsonKey(name: 'productId', includeIfNull: false)
  final num productId;
  static const fromJsonFactory = _$ProductSortFromJson;
  static const toJsonFactory = _$ProductSortToJson;
  Map<String, dynamic> toJson() => _$ProductSortToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductSort &&
            (identical(other.nodeId, nodeId) ||
                const DeepCollectionEquality().equals(other.nodeId, nodeId)) &&
            (identical(other.nodeName, nodeName) ||
                const DeepCollectionEquality()
                    .equals(other.nodeName, nodeName)) &&
            (identical(other.productId, productId) ||
                const DeepCollectionEquality()
                    .equals(other.productId, productId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nodeId) ^
      const DeepCollectionEquality().hash(nodeName) ^
      const DeepCollectionEquality().hash(productId) ^
      runtimeType.hashCode;
}

extension $ProductSortExtension on ProductSort {
  ProductSort copyWith({num? nodeId, String? nodeName, num? productId}) {
    return ProductSort(
        nodeId: nodeId ?? this.nodeId,
        nodeName: nodeName ?? this.nodeName,
        productId: productId ?? this.productId);
  }

  ProductSort copyWithWrapped(
      {Wrapped<num?>? nodeId,
      Wrapped<String?>? nodeName,
      Wrapped<num>? productId}) {
    return ProductSort(
        nodeId: (nodeId != null ? nodeId.value : this.nodeId),
        nodeName: (nodeName != null ? nodeName.value : this.nodeName),
        productId: (productId != null ? productId.value : this.productId));
  }
}

@JsonSerializable(explicitToJson: true)
class TaxonomyV3 {
  TaxonomyV3({
    required this.children,
    required this.id,
    this.image,
    required this.name,
    required this.parents,
    required this.products,
    required this.shown,
  });

  factory TaxonomyV3.fromJson(Map<String, dynamic> json) =>
      _$TaxonomyV3FromJson(json);

  @JsonKey(name: 'children', includeIfNull: false, defaultValue: <num>[])
  final List<num> children;
  @JsonKey(name: 'id', includeIfNull: false)
  final num id;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'parents', includeIfNull: false, defaultValue: <num>[])
  final List<num> parents;
  @JsonKey(name: 'products', includeIfNull: false, defaultValue: <num>[])
  final List<num> products;
  @JsonKey(name: 'shown', includeIfNull: false)
  final bool shown;
  static const fromJsonFactory = _$TaxonomyV3FromJson;
  static const toJsonFactory = _$TaxonomyV3ToJson;
  Map<String, dynamic> toJson() => _$TaxonomyV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaxonomyV3 &&
            (identical(other.children, children) ||
                const DeepCollectionEquality()
                    .equals(other.children, children)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.parents, parents) ||
                const DeepCollectionEquality()
                    .equals(other.parents, parents)) &&
            (identical(other.products, products) ||
                const DeepCollectionEquality()
                    .equals(other.products, products)) &&
            (identical(other.shown, shown) ||
                const DeepCollectionEquality().equals(other.shown, shown)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(children) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(parents) ^
      const DeepCollectionEquality().hash(products) ^
      const DeepCollectionEquality().hash(shown) ^
      runtimeType.hashCode;
}

extension $TaxonomyV3Extension on TaxonomyV3 {
  TaxonomyV3 copyWith(
      {List<num>? children,
      num? id,
      String? image,
      String? name,
      List<num>? parents,
      List<num>? products,
      bool? shown}) {
    return TaxonomyV3(
        children: children ?? this.children,
        id: id ?? this.id,
        image: image ?? this.image,
        name: name ?? this.name,
        parents: parents ?? this.parents,
        products: products ?? this.products,
        shown: shown ?? this.shown);
  }

  TaxonomyV3 copyWithWrapped(
      {Wrapped<List<num>>? children,
      Wrapped<num>? id,
      Wrapped<String?>? image,
      Wrapped<String>? name,
      Wrapped<List<num>>? parents,
      Wrapped<List<num>>? products,
      Wrapped<bool>? shown}) {
    return TaxonomyV3(
        children: (children != null ? children.value : this.children),
        id: (id != null ? id.value : this.id),
        image: (image != null ? image.value : this.image),
        name: (name != null ? name.value : this.name),
        parents: (parents != null ? parents.value : this.parents),
        products: (products != null ? products.value : this.products),
        shown: (shown != null ? shown.value : this.shown));
  }
}

@JsonSerializable(explicitToJson: true)
class TaxonomyV4 {
  TaxonomyV4({
    required this.active,
    this.breadcrumbs,
    required this.children,
    required this.id,
    this.image,
    required this.name,
    required this.parents,
    required this.productIds,
    required this.slugifiedName,
  });

  factory TaxonomyV4.fromJson(Map<String, dynamic> json) =>
      _$TaxonomyV4FromJson(json);

  @JsonKey(name: 'active', includeIfNull: false)
  final bool active;
  @JsonKey(
      name: 'breadcrumbs', includeIfNull: false, defaultValue: <TaxonomyV4>[])
  final List<TaxonomyV4>? breadcrumbs;
  @JsonKey(name: 'children', includeIfNull: false, defaultValue: <num>[])
  final List<num> children;
  @JsonKey(name: 'id', includeIfNull: false)
  final num id;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'parents', includeIfNull: false, defaultValue: <num>[])
  final List<num> parents;
  @JsonKey(name: 'productIds', includeIfNull: false, defaultValue: <num>[])
  final List<num> productIds;
  @JsonKey(name: 'slugifiedName', includeIfNull: false, defaultValue: '')
  final String slugifiedName;
  static const fromJsonFactory = _$TaxonomyV4FromJson;
  static const toJsonFactory = _$TaxonomyV4ToJson;
  Map<String, dynamic> toJson() => _$TaxonomyV4ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaxonomyV4 &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.breadcrumbs, breadcrumbs) ||
                const DeepCollectionEquality()
                    .equals(other.breadcrumbs, breadcrumbs)) &&
            (identical(other.children, children) ||
                const DeepCollectionEquality()
                    .equals(other.children, children)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.parents, parents) ||
                const DeepCollectionEquality()
                    .equals(other.parents, parents)) &&
            (identical(other.productIds, productIds) ||
                const DeepCollectionEquality()
                    .equals(other.productIds, productIds)) &&
            (identical(other.slugifiedName, slugifiedName) ||
                const DeepCollectionEquality()
                    .equals(other.slugifiedName, slugifiedName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(breadcrumbs) ^
      const DeepCollectionEquality().hash(children) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(parents) ^
      const DeepCollectionEquality().hash(productIds) ^
      const DeepCollectionEquality().hash(slugifiedName) ^
      runtimeType.hashCode;
}

extension $TaxonomyV4Extension on TaxonomyV4 {
  TaxonomyV4 copyWith(
      {bool? active,
      List<TaxonomyV4>? breadcrumbs,
      List<num>? children,
      num? id,
      String? image,
      String? name,
      List<num>? parents,
      List<num>? productIds,
      String? slugifiedName}) {
    return TaxonomyV4(
        active: active ?? this.active,
        breadcrumbs: breadcrumbs ?? this.breadcrumbs,
        children: children ?? this.children,
        id: id ?? this.id,
        image: image ?? this.image,
        name: name ?? this.name,
        parents: parents ?? this.parents,
        productIds: productIds ?? this.productIds,
        slugifiedName: slugifiedName ?? this.slugifiedName);
  }

  TaxonomyV4 copyWithWrapped(
      {Wrapped<bool>? active,
      Wrapped<List<TaxonomyV4>?>? breadcrumbs,
      Wrapped<List<num>>? children,
      Wrapped<num>? id,
      Wrapped<String?>? image,
      Wrapped<String>? name,
      Wrapped<List<num>>? parents,
      Wrapped<List<num>>? productIds,
      Wrapped<String>? slugifiedName}) {
    return TaxonomyV4(
        active: (active != null ? active.value : this.active),
        breadcrumbs:
            (breadcrumbs != null ? breadcrumbs.value : this.breadcrumbs),
        children: (children != null ? children.value : this.children),
        id: (id != null ? id.value : this.id),
        image: (image != null ? image.value : this.image),
        name: (name != null ? name.value : this.name),
        parents: (parents != null ? parents.value : this.parents),
        productIds: (productIds != null ? productIds.value : this.productIds),
        slugifiedName:
            (slugifiedName != null ? slugifiedName.value : this.slugifiedName));
  }
}

@JsonSerializable(explicitToJson: true)
class TaxonomyV5 {
  TaxonomyV5({
    required this.active,
    required this.children,
    required this.id,
    this.image,
    required this.name,
    required this.parents,
    required this.productIds,
    required this.slugifiedName,
  });

  factory TaxonomyV5.fromJson(Map<String, dynamic> json) =>
      _$TaxonomyV5FromJson(json);

  @JsonKey(name: 'active', includeIfNull: false)
  final bool active;
  @JsonKey(name: 'children', includeIfNull: false, defaultValue: <num>[])
  final List<num> children;
  @JsonKey(name: 'id', includeIfNull: false)
  final num id;
  @JsonKey(name: 'image', includeIfNull: false)
  final Image? image;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'parents', includeIfNull: false, defaultValue: <num>[])
  final List<num> parents;
  @JsonKey(name: 'productIds', includeIfNull: false, defaultValue: <num>[])
  final List<num> productIds;
  @JsonKey(name: 'slugifiedName', includeIfNull: false, defaultValue: '')
  final String slugifiedName;
  static const fromJsonFactory = _$TaxonomyV5FromJson;
  static const toJsonFactory = _$TaxonomyV5ToJson;
  Map<String, dynamic> toJson() => _$TaxonomyV5ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaxonomyV5 &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.children, children) ||
                const DeepCollectionEquality()
                    .equals(other.children, children)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.parents, parents) ||
                const DeepCollectionEquality()
                    .equals(other.parents, parents)) &&
            (identical(other.productIds, productIds) ||
                const DeepCollectionEquality()
                    .equals(other.productIds, productIds)) &&
            (identical(other.slugifiedName, slugifiedName) ||
                const DeepCollectionEquality()
                    .equals(other.slugifiedName, slugifiedName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(children) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(parents) ^
      const DeepCollectionEquality().hash(productIds) ^
      const DeepCollectionEquality().hash(slugifiedName) ^
      runtimeType.hashCode;
}

extension $TaxonomyV5Extension on TaxonomyV5 {
  TaxonomyV5 copyWith(
      {bool? active,
      List<num>? children,
      num? id,
      Image? image,
      String? name,
      List<num>? parents,
      List<num>? productIds,
      String? slugifiedName}) {
    return TaxonomyV5(
        active: active ?? this.active,
        children: children ?? this.children,
        id: id ?? this.id,
        image: image ?? this.image,
        name: name ?? this.name,
        parents: parents ?? this.parents,
        productIds: productIds ?? this.productIds,
        slugifiedName: slugifiedName ?? this.slugifiedName);
  }

  TaxonomyV5 copyWithWrapped(
      {Wrapped<bool>? active,
      Wrapped<List<num>>? children,
      Wrapped<num>? id,
      Wrapped<Image?>? image,
      Wrapped<String>? name,
      Wrapped<List<num>>? parents,
      Wrapped<List<num>>? productIds,
      Wrapped<String>? slugifiedName}) {
    return TaxonomyV5(
        active: (active != null ? active.value : this.active),
        children: (children != null ? children.value : this.children),
        id: (id != null ? id.value : this.id),
        image: (image != null ? image.value : this.image),
        name: (name != null ? name.value : this.name),
        parents: (parents != null ? parents.value : this.parents),
        productIds: (productIds != null ? productIds.value : this.productIds),
        slugifiedName:
            (slugifiedName != null ? slugifiedName.value : this.slugifiedName));
  }
}

String? v3TaxonomyByNodeGetAppCodeToJson(
    enums.V3TaxonomyByNodeGetAppCode? v3TaxonomyByNodeGetAppCode) {
  return enums.$V3TaxonomyByNodeGetAppCodeMap[v3TaxonomyByNodeGetAppCode];
}

enums.V3TaxonomyByNodeGetAppCode v3TaxonomyByNodeGetAppCodeFromJson(
  Object? v3TaxonomyByNodeGetAppCode, [
  enums.V3TaxonomyByNodeGetAppCode? defaultValue,
]) {
  if (v3TaxonomyByNodeGetAppCode is String) {
    return enums.$V3TaxonomyByNodeGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v3TaxonomyByNodeGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V3TaxonomyByNodeGetAppCode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V3TaxonomyByNodeGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V3TaxonomyByNodeGetAppCode.swaggerGeneratedUnknown;
}

List<String> v3TaxonomyByNodeGetAppCodeListToJson(
    List<enums.V3TaxonomyByNodeGetAppCode>? v3TaxonomyByNodeGetAppCode) {
  if (v3TaxonomyByNodeGetAppCode == null) {
    return [];
  }

  return v3TaxonomyByNodeGetAppCode
      .map((e) => enums.$V3TaxonomyByNodeGetAppCodeMap[e]!)
      .toList();
}

List<enums.V3TaxonomyByNodeGetAppCode> v3TaxonomyByNodeGetAppCodeListFromJson(
  List? v3TaxonomyByNodeGetAppCode, [
  List<enums.V3TaxonomyByNodeGetAppCode>? defaultValue,
]) {
  if (v3TaxonomyByNodeGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v3TaxonomyByNodeGetAppCode
      .map((e) => v3TaxonomyByNodeGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V3TaxonomyByNodeGetAppCode>?
    v3TaxonomyByNodeGetAppCodeNullableListFromJson(
  List? v3TaxonomyByNodeGetAppCode, [
  List<enums.V3TaxonomyByNodeGetAppCode>? defaultValue,
]) {
  if (v3TaxonomyByNodeGetAppCode == null) {
    return defaultValue;
  }

  return v3TaxonomyByNodeGetAppCode
      .map((e) => v3TaxonomyByNodeGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v3TaxonomyByNodeGetIncludeToJson(
    enums.V3TaxonomyByNodeGetInclude? v3TaxonomyByNodeGetInclude) {
  return enums.$V3TaxonomyByNodeGetIncludeMap[v3TaxonomyByNodeGetInclude];
}

enums.V3TaxonomyByNodeGetInclude v3TaxonomyByNodeGetIncludeFromJson(
  Object? v3TaxonomyByNodeGetInclude, [
  enums.V3TaxonomyByNodeGetInclude? defaultValue,
]) {
  if (v3TaxonomyByNodeGetInclude is String) {
    return enums.$V3TaxonomyByNodeGetIncludeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v3TaxonomyByNodeGetInclude.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V3TaxonomyByNodeGetInclude.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V3TaxonomyByNodeGetIncludeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V3TaxonomyByNodeGetInclude.swaggerGeneratedUnknown;
}

List<String> v3TaxonomyByNodeGetIncludeListToJson(
    List<enums.V3TaxonomyByNodeGetInclude>? v3TaxonomyByNodeGetInclude) {
  if (v3TaxonomyByNodeGetInclude == null) {
    return [];
  }

  return v3TaxonomyByNodeGetInclude
      .map((e) => enums.$V3TaxonomyByNodeGetIncludeMap[e]!)
      .toList();
}

List<enums.V3TaxonomyByNodeGetInclude> v3TaxonomyByNodeGetIncludeListFromJson(
  List? v3TaxonomyByNodeGetInclude, [
  List<enums.V3TaxonomyByNodeGetInclude>? defaultValue,
]) {
  if (v3TaxonomyByNodeGetInclude == null) {
    return defaultValue ?? [];
  }

  return v3TaxonomyByNodeGetInclude
      .map((e) => v3TaxonomyByNodeGetIncludeFromJson(e.toString()))
      .toList();
}

List<enums.V3TaxonomyByNodeGetInclude>?
    v3TaxonomyByNodeGetIncludeNullableListFromJson(
  List? v3TaxonomyByNodeGetInclude, [
  List<enums.V3TaxonomyByNodeGetInclude>? defaultValue,
]) {
  if (v3TaxonomyByNodeGetInclude == null) {
    return defaultValue;
  }

  return v3TaxonomyByNodeGetInclude
      .map((e) => v3TaxonomyByNodeGetIncludeFromJson(e.toString()))
      .toList();
}

String? v3TaxonomyByProductGetAppCodeToJson(
    enums.V3TaxonomyByProductGetAppCode? v3TaxonomyByProductGetAppCode) {
  return enums.$V3TaxonomyByProductGetAppCodeMap[v3TaxonomyByProductGetAppCode];
}

enums.V3TaxonomyByProductGetAppCode v3TaxonomyByProductGetAppCodeFromJson(
  Object? v3TaxonomyByProductGetAppCode, [
  enums.V3TaxonomyByProductGetAppCode? defaultValue,
]) {
  if (v3TaxonomyByProductGetAppCode is String) {
    return enums.$V3TaxonomyByProductGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v3TaxonomyByProductGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V3TaxonomyByProductGetAppCode.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V3TaxonomyByProductGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V3TaxonomyByProductGetAppCode.swaggerGeneratedUnknown;
}

List<String> v3TaxonomyByProductGetAppCodeListToJson(
    List<enums.V3TaxonomyByProductGetAppCode>? v3TaxonomyByProductGetAppCode) {
  if (v3TaxonomyByProductGetAppCode == null) {
    return [];
  }

  return v3TaxonomyByProductGetAppCode
      .map((e) => enums.$V3TaxonomyByProductGetAppCodeMap[e]!)
      .toList();
}

List<enums.V3TaxonomyByProductGetAppCode>
    v3TaxonomyByProductGetAppCodeListFromJson(
  List? v3TaxonomyByProductGetAppCode, [
  List<enums.V3TaxonomyByProductGetAppCode>? defaultValue,
]) {
  if (v3TaxonomyByProductGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v3TaxonomyByProductGetAppCode
      .map((e) => v3TaxonomyByProductGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V3TaxonomyByProductGetAppCode>?
    v3TaxonomyByProductGetAppCodeNullableListFromJson(
  List? v3TaxonomyByProductGetAppCode, [
  List<enums.V3TaxonomyByProductGetAppCode>? defaultValue,
]) {
  if (v3TaxonomyByProductGetAppCode == null) {
    return defaultValue;
  }

  return v3TaxonomyByProductGetAppCode
      .map((e) => v3TaxonomyByProductGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v3TaxonomyByProductGetIncludeToJson(
    enums.V3TaxonomyByProductGetInclude? v3TaxonomyByProductGetInclude) {
  return enums.$V3TaxonomyByProductGetIncludeMap[v3TaxonomyByProductGetInclude];
}

enums.V3TaxonomyByProductGetInclude v3TaxonomyByProductGetIncludeFromJson(
  Object? v3TaxonomyByProductGetInclude, [
  enums.V3TaxonomyByProductGetInclude? defaultValue,
]) {
  if (v3TaxonomyByProductGetInclude is String) {
    return enums.$V3TaxonomyByProductGetIncludeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v3TaxonomyByProductGetInclude.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V3TaxonomyByProductGetInclude.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V3TaxonomyByProductGetIncludeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V3TaxonomyByProductGetInclude.swaggerGeneratedUnknown;
}

List<String> v3TaxonomyByProductGetIncludeListToJson(
    List<enums.V3TaxonomyByProductGetInclude>? v3TaxonomyByProductGetInclude) {
  if (v3TaxonomyByProductGetInclude == null) {
    return [];
  }

  return v3TaxonomyByProductGetInclude
      .map((e) => enums.$V3TaxonomyByProductGetIncludeMap[e]!)
      .toList();
}

List<enums.V3TaxonomyByProductGetInclude>
    v3TaxonomyByProductGetIncludeListFromJson(
  List? v3TaxonomyByProductGetInclude, [
  List<enums.V3TaxonomyByProductGetInclude>? defaultValue,
]) {
  if (v3TaxonomyByProductGetInclude == null) {
    return defaultValue ?? [];
  }

  return v3TaxonomyByProductGetInclude
      .map((e) => v3TaxonomyByProductGetIncludeFromJson(e.toString()))
      .toList();
}

List<enums.V3TaxonomyByProductGetInclude>?
    v3TaxonomyByProductGetIncludeNullableListFromJson(
  List? v3TaxonomyByProductGetInclude, [
  List<enums.V3TaxonomyByProductGetInclude>? defaultValue,
]) {
  if (v3TaxonomyByProductGetInclude == null) {
    return defaultValue;
  }

  return v3TaxonomyByProductGetInclude
      .map((e) => v3TaxonomyByProductGetIncludeFromJson(e.toString()))
      .toList();
}

String? v3TaxonomySortPostAppCodeToJson(
    enums.V3TaxonomySortPostAppCode? v3TaxonomySortPostAppCode) {
  return enums.$V3TaxonomySortPostAppCodeMap[v3TaxonomySortPostAppCode];
}

enums.V3TaxonomySortPostAppCode v3TaxonomySortPostAppCodeFromJson(
  Object? v3TaxonomySortPostAppCode, [
  enums.V3TaxonomySortPostAppCode? defaultValue,
]) {
  if (v3TaxonomySortPostAppCode is String) {
    return enums.$V3TaxonomySortPostAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v3TaxonomySortPostAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V3TaxonomySortPostAppCode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V3TaxonomySortPostAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V3TaxonomySortPostAppCode.swaggerGeneratedUnknown;
}

List<String> v3TaxonomySortPostAppCodeListToJson(
    List<enums.V3TaxonomySortPostAppCode>? v3TaxonomySortPostAppCode) {
  if (v3TaxonomySortPostAppCode == null) {
    return [];
  }

  return v3TaxonomySortPostAppCode
      .map((e) => enums.$V3TaxonomySortPostAppCodeMap[e]!)
      .toList();
}

List<enums.V3TaxonomySortPostAppCode> v3TaxonomySortPostAppCodeListFromJson(
  List? v3TaxonomySortPostAppCode, [
  List<enums.V3TaxonomySortPostAppCode>? defaultValue,
]) {
  if (v3TaxonomySortPostAppCode == null) {
    return defaultValue ?? [];
  }

  return v3TaxonomySortPostAppCode
      .map((e) => v3TaxonomySortPostAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V3TaxonomySortPostAppCode>?
    v3TaxonomySortPostAppCodeNullableListFromJson(
  List? v3TaxonomySortPostAppCode, [
  List<enums.V3TaxonomySortPostAppCode>? defaultValue,
]) {
  if (v3TaxonomySortPostAppCode == null) {
    return defaultValue;
  }

  return v3TaxonomySortPostAppCode
      .map((e) => v3TaxonomySortPostAppCodeFromJson(e.toString()))
      .toList();
}

String? v3TaxonomyTopLevelGetAppCodeToJson(
    enums.V3TaxonomyTopLevelGetAppCode? v3TaxonomyTopLevelGetAppCode) {
  return enums.$V3TaxonomyTopLevelGetAppCodeMap[v3TaxonomyTopLevelGetAppCode];
}

enums.V3TaxonomyTopLevelGetAppCode v3TaxonomyTopLevelGetAppCodeFromJson(
  Object? v3TaxonomyTopLevelGetAppCode, [
  enums.V3TaxonomyTopLevelGetAppCode? defaultValue,
]) {
  if (v3TaxonomyTopLevelGetAppCode is String) {
    return enums.$V3TaxonomyTopLevelGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v3TaxonomyTopLevelGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V3TaxonomyTopLevelGetAppCode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V3TaxonomyTopLevelGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V3TaxonomyTopLevelGetAppCode.swaggerGeneratedUnknown;
}

List<String> v3TaxonomyTopLevelGetAppCodeListToJson(
    List<enums.V3TaxonomyTopLevelGetAppCode>? v3TaxonomyTopLevelGetAppCode) {
  if (v3TaxonomyTopLevelGetAppCode == null) {
    return [];
  }

  return v3TaxonomyTopLevelGetAppCode
      .map((e) => enums.$V3TaxonomyTopLevelGetAppCodeMap[e]!)
      .toList();
}

List<enums.V3TaxonomyTopLevelGetAppCode>
    v3TaxonomyTopLevelGetAppCodeListFromJson(
  List? v3TaxonomyTopLevelGetAppCode, [
  List<enums.V3TaxonomyTopLevelGetAppCode>? defaultValue,
]) {
  if (v3TaxonomyTopLevelGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v3TaxonomyTopLevelGetAppCode
      .map((e) => v3TaxonomyTopLevelGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V3TaxonomyTopLevelGetAppCode>?
    v3TaxonomyTopLevelGetAppCodeNullableListFromJson(
  List? v3TaxonomyTopLevelGetAppCode, [
  List<enums.V3TaxonomyTopLevelGetAppCode>? defaultValue,
]) {
  if (v3TaxonomyTopLevelGetAppCode == null) {
    return defaultValue;
  }

  return v3TaxonomyTopLevelGetAppCode
      .map((e) => v3TaxonomyTopLevelGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesGetAppCodeToJson(
    enums.V4TaxonomyNodesGetAppCode? v4TaxonomyNodesGetAppCode) {
  return enums.$V4TaxonomyNodesGetAppCodeMap[v4TaxonomyNodesGetAppCode];
}

enums.V4TaxonomyNodesGetAppCode v4TaxonomyNodesGetAppCodeFromJson(
  Object? v4TaxonomyNodesGetAppCode, [
  enums.V4TaxonomyNodesGetAppCode? defaultValue,
]) {
  if (v4TaxonomyNodesGetAppCode is String) {
    return enums.$V4TaxonomyNodesGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesGetAppCode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesGetAppCode.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesGetAppCodeListToJson(
    List<enums.V4TaxonomyNodesGetAppCode>? v4TaxonomyNodesGetAppCode) {
  if (v4TaxonomyNodesGetAppCode == null) {
    return [];
  }

  return v4TaxonomyNodesGetAppCode
      .map((e) => enums.$V4TaxonomyNodesGetAppCodeMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesGetAppCode> v4TaxonomyNodesGetAppCodeListFromJson(
  List? v4TaxonomyNodesGetAppCode, [
  List<enums.V4TaxonomyNodesGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesGetAppCode
      .map((e) => v4TaxonomyNodesGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesGetAppCode>?
    v4TaxonomyNodesGetAppCodeNullableListFromJson(
  List? v4TaxonomyNodesGetAppCode, [
  List<enums.V4TaxonomyNodesGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesGetAppCode == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesGetAppCode
      .map((e) => v4TaxonomyNodesGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesGetFieldsToJson(
    enums.V4TaxonomyNodesGetFields? v4TaxonomyNodesGetFields) {
  return enums.$V4TaxonomyNodesGetFieldsMap[v4TaxonomyNodesGetFields];
}

enums.V4TaxonomyNodesGetFields v4TaxonomyNodesGetFieldsFromJson(
  Object? v4TaxonomyNodesGetFields, [
  enums.V4TaxonomyNodesGetFields? defaultValue,
]) {
  if (v4TaxonomyNodesGetFields is String) {
    return enums.$V4TaxonomyNodesGetFieldsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesGetFields.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesGetFields.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesGetFieldsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesGetFields.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesGetFieldsListToJson(
    List<enums.V4TaxonomyNodesGetFields>? v4TaxonomyNodesGetFields) {
  if (v4TaxonomyNodesGetFields == null) {
    return [];
  }

  return v4TaxonomyNodesGetFields
      .map((e) => enums.$V4TaxonomyNodesGetFieldsMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesGetFields> v4TaxonomyNodesGetFieldsListFromJson(
  List? v4TaxonomyNodesGetFields, [
  List<enums.V4TaxonomyNodesGetFields>? defaultValue,
]) {
  if (v4TaxonomyNodesGetFields == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesGetFields
      .map((e) => v4TaxonomyNodesGetFieldsFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesGetFields>?
    v4TaxonomyNodesGetFieldsNullableListFromJson(
  List? v4TaxonomyNodesGetFields, [
  List<enums.V4TaxonomyNodesGetFields>? defaultValue,
]) {
  if (v4TaxonomyNodesGetFields == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesGetFields
      .map((e) => v4TaxonomyNodesGetFieldsFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesSortPostAppCodeToJson(
    enums.V4TaxonomyNodesSortPostAppCode? v4TaxonomyNodesSortPostAppCode) {
  return enums
      .$V4TaxonomyNodesSortPostAppCodeMap[v4TaxonomyNodesSortPostAppCode];
}

enums.V4TaxonomyNodesSortPostAppCode v4TaxonomyNodesSortPostAppCodeFromJson(
  Object? v4TaxonomyNodesSortPostAppCode, [
  enums.V4TaxonomyNodesSortPostAppCode? defaultValue,
]) {
  if (v4TaxonomyNodesSortPostAppCode is String) {
    return enums.$V4TaxonomyNodesSortPostAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesSortPostAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesSortPostAppCode.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesSortPostAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesSortPostAppCode.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesSortPostAppCodeListToJson(
    List<enums.V4TaxonomyNodesSortPostAppCode>?
        v4TaxonomyNodesSortPostAppCode) {
  if (v4TaxonomyNodesSortPostAppCode == null) {
    return [];
  }

  return v4TaxonomyNodesSortPostAppCode
      .map((e) => enums.$V4TaxonomyNodesSortPostAppCodeMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesSortPostAppCode>
    v4TaxonomyNodesSortPostAppCodeListFromJson(
  List? v4TaxonomyNodesSortPostAppCode, [
  List<enums.V4TaxonomyNodesSortPostAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesSortPostAppCode == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesSortPostAppCode
      .map((e) => v4TaxonomyNodesSortPostAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesSortPostAppCode>?
    v4TaxonomyNodesSortPostAppCodeNullableListFromJson(
  List? v4TaxonomyNodesSortPostAppCode, [
  List<enums.V4TaxonomyNodesSortPostAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesSortPostAppCode == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesSortPostAppCode
      .map((e) => v4TaxonomyNodesSortPostAppCodeFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesTopLevelGetAppCodeToJson(
    enums.V4TaxonomyNodesTopLevelGetAppCode?
        v4TaxonomyNodesTopLevelGetAppCode) {
  return enums
      .$V4TaxonomyNodesTopLevelGetAppCodeMap[v4TaxonomyNodesTopLevelGetAppCode];
}

enums.V4TaxonomyNodesTopLevelGetAppCode
    v4TaxonomyNodesTopLevelGetAppCodeFromJson(
  Object? v4TaxonomyNodesTopLevelGetAppCode, [
  enums.V4TaxonomyNodesTopLevelGetAppCode? defaultValue,
]) {
  if (v4TaxonomyNodesTopLevelGetAppCode is String) {
    return enums.$V4TaxonomyNodesTopLevelGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesTopLevelGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesTopLevelGetAppCode.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesTopLevelGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesTopLevelGetAppCode.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesTopLevelGetAppCodeListToJson(
    List<enums.V4TaxonomyNodesTopLevelGetAppCode>?
        v4TaxonomyNodesTopLevelGetAppCode) {
  if (v4TaxonomyNodesTopLevelGetAppCode == null) {
    return [];
  }

  return v4TaxonomyNodesTopLevelGetAppCode
      .map((e) => enums.$V4TaxonomyNodesTopLevelGetAppCodeMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesTopLevelGetAppCode>
    v4TaxonomyNodesTopLevelGetAppCodeListFromJson(
  List? v4TaxonomyNodesTopLevelGetAppCode, [
  List<enums.V4TaxonomyNodesTopLevelGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesTopLevelGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesTopLevelGetAppCode
      .map((e) => v4TaxonomyNodesTopLevelGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesTopLevelGetAppCode>?
    v4TaxonomyNodesTopLevelGetAppCodeNullableListFromJson(
  List? v4TaxonomyNodesTopLevelGetAppCode, [
  List<enums.V4TaxonomyNodesTopLevelGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesTopLevelGetAppCode == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesTopLevelGetAppCode
      .map((e) => v4TaxonomyNodesTopLevelGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesIdGetAppCodeToJson(
    enums.V4TaxonomyNodesIdGetAppCode? v4TaxonomyNodesIdGetAppCode) {
  return enums.$V4TaxonomyNodesIdGetAppCodeMap[v4TaxonomyNodesIdGetAppCode];
}

enums.V4TaxonomyNodesIdGetAppCode v4TaxonomyNodesIdGetAppCodeFromJson(
  Object? v4TaxonomyNodesIdGetAppCode, [
  enums.V4TaxonomyNodesIdGetAppCode? defaultValue,
]) {
  if (v4TaxonomyNodesIdGetAppCode is String) {
    return enums.$V4TaxonomyNodesIdGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesIdGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesIdGetAppCode.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesIdGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesIdGetAppCode.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesIdGetAppCodeListToJson(
    List<enums.V4TaxonomyNodesIdGetAppCode>? v4TaxonomyNodesIdGetAppCode) {
  if (v4TaxonomyNodesIdGetAppCode == null) {
    return [];
  }

  return v4TaxonomyNodesIdGetAppCode
      .map((e) => enums.$V4TaxonomyNodesIdGetAppCodeMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesIdGetAppCode> v4TaxonomyNodesIdGetAppCodeListFromJson(
  List? v4TaxonomyNodesIdGetAppCode, [
  List<enums.V4TaxonomyNodesIdGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesIdGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesIdGetAppCode
      .map((e) => v4TaxonomyNodesIdGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesIdGetAppCode>?
    v4TaxonomyNodesIdGetAppCodeNullableListFromJson(
  List? v4TaxonomyNodesIdGetAppCode, [
  List<enums.V4TaxonomyNodesIdGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesIdGetAppCode == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesIdGetAppCode
      .map((e) => v4TaxonomyNodesIdGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesIdGetFieldsToJson(
    enums.V4TaxonomyNodesIdGetFields? v4TaxonomyNodesIdGetFields) {
  return enums.$V4TaxonomyNodesIdGetFieldsMap[v4TaxonomyNodesIdGetFields];
}

enums.V4TaxonomyNodesIdGetFields v4TaxonomyNodesIdGetFieldsFromJson(
  Object? v4TaxonomyNodesIdGetFields, [
  enums.V4TaxonomyNodesIdGetFields? defaultValue,
]) {
  if (v4TaxonomyNodesIdGetFields is String) {
    return enums.$V4TaxonomyNodesIdGetFieldsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesIdGetFields.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesIdGetFields.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesIdGetFieldsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesIdGetFields.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesIdGetFieldsListToJson(
    List<enums.V4TaxonomyNodesIdGetFields>? v4TaxonomyNodesIdGetFields) {
  if (v4TaxonomyNodesIdGetFields == null) {
    return [];
  }

  return v4TaxonomyNodesIdGetFields
      .map((e) => enums.$V4TaxonomyNodesIdGetFieldsMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesIdGetFields> v4TaxonomyNodesIdGetFieldsListFromJson(
  List? v4TaxonomyNodesIdGetFields, [
  List<enums.V4TaxonomyNodesIdGetFields>? defaultValue,
]) {
  if (v4TaxonomyNodesIdGetFields == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesIdGetFields
      .map((e) => v4TaxonomyNodesIdGetFieldsFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesIdGetFields>?
    v4TaxonomyNodesIdGetFieldsNullableListFromJson(
  List? v4TaxonomyNodesIdGetFields, [
  List<enums.V4TaxonomyNodesIdGetFields>? defaultValue,
]) {
  if (v4TaxonomyNodesIdGetFields == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesIdGetFields
      .map((e) => v4TaxonomyNodesIdGetFieldsFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesSlugifiedNameGetAppCodeToJson(
    enums.V4TaxonomyNodesSlugifiedNameGetAppCode?
        v4TaxonomyNodesSlugifiedNameGetAppCode) {
  return enums.$V4TaxonomyNodesSlugifiedNameGetAppCodeMap[
      v4TaxonomyNodesSlugifiedNameGetAppCode];
}

enums.V4TaxonomyNodesSlugifiedNameGetAppCode
    v4TaxonomyNodesSlugifiedNameGetAppCodeFromJson(
  Object? v4TaxonomyNodesSlugifiedNameGetAppCode, [
  enums.V4TaxonomyNodesSlugifiedNameGetAppCode? defaultValue,
]) {
  if (v4TaxonomyNodesSlugifiedNameGetAppCode is String) {
    return enums.$V4TaxonomyNodesSlugifiedNameGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesSlugifiedNameGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesSlugifiedNameGetAppCode
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesSlugifiedNameGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesSlugifiedNameGetAppCode.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesSlugifiedNameGetAppCodeListToJson(
    List<enums.V4TaxonomyNodesSlugifiedNameGetAppCode>?
        v4TaxonomyNodesSlugifiedNameGetAppCode) {
  if (v4TaxonomyNodesSlugifiedNameGetAppCode == null) {
    return [];
  }

  return v4TaxonomyNodesSlugifiedNameGetAppCode
      .map((e) => enums.$V4TaxonomyNodesSlugifiedNameGetAppCodeMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesSlugifiedNameGetAppCode>
    v4TaxonomyNodesSlugifiedNameGetAppCodeListFromJson(
  List? v4TaxonomyNodesSlugifiedNameGetAppCode, [
  List<enums.V4TaxonomyNodesSlugifiedNameGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesSlugifiedNameGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesSlugifiedNameGetAppCode
      .map((e) => v4TaxonomyNodesSlugifiedNameGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesSlugifiedNameGetAppCode>?
    v4TaxonomyNodesSlugifiedNameGetAppCodeNullableListFromJson(
  List? v4TaxonomyNodesSlugifiedNameGetAppCode, [
  List<enums.V4TaxonomyNodesSlugifiedNameGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyNodesSlugifiedNameGetAppCode == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesSlugifiedNameGetAppCode
      .map((e) => v4TaxonomyNodesSlugifiedNameGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyNodesSlugifiedNameGetFieldsToJson(
    enums.V4TaxonomyNodesSlugifiedNameGetFields?
        v4TaxonomyNodesSlugifiedNameGetFields) {
  return enums.$V4TaxonomyNodesSlugifiedNameGetFieldsMap[
      v4TaxonomyNodesSlugifiedNameGetFields];
}

enums.V4TaxonomyNodesSlugifiedNameGetFields
    v4TaxonomyNodesSlugifiedNameGetFieldsFromJson(
  Object? v4TaxonomyNodesSlugifiedNameGetFields, [
  enums.V4TaxonomyNodesSlugifiedNameGetFields? defaultValue,
]) {
  if (v4TaxonomyNodesSlugifiedNameGetFields is String) {
    return enums.$V4TaxonomyNodesSlugifiedNameGetFieldsMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyNodesSlugifiedNameGetFields.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyNodesSlugifiedNameGetFields
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyNodesSlugifiedNameGetFieldsMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyNodesSlugifiedNameGetFields.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyNodesSlugifiedNameGetFieldsListToJson(
    List<enums.V4TaxonomyNodesSlugifiedNameGetFields>?
        v4TaxonomyNodesSlugifiedNameGetFields) {
  if (v4TaxonomyNodesSlugifiedNameGetFields == null) {
    return [];
  }

  return v4TaxonomyNodesSlugifiedNameGetFields
      .map((e) => enums.$V4TaxonomyNodesSlugifiedNameGetFieldsMap[e]!)
      .toList();
}

List<enums.V4TaxonomyNodesSlugifiedNameGetFields>
    v4TaxonomyNodesSlugifiedNameGetFieldsListFromJson(
  List? v4TaxonomyNodesSlugifiedNameGetFields, [
  List<enums.V4TaxonomyNodesSlugifiedNameGetFields>? defaultValue,
]) {
  if (v4TaxonomyNodesSlugifiedNameGetFields == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyNodesSlugifiedNameGetFields
      .map((e) => v4TaxonomyNodesSlugifiedNameGetFieldsFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyNodesSlugifiedNameGetFields>?
    v4TaxonomyNodesSlugifiedNameGetFieldsNullableListFromJson(
  List? v4TaxonomyNodesSlugifiedNameGetFields, [
  List<enums.V4TaxonomyNodesSlugifiedNameGetFields>? defaultValue,
]) {
  if (v4TaxonomyNodesSlugifiedNameGetFields == null) {
    return defaultValue;
  }

  return v4TaxonomyNodesSlugifiedNameGetFields
      .map((e) => v4TaxonomyNodesSlugifiedNameGetFieldsFromJson(e.toString()))
      .toList();
}

String? v4TaxonomyPathsFromRootGetAppCodeToJson(
    enums.V4TaxonomyPathsFromRootGetAppCode?
        v4TaxonomyPathsFromRootGetAppCode) {
  return enums
      .$V4TaxonomyPathsFromRootGetAppCodeMap[v4TaxonomyPathsFromRootGetAppCode];
}

enums.V4TaxonomyPathsFromRootGetAppCode
    v4TaxonomyPathsFromRootGetAppCodeFromJson(
  Object? v4TaxonomyPathsFromRootGetAppCode, [
  enums.V4TaxonomyPathsFromRootGetAppCode? defaultValue,
]) {
  if (v4TaxonomyPathsFromRootGetAppCode is String) {
    return enums.$V4TaxonomyPathsFromRootGetAppCodeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v4TaxonomyPathsFromRootGetAppCode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V4TaxonomyPathsFromRootGetAppCode.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V4TaxonomyPathsFromRootGetAppCodeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V4TaxonomyPathsFromRootGetAppCode.swaggerGeneratedUnknown;
}

List<String> v4TaxonomyPathsFromRootGetAppCodeListToJson(
    List<enums.V4TaxonomyPathsFromRootGetAppCode>?
        v4TaxonomyPathsFromRootGetAppCode) {
  if (v4TaxonomyPathsFromRootGetAppCode == null) {
    return [];
  }

  return v4TaxonomyPathsFromRootGetAppCode
      .map((e) => enums.$V4TaxonomyPathsFromRootGetAppCodeMap[e]!)
      .toList();
}

List<enums.V4TaxonomyPathsFromRootGetAppCode>
    v4TaxonomyPathsFromRootGetAppCodeListFromJson(
  List? v4TaxonomyPathsFromRootGetAppCode, [
  List<enums.V4TaxonomyPathsFromRootGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyPathsFromRootGetAppCode == null) {
    return defaultValue ?? [];
  }

  return v4TaxonomyPathsFromRootGetAppCode
      .map((e) => v4TaxonomyPathsFromRootGetAppCodeFromJson(e.toString()))
      .toList();
}

List<enums.V4TaxonomyPathsFromRootGetAppCode>?
    v4TaxonomyPathsFromRootGetAppCodeNullableListFromJson(
  List? v4TaxonomyPathsFromRootGetAppCode, [
  List<enums.V4TaxonomyPathsFromRootGetAppCode>? defaultValue,
]) {
  if (v4TaxonomyPathsFromRootGetAppCode == null) {
    return defaultValue;
  }

  return v4TaxonomyPathsFromRootGetAppCode
      .map((e) => v4TaxonomyPathsFromRootGetAppCodeFromJson(e.toString()))
      .toList();
}

String? v5TaxonomyNodesTopLevelGetApplicationToJson(
    enums.V5TaxonomyNodesTopLevelGetApplication?
        v5TaxonomyNodesTopLevelGetApplication) {
  return enums.$V5TaxonomyNodesTopLevelGetApplicationMap[
      v5TaxonomyNodesTopLevelGetApplication];
}

enums.V5TaxonomyNodesTopLevelGetApplication
    v5TaxonomyNodesTopLevelGetApplicationFromJson(
  Object? v5TaxonomyNodesTopLevelGetApplication, [
  enums.V5TaxonomyNodesTopLevelGetApplication? defaultValue,
]) {
  if (v5TaxonomyNodesTopLevelGetApplication is String) {
    return enums.$V5TaxonomyNodesTopLevelGetApplicationMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v5TaxonomyNodesTopLevelGetApplication.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V5TaxonomyNodesTopLevelGetApplication
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V5TaxonomyNodesTopLevelGetApplicationMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V5TaxonomyNodesTopLevelGetApplication.swaggerGeneratedUnknown;
}

List<String> v5TaxonomyNodesTopLevelGetApplicationListToJson(
    List<enums.V5TaxonomyNodesTopLevelGetApplication>?
        v5TaxonomyNodesTopLevelGetApplication) {
  if (v5TaxonomyNodesTopLevelGetApplication == null) {
    return [];
  }

  return v5TaxonomyNodesTopLevelGetApplication
      .map((e) => enums.$V5TaxonomyNodesTopLevelGetApplicationMap[e]!)
      .toList();
}

List<enums.V5TaxonomyNodesTopLevelGetApplication>
    v5TaxonomyNodesTopLevelGetApplicationListFromJson(
  List? v5TaxonomyNodesTopLevelGetApplication, [
  List<enums.V5TaxonomyNodesTopLevelGetApplication>? defaultValue,
]) {
  if (v5TaxonomyNodesTopLevelGetApplication == null) {
    return defaultValue ?? [];
  }

  return v5TaxonomyNodesTopLevelGetApplication
      .map((e) => v5TaxonomyNodesTopLevelGetApplicationFromJson(e.toString()))
      .toList();
}

List<enums.V5TaxonomyNodesTopLevelGetApplication>?
    v5TaxonomyNodesTopLevelGetApplicationNullableListFromJson(
  List? v5TaxonomyNodesTopLevelGetApplication, [
  List<enums.V5TaxonomyNodesTopLevelGetApplication>? defaultValue,
]) {
  if (v5TaxonomyNodesTopLevelGetApplication == null) {
    return defaultValue;
  }

  return v5TaxonomyNodesTopLevelGetApplication
      .map((e) => v5TaxonomyNodesTopLevelGetApplicationFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
