// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'thumbnail_service.enums.swagger.dart' as enums;
export 'thumbnail_service.enums.swagger.dart';

part 'thumbnail_service.swagger.chopper.dart';
part 'thumbnail_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ThumbnailService extends ChopperService {
  static ThumbnailService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ThumbnailService(client);
    }

    final newClient = ChopperClient(
        services: [_$ThumbnailService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$ThumbnailService(newClient);
  }

  ///Assetize content from rolling buffer
  Future<chopper.Response<NotificationResponse>> assetsAssetizePost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        NotificationResponse, () => NotificationResponse.fromJsonFactory);

    return _assetsAssetizePost(cacheControl: cacheControl);
  }

  ///Assetize content from rolling buffer
  @Post(
    path: '/assets/assetize',
    optionalBody: true,
  )
  Future<chopper.Response<NotificationResponse>> _assetsAssetizePost(
      {@Header('Cache-Control') String? cacheControl});

  ///Get or create WebVTT file
  ///@param assetId Content reference identifier
  ///@param start-offset Start offset (in seconds)
  ///@param end-offset End offset (in seconds)
  ///@param X-Original-URI
  Future<chopper.Response<String>> assetsAssetIdGet({
    required String? assetId,
    String? startOffset,
    String? endOffset,
    String? xOriginalURI,
    String? cacheControl,
  }) {
    return _assetsAssetIdGet(
        assetId: assetId,
        startOffset: startOffset,
        endOffset: endOffset,
        xOriginalURI: xOriginalURI,
        cacheControl: cacheControl);
  }

  ///Get or create WebVTT file
  ///@param assetId Content reference identifier
  ///@param start-offset Start offset (in seconds)
  ///@param end-offset End offset (in seconds)
  ///@param X-Original-URI
  @Get(path: '/assets/{assetId}')
  Future<chopper.Response<String>> _assetsAssetIdGet({
    @Path('assetId') required String? assetId,
    @Query('start-offset') String? startOffset,
    @Query('end-offset') String? endOffset,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Uploads thumbnails files
  ///@param assetId Content reference identifier
  Future<chopper.Response> assetsAssetIdThumbnailsPost({
    required String? assetId,
    String? cacheControl,
    List? files,
  }) {
    return _assetsAssetIdThumbnailsPost(
        assetId: assetId, cacheControl: cacheControl, files: files);
  }

  ///Uploads thumbnails files
  ///@param assetId Content reference identifier
  @Post(path: '/assets/{assetId}/thumbnails')
  Future<chopper.Response> _assetsAssetIdThumbnailsPost({
    @Path('assetId') required String? assetId,
    @Header('Cache-Control') String? cacheControl,
    @Part() List? files,
  });

  ///Cleanup thumbnails files
  ///@param assetId Content reference identifier
  Future<chopper.Response> assetsAssetIdThumbnailsDelete({
    required String? assetId,
    String? cacheControl,
  }) {
    return _assetsAssetIdThumbnailsDelete(
        assetId: assetId, cacheControl: cacheControl);
  }

  ///Cleanup thumbnails files
  ///@param assetId Content reference identifier
  @Delete(path: '/assets/{assetId}/thumbnails')
  Future<chopper.Response> _assetsAssetIdThumbnailsDelete({
    @Path('assetId') required String? assetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get binary file
  ///@param assetId Content reference identifier
  ///@param binFileName Binary file name
  ///@param Range Requested binary data range
  Future<chopper.Response<String>> assetsAssetIdBinFileNameGet({
    required String? assetId,
    required String? binFileName,
    String? range,
    String? cacheControl,
  }) {
    return _assetsAssetIdBinFileNameGet(
        assetId: assetId,
        binFileName: binFileName,
        range: range,
        cacheControl: cacheControl);
  }

  ///Get binary file
  ///@param assetId Content reference identifier
  ///@param binFileName Binary file name
  ///@param Range Requested binary data range
  @Get(path: '/assets/{assetId}/{binFileName}')
  Future<chopper.Response<String>> _assetsAssetIdBinFileNameGet({
    @Path('assetId') required String? assetId,
    @Path('binFileName') required String? binFileName,
    @Header('Range') String? range,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get WebVTT file
  ///@param channelId Channel identifier
  ///@param start Start time: Please use format 'YYYY-MM-DDTHH:mm:ssZ'
  ///@param end End time: Please use format 'YYYY-MM-DDTHH:mm:ssZ'
  ///@param source Video sub folder source for thumbnails.
  ///@param X-Original-URI
  Future<chopper.Response> channelsChannelIdGet({
    required String? channelId,
    required String? start,
    required String? end,
    enums.ChannelsChannelIdGetSource? source,
    String? xOriginalURI,
    String? cacheControl,
  }) {
    return _channelsChannelIdGet(
        channelId: channelId,
        start: start,
        end: end,
        source: enums.$ChannelsChannelIdGetSourceMap[source]?.toString(),
        xOriginalURI: xOriginalURI,
        cacheControl: cacheControl);
  }

  ///Get WebVTT file
  ///@param channelId Channel identifier
  ///@param start Start time: Please use format 'YYYY-MM-DDTHH:mm:ssZ'
  ///@param end End time: Please use format 'YYYY-MM-DDTHH:mm:ssZ'
  ///@param source Video sub folder source for thumbnails.
  ///@param X-Original-URI
  @Get(path: '/channels/{channelId}')
  Future<chopper.Response> _channelsChannelIdGet({
    @Path('channelId') required String? channelId,
    @Query('start') required String? start,
    @Query('end') required String? end,
    @Query('source') String? source,
    @Header('X-Original-URI') String? xOriginalURI,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns the latest available thumbnail for the channel
  ///@param channelId Channel identifier
  Future<chopper.Response<String>> channelsChannelIdLatestGet({
    required String? channelId,
    String? cacheControl,
  }) {
    return _channelsChannelIdLatestGet(
        channelId: channelId, cacheControl: cacheControl);
  }

  ///Returns the latest available thumbnail for the channel
  ///@param channelId Channel identifier
  @Get(path: '/channels/{channelId}/latest')
  Future<chopper.Response<String>> _channelsChannelIdLatestGet({
    @Path('channelId') required String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  ///@param source Video sub folder source for thumbnails.
  Future<chopper.Response<String>> channelsChannelIdBinFileNameGet({
    required String? channelId,
    required String? binFileName,
    enums.ChannelsChannelIdBinFileNameGetSource? source,
    String? cacheControl,
  }) {
    return _channelsChannelIdBinFileNameGet(
        channelId: channelId,
        binFileName: binFileName,
        source:
            enums.$ChannelsChannelIdBinFileNameGetSourceMap[source]?.toString(),
        cacheControl: cacheControl);
  }

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  ///@param source Video sub folder source for thumbnails.
  @Get(path: '/channels/{channelId}/{binFileName}')
  Future<chopper.Response<String>> _channelsChannelIdBinFileNameGet({
    @Path('channelId') required String? channelId,
    @Path('binFileName') required String? binFileName,
    @Query('source') String? source,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  ///@param source Video sub folder source for thumbnails.
  Future<chopper.Response> channelsChannelIdBinFileNameHead({
    required String? channelId,
    required String? binFileName,
    enums.ChannelsChannelIdBinFileNameHeadSource? source,
    String? cacheControl,
  }) {
    return _channelsChannelIdBinFileNameHead(
        channelId: channelId,
        binFileName: binFileName,
        source: enums.$ChannelsChannelIdBinFileNameHeadSourceMap[source]
            ?.toString(),
        cacheControl: cacheControl);
  }

  ///Get binary file
  ///@param channelId Channel identifier
  ///@param binFileName Name of the BIN file
  ///@param source Video sub folder source for thumbnails.
  @Head(path: '/channels/{channelId}/{binFileName}')
  Future<chopper.Response> _channelsChannelIdBinFileNameHead({
    @Path('channelId') required String? channelId,
    @Path('binFileName') required String? binFileName,
    @Query('source') String? source,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get image file
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  Future<chopper.Response> channelsChannelIdYearMonthDayHourMinuteSecondGet({
    required String? channelId,
    required int? year,
    required int? month,
    required int? day,
    required int? hour,
    required int? minute,
    required int? second,
    String? cacheControl,
  }) {
    return _channelsChannelIdYearMonthDayHourMinuteSecondGet(
        channelId: channelId,
        year: year,
        month: month,
        day: day,
        hour: hour,
        minute: minute,
        second: second,
        cacheControl: cacheControl);
  }

  ///Get image file
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  @Get(
      path:
          '/channels/{channelId}/{year}/{month}/{day}/{hour}/{minute}/{second}')
  Future<chopper.Response> _channelsChannelIdYearMonthDayHourMinuteSecondGet({
    @Path('channelId') required String? channelId,
    @Path('year') required int? year,
    @Path('month') required int? month,
    @Path('day') required int? day,
    @Path('hour') required int? hour,
    @Path('minute') required int? minute,
    @Path('second') required int? second,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns a screengrab image located at the path on the unassetized screengrab storage
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  Future<chopper.Response>
      screengrabsChannelsChannelIdYearMonthDayHourMinuteSecondGet({
    required String? channelId,
    required int? year,
    required int? month,
    required int? day,
    required int? hour,
    required int? minute,
    required int? second,
    String? cacheControl,
  }) {
    return _screengrabsChannelsChannelIdYearMonthDayHourMinuteSecondGet(
        channelId: channelId,
        year: year,
        month: month,
        day: day,
        hour: hour,
        minute: minute,
        second: second,
        cacheControl: cacheControl);
  }

  ///Returns a screengrab image located at the path on the unassetized screengrab storage
  ///@param channelId Channel identifier
  ///@param year Year
  ///@param month Month
  ///@param day Day of month
  ///@param hour Hour of a day
  ///@param minute Minute
  ///@param second Second
  @Get(
      path:
          '/screengrabs/channels/{channelId}/{year}/{month}/{day}/{hour}/{minute}/{second}')
  Future<chopper.Response>
      _screengrabsChannelsChannelIdYearMonthDayHourMinuteSecondGet({
    @Path('channelId') required String? channelId,
    @Path('year') required int? year,
    @Path('month') required int? month,
    @Path('day') required int? day,
    @Path('hour') required int? hour,
    @Path('minute') required int? minute,
    @Path('second') required int? second,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get metadata for screensgrabs of some asset
  ///@param assetId Asset id
  Future<chopper.Response> screengrabsAssetIdMetadataGet({
    required String? assetId,
    String? cacheControl,
  }) {
    return _screengrabsAssetIdMetadataGet(
        assetId: assetId, cacheControl: cacheControl);
  }

  ///Get metadata for screensgrabs of some asset
  ///@param assetId Asset id
  @Get(path: '/screengrabs/{assetId}/metadata')
  Future<chopper.Response> _screengrabsAssetIdMetadataGet({
    @Path('assetId') required String? assetId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns a screengrab image located at the path on the assetized screengrab storage
  ///@param assetId Screengrab assetId
  ///@param fileName Screengrab fileName
  Future<chopper.Response> screengrabsAssetIdFileNameGet({
    required String? assetId,
    required String? fileName,
    String? cacheControl,
  }) {
    return _screengrabsAssetIdFileNameGet(
        assetId: assetId, fileName: fileName, cacheControl: cacheControl);
  }

  ///Returns a screengrab image located at the path on the assetized screengrab storage
  ///@param assetId Screengrab assetId
  ///@param fileName Screengrab fileName
  @Get(path: '/screengrabs/{assetId}/{fileName}')
  Future<chopper.Response> _screengrabsAssetIdFileNameGet({
    @Path('assetId') required String? assetId,
    @Path('fileName') required String? fileName,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class NotificationResponse {
  NotificationResponse();

  factory NotificationResponse.fromJson(Map<String, dynamic> json) =>
      _$NotificationResponseFromJson(json);

  static const fromJsonFactory = _$NotificationResponseFromJson;
  static const toJsonFactory = _$NotificationResponseToJson;
  Map<String, dynamic> toJson() => _$NotificationResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

String? channelsChannelIdGetSourceToJson(
    enums.ChannelsChannelIdGetSource? channelsChannelIdGetSource) {
  return enums.$ChannelsChannelIdGetSourceMap[channelsChannelIdGetSource];
}

enums.ChannelsChannelIdGetSource channelsChannelIdGetSourceFromJson(
  Object? channelsChannelIdGetSource, [
  enums.ChannelsChannelIdGetSource? defaultValue,
]) {
  if (channelsChannelIdGetSource is String) {
    return enums.$ChannelsChannelIdGetSourceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                channelsChannelIdGetSource.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelsChannelIdGetSource.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelsChannelIdGetSourceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelsChannelIdGetSource.swaggerGeneratedUnknown;
}

List<String> channelsChannelIdGetSourceListToJson(
    List<enums.ChannelsChannelIdGetSource>? channelsChannelIdGetSource) {
  if (channelsChannelIdGetSource == null) {
    return [];
  }

  return channelsChannelIdGetSource
      .map((e) => enums.$ChannelsChannelIdGetSourceMap[e]!)
      .toList();
}

List<enums.ChannelsChannelIdGetSource> channelsChannelIdGetSourceListFromJson(
  List? channelsChannelIdGetSource, [
  List<enums.ChannelsChannelIdGetSource>? defaultValue,
]) {
  if (channelsChannelIdGetSource == null) {
    return defaultValue ?? [];
  }

  return channelsChannelIdGetSource
      .map((e) => channelsChannelIdGetSourceFromJson(e.toString()))
      .toList();
}

List<enums.ChannelsChannelIdGetSource>?
    channelsChannelIdGetSourceNullableListFromJson(
  List? channelsChannelIdGetSource, [
  List<enums.ChannelsChannelIdGetSource>? defaultValue,
]) {
  if (channelsChannelIdGetSource == null) {
    return defaultValue;
  }

  return channelsChannelIdGetSource
      .map((e) => channelsChannelIdGetSourceFromJson(e.toString()))
      .toList();
}

String? channelsChannelIdBinFileNameGetSourceToJson(
    enums.ChannelsChannelIdBinFileNameGetSource?
        channelsChannelIdBinFileNameGetSource) {
  return enums.$ChannelsChannelIdBinFileNameGetSourceMap[
      channelsChannelIdBinFileNameGetSource];
}

enums.ChannelsChannelIdBinFileNameGetSource
    channelsChannelIdBinFileNameGetSourceFromJson(
  Object? channelsChannelIdBinFileNameGetSource, [
  enums.ChannelsChannelIdBinFileNameGetSource? defaultValue,
]) {
  if (channelsChannelIdBinFileNameGetSource is String) {
    return enums.$ChannelsChannelIdBinFileNameGetSourceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                channelsChannelIdBinFileNameGetSource.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelsChannelIdBinFileNameGetSource
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelsChannelIdBinFileNameGetSourceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelsChannelIdBinFileNameGetSource.swaggerGeneratedUnknown;
}

List<String> channelsChannelIdBinFileNameGetSourceListToJson(
    List<enums.ChannelsChannelIdBinFileNameGetSource>?
        channelsChannelIdBinFileNameGetSource) {
  if (channelsChannelIdBinFileNameGetSource == null) {
    return [];
  }

  return channelsChannelIdBinFileNameGetSource
      .map((e) => enums.$ChannelsChannelIdBinFileNameGetSourceMap[e]!)
      .toList();
}

List<enums.ChannelsChannelIdBinFileNameGetSource>
    channelsChannelIdBinFileNameGetSourceListFromJson(
  List? channelsChannelIdBinFileNameGetSource, [
  List<enums.ChannelsChannelIdBinFileNameGetSource>? defaultValue,
]) {
  if (channelsChannelIdBinFileNameGetSource == null) {
    return defaultValue ?? [];
  }

  return channelsChannelIdBinFileNameGetSource
      .map((e) => channelsChannelIdBinFileNameGetSourceFromJson(e.toString()))
      .toList();
}

List<enums.ChannelsChannelIdBinFileNameGetSource>?
    channelsChannelIdBinFileNameGetSourceNullableListFromJson(
  List? channelsChannelIdBinFileNameGetSource, [
  List<enums.ChannelsChannelIdBinFileNameGetSource>? defaultValue,
]) {
  if (channelsChannelIdBinFileNameGetSource == null) {
    return defaultValue;
  }

  return channelsChannelIdBinFileNameGetSource
      .map((e) => channelsChannelIdBinFileNameGetSourceFromJson(e.toString()))
      .toList();
}

String? channelsChannelIdBinFileNameHeadSourceToJson(
    enums.ChannelsChannelIdBinFileNameHeadSource?
        channelsChannelIdBinFileNameHeadSource) {
  return enums.$ChannelsChannelIdBinFileNameHeadSourceMap[
      channelsChannelIdBinFileNameHeadSource];
}

enums.ChannelsChannelIdBinFileNameHeadSource
    channelsChannelIdBinFileNameHeadSourceFromJson(
  Object? channelsChannelIdBinFileNameHeadSource, [
  enums.ChannelsChannelIdBinFileNameHeadSource? defaultValue,
]) {
  if (channelsChannelIdBinFileNameHeadSource is String) {
    return enums.$ChannelsChannelIdBinFileNameHeadSourceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                channelsChannelIdBinFileNameHeadSource.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ChannelsChannelIdBinFileNameHeadSource
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ChannelsChannelIdBinFileNameHeadSourceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ChannelsChannelIdBinFileNameHeadSource.swaggerGeneratedUnknown;
}

List<String> channelsChannelIdBinFileNameHeadSourceListToJson(
    List<enums.ChannelsChannelIdBinFileNameHeadSource>?
        channelsChannelIdBinFileNameHeadSource) {
  if (channelsChannelIdBinFileNameHeadSource == null) {
    return [];
  }

  return channelsChannelIdBinFileNameHeadSource
      .map((e) => enums.$ChannelsChannelIdBinFileNameHeadSourceMap[e]!)
      .toList();
}

List<enums.ChannelsChannelIdBinFileNameHeadSource>
    channelsChannelIdBinFileNameHeadSourceListFromJson(
  List? channelsChannelIdBinFileNameHeadSource, [
  List<enums.ChannelsChannelIdBinFileNameHeadSource>? defaultValue,
]) {
  if (channelsChannelIdBinFileNameHeadSource == null) {
    return defaultValue ?? [];
  }

  return channelsChannelIdBinFileNameHeadSource
      .map((e) => channelsChannelIdBinFileNameHeadSourceFromJson(e.toString()))
      .toList();
}

List<enums.ChannelsChannelIdBinFileNameHeadSource>?
    channelsChannelIdBinFileNameHeadSourceNullableListFromJson(
  List? channelsChannelIdBinFileNameHeadSource, [
  List<enums.ChannelsChannelIdBinFileNameHeadSource>? defaultValue,
]) {
  if (channelsChannelIdBinFileNameHeadSource == null) {
    return defaultValue;
  }

  return channelsChannelIdBinFileNameHeadSource
      .map((e) => channelsChannelIdBinFileNameHeadSourceFromJson(e.toString()))
      .toList();
}

@JsonSerializable(explicitToJson: true)
class AssetsAssetIdThumbnailsPost$RequestBody {
  AssetsAssetIdThumbnailsPost$RequestBody({
    this.files,
  });

  factory AssetsAssetIdThumbnailsPost$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$AssetsAssetIdThumbnailsPost$RequestBodyFromJson(json);

  @JsonKey(name: 'files', includeIfNull: false, defaultValue: <String>[])
  final List<String>? files;
  static const fromJsonFactory =
      _$AssetsAssetIdThumbnailsPost$RequestBodyFromJson;
  static const toJsonFactory = _$AssetsAssetIdThumbnailsPost$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$AssetsAssetIdThumbnailsPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AssetsAssetIdThumbnailsPost$RequestBody &&
            (identical(other.files, files) ||
                const DeepCollectionEquality().equals(other.files, files)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(files) ^ runtimeType.hashCode;
}

extension $AssetsAssetIdThumbnailsPost$RequestBodyExtension
    on AssetsAssetIdThumbnailsPost$RequestBody {
  AssetsAssetIdThumbnailsPost$RequestBody copyWith({List<String>? files}) {
    return AssetsAssetIdThumbnailsPost$RequestBody(files: files ?? this.files);
  }

  AssetsAssetIdThumbnailsPost$RequestBody copyWithWrapped(
      {Wrapped<List<String>?>? files}) {
    return AssetsAssetIdThumbnailsPost$RequestBody(
        files: (files != null ? files.value : this.files));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
