// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;

part 'api_docs.swagger.chopper.dart';
part 'api_docs.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class ApiDocs extends ChopperService {
  static ApiDocs create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$ApiDocs(client);
    }

    final newClient = ChopperClient(
        services: [_$ApiDocs()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$ApiDocs(newClient);
  }

  ///Отправка смс кода
  Future<chopper.Response> apiV1AuthSendCodePost({
    String? cacheControl,
    required SendCodeRequest? body,
  }) {
    return _apiV1AuthSendCodePost(cacheControl: cacheControl, body: body);
  }

  ///Отправка смс кода
  @Post(path: '/api/v1/auth/send_code')
  Future<chopper.Response> _apiV1AuthSendCodePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SendCodeRequest? body,
  });

  ///Вход
  Future<chopper.Response<SigninResource>> apiV1AuthSigninPost({
    String? cacheControl,
    required SigninRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        SigninResource, () => SigninResource.fromJsonFactory);

    return _apiV1AuthSigninPost(cacheControl: cacheControl, body: body);
  }

  ///Вход
  @Post(path: '/api/v1/auth/signin')
  Future<chopper.Response<SigninResource>> _apiV1AuthSigninPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SigninRequest? body,
  });

  ///Обновить токен
  Future<chopper.Response<TokenResource>> apiV1AuthTokenRefreshPost({
    String? cacheControl,
    required RefreshTokenRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        TokenResource, () => TokenResource.fromJsonFactory);

    return _apiV1AuthTokenRefreshPost(cacheControl: cacheControl, body: body);
  }

  ///Обновить токен
  @Post(path: '/api/v1/auth/token/refresh')
  Future<chopper.Response<TokenResource>> _apiV1AuthTokenRefreshPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RefreshTokenRequest? body,
  });

  ///Выйти
  Future<chopper.Response> apiV1AuthSignoutDelete({String? cacheControl}) {
    return _apiV1AuthSignoutDelete(cacheControl: cacheControl);
  }

  ///Выйти
  @Delete(path: '/api/v1/auth/signout')
  Future<chopper.Response> _apiV1AuthSignoutDelete(
      {@Header('Cache-Control') String? cacheControl});

  ///Получить список категорий
  ///@param city_id Идентификатор города
  Future<chopper.Response<CategoryAllResource>> apiV1CategoriesAllGet({
    required Object? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CategoryAllResource, () => CategoryAllResource.fromJsonFactory);

    return _apiV1CategoriesAllGet(cityId: cityId, cacheControl: cacheControl);
  }

  ///Получить список категорий
  ///@param city_id Идентификатор города
  @Get(path: '/api/v1/categories/all')
  Future<chopper.Response<CategoryAllResource>> _apiV1CategoriesAllGet({
    @Query('city_id') required Object? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить список городов
  Future<chopper.Response<CityAllResource>> apiV1CitiesAllGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        CityAllResource, () => CityAllResource.fromJsonFactory);

    return _apiV1CitiesAllGet(cacheControl: cacheControl);
  }

  ///Получить список городов
  @Get(path: '/api/v1/cities/all')
  Future<chopper.Response<CityAllResource>> _apiV1CitiesAllGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Получить список компаний
  ///@param city_id Идентификатор города
  ///@param category_id Идентификатор категории
  ///@param query Поиск
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  Future<chopper.Response<CompanyIndexResource>> apiV1CompaniesIndexGet({
    required Object? cityId,
    Object? categoryId,
    String? query,
    Object? page,
    Object? perPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CompanyIndexResource, () => CompanyIndexResource.fromJsonFactory);

    return _apiV1CompaniesIndexGet(
        cityId: cityId,
        categoryId: categoryId,
        query: query,
        page: page,
        perPage: perPage,
        cacheControl: cacheControl);
  }

  ///Получить список компаний
  ///@param city_id Идентификатор города
  ///@param category_id Идентификатор категории
  ///@param query Поиск
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  @Get(path: '/api/v1/companies/index')
  Future<chopper.Response<CompanyIndexResource>> _apiV1CompaniesIndexGet({
    @Query('city_id') required Object? cityId,
    @Query('category_id') Object? categoryId,
    @Query('query') String? query,
    @Query('page') Object? page,
    @Query('per_page') Object? perPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить компанию
  ///@param id Идентификатор компании
  Future<chopper.Response<CompanyShowResource>> apiV1CompaniesShowGet({
    required Object? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CompanyShowResource, () => CompanyShowResource.fromJsonFactory);

    return _apiV1CompaniesShowGet(id: id, cacheControl: cacheControl);
  }

  ///Получить компанию
  ///@param id Идентификатор компании
  @Get(path: '/api/v1/companies/show')
  Future<chopper.Response<CompanyShowResource>> _apiV1CompaniesShowGet({
    @Query('id') required Object? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Список избранных
  ///@param city_id Идентификатор города
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  Future<chopper.Response<CompanyIndexResource>> apiV1FavoritesIndexGet({
    required Object? cityId,
    Object? page,
    Object? perPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CompanyIndexResource, () => CompanyIndexResource.fromJsonFactory);

    return _apiV1FavoritesIndexGet(
        cityId: cityId,
        page: page,
        perPage: perPage,
        cacheControl: cacheControl);
  }

  ///Список избранных
  ///@param city_id Идентификатор города
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  @Get(path: '/api/v1/favorites/index')
  Future<chopper.Response<CompanyIndexResource>> _apiV1FavoritesIndexGet({
    @Query('city_id') required Object? cityId,
    @Query('page') Object? page,
    @Query('per_page') Object? perPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Добавить/убрать в избранное
  Future<chopper.Response> apiV1FavoritesStorePatch({
    String? cacheControl,
    required FavoriteStoreRequest? body,
  }) {
    return _apiV1FavoritesStorePatch(cacheControl: cacheControl, body: body);
  }

  ///Добавить/убрать в избранное
  @Patch(path: '/api/v1/favorites/store')
  Future<chopper.Response> _apiV1FavoritesStorePatch({
    @Header('Cache-Control') String? cacheControl,
    @Body() required FavoriteStoreRequest? body,
  });

  ///Получить код замка
  Future<chopper.Response<ShowResource>> apiV1LockCodesShowGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ShowResource, () => ShowResource.fromJsonFactory);

    return _apiV1LockCodesShowGet(cacheControl: cacheControl);
  }

  ///Получить код замка
  @Get(path: '/api/v1/lock_codes/show')
  Future<chopper.Response<ShowResource>> _apiV1LockCodesShowGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Получить уведомления
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  Future<chopper.Response<NotificationIndexResource>>
      apiV1NotificationsIndexGet({
    Object? page,
    Object? perPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(NotificationIndexResource,
        () => NotificationIndexResource.fromJsonFactory);

    return _apiV1NotificationsIndexGet(
        page: page, perPage: perPage, cacheControl: cacheControl);
  }

  ///Получить уведомления
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  @Get(path: '/api/v1/notifications/index')
  Future<chopper.Response<NotificationIndexResource>>
      _apiV1NotificationsIndexGet({
    @Query('page') Object? page,
    @Query('per_page') Object? perPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить уведомление
  ///@param id Идентификатор уведомления
  Future<chopper.Response<NotificationShowResource>> apiV1NotificationsShowGet({
    Object? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(NotificationShowResource,
        () => NotificationShowResource.fromJsonFactory);

    return _apiV1NotificationsShowGet(id: id, cacheControl: cacheControl);
  }

  ///Получить уведомление
  ///@param id Идентификатор уведомления
  @Get(path: '/api/v1/notifications/show')
  Future<chopper.Response<NotificationShowResource>>
      _apiV1NotificationsShowGet({
    @Query('id') Object? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Удалить уведомление
  ///@param id Идентификатор уведомления
  Future<chopper.Response> apiV1NotificationsDeleteDelete({
    Object? id,
    String? cacheControl,
  }) {
    return _apiV1NotificationsDeleteDelete(id: id, cacheControl: cacheControl);
  }

  ///Удалить уведомление
  ///@param id Идентификатор уведомления
  @Delete(path: '/api/v1/notifications/delete')
  Future<chopper.Response> _apiV1NotificationsDeleteDelete({
    @Query('id') Object? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить раписание
  ///@param service_id Идентификатор услуги
  ///@param user_id Идентификатор сотрудника
  Future<chopper.Response<ScheduleAllResource>> apiV1SchedulesAllGet({
    required Object? serviceId,
    Object? userId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ScheduleAllResource, () => ScheduleAllResource.fromJsonFactory);

    return _apiV1SchedulesAllGet(
        serviceId: serviceId, userId: userId, cacheControl: cacheControl);
  }

  ///Получить раписание
  ///@param service_id Идентификатор услуги
  ///@param user_id Идентификатор сотрудника
  @Get(path: '/api/v1/schedules/all')
  Future<chopper.Response<ScheduleAllResource>> _apiV1SchedulesAllGet({
    @Query('service_id') required Object? serviceId,
    @Query('user_id') Object? userId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Создать расписание
  Future<chopper.Response> apiV1SchedulesCreatePost({
    String? cacheControl,
    required ScheduleCreateRequest? body,
  }) {
    return _apiV1SchedulesCreatePost(cacheControl: cacheControl, body: body);
  }

  ///Создать расписание
  @Post(path: '/api/v1/schedules/create')
  Future<chopper.Response> _apiV1SchedulesCreatePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ScheduleCreateRequest? body,
  });

  ///Редактировать расписание
  Future<chopper.Response> apiV1SchedulesUpdatePatch({
    String? cacheControl,
    required ScheduleUpdateRequest? body,
  }) {
    return _apiV1SchedulesUpdatePatch(cacheControl: cacheControl, body: body);
  }

  ///Редактировать расписание
  @Patch(path: '/api/v1/schedules/update')
  Future<chopper.Response> _apiV1SchedulesUpdatePatch({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ScheduleUpdateRequest? body,
  });

  ///Получить мое расписание
  Future<chopper.Response<ScheduleIndexResource>> apiV1SchedulesMyGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ScheduleIndexResource, () => ScheduleIndexResource.fromJsonFactory);

    return _apiV1SchedulesMyGet(cacheControl: cacheControl);
  }

  ///Получить мое расписание
  @Get(path: '/api/v1/schedules/my')
  Future<chopper.Response<ScheduleIndexResource>> _apiV1SchedulesMyGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Просмотр
  Future<chopper.Response<ScheduleShowResource>> apiV1SchedulesShowGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ScheduleShowResource, () => ScheduleShowResource.fromJsonFactory);

    return _apiV1SchedulesShowGet(cacheControl: cacheControl);
  }

  ///Просмотр
  @Get(path: '/api/v1/schedules/show')
  Future<chopper.Response<ScheduleShowResource>> _apiV1SchedulesShowGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Получить список категорий компании с услугами
  ///@param company_id Идентификатор компании
  ///@param specialist_id Идентификатор сотрудника
  Future<chopper.Response<List<Object>>> apiV1ServiceCategoriesAllGet({
    required Object? companyId,
    Object? specialistId,
    String? cacheControl,
  }) {
    return _apiV1ServiceCategoriesAllGet(
        companyId: companyId,
        specialistId: specialistId,
        cacheControl: cacheControl);
  }

  ///Получить список категорий компании с услугами
  ///@param company_id Идентификатор компании
  ///@param specialist_id Идентификатор сотрудника
  @Get(path: '/api/v1/service_categories/all')
  Future<chopper.Response<List<Object>>> _apiV1ServiceCategoriesAllGet({
    @Query('company_id') required Object? companyId,
    @Query('specialist_id') Object? specialistId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить список услуг
  ///@param company_id Идентификатор компании
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  Future<chopper.Response<ServiceIndexResource>> apiV1ServicesIndexGet({
    Object? companyId,
    Object? page,
    Object? perPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceIndexResource, () => ServiceIndexResource.fromJsonFactory);

    return _apiV1ServicesIndexGet(
        companyId: companyId,
        page: page,
        perPage: perPage,
        cacheControl: cacheControl);
  }

  ///Получить список услуг
  ///@param company_id Идентификатор компании
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  @Get(path: '/api/v1/services/index')
  Future<chopper.Response<ServiceIndexResource>> _apiV1ServicesIndexGet({
    @Query('company_id') Object? companyId,
    @Query('page') Object? page,
    @Query('per_page') Object? perPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить услугу
  ///@param id Идентификатор услуги
  Future<chopper.Response<ServiceShowResource>> apiV1ServicesShowGet({
    required Object? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceShowResource, () => ServiceShowResource.fromJsonFactory);

    return _apiV1ServicesShowGet(id: id, cacheControl: cacheControl);
  }

  ///Получить услугу
  ///@param id Идентификатор услуги
  @Get(path: '/api/v1/services/show')
  Future<chopper.Response<ServiceShowResource>> _apiV1ServicesShowGet({
    @Query('id') required Object? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить мои услуги
  Future<chopper.Response<List<ServiceMyResource>>>
      apiV1ProfileServicesIndexGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ServiceMyResource, () => ServiceMyResource.fromJsonFactory);

    return _apiV1ProfileServicesIndexGet(cacheControl: cacheControl);
  }

  ///Получить мои услуги
  @Get(path: '/api/v1/profile/services/index')
  Future<chopper.Response<List<ServiceMyResource>>>
      _apiV1ProfileServicesIndexGet(
          {@Header('Cache-Control') String? cacheControl});

  ///Обновление ставки
  Future<chopper.Response> apiV1ProfileServicesUpdateRatePatch({
    String? cacheControl,
    required List<ServiceUpdateRateRequest>? body,
  }) {
    return _apiV1ProfileServicesUpdateRatePatch(
        cacheControl: cacheControl, body: body);
  }

  ///Обновление ставки
  @Patch(path: '/api/v1/profile/services/update_rate')
  Future<chopper.Response> _apiV1ProfileServicesUpdateRatePatch({
    @Header('Cache-Control') String? cacheControl,
    @Body() required List<ServiceUpdateRateRequest>? body,
  });

  ///Получить сотрудников
  ///@param company_id идентификатор компании
  ///@param service_id идентификатор услуги
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  Future<chopper.Response<SpecialistIndexResource>> apiV1SpecialistsIndexGet({
    required Object? companyId,
    Object? serviceId,
    Object? page,
    Object? perPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SpecialistIndexResource, () => SpecialistIndexResource.fromJsonFactory);

    return _apiV1SpecialistsIndexGet(
        companyId: companyId,
        serviceId: serviceId,
        page: page,
        perPage: perPage,
        cacheControl: cacheControl);
  }

  ///Получить сотрудников
  ///@param company_id идентификатор компании
  ///@param service_id идентификатор услуги
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  @Get(path: '/api/v1/specialists/index')
  Future<chopper.Response<SpecialistIndexResource>> _apiV1SpecialistsIndexGet({
    @Query('company_id') required Object? companyId,
    @Query('service_id') Object? serviceId,
    @Query('page') Object? page,
    @Query('per_page') Object? perPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить сотрудника
  ///@param specialist_id идентификатор сотрудника
  Future<chopper.Response<SpecialistShowResource>> apiV1SpecialistsShowGet({
    required Object? specialistId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SpecialistShowResource, () => SpecialistShowResource.fromJsonFactory);

    return _apiV1SpecialistsShowGet(
        specialistId: specialistId, cacheControl: cacheControl);
  }

  ///Получить сотрудника
  ///@param specialist_id идентификатор сотрудника
  @Get(path: '/api/v1/specialists/show')
  Future<chopper.Response<SpecialistShowResource>> _apiV1SpecialistsShowGet({
    @Query('specialist_id') required Object? specialistId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Статистика по специалисту
  ///@param date_from Дата от
  ///@param date_to Дата до
  Future<chopper.Response<Object>> apiV1ProfileStatisticsSpecialistGet({
    required Object? dateFrom,
    required Object? dateTo,
    String? cacheControl,
  }) {
    return _apiV1ProfileStatisticsSpecialistGet(
        dateFrom: dateFrom, dateTo: dateTo, cacheControl: cacheControl);
  }

  ///Статистика по специалисту
  ///@param date_from Дата от
  ///@param date_to Дата до
  @Get(path: '/api/v1/profile/statistics/specialist')
  Future<chopper.Response<Object>> _apiV1ProfileStatisticsSpecialistGet({
    @Query('date_from') required Object? dateFrom,
    @Query('date_to') required Object? dateTo,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Статистика по пользователю
  ///@param date_from Дата от
  ///@param date_to Дата до
  Future<chopper.Response<Object>> apiV1ProfileStatisticsUserGet({
    required Object? dateFrom,
    required Object? dateTo,
    String? cacheControl,
  }) {
    return _apiV1ProfileStatisticsUserGet(
        dateFrom: dateFrom, dateTo: dateTo, cacheControl: cacheControl);
  }

  ///Статистика по пользователю
  ///@param date_from Дата от
  ///@param date_to Дата до
  @Get(path: '/api/v1/profile/statistics/user')
  Future<chopper.Response<Object>> _apiV1ProfileStatisticsUserGet({
    @Query('date_from') required Object? dateFrom,
    @Query('date_to') required Object? dateTo,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Получить абонементы
  ///@param company_id идентификатор компании
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  Future<chopper.Response<SubscriptionsTypeIndexResource>>
      apiV1SubscriptionsTypesIndexGet({
    required Object? companyId,
    Object? page,
    Object? perPage,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SubscriptionsTypeIndexResource,
        () => SubscriptionsTypeIndexResource.fromJsonFactory);

    return _apiV1SubscriptionsTypesIndexGet(
        companyId: companyId,
        page: page,
        perPage: perPage,
        cacheControl: cacheControl);
  }

  ///Получить абонементы
  ///@param company_id идентификатор компании
  ///@param page Номер страницы
  ///@param per_page Кол-во записей на странице
  @Get(path: '/api/v1/subscriptions_types/index')
  Future<chopper.Response<SubscriptionsTypeIndexResource>>
      _apiV1SubscriptionsTypesIndexGet({
    @Query('company_id') required Object? companyId,
    @Query('page') Object? page,
    @Query('per_page') Object? perPage,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Загрузить
  Future<chopper.Response<Object>> apiV1UploaderUploadPost({
    String? cacheControl,
    required UploadRequest? body,
  }) {
    return _apiV1UploaderUploadPost(cacheControl: cacheControl, body: body);
  }

  ///Загрузить
  @Post(path: '/api/v1/uploader/upload')
  Future<chopper.Response<Object>> _apiV1UploaderUploadPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UploadRequest? body,
  });

  ///Удалить
  Future<chopper.Response> apiV1UploaderDeleteDelete({
    String? cacheControl,
    required UploaderDeleteRequest? body,
  }) {
    return _apiV1UploaderDeleteDelete(cacheControl: cacheControl, body: body);
  }

  ///Удалить
  @Delete(path: '/api/v1/uploader/delete')
  Future<chopper.Response> _apiV1UploaderDeleteDelete({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UploaderDeleteRequest? body,
  });

  ///Удалить
  Future<chopper.Response> apiV1UploaderMediaDeleteDelete({
    String? cacheControl,
    required UploaderMediaDeleteRequest? body,
  }) {
    return _apiV1UploaderMediaDeleteDelete(
        cacheControl: cacheControl, body: body);
  }

  ///Удалить
  @Delete(path: '/api/v1/uploader/media/delete')
  Future<chopper.Response> _apiV1UploaderMediaDeleteDelete({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UploaderMediaDeleteRequest? body,
  });

  ///Включение/выключение уведомлений
  ///@param state включено/выключено
  Future<chopper.Response> apiV1UsersPushNotificationPatch({
    required Object? state,
    String? cacheControl,
  }) {
    return _apiV1UsersPushNotificationPatch(
        state: state, cacheControl: cacheControl);
  }

  ///Включение/выключение уведомлений
  ///@param state включено/выключено
  @Patch(
    path: '/api/v1/users/push_notification',
    optionalBody: true,
  )
  Future<chopper.Response> _apiV1UsersPushNotificationPatch({
    @Query('state') required Object? state,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Проверка есть ли у пользователя роль специалиста
  Future<chopper.Response> apiV1ProfileCheckStaffGet({String? cacheControl}) {
    return _apiV1ProfileCheckStaffGet(cacheControl: cacheControl);
  }

  ///Проверка есть ли у пользователя роль специалиста
  @Get(path: '/api/v1/profile/check_staff')
  Future<chopper.Response> _apiV1ProfileCheckStaffGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Получить чат по id
  Future<chopper.Response<ChatModuleChatResource>> chatModuleChatsChatIdGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ChatModuleChatResource, () => ChatModuleChatResource.fromJsonFactory);

    return _chatModuleChatsChatIdGet(cacheControl: cacheControl);
  }

  ///Получить чат по id
  @Get(path: '/chat_module/chats/{chat_id}')
  Future<chopper.Response<ChatModuleChatResource>> _chatModuleChatsChatIdGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Ивенты - получить пагинированный список всех непрочитанных ивентов
  Future<chopper.Response<List<ChatModuleEventResource>>>
      chatModuleChatsChatIdEventsIndexGet({
    String? cacheControl,
    required ChatModuleEventsGetEventsRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ChatModuleEventResource, () => ChatModuleEventResource.fromJsonFactory);

    return _chatModuleChatsChatIdEventsIndexGet(
        cacheControl: cacheControl, body: body);
  }

  ///Ивенты - получить пагинированный список всех непрочитанных ивентов
  @Get(path: '/chat_module/chats/{chat_id}/events/index')
  Future<chopper.Response<List<ChatModuleEventResource>>>
      _chatModuleChatsChatIdEventsIndexGet({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChatModuleEventsGetEventsRequest? body,
  });

  ///Ивенты - получить все непрочитанные ивенты через сокеты
  Future<chopper.Response> chatModuleChatsChatIdEventsGet(
      {String? cacheControl}) {
    return _chatModuleChatsChatIdEventsGet(cacheControl: cacheControl);
  }

  ///Ивенты - получить все непрочитанные ивенты через сокеты
  @Get(path: '/chat_module/chats/{chat_id}/events')
  Future<chopper.Response> _chatModuleChatsChatIdEventsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Ивенты - пометить ивент как прочитанный
  Future<chopper.Response<ChatModuleChatResource>>
      chatModuleChatsChatIdEventsPost({
    String? cacheControl,
    required ChatModuleEventsSetDeliveredRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ChatModuleChatResource, () => ChatModuleChatResource.fromJsonFactory);

    return _chatModuleChatsChatIdEventsPost(
        cacheControl: cacheControl, body: body);
  }

  ///Ивенты - пометить ивент как прочитанный
  @Post(path: '/chat_module/chats/{chat_id}/events')
  Future<chopper.Response<ChatModuleChatResource>>
      _chatModuleChatsChatIdEventsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChatModuleEventsSetDeliveredRequest? body,
  });

  ///Сообщения - пагинированный список сообщений
  Future<chopper.Response<List<ChatModuleIndexResourcesMessageResource>>>
      chatModuleChatsChatIdMessagesGet({
    String? cacheControl,
    required ChatModuleMessagesIndexRequest? body,
  }) {
    generatedMapping.putIfAbsent(ChatModuleIndexResourcesMessageResource,
        () => ChatModuleIndexResourcesMessageResource.fromJsonFactory);

    return _chatModuleChatsChatIdMessagesGet(
        cacheControl: cacheControl, body: body);
  }

  ///Сообщения - пагинированный список сообщений
  @Get(path: '/chat_module/chats/{chat_id}/messages')
  Future<chopper.Response<List<ChatModuleIndexResourcesMessageResource>>>
      _chatModuleChatsChatIdMessagesGet({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChatModuleMessagesIndexRequest? body,
  });

  ///Сообщения - отправить сообщение в чат
  Future<chopper.Response<ChatModuleEventResource>>
      chatModuleChatsChatIdMessagesPost({
    String? cacheControl,
    required ChatModuleMessagesSendRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ChatModuleEventResource, () => ChatModuleEventResource.fromJsonFactory);

    return _chatModuleChatsChatIdMessagesPost(
        cacheControl: cacheControl, body: body);
  }

  ///Сообщения - отправить сообщение в чат
  @Post(path: '/chat_module/chats/{chat_id}/messages')
  Future<chopper.Response<ChatModuleEventResource>>
      _chatModuleChatsChatIdMessagesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChatModuleMessagesSendRequest? body,
  });

  ///Сообщения - массовое удаление сообщений
  Future<chopper.Response<List<ChatModuleEventResource>>>
      chatModuleChatsChatIdMessagesDelete({
    String? cacheControl,
    required ChatModuleMessagesDeleteRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ChatModuleEventResource, () => ChatModuleEventResource.fromJsonFactory);

    return _chatModuleChatsChatIdMessagesDelete(
        cacheControl: cacheControl, body: body);
  }

  ///Сообщения - массовое удаление сообщений
  @Delete(path: '/chat_module/chats/{chat_id}/messages')
  Future<chopper.Response<List<ChatModuleEventResource>>>
      _chatModuleChatsChatIdMessagesDelete({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChatModuleMessagesDeleteRequest? body,
  });

  ///Сообщения - редактировать сообщение
  Future<chopper.Response<ChatModuleEventResource>>
      chatModuleChatsChatIdMessagesMessageIdPatch({
    String? cacheControl,
    required ChatModuleMessagesUpdateRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ChatModuleEventResource, () => ChatModuleEventResource.fromJsonFactory);

    return _chatModuleChatsChatIdMessagesMessageIdPatch(
        cacheControl: cacheControl, body: body);
  }

  ///Сообщения - редактировать сообщение
  @Patch(path: '/chat_module/chats/{chat_id}/messages/{message_id}')
  Future<chopper.Response<ChatModuleEventResource>>
      _chatModuleChatsChatIdMessagesMessageIdPatch({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChatModuleMessagesUpdateRequest? body,
  });

  ///Получить перенаправление на файл (базовый)
  ///@param slug File slug
  Future<chopper.Response> filesSlugGet({
    required Object? slug,
    String? cacheControl,
  }) {
    return _filesSlugGet(slug: slug, cacheControl: cacheControl);
  }

  ///Получить перенаправление на файл (базовый)
  ///@param slug File slug
  @Get(path: '/files/{slug}')
  Future<chopper.Response> _filesSlugGet({
    @Query('slug') required Object? slug,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Присвоить firebase токен (базовый)
  Future<chopper.Response> apiV1PushNotificationsFirebasePatch({
    String? cacheControl,
    required UpdateFirebaseToken? body,
  }) {
    return _apiV1PushNotificationsFirebasePatch(
        cacheControl: cacheControl, body: body);
  }

  ///Присвоить firebase токен (базовый)
  @Patch(path: '/api/v1/push_notifications/firebase')
  Future<chopper.Response> _apiV1PushNotificationsFirebasePatch({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UpdateFirebaseToken? body,
  });

  ///Получить/создать чат с тех поддержкой (базовый)
  Future<chopper.Response<ChatModuleChatResource>> apiV1TechnicalSupportGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ChatModuleChatResource, () => ChatModuleChatResource.fromJsonFactory);

    return _apiV1TechnicalSupportGet(cacheControl: cacheControl);
  }

  ///Получить/создать чат с тех поддержкой (базовый)
  @Get(path: '/api/v1/technical_support/')
  Future<chopper.Response<ChatModuleChatResource>> _apiV1TechnicalSupportGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Получить свой профиль (базовый)
  Future<chopper.Response<UserResource>> apiV1UsersMeGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        UserResource, () => UserResource.fromJsonFactory);

    return _apiV1UsersMeGet(cacheControl: cacheControl);
  }

  ///Получить свой профиль (базовый)
  @Get(path: '/api/v1/users/me')
  Future<chopper.Response<UserResource>> _apiV1UsersMeGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Обновить профиль (базовый)
  Future<chopper.Response<UserResource>> apiV1UsersUpdatePut({
    String? cacheControl,
    required UserUpdateRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        UserResource, () => UserResource.fromJsonFactory);

    return _apiV1UsersUpdatePut(cacheControl: cacheControl, body: body);
  }

  ///Обновить профиль (базовый)
  @Put(path: '/api/v1/users/update')
  Future<chopper.Response<UserResource>> _apiV1UsersUpdatePut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserUpdateRequest? body,
  });
}

@JsonSerializable(explicitToJson: true)
class LockCodeNotFoundException {
  LockCodeNotFoundException({
    this.message,
    this.description,
  });

  factory LockCodeNotFoundException.fromJson(Map<String, dynamic> json) =>
      _$LockCodeNotFoundExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$LockCodeNotFoundExceptionFromJson;
  static const toJsonFactory = _$LockCodeNotFoundExceptionToJson;
  Map<String, dynamic> toJson() => _$LockCodeNotFoundExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LockCodeNotFoundException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $LockCodeNotFoundExceptionExtension on LockCodeNotFoundException {
  LockCodeNotFoundException copyWith({String? message, String? description}) {
    return LockCodeNotFoundException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  LockCodeNotFoundException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return LockCodeNotFoundException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleAlreadyPassedException {
  ScheduleAlreadyPassedException({
    this.message,
    this.description,
  });

  factory ScheduleAlreadyPassedException.fromJson(Map<String, dynamic> json) =>
      _$ScheduleAlreadyPassedExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$ScheduleAlreadyPassedExceptionFromJson;
  static const toJsonFactory = _$ScheduleAlreadyPassedExceptionToJson;
  Map<String, dynamic> toJson() => _$ScheduleAlreadyPassedExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleAlreadyPassedException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $ScheduleAlreadyPassedExceptionExtension
    on ScheduleAlreadyPassedException {
  ScheduleAlreadyPassedException copyWith(
      {String? message, String? description}) {
    return ScheduleAlreadyPassedException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  ScheduleAlreadyPassedException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return ScheduleAlreadyPassedException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleUsersExistsException {
  ScheduleUsersExistsException({
    this.message,
    this.description,
  });

  factory ScheduleUsersExistsException.fromJson(Map<String, dynamic> json) =>
      _$ScheduleUsersExistsExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$ScheduleUsersExistsExceptionFromJson;
  static const toJsonFactory = _$ScheduleUsersExistsExceptionToJson;
  Map<String, dynamic> toJson() => _$ScheduleUsersExistsExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleUsersExistsException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $ScheduleUsersExistsExceptionExtension
    on ScheduleUsersExistsException {
  ScheduleUsersExistsException copyWith(
      {String? message, String? description}) {
    return ScheduleUsersExistsException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  ScheduleUsersExistsException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return ScheduleUsersExistsException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class SmsCodeCoolDownException {
  SmsCodeCoolDownException({
    this.message,
    this.description,
  });

  factory SmsCodeCoolDownException.fromJson(Map<String, dynamic> json) =>
      _$SmsCodeCoolDownExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$SmsCodeCoolDownExceptionFromJson;
  static const toJsonFactory = _$SmsCodeCoolDownExceptionToJson;
  Map<String, dynamic> toJson() => _$SmsCodeCoolDownExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SmsCodeCoolDownException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $SmsCodeCoolDownExceptionExtension on SmsCodeCoolDownException {
  SmsCodeCoolDownException copyWith({String? message, String? description}) {
    return SmsCodeCoolDownException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  SmsCodeCoolDownException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return SmsCodeCoolDownException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class SmsNotSendException {
  SmsNotSendException({
    this.message,
    this.description,
  });

  factory SmsNotSendException.fromJson(Map<String, dynamic> json) =>
      _$SmsNotSendExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$SmsNotSendExceptionFromJson;
  static const toJsonFactory = _$SmsNotSendExceptionToJson;
  Map<String, dynamic> toJson() => _$SmsNotSendExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SmsNotSendException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $SmsNotSendExceptionExtension on SmsNotSendException {
  SmsNotSendException copyWith({String? message, String? description}) {
    return SmsNotSendException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  SmsNotSendException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return SmsNotSendException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class UserNotFoundException {
  UserNotFoundException({
    this.message,
    this.description,
  });

  factory UserNotFoundException.fromJson(Map<String, dynamic> json) =>
      _$UserNotFoundExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$UserNotFoundExceptionFromJson;
  static const toJsonFactory = _$UserNotFoundExceptionToJson;
  Map<String, dynamic> toJson() => _$UserNotFoundExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserNotFoundException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $UserNotFoundExceptionExtension on UserNotFoundException {
  UserNotFoundException copyWith({String? message, String? description}) {
    return UserNotFoundException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  UserNotFoundException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return UserNotFoundException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class UserNotSpecialistException {
  UserNotSpecialistException({
    this.message,
    this.description,
  });

  factory UserNotSpecialistException.fromJson(Map<String, dynamic> json) =>
      _$UserNotSpecialistExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$UserNotSpecialistExceptionFromJson;
  static const toJsonFactory = _$UserNotSpecialistExceptionToJson;
  Map<String, dynamic> toJson() => _$UserNotSpecialistExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserNotSpecialistException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $UserNotSpecialistExceptionExtension on UserNotSpecialistException {
  UserNotSpecialistException copyWith({String? message, String? description}) {
    return UserNotSpecialistException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  UserNotSpecialistException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return UserNotSpecialistException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class RefreshTokenRequest {
  RefreshTokenRequest({
    required this.refreshToken,
  });

  factory RefreshTokenRequest.fromJson(Map<String, dynamic> json) =>
      _$RefreshTokenRequestFromJson(json);

  @JsonKey(name: 'refresh_token', includeIfNull: false, defaultValue: '')
  final String refreshToken;
  static const fromJsonFactory = _$RefreshTokenRequestFromJson;
  static const toJsonFactory = _$RefreshTokenRequestToJson;
  Map<String, dynamic> toJson() => _$RefreshTokenRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RefreshTokenRequest &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(refreshToken) ^ runtimeType.hashCode;
}

extension $RefreshTokenRequestExtension on RefreshTokenRequest {
  RefreshTokenRequest copyWith({String? refreshToken}) {
    return RefreshTokenRequest(refreshToken: refreshToken ?? this.refreshToken);
  }

  RefreshTokenRequest copyWithWrapped({Wrapped<String>? refreshToken}) {
    return RefreshTokenRequest(
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class SendCodeRequest {
  SendCodeRequest({
    required this.phone,
  });

  factory SendCodeRequest.fromJson(Map<String, dynamic> json) =>
      _$SendCodeRequestFromJson(json);

  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String phone;
  static const fromJsonFactory = _$SendCodeRequestFromJson;
  static const toJsonFactory = _$SendCodeRequestToJson;
  Map<String, dynamic> toJson() => _$SendCodeRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SendCodeRequest &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(phone) ^ runtimeType.hashCode;
}

extension $SendCodeRequestExtension on SendCodeRequest {
  SendCodeRequest copyWith({String? phone}) {
    return SendCodeRequest(phone: phone ?? this.phone);
  }

  SendCodeRequest copyWithWrapped({Wrapped<String>? phone}) {
    return SendCodeRequest(phone: (phone != null ? phone.value : this.phone));
  }
}

@JsonSerializable(explicitToJson: true)
class SigninRequest {
  SigninRequest({
    required this.phone,
    required this.code,
  });

  factory SigninRequest.fromJson(Map<String, dynamic> json) =>
      _$SigninRequestFromJson(json);

  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String phone;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String code;
  static const fromJsonFactory = _$SigninRequestFromJson;
  static const toJsonFactory = _$SigninRequestToJson;
  Map<String, dynamic> toJson() => _$SigninRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SigninRequest &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(code) ^
      runtimeType.hashCode;
}

extension $SigninRequestExtension on SigninRequest {
  SigninRequest copyWith({String? phone, String? code}) {
    return SigninRequest(phone: phone ?? this.phone, code: code ?? this.code);
  }

  SigninRequest copyWithWrapped(
      {Wrapped<String>? phone, Wrapped<String>? code}) {
    return SigninRequest(
        phone: (phone != null ? phone.value : this.phone),
        code: (code != null ? code.value : this.code));
  }
}

@JsonSerializable(explicitToJson: true)
class CategoryAllRequest {
  CategoryAllRequest({
    required this.cityId,
  });

  factory CategoryAllRequest.fromJson(Map<String, dynamic> json) =>
      _$CategoryAllRequestFromJson(json);

  @JsonKey(name: 'city_id', includeIfNull: false)
  final int cityId;
  static const fromJsonFactory = _$CategoryAllRequestFromJson;
  static const toJsonFactory = _$CategoryAllRequestToJson;
  Map<String, dynamic> toJson() => _$CategoryAllRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CategoryAllRequest &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(cityId) ^ runtimeType.hashCode;
}

extension $CategoryAllRequestExtension on CategoryAllRequest {
  CategoryAllRequest copyWith({int? cityId}) {
    return CategoryAllRequest(cityId: cityId ?? this.cityId);
  }

  CategoryAllRequest copyWithWrapped({Wrapped<int>? cityId}) {
    return CategoryAllRequest(
        cityId: (cityId != null ? cityId.value : this.cityId));
  }
}

@JsonSerializable(explicitToJson: true)
class CompanyIndexRequest {
  CompanyIndexRequest({
    required this.cityId,
  });

  factory CompanyIndexRequest.fromJson(Map<String, dynamic> json) =>
      _$CompanyIndexRequestFromJson(json);

  @JsonKey(name: 'city_id', includeIfNull: false)
  final int cityId;
  static const fromJsonFactory = _$CompanyIndexRequestFromJson;
  static const toJsonFactory = _$CompanyIndexRequestToJson;
  Map<String, dynamic> toJson() => _$CompanyIndexRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompanyIndexRequest &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(cityId) ^ runtimeType.hashCode;
}

extension $CompanyIndexRequestExtension on CompanyIndexRequest {
  CompanyIndexRequest copyWith({int? cityId}) {
    return CompanyIndexRequest(cityId: cityId ?? this.cityId);
  }

  CompanyIndexRequest copyWithWrapped({Wrapped<int>? cityId}) {
    return CompanyIndexRequest(
        cityId: (cityId != null ? cityId.value : this.cityId));
  }
}

@JsonSerializable(explicitToJson: true)
class CompanyShowRequest {
  CompanyShowRequest({
    required this.id,
  });

  factory CompanyShowRequest.fromJson(Map<String, dynamic> json) =>
      _$CompanyShowRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$CompanyShowRequestFromJson;
  static const toJsonFactory = _$CompanyShowRequestToJson;
  Map<String, dynamic> toJson() => _$CompanyShowRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompanyShowRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $CompanyShowRequestExtension on CompanyShowRequest {
  CompanyShowRequest copyWith({int? id}) {
    return CompanyShowRequest(id: id ?? this.id);
  }

  CompanyShowRequest copyWithWrapped({Wrapped<int>? id}) {
    return CompanyShowRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class FavoriteIndexRequest {
  FavoriteIndexRequest({
    required this.cityId,
  });

  factory FavoriteIndexRequest.fromJson(Map<String, dynamic> json) =>
      _$FavoriteIndexRequestFromJson(json);

  @JsonKey(name: 'city_id', includeIfNull: false)
  final int cityId;
  static const fromJsonFactory = _$FavoriteIndexRequestFromJson;
  static const toJsonFactory = _$FavoriteIndexRequestToJson;
  Map<String, dynamic> toJson() => _$FavoriteIndexRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FavoriteIndexRequest &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(cityId) ^ runtimeType.hashCode;
}

extension $FavoriteIndexRequestExtension on FavoriteIndexRequest {
  FavoriteIndexRequest copyWith({int? cityId}) {
    return FavoriteIndexRequest(cityId: cityId ?? this.cityId);
  }

  FavoriteIndexRequest copyWithWrapped({Wrapped<int>? cityId}) {
    return FavoriteIndexRequest(
        cityId: (cityId != null ? cityId.value : this.cityId));
  }
}

@JsonSerializable(explicitToJson: true)
class FavoriteStoreRequest {
  FavoriteStoreRequest({
    required this.companyId,
    this.state,
  });

  factory FavoriteStoreRequest.fromJson(Map<String, dynamic> json) =>
      _$FavoriteStoreRequestFromJson(json);

  @JsonKey(name: 'company_id', includeIfNull: false)
  final int companyId;
  @JsonKey(name: 'state', includeIfNull: false)
  final Object? state;
  static const fromJsonFactory = _$FavoriteStoreRequestFromJson;
  static const toJsonFactory = _$FavoriteStoreRequestToJson;
  Map<String, dynamic> toJson() => _$FavoriteStoreRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FavoriteStoreRequest &&
            (identical(other.companyId, companyId) ||
                const DeepCollectionEquality()
                    .equals(other.companyId, companyId)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(companyId) ^
      const DeepCollectionEquality().hash(state) ^
      runtimeType.hashCode;
}

extension $FavoriteStoreRequestExtension on FavoriteStoreRequest {
  FavoriteStoreRequest copyWith({int? companyId, Object? state}) {
    return FavoriteStoreRequest(
        companyId: companyId ?? this.companyId, state: state ?? this.state);
  }

  FavoriteStoreRequest copyWithWrapped(
      {Wrapped<int>? companyId, Wrapped<Object?>? state}) {
    return FavoriteStoreRequest(
        companyId: (companyId != null ? companyId.value : this.companyId),
        state: (state != null ? state.value : this.state));
  }
}

@JsonSerializable(explicitToJson: true)
class NotificationDeleteRequest {
  NotificationDeleteRequest({
    required this.id,
  });

  factory NotificationDeleteRequest.fromJson(Map<String, dynamic> json) =>
      _$NotificationDeleteRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$NotificationDeleteRequestFromJson;
  static const toJsonFactory = _$NotificationDeleteRequestToJson;
  Map<String, dynamic> toJson() => _$NotificationDeleteRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotificationDeleteRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $NotificationDeleteRequestExtension on NotificationDeleteRequest {
  NotificationDeleteRequest copyWith({int? id}) {
    return NotificationDeleteRequest(id: id ?? this.id);
  }

  NotificationDeleteRequest copyWithWrapped({Wrapped<int>? id}) {
    return NotificationDeleteRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class NotificationShowRequest {
  NotificationShowRequest({
    required this.id,
  });

  factory NotificationShowRequest.fromJson(Map<String, dynamic> json) =>
      _$NotificationShowRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$NotificationShowRequestFromJson;
  static const toJsonFactory = _$NotificationShowRequestToJson;
  Map<String, dynamic> toJson() => _$NotificationShowRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotificationShowRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $NotificationShowRequestExtension on NotificationShowRequest {
  NotificationShowRequest copyWith({int? id}) {
    return NotificationShowRequest(id: id ?? this.id);
  }

  NotificationShowRequest copyWithWrapped({Wrapped<int>? id}) {
    return NotificationShowRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleAllRequest {
  ScheduleAllRequest({
    required this.serviceId,
    this.userId,
  });

  factory ScheduleAllRequest.fromJson(Map<String, dynamic> json) =>
      _$ScheduleAllRequestFromJson(json);

  @JsonKey(name: 'service_id', includeIfNull: false)
  final int serviceId;
  @JsonKey(name: 'user_id', includeIfNull: false)
  final int? userId;
  static const fromJsonFactory = _$ScheduleAllRequestFromJson;
  static const toJsonFactory = _$ScheduleAllRequestToJson;
  Map<String, dynamic> toJson() => _$ScheduleAllRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleAllRequest &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(userId) ^
      runtimeType.hashCode;
}

extension $ScheduleAllRequestExtension on ScheduleAllRequest {
  ScheduleAllRequest copyWith({int? serviceId, int? userId}) {
    return ScheduleAllRequest(
        serviceId: serviceId ?? this.serviceId, userId: userId ?? this.userId);
  }

  ScheduleAllRequest copyWithWrapped(
      {Wrapped<int>? serviceId, Wrapped<int?>? userId}) {
    return ScheduleAllRequest(
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        userId: (userId != null ? userId.value : this.userId));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleCreateRequest {
  ScheduleCreateRequest({
    this.startIn,
    required this.serviceId,
    this.capacity,
  });

  factory ScheduleCreateRequest.fromJson(Map<String, dynamic> json) =>
      _$ScheduleCreateRequestFromJson(json);

  @JsonKey(name: 'start_in', includeIfNull: false)
  final Object? startIn;
  @JsonKey(name: 'service_id', includeIfNull: false)
  final int serviceId;
  @JsonKey(name: 'capacity', includeIfNull: false)
  final int? capacity;
  static const fromJsonFactory = _$ScheduleCreateRequestFromJson;
  static const toJsonFactory = _$ScheduleCreateRequestToJson;
  Map<String, dynamic> toJson() => _$ScheduleCreateRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleCreateRequest &&
            (identical(other.startIn, startIn) ||
                const DeepCollectionEquality()
                    .equals(other.startIn, startIn)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.capacity, capacity) ||
                const DeepCollectionEquality()
                    .equals(other.capacity, capacity)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(startIn) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(capacity) ^
      runtimeType.hashCode;
}

extension $ScheduleCreateRequestExtension on ScheduleCreateRequest {
  ScheduleCreateRequest copyWith(
      {Object? startIn, int? serviceId, int? capacity}) {
    return ScheduleCreateRequest(
        startIn: startIn ?? this.startIn,
        serviceId: serviceId ?? this.serviceId,
        capacity: capacity ?? this.capacity);
  }

  ScheduleCreateRequest copyWithWrapped(
      {Wrapped<Object?>? startIn,
      Wrapped<int>? serviceId,
      Wrapped<int?>? capacity}) {
    return ScheduleCreateRequest(
        startIn: (startIn != null ? startIn.value : this.startIn),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        capacity: (capacity != null ? capacity.value : this.capacity));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleShowRequest {
  ScheduleShowRequest({
    required this.id,
  });

  factory ScheduleShowRequest.fromJson(Map<String, dynamic> json) =>
      _$ScheduleShowRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$ScheduleShowRequestFromJson;
  static const toJsonFactory = _$ScheduleShowRequestToJson;
  Map<String, dynamic> toJson() => _$ScheduleShowRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleShowRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $ScheduleShowRequestExtension on ScheduleShowRequest {
  ScheduleShowRequest copyWith({int? id}) {
    return ScheduleShowRequest(id: id ?? this.id);
  }

  ScheduleShowRequest copyWithWrapped({Wrapped<int>? id}) {
    return ScheduleShowRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleUpdateRequest {
  ScheduleUpdateRequest({
    required this.id,
    this.startIn,
    required this.serviceId,
    this.capacity,
  });

  factory ScheduleUpdateRequest.fromJson(Map<String, dynamic> json) =>
      _$ScheduleUpdateRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  @JsonKey(name: 'start_in', includeIfNull: false)
  final Object? startIn;
  @JsonKey(name: 'service_id', includeIfNull: false)
  final int serviceId;
  @JsonKey(name: 'capacity', includeIfNull: false)
  final int? capacity;
  static const fromJsonFactory = _$ScheduleUpdateRequestFromJson;
  static const toJsonFactory = _$ScheduleUpdateRequestToJson;
  Map<String, dynamic> toJson() => _$ScheduleUpdateRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleUpdateRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startIn, startIn) ||
                const DeepCollectionEquality()
                    .equals(other.startIn, startIn)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.capacity, capacity) ||
                const DeepCollectionEquality()
                    .equals(other.capacity, capacity)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startIn) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(capacity) ^
      runtimeType.hashCode;
}

extension $ScheduleUpdateRequestExtension on ScheduleUpdateRequest {
  ScheduleUpdateRequest copyWith(
      {int? id, Object? startIn, int? serviceId, int? capacity}) {
    return ScheduleUpdateRequest(
        id: id ?? this.id,
        startIn: startIn ?? this.startIn,
        serviceId: serviceId ?? this.serviceId,
        capacity: capacity ?? this.capacity);
  }

  ScheduleUpdateRequest copyWithWrapped(
      {Wrapped<int>? id,
      Wrapped<Object?>? startIn,
      Wrapped<int>? serviceId,
      Wrapped<int?>? capacity}) {
    return ScheduleUpdateRequest(
        id: (id != null ? id.value : this.id),
        startIn: (startIn != null ? startIn.value : this.startIn),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        capacity: (capacity != null ? capacity.value : this.capacity));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceIndexRequest {
  ServiceIndexRequest({
    required this.companyId,
  });

  factory ServiceIndexRequest.fromJson(Map<String, dynamic> json) =>
      _$ServiceIndexRequestFromJson(json);

  @JsonKey(name: 'company_id', includeIfNull: false)
  final int companyId;
  static const fromJsonFactory = _$ServiceIndexRequestFromJson;
  static const toJsonFactory = _$ServiceIndexRequestToJson;
  Map<String, dynamic> toJson() => _$ServiceIndexRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceIndexRequest &&
            (identical(other.companyId, companyId) ||
                const DeepCollectionEquality()
                    .equals(other.companyId, companyId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(companyId) ^ runtimeType.hashCode;
}

extension $ServiceIndexRequestExtension on ServiceIndexRequest {
  ServiceIndexRequest copyWith({int? companyId}) {
    return ServiceIndexRequest(companyId: companyId ?? this.companyId);
  }

  ServiceIndexRequest copyWithWrapped({Wrapped<int>? companyId}) {
    return ServiceIndexRequest(
        companyId: (companyId != null ? companyId.value : this.companyId));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceShowRequest {
  ServiceShowRequest({
    required this.id,
  });

  factory ServiceShowRequest.fromJson(Map<String, dynamic> json) =>
      _$ServiceShowRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$ServiceShowRequestFromJson;
  static const toJsonFactory = _$ServiceShowRequestToJson;
  Map<String, dynamic> toJson() => _$ServiceShowRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceShowRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $ServiceShowRequestExtension on ServiceShowRequest {
  ServiceShowRequest copyWith({int? id}) {
    return ServiceShowRequest(id: id ?? this.id);
  }

  ServiceShowRequest copyWithWrapped({Wrapped<int>? id}) {
    return ServiceShowRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceUpdateRateRequest {
  ServiceUpdateRateRequest({
    required this.serviceId,
    required this.rate,
  });

  factory ServiceUpdateRateRequest.fromJson(Map<String, dynamic> json) =>
      _$ServiceUpdateRateRequestFromJson(json);

  @JsonKey(name: 'service_id', includeIfNull: false)
  final int serviceId;
  @JsonKey(name: 'rate', includeIfNull: false)
  final Object rate;
  static const fromJsonFactory = _$ServiceUpdateRateRequestFromJson;
  static const toJsonFactory = _$ServiceUpdateRateRequestToJson;
  Map<String, dynamic> toJson() => _$ServiceUpdateRateRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceUpdateRateRequest &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.rate, rate) ||
                const DeepCollectionEquality().equals(other.rate, rate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(rate) ^
      runtimeType.hashCode;
}

extension $ServiceUpdateRateRequestExtension on ServiceUpdateRateRequest {
  ServiceUpdateRateRequest copyWith({int? serviceId, Object? rate}) {
    return ServiceUpdateRateRequest(
        serviceId: serviceId ?? this.serviceId, rate: rate ?? this.rate);
  }

  ServiceUpdateRateRequest copyWithWrapped(
      {Wrapped<int>? serviceId, Wrapped<Object>? rate}) {
    return ServiceUpdateRateRequest(
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        rate: (rate != null ? rate.value : this.rate));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceCategoryAllRequest {
  ServiceCategoryAllRequest({
    required this.companyId,
    this.specialistId,
  });

  factory ServiceCategoryAllRequest.fromJson(Map<String, dynamic> json) =>
      _$ServiceCategoryAllRequestFromJson(json);

  @JsonKey(name: 'company_id', includeIfNull: false)
  final int companyId;
  @JsonKey(name: 'specialist_id', includeIfNull: false)
  final int? specialistId;
  static const fromJsonFactory = _$ServiceCategoryAllRequestFromJson;
  static const toJsonFactory = _$ServiceCategoryAllRequestToJson;
  Map<String, dynamic> toJson() => _$ServiceCategoryAllRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceCategoryAllRequest &&
            (identical(other.companyId, companyId) ||
                const DeepCollectionEquality()
                    .equals(other.companyId, companyId)) &&
            (identical(other.specialistId, specialistId) ||
                const DeepCollectionEquality()
                    .equals(other.specialistId, specialistId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(companyId) ^
      const DeepCollectionEquality().hash(specialistId) ^
      runtimeType.hashCode;
}

extension $ServiceCategoryAllRequestExtension on ServiceCategoryAllRequest {
  ServiceCategoryAllRequest copyWith({int? companyId, int? specialistId}) {
    return ServiceCategoryAllRequest(
        companyId: companyId ?? this.companyId,
        specialistId: specialistId ?? this.specialistId);
  }

  ServiceCategoryAllRequest copyWithWrapped(
      {Wrapped<int>? companyId, Wrapped<int?>? specialistId}) {
    return ServiceCategoryAllRequest(
        companyId: (companyId != null ? companyId.value : this.companyId),
        specialistId:
            (specialistId != null ? specialistId.value : this.specialistId));
  }
}

@JsonSerializable(explicitToJson: true)
class SpecialistIndexRequest {
  SpecialistIndexRequest({
    required this.companyId,
  });

  factory SpecialistIndexRequest.fromJson(Map<String, dynamic> json) =>
      _$SpecialistIndexRequestFromJson(json);

  @JsonKey(name: 'company_id', includeIfNull: false)
  final int companyId;
  static const fromJsonFactory = _$SpecialistIndexRequestFromJson;
  static const toJsonFactory = _$SpecialistIndexRequestToJson;
  Map<String, dynamic> toJson() => _$SpecialistIndexRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpecialistIndexRequest &&
            (identical(other.companyId, companyId) ||
                const DeepCollectionEquality()
                    .equals(other.companyId, companyId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(companyId) ^ runtimeType.hashCode;
}

extension $SpecialistIndexRequestExtension on SpecialistIndexRequest {
  SpecialistIndexRequest copyWith({int? companyId}) {
    return SpecialistIndexRequest(companyId: companyId ?? this.companyId);
  }

  SpecialistIndexRequest copyWithWrapped({Wrapped<int>? companyId}) {
    return SpecialistIndexRequest(
        companyId: (companyId != null ? companyId.value : this.companyId));
  }
}

@JsonSerializable(explicitToJson: true)
class SpecialistShowRequest {
  SpecialistShowRequest({
    required this.specialistId,
  });

  factory SpecialistShowRequest.fromJson(Map<String, dynamic> json) =>
      _$SpecialistShowRequestFromJson(json);

  @JsonKey(name: 'specialist_id', includeIfNull: false)
  final int specialistId;
  static const fromJsonFactory = _$SpecialistShowRequestFromJson;
  static const toJsonFactory = _$SpecialistShowRequestToJson;
  Map<String, dynamic> toJson() => _$SpecialistShowRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpecialistShowRequest &&
            (identical(other.specialistId, specialistId) ||
                const DeepCollectionEquality()
                    .equals(other.specialistId, specialistId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(specialistId) ^ runtimeType.hashCode;
}

extension $SpecialistShowRequestExtension on SpecialistShowRequest {
  SpecialistShowRequest copyWith({int? specialistId}) {
    return SpecialistShowRequest(
        specialistId: specialistId ?? this.specialistId);
  }

  SpecialistShowRequest copyWithWrapped({Wrapped<int>? specialistId}) {
    return SpecialistShowRequest(
        specialistId:
            (specialistId != null ? specialistId.value : this.specialistId));
  }
}

@JsonSerializable(explicitToJson: true)
class StatisticSpecialistRequest {
  StatisticSpecialistRequest({
    required this.dateFrom,
    required this.dateTo,
  });

  factory StatisticSpecialistRequest.fromJson(Map<String, dynamic> json) =>
      _$StatisticSpecialistRequestFromJson(json);

  @JsonKey(name: 'date_from', includeIfNull: false)
  final Object dateFrom;
  @JsonKey(name: 'date_to', includeIfNull: false)
  final Object dateTo;
  static const fromJsonFactory = _$StatisticSpecialistRequestFromJson;
  static const toJsonFactory = _$StatisticSpecialistRequestToJson;
  Map<String, dynamic> toJson() => _$StatisticSpecialistRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StatisticSpecialistRequest &&
            (identical(other.dateFrom, dateFrom) ||
                const DeepCollectionEquality()
                    .equals(other.dateFrom, dateFrom)) &&
            (identical(other.dateTo, dateTo) ||
                const DeepCollectionEquality().equals(other.dateTo, dateTo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(dateFrom) ^
      const DeepCollectionEquality().hash(dateTo) ^
      runtimeType.hashCode;
}

extension $StatisticSpecialistRequestExtension on StatisticSpecialistRequest {
  StatisticSpecialistRequest copyWith({Object? dateFrom, Object? dateTo}) {
    return StatisticSpecialistRequest(
        dateFrom: dateFrom ?? this.dateFrom, dateTo: dateTo ?? this.dateTo);
  }

  StatisticSpecialistRequest copyWithWrapped(
      {Wrapped<Object>? dateFrom, Wrapped<Object>? dateTo}) {
    return StatisticSpecialistRequest(
        dateFrom: (dateFrom != null ? dateFrom.value : this.dateFrom),
        dateTo: (dateTo != null ? dateTo.value : this.dateTo));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionsTypeIndexRequest {
  SubscriptionsTypeIndexRequest({
    required this.companyId,
  });

  factory SubscriptionsTypeIndexRequest.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionsTypeIndexRequestFromJson(json);

  @JsonKey(name: 'company_id', includeIfNull: false)
  final int companyId;
  static const fromJsonFactory = _$SubscriptionsTypeIndexRequestFromJson;
  static const toJsonFactory = _$SubscriptionsTypeIndexRequestToJson;
  Map<String, dynamic> toJson() => _$SubscriptionsTypeIndexRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionsTypeIndexRequest &&
            (identical(other.companyId, companyId) ||
                const DeepCollectionEquality()
                    .equals(other.companyId, companyId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(companyId) ^ runtimeType.hashCode;
}

extension $SubscriptionsTypeIndexRequestExtension
    on SubscriptionsTypeIndexRequest {
  SubscriptionsTypeIndexRequest copyWith({int? companyId}) {
    return SubscriptionsTypeIndexRequest(
        companyId: companyId ?? this.companyId);
  }

  SubscriptionsTypeIndexRequest copyWithWrapped({Wrapped<int>? companyId}) {
    return SubscriptionsTypeIndexRequest(
        companyId: (companyId != null ? companyId.value : this.companyId));
  }
}

@JsonSerializable(explicitToJson: true)
class UserPushNotificationRequest {
  UserPushNotificationRequest({
    required this.state,
  });

  factory UserPushNotificationRequest.fromJson(Map<String, dynamic> json) =>
      _$UserPushNotificationRequestFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false)
  final bool state;
  static const fromJsonFactory = _$UserPushNotificationRequestFromJson;
  static const toJsonFactory = _$UserPushNotificationRequestToJson;
  Map<String, dynamic> toJson() => _$UserPushNotificationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserPushNotificationRequest &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^ runtimeType.hashCode;
}

extension $UserPushNotificationRequestExtension on UserPushNotificationRequest {
  UserPushNotificationRequest copyWith({bool? state}) {
    return UserPushNotificationRequest(state: state ?? this.state);
  }

  UserPushNotificationRequest copyWithWrapped({Wrapped<bool>? state}) {
    return UserPushNotificationRequest(
        state: (state != null ? state.value : this.state));
  }
}

@JsonSerializable(explicitToJson: true)
class CategoryAllResource {
  CategoryAllResource({
    this.id,
    this.name,
  });

  factory CategoryAllResource.fromJson(Map<String, dynamic> json) =>
      _$CategoryAllResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$CategoryAllResourceFromJson;
  static const toJsonFactory = _$CategoryAllResourceToJson;
  Map<String, dynamic> toJson() => _$CategoryAllResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CategoryAllResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $CategoryAllResourceExtension on CategoryAllResource {
  CategoryAllResource copyWith({int? id, String? name}) {
    return CategoryAllResource(id: id ?? this.id, name: name ?? this.name);
  }

  CategoryAllResource copyWithWrapped(
      {Wrapped<int?>? id, Wrapped<String?>? name}) {
    return CategoryAllResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class CityAllResource {
  CityAllResource({
    this.id,
    this.name,
  });

  factory CityAllResource.fromJson(Map<String, dynamic> json) =>
      _$CityAllResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$CityAllResourceFromJson;
  static const toJsonFactory = _$CityAllResourceToJson;
  Map<String, dynamic> toJson() => _$CityAllResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CityAllResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $CityAllResourceExtension on CityAllResource {
  CityAllResource copyWith({int? id, String? name}) {
    return CityAllResource(id: id ?? this.id, name: name ?? this.name);
  }

  CityAllResource copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? name}) {
    return CityAllResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class CompanyAllResource {
  CompanyAllResource({
    this.id,
    this.name,
    this.logo,
  });

  factory CompanyAllResource.fromJson(Map<String, dynamic> json) =>
      _$CompanyAllResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'logo', includeIfNull: false)
  final MediaResource? logo;
  static const fromJsonFactory = _$CompanyAllResourceFromJson;
  static const toJsonFactory = _$CompanyAllResourceToJson;
  Map<String, dynamic> toJson() => _$CompanyAllResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompanyAllResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(logo) ^
      runtimeType.hashCode;
}

extension $CompanyAllResourceExtension on CompanyAllResource {
  CompanyAllResource copyWith({int? id, String? name, MediaResource? logo}) {
    return CompanyAllResource(
        id: id ?? this.id, name: name ?? this.name, logo: logo ?? this.logo);
  }

  CompanyAllResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<MediaResource?>? logo}) {
    return CompanyAllResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        logo: (logo != null ? logo.value : this.logo));
  }
}

@JsonSerializable(explicitToJson: true)
class CompanyResource {
  CompanyResource({
    this.id,
    this.name,
    this.address,
    this.hasFavorite,
    this.logo,
    this.category,
  });

  factory CompanyResource.fromJson(Map<String, dynamic> json) =>
      _$CompanyResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'address', includeIfNull: false, defaultValue: '')
  final String? address;
  @JsonKey(name: 'has_favorite', includeIfNull: false)
  final Object? hasFavorite;
  @JsonKey(name: 'logo', includeIfNull: false)
  final MediaResource? logo;
  @JsonKey(name: 'category', includeIfNull: false)
  final CategoryAllResource? category;
  static const fromJsonFactory = _$CompanyResourceFromJson;
  static const toJsonFactory = _$CompanyResourceToJson;
  Map<String, dynamic> toJson() => _$CompanyResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompanyResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.hasFavorite, hasFavorite) ||
                const DeepCollectionEquality()
                    .equals(other.hasFavorite, hasFavorite)) &&
            (identical(other.logo, logo) ||
                const DeepCollectionEquality().equals(other.logo, logo)) &&
            (identical(other.category, category) ||
                const DeepCollectionEquality()
                    .equals(other.category, category)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(hasFavorite) ^
      const DeepCollectionEquality().hash(logo) ^
      const DeepCollectionEquality().hash(category) ^
      runtimeType.hashCode;
}

extension $CompanyResourceExtension on CompanyResource {
  CompanyResource copyWith(
      {int? id,
      String? name,
      String? address,
      Object? hasFavorite,
      MediaResource? logo,
      CategoryAllResource? category}) {
    return CompanyResource(
        id: id ?? this.id,
        name: name ?? this.name,
        address: address ?? this.address,
        hasFavorite: hasFavorite ?? this.hasFavorite,
        logo: logo ?? this.logo,
        category: category ?? this.category);
  }

  CompanyResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? address,
      Wrapped<Object?>? hasFavorite,
      Wrapped<MediaResource?>? logo,
      Wrapped<CategoryAllResource?>? category}) {
    return CompanyResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        address: (address != null ? address.value : this.address),
        hasFavorite:
            (hasFavorite != null ? hasFavorite.value : this.hasFavorite),
        logo: (logo != null ? logo.value : this.logo),
        category: (category != null ? category.value : this.category));
  }
}

@JsonSerializable(explicitToJson: true)
class CompanyIndexResource {
  CompanyIndexResource({
    this.data,
    this.meta,
  });

  factory CompanyIndexResource.fromJson(Map<String, dynamic> json) =>
      _$CompanyIndexResourceFromJson(json);

  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <CompanyResource>[])
  final List<CompanyResource>? data;
  @JsonKey(name: 'meta', includeIfNull: false)
  final MetaPaginationResource? meta;
  static const fromJsonFactory = _$CompanyIndexResourceFromJson;
  static const toJsonFactory = _$CompanyIndexResourceToJson;
  Map<String, dynamic> toJson() => _$CompanyIndexResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompanyIndexResource &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(meta) ^
      runtimeType.hashCode;
}

extension $CompanyIndexResourceExtension on CompanyIndexResource {
  CompanyIndexResource copyWith(
      {List<CompanyResource>? data, MetaPaginationResource? meta}) {
    return CompanyIndexResource(
        data: data ?? this.data, meta: meta ?? this.meta);
  }

  CompanyIndexResource copyWithWrapped(
      {Wrapped<List<CompanyResource>?>? data,
      Wrapped<MetaPaginationResource?>? meta}) {
    return CompanyIndexResource(
        data: (data != null ? data.value : this.data),
        meta: (meta != null ? meta.value : this.meta));
  }
}

@JsonSerializable(explicitToJson: true)
class CompanyShowResource {
  CompanyShowResource({
    this.id,
    this.name,
    this.address,
    this.phone,
    this.site,
    this.hasFavorite,
    this.mainImage,
    this.city,
  });

  factory CompanyShowResource.fromJson(Map<String, dynamic> json) =>
      _$CompanyShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'address', includeIfNull: false, defaultValue: '')
  final String? address;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  @JsonKey(name: 'site', includeIfNull: false, defaultValue: '')
  final String? site;
  @JsonKey(name: 'has_favorite', includeIfNull: false)
  final Object? hasFavorite;
  @JsonKey(name: 'main_image', includeIfNull: false)
  final MediaResource? mainImage;
  @JsonKey(name: 'city', includeIfNull: false)
  final CityAllResource? city;
  static const fromJsonFactory = _$CompanyShowResourceFromJson;
  static const toJsonFactory = _$CompanyShowResourceToJson;
  Map<String, dynamic> toJson() => _$CompanyShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CompanyShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.site, site) ||
                const DeepCollectionEquality().equals(other.site, site)) &&
            (identical(other.hasFavorite, hasFavorite) ||
                const DeepCollectionEquality()
                    .equals(other.hasFavorite, hasFavorite)) &&
            (identical(other.mainImage, mainImage) ||
                const DeepCollectionEquality()
                    .equals(other.mainImage, mainImage)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(site) ^
      const DeepCollectionEquality().hash(hasFavorite) ^
      const DeepCollectionEquality().hash(mainImage) ^
      const DeepCollectionEquality().hash(city) ^
      runtimeType.hashCode;
}

extension $CompanyShowResourceExtension on CompanyShowResource {
  CompanyShowResource copyWith(
      {int? id,
      String? name,
      String? address,
      String? phone,
      String? site,
      Object? hasFavorite,
      MediaResource? mainImage,
      CityAllResource? city}) {
    return CompanyShowResource(
        id: id ?? this.id,
        name: name ?? this.name,
        address: address ?? this.address,
        phone: phone ?? this.phone,
        site: site ?? this.site,
        hasFavorite: hasFavorite ?? this.hasFavorite,
        mainImage: mainImage ?? this.mainImage,
        city: city ?? this.city);
  }

  CompanyShowResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? address,
      Wrapped<String?>? phone,
      Wrapped<String?>? site,
      Wrapped<Object?>? hasFavorite,
      Wrapped<MediaResource?>? mainImage,
      Wrapped<CityAllResource?>? city}) {
    return CompanyShowResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        address: (address != null ? address.value : this.address),
        phone: (phone != null ? phone.value : this.phone),
        site: (site != null ? site.value : this.site),
        hasFavorite:
            (hasFavorite != null ? hasFavorite.value : this.hasFavorite),
        mainImage: (mainImage != null ? mainImage.value : this.mainImage),
        city: (city != null ? city.value : this.city));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowResource {
  ShowResource({
    this.id,
    this.code,
    this.expiresAt,
  });

  factory ShowResource.fromJson(Map<String, dynamic> json) =>
      _$ShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String? code;
  @JsonKey(name: 'expires_at', includeIfNull: false)
  final Object? expiresAt;
  static const fromJsonFactory = _$ShowResourceFromJson;
  static const toJsonFactory = _$ShowResourceToJson;
  Map<String, dynamic> toJson() => _$ShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.expiresAt, expiresAt) ||
                const DeepCollectionEquality()
                    .equals(other.expiresAt, expiresAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(expiresAt) ^
      runtimeType.hashCode;
}

extension $ShowResourceExtension on ShowResource {
  ShowResource copyWith({int? id, String? code, Object? expiresAt}) {
    return ShowResource(
        id: id ?? this.id,
        code: code ?? this.code,
        expiresAt: expiresAt ?? this.expiresAt);
  }

  ShowResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? code,
      Wrapped<Object?>? expiresAt}) {
    return ShowResource(
        id: (id != null ? id.value : this.id),
        code: (code != null ? code.value : this.code),
        expiresAt: (expiresAt != null ? expiresAt.value : this.expiresAt));
  }
}

@JsonSerializable(explicitToJson: true)
class NotificationIndexResource {
  NotificationIndexResource({
    this.data,
    this.meta,
  });

  factory NotificationIndexResource.fromJson(Map<String, dynamic> json) =>
      _$NotificationIndexResourceFromJson(json);

  @JsonKey(
      name: 'data',
      includeIfNull: false,
      defaultValue: <NotificationResource>[])
  final List<NotificationResource>? data;
  @JsonKey(name: 'meta', includeIfNull: false)
  final MetaPaginationResource? meta;
  static const fromJsonFactory = _$NotificationIndexResourceFromJson;
  static const toJsonFactory = _$NotificationIndexResourceToJson;
  Map<String, dynamic> toJson() => _$NotificationIndexResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotificationIndexResource &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(meta) ^
      runtimeType.hashCode;
}

extension $NotificationIndexResourceExtension on NotificationIndexResource {
  NotificationIndexResource copyWith(
      {List<NotificationResource>? data, MetaPaginationResource? meta}) {
    return NotificationIndexResource(
        data: data ?? this.data, meta: meta ?? this.meta);
  }

  NotificationIndexResource copyWithWrapped(
      {Wrapped<List<NotificationResource>?>? data,
      Wrapped<MetaPaginationResource?>? meta}) {
    return NotificationIndexResource(
        data: (data != null ? data.value : this.data),
        meta: (meta != null ? meta.value : this.meta));
  }
}

@JsonSerializable(explicitToJson: true)
class NotificationResource {
  NotificationResource({
    this.id,
    this.title,
    this.body,
    this.createdAt,
    this.viewed,
    this.company,
  });

  factory NotificationResource.fromJson(Map<String, dynamic> json) =>
      _$NotificationResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String? body;
  @JsonKey(name: 'created_at', includeIfNull: false)
  final Object? createdAt;
  @JsonKey(name: 'viewed', includeIfNull: false)
  final bool? viewed;
  @JsonKey(name: 'company', includeIfNull: false)
  final CompanyAllResource? company;
  static const fromJsonFactory = _$NotificationResourceFromJson;
  static const toJsonFactory = _$NotificationResourceToJson;
  Map<String, dynamic> toJson() => _$NotificationResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotificationResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.viewed, viewed) ||
                const DeepCollectionEquality().equals(other.viewed, viewed)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality().equals(other.company, company)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(viewed) ^
      const DeepCollectionEquality().hash(company) ^
      runtimeType.hashCode;
}

extension $NotificationResourceExtension on NotificationResource {
  NotificationResource copyWith(
      {int? id,
      String? title,
      String? body,
      Object? createdAt,
      bool? viewed,
      CompanyAllResource? company}) {
    return NotificationResource(
        id: id ?? this.id,
        title: title ?? this.title,
        body: body ?? this.body,
        createdAt: createdAt ?? this.createdAt,
        viewed: viewed ?? this.viewed,
        company: company ?? this.company);
  }

  NotificationResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? body,
      Wrapped<Object?>? createdAt,
      Wrapped<bool?>? viewed,
      Wrapped<CompanyAllResource?>? company}) {
    return NotificationResource(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        body: (body != null ? body.value : this.body),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        viewed: (viewed != null ? viewed.value : this.viewed),
        company: (company != null ? company.value : this.company));
  }
}

@JsonSerializable(explicitToJson: true)
class NotificationShowResource {
  NotificationShowResource({
    this.id,
    this.title,
    this.body,
    this.createdAt,
    this.company,
  });

  factory NotificationShowResource.fromJson(Map<String, dynamic> json) =>
      _$NotificationShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'body', includeIfNull: false, defaultValue: '')
  final String? body;
  @JsonKey(name: 'created_at', includeIfNull: false)
  final Object? createdAt;
  @JsonKey(name: 'company', includeIfNull: false)
  final CompanyAllResource? company;
  static const fromJsonFactory = _$NotificationShowResourceFromJson;
  static const toJsonFactory = _$NotificationShowResourceToJson;
  Map<String, dynamic> toJson() => _$NotificationShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NotificationShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.body, body) ||
                const DeepCollectionEquality().equals(other.body, body)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality().equals(other.company, company)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(body) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(company) ^
      runtimeType.hashCode;
}

extension $NotificationShowResourceExtension on NotificationShowResource {
  NotificationShowResource copyWith(
      {int? id,
      String? title,
      String? body,
      Object? createdAt,
      CompanyAllResource? company}) {
    return NotificationShowResource(
        id: id ?? this.id,
        title: title ?? this.title,
        body: body ?? this.body,
        createdAt: createdAt ?? this.createdAt,
        company: company ?? this.company);
  }

  NotificationShowResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? body,
      Wrapped<Object?>? createdAt,
      Wrapped<CompanyAllResource?>? company}) {
    return NotificationShowResource(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        body: (body != null ? body.value : this.body),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        company: (company != null ? company.value : this.company));
  }
}

@JsonSerializable(explicitToJson: true)
class ParticipantResource {
  ParticipantResource({
    this.id,
    this.firstName,
    this.lastName,
    this.phone,
    this.payment,
  });

  factory ParticipantResource.fromJson(Map<String, dynamic> json) =>
      _$ParticipantResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'first_name', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'last_name', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  @JsonKey(name: 'payment', includeIfNull: false)
  final bool? payment;
  static const fromJsonFactory = _$ParticipantResourceFromJson;
  static const toJsonFactory = _$ParticipantResourceToJson;
  Map<String, dynamic> toJson() => _$ParticipantResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ParticipantResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.payment, payment) ||
                const DeepCollectionEquality().equals(other.payment, payment)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(payment) ^
      runtimeType.hashCode;
}

extension $ParticipantResourceExtension on ParticipantResource {
  ParticipantResource copyWith(
      {int? id,
      String? firstName,
      String? lastName,
      String? phone,
      bool? payment}) {
    return ParticipantResource(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        phone: phone ?? this.phone,
        payment: payment ?? this.payment);
  }

  ParticipantResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? phone,
      Wrapped<bool?>? payment}) {
    return ParticipantResource(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        phone: (phone != null ? phone.value : this.phone),
        payment: (payment != null ? payment.value : this.payment));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleAllResource {
  ScheduleAllResource({
    this.date,
    this.times,
  });

  factory ScheduleAllResource.fromJson(Map<String, dynamic> json) =>
      _$ScheduleAllResourceFromJson(json);

  @JsonKey(name: 'date', includeIfNull: false, defaultValue: '')
  final String? date;
  @JsonKey(
      name: 'times', includeIfNull: false, defaultValue: <ScheduleResource>[])
  final List<ScheduleResource>? times;
  static const fromJsonFactory = _$ScheduleAllResourceFromJson;
  static const toJsonFactory = _$ScheduleAllResourceToJson;
  Map<String, dynamic> toJson() => _$ScheduleAllResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleAllResource &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.times, times) ||
                const DeepCollectionEquality().equals(other.times, times)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(times) ^
      runtimeType.hashCode;
}

extension $ScheduleAllResourceExtension on ScheduleAllResource {
  ScheduleAllResource copyWith({String? date, List<ScheduleResource>? times}) {
    return ScheduleAllResource(
        date: date ?? this.date, times: times ?? this.times);
  }

  ScheduleAllResource copyWithWrapped(
      {Wrapped<String?>? date, Wrapped<List<ScheduleResource>?>? times}) {
    return ScheduleAllResource(
        date: (date != null ? date.value : this.date),
        times: (times != null ? times.value : this.times));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleIndexResource {
  ScheduleIndexResource({
    this.data,
    this.meta,
  });

  factory ScheduleIndexResource.fromJson(Map<String, dynamic> json) =>
      _$ScheduleIndexResourceFromJson(json);

  @JsonKey(
      name: 'data',
      includeIfNull: false,
      defaultValue: <ScheduleWithServiceResource>[])
  final List<ScheduleWithServiceResource>? data;
  @JsonKey(name: 'meta', includeIfNull: false)
  final MetaPaginationResource? meta;
  static const fromJsonFactory = _$ScheduleIndexResourceFromJson;
  static const toJsonFactory = _$ScheduleIndexResourceToJson;
  Map<String, dynamic> toJson() => _$ScheduleIndexResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleIndexResource &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(meta) ^
      runtimeType.hashCode;
}

extension $ScheduleIndexResourceExtension on ScheduleIndexResource {
  ScheduleIndexResource copyWith(
      {List<ScheduleWithServiceResource>? data, MetaPaginationResource? meta}) {
    return ScheduleIndexResource(
        data: data ?? this.data, meta: meta ?? this.meta);
  }

  ScheduleIndexResource copyWithWrapped(
      {Wrapped<List<ScheduleWithServiceResource>?>? data,
      Wrapped<MetaPaginationResource?>? meta}) {
    return ScheduleIndexResource(
        data: (data != null ? data.value : this.data),
        meta: (meta != null ? meta.value : this.meta));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleResource {
  ScheduleResource({
    this.id,
    this.startIn,
    this.user,
  });

  factory ScheduleResource.fromJson(Map<String, dynamic> json) =>
      _$ScheduleResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'start_in', includeIfNull: false, defaultValue: '')
  final String? startIn;
  @JsonKey(name: 'user', includeIfNull: false)
  final SpecialistWithPriceResource? user;
  static const fromJsonFactory = _$ScheduleResourceFromJson;
  static const toJsonFactory = _$ScheduleResourceToJson;
  Map<String, dynamic> toJson() => _$ScheduleResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startIn, startIn) ||
                const DeepCollectionEquality()
                    .equals(other.startIn, startIn)) &&
            (identical(other.user, user) ||
                const DeepCollectionEquality().equals(other.user, user)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startIn) ^
      const DeepCollectionEquality().hash(user) ^
      runtimeType.hashCode;
}

extension $ScheduleResourceExtension on ScheduleResource {
  ScheduleResource copyWith(
      {int? id, String? startIn, SpecialistWithPriceResource? user}) {
    return ScheduleResource(
        id: id ?? this.id,
        startIn: startIn ?? this.startIn,
        user: user ?? this.user);
  }

  ScheduleResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? startIn,
      Wrapped<SpecialistWithPriceResource?>? user}) {
    return ScheduleResource(
        id: (id != null ? id.value : this.id),
        startIn: (startIn != null ? startIn.value : this.startIn),
        user: (user != null ? user.value : this.user));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleWithServiceResource {
  ScheduleWithServiceResource({
    this.id,
    this.startIn,
    this.service,
  });

  factory ScheduleWithServiceResource.fromJson(Map<String, dynamic> json) =>
      _$ScheduleWithServiceResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'start_in', includeIfNull: false, defaultValue: '')
  final String? startIn;
  @JsonKey(name: 'service', includeIfNull: false)
  final ServiceWithServiceCategoryResource? service;
  static const fromJsonFactory = _$ScheduleWithServiceResourceFromJson;
  static const toJsonFactory = _$ScheduleWithServiceResourceToJson;
  Map<String, dynamic> toJson() => _$ScheduleWithServiceResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleWithServiceResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startIn, startIn) ||
                const DeepCollectionEquality()
                    .equals(other.startIn, startIn)) &&
            (identical(other.service, service) ||
                const DeepCollectionEquality().equals(other.service, service)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startIn) ^
      const DeepCollectionEquality().hash(service) ^
      runtimeType.hashCode;
}

extension $ScheduleWithServiceResourceExtension on ScheduleWithServiceResource {
  ScheduleWithServiceResource copyWith(
      {int? id, String? startIn, ServiceWithServiceCategoryResource? service}) {
    return ScheduleWithServiceResource(
        id: id ?? this.id,
        startIn: startIn ?? this.startIn,
        service: service ?? this.service);
  }

  ScheduleWithServiceResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? startIn,
      Wrapped<ServiceWithServiceCategoryResource?>? service}) {
    return ScheduleWithServiceResource(
        id: (id != null ? id.value : this.id),
        startIn: (startIn != null ? startIn.value : this.startIn),
        service: (service != null ? service.value : this.service));
  }
}

@JsonSerializable(explicitToJson: true)
class ScheduleShowResource {
  ScheduleShowResource({
    this.id,
    this.startIn,
    this.capacity,
    this.service,
    this.participants,
  });

  factory ScheduleShowResource.fromJson(Map<String, dynamic> json) =>
      _$ScheduleShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'start_in', includeIfNull: false)
  final Object? startIn;
  @JsonKey(name: 'capacity', includeIfNull: false)
  final int? capacity;
  @JsonKey(name: 'service', includeIfNull: false)
  final ServiceWithServiceCategoryResource? service;
  @JsonKey(
      name: 'participants',
      includeIfNull: false,
      defaultValue: <ParticipantResource>[])
  final List<ParticipantResource>? participants;
  static const fromJsonFactory = _$ScheduleShowResourceFromJson;
  static const toJsonFactory = _$ScheduleShowResourceToJson;
  Map<String, dynamic> toJson() => _$ScheduleShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ScheduleShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startIn, startIn) ||
                const DeepCollectionEquality()
                    .equals(other.startIn, startIn)) &&
            (identical(other.capacity, capacity) ||
                const DeepCollectionEquality()
                    .equals(other.capacity, capacity)) &&
            (identical(other.service, service) ||
                const DeepCollectionEquality()
                    .equals(other.service, service)) &&
            (identical(other.participants, participants) ||
                const DeepCollectionEquality()
                    .equals(other.participants, participants)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startIn) ^
      const DeepCollectionEquality().hash(capacity) ^
      const DeepCollectionEquality().hash(service) ^
      const DeepCollectionEquality().hash(participants) ^
      runtimeType.hashCode;
}

extension $ScheduleShowResourceExtension on ScheduleShowResource {
  ScheduleShowResource copyWith(
      {int? id,
      Object? startIn,
      int? capacity,
      ServiceWithServiceCategoryResource? service,
      List<ParticipantResource>? participants}) {
    return ScheduleShowResource(
        id: id ?? this.id,
        startIn: startIn ?? this.startIn,
        capacity: capacity ?? this.capacity,
        service: service ?? this.service,
        participants: participants ?? this.participants);
  }

  ScheduleShowResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<Object?>? startIn,
      Wrapped<int?>? capacity,
      Wrapped<ServiceWithServiceCategoryResource?>? service,
      Wrapped<List<ParticipantResource>?>? participants}) {
    return ScheduleShowResource(
        id: (id != null ? id.value : this.id),
        startIn: (startIn != null ? startIn.value : this.startIn),
        capacity: (capacity != null ? capacity.value : this.capacity),
        service: (service != null ? service.value : this.service),
        participants:
            (participants != null ? participants.value : this.participants));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceIndexResource {
  ServiceIndexResource({
    this.data,
    this.meta,
  });

  factory ServiceIndexResource.fromJson(Map<String, dynamic> json) =>
      _$ServiceIndexResourceFromJson(json);

  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <ServiceResource>[])
  final List<ServiceResource>? data;
  @JsonKey(name: 'meta', includeIfNull: false)
  final MetaPaginationResource? meta;
  static const fromJsonFactory = _$ServiceIndexResourceFromJson;
  static const toJsonFactory = _$ServiceIndexResourceToJson;
  Map<String, dynamic> toJson() => _$ServiceIndexResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceIndexResource &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(meta) ^
      runtimeType.hashCode;
}

extension $ServiceIndexResourceExtension on ServiceIndexResource {
  ServiceIndexResource copyWith(
      {List<ServiceResource>? data, MetaPaginationResource? meta}) {
    return ServiceIndexResource(
        data: data ?? this.data, meta: meta ?? this.meta);
  }

  ServiceIndexResource copyWithWrapped(
      {Wrapped<List<ServiceResource>?>? data,
      Wrapped<MetaPaginationResource?>? meta}) {
    return ServiceIndexResource(
        data: (data != null ? data.value : this.data),
        meta: (meta != null ? meta.value : this.meta));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceMyResource {
  ServiceMyResource({
    this.id,
    this.name,
  });

  factory ServiceMyResource.fromJson(Map<String, dynamic> json) =>
      _$ServiceMyResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$ServiceMyResourceFromJson;
  static const toJsonFactory = _$ServiceMyResourceToJson;
  Map<String, dynamic> toJson() => _$ServiceMyResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceMyResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $ServiceMyResourceExtension on ServiceMyResource {
  ServiceMyResource copyWith({int? id, String? name}) {
    return ServiceMyResource(id: id ?? this.id, name: name ?? this.name);
  }

  ServiceMyResource copyWithWrapped(
      {Wrapped<int?>? id, Wrapped<String?>? name}) {
    return ServiceMyResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceResource {
  ServiceResource({
    this.id,
    this.name,
    this.price,
    this.startIn,
    this.group,
  });

  factory ServiceResource.fromJson(Map<String, dynamic> json) =>
      _$ServiceResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'price', includeIfNull: false)
  final Object? price;
  @JsonKey(name: 'start_in', includeIfNull: false, defaultValue: '')
  final String? startIn;
  @JsonKey(name: 'group', includeIfNull: false)
  final Object? group;
  static const fromJsonFactory = _$ServiceResourceFromJson;
  static const toJsonFactory = _$ServiceResourceToJson;
  Map<String, dynamic> toJson() => _$ServiceResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.startIn, startIn) ||
                const DeepCollectionEquality()
                    .equals(other.startIn, startIn)) &&
            (identical(other.group, group) ||
                const DeepCollectionEquality().equals(other.group, group)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(startIn) ^
      const DeepCollectionEquality().hash(group) ^
      runtimeType.hashCode;
}

extension $ServiceResourceExtension on ServiceResource {
  ServiceResource copyWith(
      {int? id, String? name, Object? price, String? startIn, Object? group}) {
    return ServiceResource(
        id: id ?? this.id,
        name: name ?? this.name,
        price: price ?? this.price,
        startIn: startIn ?? this.startIn,
        group: group ?? this.group);
  }

  ServiceResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<Object?>? price,
      Wrapped<String?>? startIn,
      Wrapped<Object?>? group}) {
    return ServiceResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        price: (price != null ? price.value : this.price),
        startIn: (startIn != null ? startIn.value : this.startIn),
        group: (group != null ? group.value : this.group));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceWithServiceCategoryResource {
  ServiceWithServiceCategoryResource({
    this.id,
    this.name,
    this.duration,
    this.group,
    this.serviceCategory,
  });

  factory ServiceWithServiceCategoryResource.fromJson(
          Map<String, dynamic> json) =>
      _$ServiceWithServiceCategoryResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'group', includeIfNull: false)
  final bool? group;
  @JsonKey(name: 'service_category', includeIfNull: false)
  final ServiceCategoryShowResource? serviceCategory;
  static const fromJsonFactory = _$ServiceWithServiceCategoryResourceFromJson;
  static const toJsonFactory = _$ServiceWithServiceCategoryResourceToJson;
  Map<String, dynamic> toJson() =>
      _$ServiceWithServiceCategoryResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceWithServiceCategoryResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.group, group) ||
                const DeepCollectionEquality().equals(other.group, group)) &&
            (identical(other.serviceCategory, serviceCategory) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategory, serviceCategory)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(group) ^
      const DeepCollectionEquality().hash(serviceCategory) ^
      runtimeType.hashCode;
}

extension $ServiceWithServiceCategoryResourceExtension
    on ServiceWithServiceCategoryResource {
  ServiceWithServiceCategoryResource copyWith(
      {int? id,
      String? name,
      int? duration,
      bool? group,
      ServiceCategoryShowResource? serviceCategory}) {
    return ServiceWithServiceCategoryResource(
        id: id ?? this.id,
        name: name ?? this.name,
        duration: duration ?? this.duration,
        group: group ?? this.group,
        serviceCategory: serviceCategory ?? this.serviceCategory);
  }

  ServiceWithServiceCategoryResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? duration,
      Wrapped<bool?>? group,
      Wrapped<ServiceCategoryShowResource?>? serviceCategory}) {
    return ServiceWithServiceCategoryResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        duration: (duration != null ? duration.value : this.duration),
        group: (group != null ? group.value : this.group),
        serviceCategory: (serviceCategory != null
            ? serviceCategory.value
            : this.serviceCategory));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceShowResource {
  ServiceShowResource({
    this.id,
    this.name,
    this.description,
    this.duration,
    this.group,
  });

  factory ServiceShowResource.fromJson(Map<String, dynamic> json) =>
      _$ServiceShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'group', includeIfNull: false)
  final bool? group;
  static const fromJsonFactory = _$ServiceShowResourceFromJson;
  static const toJsonFactory = _$ServiceShowResourceToJson;
  Map<String, dynamic> toJson() => _$ServiceShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.group, group) ||
                const DeepCollectionEquality().equals(other.group, group)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(group) ^
      runtimeType.hashCode;
}

extension $ServiceShowResourceExtension on ServiceShowResource {
  ServiceShowResource copyWith(
      {int? id,
      String? name,
      String? description,
      int? duration,
      bool? group}) {
    return ServiceShowResource(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        duration: duration ?? this.duration,
        group: group ?? this.group);
  }

  ServiceShowResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<int?>? duration,
      Wrapped<bool?>? group}) {
    return ServiceShowResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        duration: (duration != null ? duration.value : this.duration),
        group: (group != null ? group.value : this.group));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceCateogryAllResource {
  ServiceCateogryAllResource({
    this.id,
    this.name,
    this.services,
  });

  factory ServiceCateogryAllResource.fromJson(Map<String, dynamic> json) =>
      _$ServiceCateogryAllResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'services', includeIfNull: false)
  final List<ServiceResource>? services;
  static const fromJsonFactory = _$ServiceCateogryAllResourceFromJson;
  static const toJsonFactory = _$ServiceCateogryAllResourceToJson;
  Map<String, dynamic> toJson() => _$ServiceCateogryAllResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceCateogryAllResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.services, services) ||
                const DeepCollectionEquality()
                    .equals(other.services, services)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(services) ^
      runtimeType.hashCode;
}

extension $ServiceCateogryAllResourceExtension on ServiceCateogryAllResource {
  ServiceCateogryAllResource copyWith(
      {int? id, String? name, List<ServiceResource>? services}) {
    return ServiceCateogryAllResource(
        id: id ?? this.id,
        name: name ?? this.name,
        services: services ?? this.services);
  }

  ServiceCateogryAllResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<List<ServiceResource>?>? services}) {
    return ServiceCateogryAllResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        services: (services != null ? services.value : this.services));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceCategoryShowResource {
  ServiceCategoryShowResource({
    this.id,
    this.name,
  });

  factory ServiceCategoryShowResource.fromJson(Map<String, dynamic> json) =>
      _$ServiceCategoryShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$ServiceCategoryShowResourceFromJson;
  static const toJsonFactory = _$ServiceCategoryShowResourceToJson;
  Map<String, dynamic> toJson() => _$ServiceCategoryShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceCategoryShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $ServiceCategoryShowResourceExtension on ServiceCategoryShowResource {
  ServiceCategoryShowResource copyWith({int? id, String? name}) {
    return ServiceCategoryShowResource(
        id: id ?? this.id, name: name ?? this.name);
  }

  ServiceCategoryShowResource copyWithWrapped(
      {Wrapped<int?>? id, Wrapped<String?>? name}) {
    return ServiceCategoryShowResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class SpecialistIndexResource {
  SpecialistIndexResource({
    this.data,
    this.meta,
  });

  factory SpecialistIndexResource.fromJson(Map<String, dynamic> json) =>
      _$SpecialistIndexResourceFromJson(json);

  @JsonKey(
      name: 'data', includeIfNull: false, defaultValue: <SpecialistResource>[])
  final List<SpecialistResource>? data;
  @JsonKey(name: 'meta', includeIfNull: false)
  final MetaPaginationResource? meta;
  static const fromJsonFactory = _$SpecialistIndexResourceFromJson;
  static const toJsonFactory = _$SpecialistIndexResourceToJson;
  Map<String, dynamic> toJson() => _$SpecialistIndexResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpecialistIndexResource &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(meta) ^
      runtimeType.hashCode;
}

extension $SpecialistIndexResourceExtension on SpecialistIndexResource {
  SpecialistIndexResource copyWith(
      {List<SpecialistResource>? data, MetaPaginationResource? meta}) {
    return SpecialistIndexResource(
        data: data ?? this.data, meta: meta ?? this.meta);
  }

  SpecialistIndexResource copyWithWrapped(
      {Wrapped<List<SpecialistResource>?>? data,
      Wrapped<MetaPaginationResource?>? meta}) {
    return SpecialistIndexResource(
        data: (data != null ? data.value : this.data),
        meta: (meta != null ? meta.value : this.meta));
  }
}

@JsonSerializable(explicitToJson: true)
class SpecialistShowResource {
  SpecialistShowResource({
    this.id,
    this.firstName,
    this.lastName,
    this.patronymic,
    this.jobTitle,
    this.avatar,
    this.description,
  });

  factory SpecialistShowResource.fromJson(Map<String, dynamic> json) =>
      _$SpecialistShowResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'first_name', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'last_name', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'patronymic', includeIfNull: false, defaultValue: '')
  final String? patronymic;
  @JsonKey(name: 'job_title', includeIfNull: false, defaultValue: '')
  final String? jobTitle;
  @JsonKey(name: 'avatar', includeIfNull: false)
  final MediaResource? avatar;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$SpecialistShowResourceFromJson;
  static const toJsonFactory = _$SpecialistShowResourceToJson;
  Map<String, dynamic> toJson() => _$SpecialistShowResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpecialistShowResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.patronymic, patronymic) ||
                const DeepCollectionEquality()
                    .equals(other.patronymic, patronymic)) &&
            (identical(other.jobTitle, jobTitle) ||
                const DeepCollectionEquality()
                    .equals(other.jobTitle, jobTitle)) &&
            (identical(other.avatar, avatar) ||
                const DeepCollectionEquality().equals(other.avatar, avatar)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(patronymic) ^
      const DeepCollectionEquality().hash(jobTitle) ^
      const DeepCollectionEquality().hash(avatar) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $SpecialistShowResourceExtension on SpecialistShowResource {
  SpecialistShowResource copyWith(
      {int? id,
      String? firstName,
      String? lastName,
      String? patronymic,
      String? jobTitle,
      MediaResource? avatar,
      String? description}) {
    return SpecialistShowResource(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        patronymic: patronymic ?? this.patronymic,
        jobTitle: jobTitle ?? this.jobTitle,
        avatar: avatar ?? this.avatar,
        description: description ?? this.description);
  }

  SpecialistShowResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? patronymic,
      Wrapped<String?>? jobTitle,
      Wrapped<MediaResource?>? avatar,
      Wrapped<String?>? description}) {
    return SpecialistShowResource(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        patronymic: (patronymic != null ? patronymic.value : this.patronymic),
        jobTitle: (jobTitle != null ? jobTitle.value : this.jobTitle),
        avatar: (avatar != null ? avatar.value : this.avatar),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class SpecialistResource {
  SpecialistResource({
    this.id,
    this.firstName,
    this.lastName,
    this.patronymic,
    this.jobTitle,
    this.description,
    this.avatar,
  });

  factory SpecialistResource.fromJson(Map<String, dynamic> json) =>
      _$SpecialistResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'first_name', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'last_name', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'patronymic', includeIfNull: false, defaultValue: '')
  final String? patronymic;
  @JsonKey(name: 'job_title', includeIfNull: false, defaultValue: '')
  final String? jobTitle;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'avatar', includeIfNull: false)
  final MediaResource? avatar;
  static const fromJsonFactory = _$SpecialistResourceFromJson;
  static const toJsonFactory = _$SpecialistResourceToJson;
  Map<String, dynamic> toJson() => _$SpecialistResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpecialistResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.patronymic, patronymic) ||
                const DeepCollectionEquality()
                    .equals(other.patronymic, patronymic)) &&
            (identical(other.jobTitle, jobTitle) ||
                const DeepCollectionEquality()
                    .equals(other.jobTitle, jobTitle)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.avatar, avatar) ||
                const DeepCollectionEquality().equals(other.avatar, avatar)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(patronymic) ^
      const DeepCollectionEquality().hash(jobTitle) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(avatar) ^
      runtimeType.hashCode;
}

extension $SpecialistResourceExtension on SpecialistResource {
  SpecialistResource copyWith(
      {int? id,
      String? firstName,
      String? lastName,
      String? patronymic,
      String? jobTitle,
      String? description,
      MediaResource? avatar}) {
    return SpecialistResource(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        patronymic: patronymic ?? this.patronymic,
        jobTitle: jobTitle ?? this.jobTitle,
        description: description ?? this.description,
        avatar: avatar ?? this.avatar);
  }

  SpecialistResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? patronymic,
      Wrapped<String?>? jobTitle,
      Wrapped<String?>? description,
      Wrapped<MediaResource?>? avatar}) {
    return SpecialistResource(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        patronymic: (patronymic != null ? patronymic.value : this.patronymic),
        jobTitle: (jobTitle != null ? jobTitle.value : this.jobTitle),
        description:
            (description != null ? description.value : this.description),
        avatar: (avatar != null ? avatar.value : this.avatar));
  }
}

@JsonSerializable(explicitToJson: true)
class SpecialistWithPriceResource {
  SpecialistWithPriceResource({
    this.id,
    this.firstName,
    this.lastName,
    this.patronymic,
    this.jobTitle,
    this.avatar,
    this.price,
  });

  factory SpecialistWithPriceResource.fromJson(Map<String, dynamic> json) =>
      _$SpecialistWithPriceResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'first_name', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'last_name', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'patronymic', includeIfNull: false, defaultValue: '')
  final String? patronymic;
  @JsonKey(name: 'job_title', includeIfNull: false, defaultValue: '')
  final String? jobTitle;
  @JsonKey(name: 'avatar', includeIfNull: false)
  final MediaResource? avatar;
  @JsonKey(name: 'price', includeIfNull: false)
  final Object? price;
  static const fromJsonFactory = _$SpecialistWithPriceResourceFromJson;
  static const toJsonFactory = _$SpecialistWithPriceResourceToJson;
  Map<String, dynamic> toJson() => _$SpecialistWithPriceResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpecialistWithPriceResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.patronymic, patronymic) ||
                const DeepCollectionEquality()
                    .equals(other.patronymic, patronymic)) &&
            (identical(other.jobTitle, jobTitle) ||
                const DeepCollectionEquality()
                    .equals(other.jobTitle, jobTitle)) &&
            (identical(other.avatar, avatar) ||
                const DeepCollectionEquality().equals(other.avatar, avatar)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(patronymic) ^
      const DeepCollectionEquality().hash(jobTitle) ^
      const DeepCollectionEquality().hash(avatar) ^
      const DeepCollectionEquality().hash(price) ^
      runtimeType.hashCode;
}

extension $SpecialistWithPriceResourceExtension on SpecialistWithPriceResource {
  SpecialistWithPriceResource copyWith(
      {int? id,
      String? firstName,
      String? lastName,
      String? patronymic,
      String? jobTitle,
      MediaResource? avatar,
      Object? price}) {
    return SpecialistWithPriceResource(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        patronymic: patronymic ?? this.patronymic,
        jobTitle: jobTitle ?? this.jobTitle,
        avatar: avatar ?? this.avatar,
        price: price ?? this.price);
  }

  SpecialistWithPriceResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? patronymic,
      Wrapped<String?>? jobTitle,
      Wrapped<MediaResource?>? avatar,
      Wrapped<Object?>? price}) {
    return SpecialistWithPriceResource(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        patronymic: (patronymic != null ? patronymic.value : this.patronymic),
        jobTitle: (jobTitle != null ? jobTitle.value : this.jobTitle),
        avatar: (avatar != null ? avatar.value : this.avatar),
        price: (price != null ? price.value : this.price));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionsTypeIndexResource {
  SubscriptionsTypeIndexResource({
    this.data,
    this.meta,
  });

  factory SubscriptionsTypeIndexResource.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionsTypeIndexResourceFromJson(json);

  @JsonKey(
      name: 'data',
      includeIfNull: false,
      defaultValue: <SubscriptionsTypeResource>[])
  final List<SubscriptionsTypeResource>? data;
  @JsonKey(name: 'meta', includeIfNull: false)
  final MetaPaginationResource? meta;
  static const fromJsonFactory = _$SubscriptionsTypeIndexResourceFromJson;
  static const toJsonFactory = _$SubscriptionsTypeIndexResourceToJson;
  Map<String, dynamic> toJson() => _$SubscriptionsTypeIndexResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionsTypeIndexResource &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(meta) ^
      runtimeType.hashCode;
}

extension $SubscriptionsTypeIndexResourceExtension
    on SubscriptionsTypeIndexResource {
  SubscriptionsTypeIndexResource copyWith(
      {List<SubscriptionsTypeResource>? data, MetaPaginationResource? meta}) {
    return SubscriptionsTypeIndexResource(
        data: data ?? this.data, meta: meta ?? this.meta);
  }

  SubscriptionsTypeIndexResource copyWithWrapped(
      {Wrapped<List<SubscriptionsTypeResource>?>? data,
      Wrapped<MetaPaginationResource?>? meta}) {
    return SubscriptionsTypeIndexResource(
        data: (data != null ? data.value : this.data),
        meta: (meta != null ? meta.value : this.meta));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionsTypeResource {
  SubscriptionsTypeResource({
    this.id,
    this.name,
    this.description,
    this.price,
    this.discount,
    this.priceWithDiscount,
  });

  factory SubscriptionsTypeResource.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionsTypeResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'price', includeIfNull: false)
  final double? price;
  @JsonKey(name: 'discount', includeIfNull: false)
  final double? discount;
  @JsonKey(name: 'price_with_discount', includeIfNull: false)
  final double? priceWithDiscount;
  static const fromJsonFactory = _$SubscriptionsTypeResourceFromJson;
  static const toJsonFactory = _$SubscriptionsTypeResourceToJson;
  Map<String, dynamic> toJson() => _$SubscriptionsTypeResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionsTypeResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.price, price) ||
                const DeepCollectionEquality().equals(other.price, price)) &&
            (identical(other.discount, discount) ||
                const DeepCollectionEquality()
                    .equals(other.discount, discount)) &&
            (identical(other.priceWithDiscount, priceWithDiscount) ||
                const DeepCollectionEquality()
                    .equals(other.priceWithDiscount, priceWithDiscount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(price) ^
      const DeepCollectionEquality().hash(discount) ^
      const DeepCollectionEquality().hash(priceWithDiscount) ^
      runtimeType.hashCode;
}

extension $SubscriptionsTypeResourceExtension on SubscriptionsTypeResource {
  SubscriptionsTypeResource copyWith(
      {int? id,
      String? name,
      String? description,
      double? price,
      double? discount,
      double? priceWithDiscount}) {
    return SubscriptionsTypeResource(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        price: price ?? this.price,
        discount: discount ?? this.discount,
        priceWithDiscount: priceWithDiscount ?? this.priceWithDiscount);
  }

  SubscriptionsTypeResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<double?>? price,
      Wrapped<double?>? discount,
      Wrapped<double?>? priceWithDiscount}) {
    return SubscriptionsTypeResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        price: (price != null ? price.value : this.price),
        discount: (discount != null ? discount.value : this.discount),
        priceWithDiscount: (priceWithDiscount != null
            ? priceWithDiscount.value
            : this.priceWithDiscount));
  }
}

@JsonSerializable(explicitToJson: true)
class SigninResource {
  SigninResource({
    this.user,
    this.token,
  });

  factory SigninResource.fromJson(Map<String, dynamic> json) =>
      _$SigninResourceFromJson(json);

  @JsonKey(name: 'user', includeIfNull: false)
  final UserResource? user;
  @JsonKey(name: 'token', includeIfNull: false)
  final TokenResource? token;
  static const fromJsonFactory = _$SigninResourceFromJson;
  static const toJsonFactory = _$SigninResourceToJson;
  Map<String, dynamic> toJson() => _$SigninResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SigninResource &&
            (identical(other.user, user) ||
                const DeepCollectionEquality().equals(other.user, user)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(user) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $SigninResourceExtension on SigninResource {
  SigninResource copyWith({UserResource? user, TokenResource? token}) {
    return SigninResource(user: user ?? this.user, token: token ?? this.token);
  }

  SigninResource copyWithWrapped(
      {Wrapped<UserResource?>? user, Wrapped<TokenResource?>? token}) {
    return SigninResource(
        user: (user != null ? user.value : this.user),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class MetaPaginationResource {
  MetaPaginationResource({
    this.currentPage,
    this.lastPage,
    this.perPage,
    this.total,
  });

  factory MetaPaginationResource.fromJson(Map<String, dynamic> json) =>
      _$MetaPaginationResourceFromJson(json);

  @JsonKey(name: 'current_page', includeIfNull: false)
  final int? currentPage;
  @JsonKey(name: 'last_page', includeIfNull: false)
  final int? lastPage;
  @JsonKey(name: 'per_page', includeIfNull: false)
  final int? perPage;
  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  static const fromJsonFactory = _$MetaPaginationResourceFromJson;
  static const toJsonFactory = _$MetaPaginationResourceToJson;
  Map<String, dynamic> toJson() => _$MetaPaginationResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MetaPaginationResource &&
            (identical(other.currentPage, currentPage) ||
                const DeepCollectionEquality()
                    .equals(other.currentPage, currentPage)) &&
            (identical(other.lastPage, lastPage) ||
                const DeepCollectionEquality()
                    .equals(other.lastPage, lastPage)) &&
            (identical(other.perPage, perPage) ||
                const DeepCollectionEquality()
                    .equals(other.perPage, perPage)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(currentPage) ^
      const DeepCollectionEquality().hash(lastPage) ^
      const DeepCollectionEquality().hash(perPage) ^
      const DeepCollectionEquality().hash(total) ^
      runtimeType.hashCode;
}

extension $MetaPaginationResourceExtension on MetaPaginationResource {
  MetaPaginationResource copyWith(
      {int? currentPage, int? lastPage, int? perPage, int? total}) {
    return MetaPaginationResource(
        currentPage: currentPage ?? this.currentPage,
        lastPage: lastPage ?? this.lastPage,
        perPage: perPage ?? this.perPage,
        total: total ?? this.total);
  }

  MetaPaginationResource copyWithWrapped(
      {Wrapped<int?>? currentPage,
      Wrapped<int?>? lastPage,
      Wrapped<int?>? perPage,
      Wrapped<int?>? total}) {
    return MetaPaginationResource(
        currentPage:
            (currentPage != null ? currentPage.value : this.currentPage),
        lastPage: (lastPage != null ? lastPage.value : this.lastPage),
        perPage: (perPage != null ? perPage.value : this.perPage),
        total: (total != null ? total.value : this.total));
  }
}

@JsonSerializable(explicitToJson: true)
class UserResource {
  UserResource({
    this.id,
    this.firstName,
    this.lastName,
    this.patronymic,
    this.birthAt,
    this.gender,
    this.active,
  });

  factory UserResource.fromJson(Map<String, dynamic> json) =>
      _$UserResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'first_name', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'last_name', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'patronymic', includeIfNull: false, defaultValue: '')
  final String? patronymic;
  @JsonKey(name: 'birth_at', includeIfNull: false, defaultValue: '')
  final String? birthAt;
  @JsonKey(name: 'gender', includeIfNull: false)
  final int? gender;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  static const fromJsonFactory = _$UserResourceFromJson;
  static const toJsonFactory = _$UserResourceToJson;
  Map<String, dynamic> toJson() => _$UserResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.patronymic, patronymic) ||
                const DeepCollectionEquality()
                    .equals(other.patronymic, patronymic)) &&
            (identical(other.birthAt, birthAt) ||
                const DeepCollectionEquality()
                    .equals(other.birthAt, birthAt)) &&
            (identical(other.gender, gender) ||
                const DeepCollectionEquality().equals(other.gender, gender)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(patronymic) ^
      const DeepCollectionEquality().hash(birthAt) ^
      const DeepCollectionEquality().hash(gender) ^
      const DeepCollectionEquality().hash(active) ^
      runtimeType.hashCode;
}

extension $UserResourceExtension on UserResource {
  UserResource copyWith(
      {int? id,
      String? firstName,
      String? lastName,
      String? patronymic,
      String? birthAt,
      int? gender,
      bool? active}) {
    return UserResource(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        patronymic: patronymic ?? this.patronymic,
        birthAt: birthAt ?? this.birthAt,
        gender: gender ?? this.gender,
        active: active ?? this.active);
  }

  UserResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? patronymic,
      Wrapped<String?>? birthAt,
      Wrapped<int?>? gender,
      Wrapped<bool?>? active}) {
    return UserResource(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        patronymic: (patronymic != null ? patronymic.value : this.patronymic),
        birthAt: (birthAt != null ? birthAt.value : this.birthAt),
        gender: (gender != null ? gender.value : this.gender),
        active: (active != null ? active.value : this.active));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleEventsGetEventsRequest {
  ChatModuleEventsGetEventsRequest({
    this.eventId,
    this.page,
  });

  factory ChatModuleEventsGetEventsRequest.fromJson(
          Map<String, dynamic> json) =>
      _$ChatModuleEventsGetEventsRequestFromJson(json);

  @JsonKey(name: 'event_id', includeIfNull: false)
  final int? eventId;
  @JsonKey(name: 'page', includeIfNull: false)
  final int? page;
  static const fromJsonFactory = _$ChatModuleEventsGetEventsRequestFromJson;
  static const toJsonFactory = _$ChatModuleEventsGetEventsRequestToJson;
  Map<String, dynamic> toJson() =>
      _$ChatModuleEventsGetEventsRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleEventsGetEventsRequest &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(page) ^
      runtimeType.hashCode;
}

extension $ChatModuleEventsGetEventsRequestExtension
    on ChatModuleEventsGetEventsRequest {
  ChatModuleEventsGetEventsRequest copyWith({int? eventId, int? page}) {
    return ChatModuleEventsGetEventsRequest(
        eventId: eventId ?? this.eventId, page: page ?? this.page);
  }

  ChatModuleEventsGetEventsRequest copyWithWrapped(
      {Wrapped<int?>? eventId, Wrapped<int?>? page}) {
    return ChatModuleEventsGetEventsRequest(
        eventId: (eventId != null ? eventId.value : this.eventId),
        page: (page != null ? page.value : this.page));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleEventsSetDeliveredRequest {
  ChatModuleEventsSetDeliveredRequest({
    this.lastKnownEventId,
  });

  factory ChatModuleEventsSetDeliveredRequest.fromJson(
          Map<String, dynamic> json) =>
      _$ChatModuleEventsSetDeliveredRequestFromJson(json);

  @JsonKey(name: 'last_known_event_id', includeIfNull: false)
  final int? lastKnownEventId;
  static const fromJsonFactory = _$ChatModuleEventsSetDeliveredRequestFromJson;
  static const toJsonFactory = _$ChatModuleEventsSetDeliveredRequestToJson;
  Map<String, dynamic> toJson() =>
      _$ChatModuleEventsSetDeliveredRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleEventsSetDeliveredRequest &&
            (identical(other.lastKnownEventId, lastKnownEventId) ||
                const DeepCollectionEquality()
                    .equals(other.lastKnownEventId, lastKnownEventId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(lastKnownEventId) ^
      runtimeType.hashCode;
}

extension $ChatModuleEventsSetDeliveredRequestExtension
    on ChatModuleEventsSetDeliveredRequest {
  ChatModuleEventsSetDeliveredRequest copyWith({int? lastKnownEventId}) {
    return ChatModuleEventsSetDeliveredRequest(
        lastKnownEventId: lastKnownEventId ?? this.lastKnownEventId);
  }

  ChatModuleEventsSetDeliveredRequest copyWithWrapped(
      {Wrapped<int?>? lastKnownEventId}) {
    return ChatModuleEventsSetDeliveredRequest(
        lastKnownEventId: (lastKnownEventId != null
            ? lastKnownEventId.value
            : this.lastKnownEventId));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleMessagesDeleteRequest {
  ChatModuleMessagesDeleteRequest({
    this.messageIds,
    this.isDeleteForAll,
  });

  factory ChatModuleMessagesDeleteRequest.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleMessagesDeleteRequestFromJson(json);

  @JsonKey(name: 'message_ids', includeIfNull: false, defaultValue: <int>[])
  final List<int>? messageIds;
  @JsonKey(name: 'is_delete_for_all', includeIfNull: false, defaultValue: false)
  final bool? isDeleteForAll;
  static const fromJsonFactory = _$ChatModuleMessagesDeleteRequestFromJson;
  static const toJsonFactory = _$ChatModuleMessagesDeleteRequestToJson;
  Map<String, dynamic> toJson() =>
      _$ChatModuleMessagesDeleteRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleMessagesDeleteRequest &&
            (identical(other.messageIds, messageIds) ||
                const DeepCollectionEquality()
                    .equals(other.messageIds, messageIds)) &&
            (identical(other.isDeleteForAll, isDeleteForAll) ||
                const DeepCollectionEquality()
                    .equals(other.isDeleteForAll, isDeleteForAll)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(messageIds) ^
      const DeepCollectionEquality().hash(isDeleteForAll) ^
      runtimeType.hashCode;
}

extension $ChatModuleMessagesDeleteRequestExtension
    on ChatModuleMessagesDeleteRequest {
  ChatModuleMessagesDeleteRequest copyWith(
      {List<int>? messageIds, bool? isDeleteForAll}) {
    return ChatModuleMessagesDeleteRequest(
        messageIds: messageIds ?? this.messageIds,
        isDeleteForAll: isDeleteForAll ?? this.isDeleteForAll);
  }

  ChatModuleMessagesDeleteRequest copyWithWrapped(
      {Wrapped<List<int>?>? messageIds, Wrapped<bool?>? isDeleteForAll}) {
    return ChatModuleMessagesDeleteRequest(
        messageIds: (messageIds != null ? messageIds.value : this.messageIds),
        isDeleteForAll: (isDeleteForAll != null
            ? isDeleteForAll.value
            : this.isDeleteForAll));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleMessagesIndexRequest {
  ChatModuleMessagesIndexRequest({
    this.perPage,
    this.page,
    this.afterMessageId,
    this.loadToPerPage,
    this.beforeMessageId,
  });

  factory ChatModuleMessagesIndexRequest.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleMessagesIndexRequestFromJson(json);

  @JsonKey(name: 'per_page', includeIfNull: false)
  final int? perPage;
  @JsonKey(name: 'page', includeIfNull: false)
  final int? page;
  @JsonKey(name: 'after_message_id', includeIfNull: false)
  final int? afterMessageId;
  @JsonKey(name: 'load_to_per_page', includeIfNull: false, defaultValue: false)
  final bool? loadToPerPage;
  @JsonKey(name: 'before_message_id', includeIfNull: false)
  final int? beforeMessageId;
  static const fromJsonFactory = _$ChatModuleMessagesIndexRequestFromJson;
  static const toJsonFactory = _$ChatModuleMessagesIndexRequestToJson;
  Map<String, dynamic> toJson() => _$ChatModuleMessagesIndexRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleMessagesIndexRequest &&
            (identical(other.perPage, perPage) ||
                const DeepCollectionEquality()
                    .equals(other.perPage, perPage)) &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)) &&
            (identical(other.afterMessageId, afterMessageId) ||
                const DeepCollectionEquality()
                    .equals(other.afterMessageId, afterMessageId)) &&
            (identical(other.loadToPerPage, loadToPerPage) ||
                const DeepCollectionEquality()
                    .equals(other.loadToPerPage, loadToPerPage)) &&
            (identical(other.beforeMessageId, beforeMessageId) ||
                const DeepCollectionEquality()
                    .equals(other.beforeMessageId, beforeMessageId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(perPage) ^
      const DeepCollectionEquality().hash(page) ^
      const DeepCollectionEquality().hash(afterMessageId) ^
      const DeepCollectionEquality().hash(loadToPerPage) ^
      const DeepCollectionEquality().hash(beforeMessageId) ^
      runtimeType.hashCode;
}

extension $ChatModuleMessagesIndexRequestExtension
    on ChatModuleMessagesIndexRequest {
  ChatModuleMessagesIndexRequest copyWith(
      {int? perPage,
      int? page,
      int? afterMessageId,
      bool? loadToPerPage,
      int? beforeMessageId}) {
    return ChatModuleMessagesIndexRequest(
        perPage: perPage ?? this.perPage,
        page: page ?? this.page,
        afterMessageId: afterMessageId ?? this.afterMessageId,
        loadToPerPage: loadToPerPage ?? this.loadToPerPage,
        beforeMessageId: beforeMessageId ?? this.beforeMessageId);
  }

  ChatModuleMessagesIndexRequest copyWithWrapped(
      {Wrapped<int?>? perPage,
      Wrapped<int?>? page,
      Wrapped<int?>? afterMessageId,
      Wrapped<bool?>? loadToPerPage,
      Wrapped<int?>? beforeMessageId}) {
    return ChatModuleMessagesIndexRequest(
        perPage: (perPage != null ? perPage.value : this.perPage),
        page: (page != null ? page.value : this.page),
        afterMessageId: (afterMessageId != null
            ? afterMessageId.value
            : this.afterMessageId),
        loadToPerPage:
            (loadToPerPage != null ? loadToPerPage.value : this.loadToPerPage),
        beforeMessageId: (beforeMessageId != null
            ? beforeMessageId.value
            : this.beforeMessageId));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleMessagesSendRequest {
  ChatModuleMessagesSendRequest({
    this.message,
    this.temporaryFileIds,
  });

  factory ChatModuleMessagesSendRequest.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleMessagesSendRequestFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(
      name: 'temporary_file_ids', includeIfNull: false, defaultValue: <int>[])
  final List<int>? temporaryFileIds;
  static const fromJsonFactory = _$ChatModuleMessagesSendRequestFromJson;
  static const toJsonFactory = _$ChatModuleMessagesSendRequestToJson;
  Map<String, dynamic> toJson() => _$ChatModuleMessagesSendRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleMessagesSendRequest &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.temporaryFileIds, temporaryFileIds) ||
                const DeepCollectionEquality()
                    .equals(other.temporaryFileIds, temporaryFileIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(temporaryFileIds) ^
      runtimeType.hashCode;
}

extension $ChatModuleMessagesSendRequestExtension
    on ChatModuleMessagesSendRequest {
  ChatModuleMessagesSendRequest copyWith(
      {String? message, List<int>? temporaryFileIds}) {
    return ChatModuleMessagesSendRequest(
        message: message ?? this.message,
        temporaryFileIds: temporaryFileIds ?? this.temporaryFileIds);
  }

  ChatModuleMessagesSendRequest copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<List<int>?>? temporaryFileIds}) {
    return ChatModuleMessagesSendRequest(
        message: (message != null ? message.value : this.message),
        temporaryFileIds: (temporaryFileIds != null
            ? temporaryFileIds.value
            : this.temporaryFileIds));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleMessagesUpdateRequest {
  ChatModuleMessagesUpdateRequest({
    this.message,
  });

  factory ChatModuleMessagesUpdateRequest.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleMessagesUpdateRequestFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  static const fromJsonFactory = _$ChatModuleMessagesUpdateRequestFromJson;
  static const toJsonFactory = _$ChatModuleMessagesUpdateRequestToJson;
  Map<String, dynamic> toJson() =>
      _$ChatModuleMessagesUpdateRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleMessagesUpdateRequest &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $ChatModuleMessagesUpdateRequestExtension
    on ChatModuleMessagesUpdateRequest {
  ChatModuleMessagesUpdateRequest copyWith({String? message}) {
    return ChatModuleMessagesUpdateRequest(message: message ?? this.message);
  }

  ChatModuleMessagesUpdateRequest copyWithWrapped({Wrapped<String?>? message}) {
    return ChatModuleMessagesUpdateRequest(
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleChatResource {
  ChatModuleChatResource({
    this.id,
    this.name,
    this.lastReadEvent,
    this.unreadMessageCount,
  });

  factory ChatModuleChatResource.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleChatResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'last_read_event', includeIfNull: false)
  final ChatModuleEventResource? lastReadEvent;
  @JsonKey(name: 'unread_message_count', includeIfNull: false)
  final int? unreadMessageCount;
  static const fromJsonFactory = _$ChatModuleChatResourceFromJson;
  static const toJsonFactory = _$ChatModuleChatResourceToJson;
  Map<String, dynamic> toJson() => _$ChatModuleChatResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleChatResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.lastReadEvent, lastReadEvent) ||
                const DeepCollectionEquality()
                    .equals(other.lastReadEvent, lastReadEvent)) &&
            (identical(other.unreadMessageCount, unreadMessageCount) ||
                const DeepCollectionEquality()
                    .equals(other.unreadMessageCount, unreadMessageCount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(lastReadEvent) ^
      const DeepCollectionEquality().hash(unreadMessageCount) ^
      runtimeType.hashCode;
}

extension $ChatModuleChatResourceExtension on ChatModuleChatResource {
  ChatModuleChatResource copyWith(
      {int? id,
      String? name,
      ChatModuleEventResource? lastReadEvent,
      int? unreadMessageCount}) {
    return ChatModuleChatResource(
        id: id ?? this.id,
        name: name ?? this.name,
        lastReadEvent: lastReadEvent ?? this.lastReadEvent,
        unreadMessageCount: unreadMessageCount ?? this.unreadMessageCount);
  }

  ChatModuleChatResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? name,
      Wrapped<ChatModuleEventResource?>? lastReadEvent,
      Wrapped<int?>? unreadMessageCount}) {
    return ChatModuleChatResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        lastReadEvent:
            (lastReadEvent != null ? lastReadEvent.value : this.lastReadEvent),
        unreadMessageCount: (unreadMessageCount != null
            ? unreadMessageCount.value
            : this.unreadMessageCount));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleEventResource {
  ChatModuleEventResource({
    this.id,
    this.type,
    this.data,
    this.createdAt,
    this.chatAt,
  });

  factory ChatModuleEventResource.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleEventResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'data', includeIfNull: false)
  final ChatModuleMessageResource? data;
  @JsonKey(name: 'created_at', includeIfNull: false)
  final int? createdAt;
  @JsonKey(name: 'chat_at', includeIfNull: false)
  final int? chatAt;
  static const fromJsonFactory = _$ChatModuleEventResourceFromJson;
  static const toJsonFactory = _$ChatModuleEventResourceToJson;
  Map<String, dynamic> toJson() => _$ChatModuleEventResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleEventResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.chatAt, chatAt) ||
                const DeepCollectionEquality().equals(other.chatAt, chatAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(chatAt) ^
      runtimeType.hashCode;
}

extension $ChatModuleEventResourceExtension on ChatModuleEventResource {
  ChatModuleEventResource copyWith(
      {int? id,
      String? type,
      ChatModuleMessageResource? data,
      int? createdAt,
      int? chatAt}) {
    return ChatModuleEventResource(
        id: id ?? this.id,
        type: type ?? this.type,
        data: data ?? this.data,
        createdAt: createdAt ?? this.createdAt,
        chatAt: chatAt ?? this.chatAt);
  }

  ChatModuleEventResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? type,
      Wrapped<ChatModuleMessageResource?>? data,
      Wrapped<int?>? createdAt,
      Wrapped<int?>? chatAt}) {
    return ChatModuleEventResource(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        data: (data != null ? data.value : this.data),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        chatAt: (chatAt != null ? chatAt.value : this.chatAt));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleIndexResourcesEventResource {
  ChatModuleIndexResourcesEventResource({
    this.id,
    this.type,
    this.createdAt,
    this.chatAt,
  });

  factory ChatModuleIndexResourcesEventResource.fromJson(
          Map<String, dynamic> json) =>
      _$ChatModuleIndexResourcesEventResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'created_at', includeIfNull: false)
  final int? createdAt;
  @JsonKey(name: 'chat_at', includeIfNull: false)
  final int? chatAt;
  static const fromJsonFactory =
      _$ChatModuleIndexResourcesEventResourceFromJson;
  static const toJsonFactory = _$ChatModuleIndexResourcesEventResourceToJson;
  Map<String, dynamic> toJson() =>
      _$ChatModuleIndexResourcesEventResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleIndexResourcesEventResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.chatAt, chatAt) ||
                const DeepCollectionEquality().equals(other.chatAt, chatAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(chatAt) ^
      runtimeType.hashCode;
}

extension $ChatModuleIndexResourcesEventResourceExtension
    on ChatModuleIndexResourcesEventResource {
  ChatModuleIndexResourcesEventResource copyWith(
      {int? id, String? type, int? createdAt, int? chatAt}) {
    return ChatModuleIndexResourcesEventResource(
        id: id ?? this.id,
        type: type ?? this.type,
        createdAt: createdAt ?? this.createdAt,
        chatAt: chatAt ?? this.chatAt);
  }

  ChatModuleIndexResourcesEventResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? type,
      Wrapped<int?>? createdAt,
      Wrapped<int?>? chatAt}) {
    return ChatModuleIndexResourcesEventResource(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        chatAt: (chatAt != null ? chatAt.value : this.chatAt));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleIndexResourcesMessageResource {
  ChatModuleIndexResourcesMessageResource({
    this.id,
    this.message,
    this.files,
    this.sender,
    this.lastEvent,
    this.createdAt,
    this.updatedAt,
  });

  factory ChatModuleIndexResourcesMessageResource.fromJson(
          Map<String, dynamic> json) =>
      _$ChatModuleIndexResourcesMessageResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(
      name: 'files',
      includeIfNull: false,
      defaultValue: <ChatModuleMediaResource>[])
  final List<ChatModuleMediaResource>? files;
  @JsonKey(name: 'sender', includeIfNull: false)
  final ChatModuleSenderResource? sender;
  @JsonKey(name: 'last_event', includeIfNull: false)
  final ChatModuleIndexResourcesEventResource? lastEvent;
  @JsonKey(name: 'created_at', includeIfNull: false)
  final int? createdAt;
  @JsonKey(name: 'updated_at', includeIfNull: false)
  final int? updatedAt;
  static const fromJsonFactory =
      _$ChatModuleIndexResourcesMessageResourceFromJson;
  static const toJsonFactory = _$ChatModuleIndexResourcesMessageResourceToJson;
  Map<String, dynamic> toJson() =>
      _$ChatModuleIndexResourcesMessageResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleIndexResourcesMessageResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.files, files) ||
                const DeepCollectionEquality().equals(other.files, files)) &&
            (identical(other.sender, sender) ||
                const DeepCollectionEquality().equals(other.sender, sender)) &&
            (identical(other.lastEvent, lastEvent) ||
                const DeepCollectionEquality()
                    .equals(other.lastEvent, lastEvent)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.updatedAt, updatedAt) ||
                const DeepCollectionEquality()
                    .equals(other.updatedAt, updatedAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(files) ^
      const DeepCollectionEquality().hash(sender) ^
      const DeepCollectionEquality().hash(lastEvent) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(updatedAt) ^
      runtimeType.hashCode;
}

extension $ChatModuleIndexResourcesMessageResourceExtension
    on ChatModuleIndexResourcesMessageResource {
  ChatModuleIndexResourcesMessageResource copyWith(
      {int? id,
      String? message,
      List<ChatModuleMediaResource>? files,
      ChatModuleSenderResource? sender,
      ChatModuleIndexResourcesEventResource? lastEvent,
      int? createdAt,
      int? updatedAt}) {
    return ChatModuleIndexResourcesMessageResource(
        id: id ?? this.id,
        message: message ?? this.message,
        files: files ?? this.files,
        sender: sender ?? this.sender,
        lastEvent: lastEvent ?? this.lastEvent,
        createdAt: createdAt ?? this.createdAt,
        updatedAt: updatedAt ?? this.updatedAt);
  }

  ChatModuleIndexResourcesMessageResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? message,
      Wrapped<List<ChatModuleMediaResource>?>? files,
      Wrapped<ChatModuleSenderResource?>? sender,
      Wrapped<ChatModuleIndexResourcesEventResource?>? lastEvent,
      Wrapped<int?>? createdAt,
      Wrapped<int?>? updatedAt}) {
    return ChatModuleIndexResourcesMessageResource(
        id: (id != null ? id.value : this.id),
        message: (message != null ? message.value : this.message),
        files: (files != null ? files.value : this.files),
        sender: (sender != null ? sender.value : this.sender),
        lastEvent: (lastEvent != null ? lastEvent.value : this.lastEvent),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        updatedAt: (updatedAt != null ? updatedAt.value : this.updatedAt));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleMediaResource {
  ChatModuleMediaResource({
    this.id,
    this.url,
    this.collectionName,
    this.filename,
    this.type,
    this.status,
    this.preview,
  });

  factory ChatModuleMediaResource.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleMediaResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'collection_name', includeIfNull: false, defaultValue: '')
  final String? collectionName;
  @JsonKey(name: 'filename', includeIfNull: false, defaultValue: '')
  final String? filename;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'status', includeIfNull: false, defaultValue: '')
  final String? status;
  @JsonKey(name: 'preview', includeIfNull: false)
  final Object? preview;
  static const fromJsonFactory = _$ChatModuleMediaResourceFromJson;
  static const toJsonFactory = _$ChatModuleMediaResourceToJson;
  Map<String, dynamic> toJson() => _$ChatModuleMediaResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleMediaResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.collectionName, collectionName) ||
                const DeepCollectionEquality()
                    .equals(other.collectionName, collectionName)) &&
            (identical(other.filename, filename) ||
                const DeepCollectionEquality()
                    .equals(other.filename, filename)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.preview, preview) ||
                const DeepCollectionEquality().equals(other.preview, preview)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(collectionName) ^
      const DeepCollectionEquality().hash(filename) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(preview) ^
      runtimeType.hashCode;
}

extension $ChatModuleMediaResourceExtension on ChatModuleMediaResource {
  ChatModuleMediaResource copyWith(
      {int? id,
      String? url,
      String? collectionName,
      String? filename,
      String? type,
      String? status,
      Object? preview}) {
    return ChatModuleMediaResource(
        id: id ?? this.id,
        url: url ?? this.url,
        collectionName: collectionName ?? this.collectionName,
        filename: filename ?? this.filename,
        type: type ?? this.type,
        status: status ?? this.status,
        preview: preview ?? this.preview);
  }

  ChatModuleMediaResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? url,
      Wrapped<String?>? collectionName,
      Wrapped<String?>? filename,
      Wrapped<String?>? type,
      Wrapped<String?>? status,
      Wrapped<Object?>? preview}) {
    return ChatModuleMediaResource(
        id: (id != null ? id.value : this.id),
        url: (url != null ? url.value : this.url),
        collectionName: (collectionName != null
            ? collectionName.value
            : this.collectionName),
        filename: (filename != null ? filename.value : this.filename),
        type: (type != null ? type.value : this.type),
        status: (status != null ? status.value : this.status),
        preview: (preview != null ? preview.value : this.preview));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleMessageResource {
  ChatModuleMessageResource({
    this.id,
    this.message,
    this.files,
    this.sender,
    this.createdAt,
    this.updatedAt,
  });

  factory ChatModuleMessageResource.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleMessageResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(
      name: 'files',
      includeIfNull: false,
      defaultValue: <ChatModuleMediaResource>[])
  final List<ChatModuleMediaResource>? files;
  @JsonKey(name: 'sender', includeIfNull: false)
  final ChatModuleSenderResource? sender;
  @JsonKey(name: 'created_at', includeIfNull: false)
  final int? createdAt;
  @JsonKey(name: 'updated_at', includeIfNull: false)
  final int? updatedAt;
  static const fromJsonFactory = _$ChatModuleMessageResourceFromJson;
  static const toJsonFactory = _$ChatModuleMessageResourceToJson;
  Map<String, dynamic> toJson() => _$ChatModuleMessageResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleMessageResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.files, files) ||
                const DeepCollectionEquality().equals(other.files, files)) &&
            (identical(other.sender, sender) ||
                const DeepCollectionEquality().equals(other.sender, sender)) &&
            (identical(other.createdAt, createdAt) ||
                const DeepCollectionEquality()
                    .equals(other.createdAt, createdAt)) &&
            (identical(other.updatedAt, updatedAt) ||
                const DeepCollectionEquality()
                    .equals(other.updatedAt, updatedAt)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(files) ^
      const DeepCollectionEquality().hash(sender) ^
      const DeepCollectionEquality().hash(createdAt) ^
      const DeepCollectionEquality().hash(updatedAt) ^
      runtimeType.hashCode;
}

extension $ChatModuleMessageResourceExtension on ChatModuleMessageResource {
  ChatModuleMessageResource copyWith(
      {int? id,
      String? message,
      List<ChatModuleMediaResource>? files,
      ChatModuleSenderResource? sender,
      int? createdAt,
      int? updatedAt}) {
    return ChatModuleMessageResource(
        id: id ?? this.id,
        message: message ?? this.message,
        files: files ?? this.files,
        sender: sender ?? this.sender,
        createdAt: createdAt ?? this.createdAt,
        updatedAt: updatedAt ?? this.updatedAt);
  }

  ChatModuleMessageResource copyWithWrapped(
      {Wrapped<int?>? id,
      Wrapped<String?>? message,
      Wrapped<List<ChatModuleMediaResource>?>? files,
      Wrapped<ChatModuleSenderResource?>? sender,
      Wrapped<int?>? createdAt,
      Wrapped<int?>? updatedAt}) {
    return ChatModuleMessageResource(
        id: (id != null ? id.value : this.id),
        message: (message != null ? message.value : this.message),
        files: (files != null ? files.value : this.files),
        sender: (sender != null ? sender.value : this.sender),
        createdAt: (createdAt != null ? createdAt.value : this.createdAt),
        updatedAt: (updatedAt != null ? updatedAt.value : this.updatedAt));
  }
}

@JsonSerializable(explicitToJson: true)
class ChatModuleSenderResource {
  ChatModuleSenderResource({
    this.id,
    this.name,
    this.email,
  });

  factory ChatModuleSenderResource.fromJson(Map<String, dynamic> json) =>
      _$ChatModuleSenderResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  static const fromJsonFactory = _$ChatModuleSenderResourceFromJson;
  static const toJsonFactory = _$ChatModuleSenderResourceToJson;
  Map<String, dynamic> toJson() => _$ChatModuleSenderResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChatModuleSenderResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(email) ^
      runtimeType.hashCode;
}

extension $ChatModuleSenderResourceExtension on ChatModuleSenderResource {
  ChatModuleSenderResource copyWith({int? id, String? name, String? email}) {
    return ChatModuleSenderResource(
        id: id ?? this.id, name: name ?? this.name, email: email ?? this.email);
  }

  ChatModuleSenderResource copyWithWrapped(
      {Wrapped<int?>? id, Wrapped<String?>? name, Wrapped<String?>? email}) {
    return ChatModuleSenderResource(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        email: (email != null ? email.value : this.email));
  }
}

@JsonSerializable(explicitToJson: true)
class ValidationException {
  ValidationException({
    this.field,
    this.message,
    this.description,
  });

  factory ValidationException.fromJson(Map<String, dynamic> json) =>
      _$ValidationExceptionFromJson(json);

  @JsonKey(name: 'field', includeIfNull: false, defaultValue: '')
  final String? field;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$ValidationExceptionFromJson;
  static const toJsonFactory = _$ValidationExceptionToJson;
  Map<String, dynamic> toJson() => _$ValidationExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidationException &&
            (identical(other.field, field) ||
                const DeepCollectionEquality().equals(other.field, field)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(field) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $ValidationExceptionExtension on ValidationException {
  ValidationException copyWith(
      {String? field, String? message, String? description}) {
    return ValidationException(
        field: field ?? this.field,
        message: message ?? this.message,
        description: description ?? this.description);
  }

  ValidationException copyWithWrapped(
      {Wrapped<String?>? field,
      Wrapped<String?>? message,
      Wrapped<String?>? description}) {
    return ValidationException(
        field: (field != null ? field.value : this.field),
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class AuthorizationException {
  AuthorizationException({
    this.message,
    this.description,
  });

  factory AuthorizationException.fromJson(Map<String, dynamic> json) =>
      _$AuthorizationExceptionFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$AuthorizationExceptionFromJson;
  static const toJsonFactory = _$AuthorizationExceptionToJson;
  Map<String, dynamic> toJson() => _$AuthorizationExceptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AuthorizationException &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $AuthorizationExceptionExtension on AuthorizationException {
  AuthorizationException copyWith({String? message, String? description}) {
    return AuthorizationException(
        message: message ?? this.message,
        description: description ?? this.description);
  }

  AuthorizationException copyWithWrapped(
      {Wrapped<String?>? message, Wrapped<String?>? description}) {
    return AuthorizationException(
        message: (message != null ? message.value : this.message),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class UpdateFirebaseToken {
  UpdateFirebaseToken({
    required this.firebaseToken,
  });

  factory UpdateFirebaseToken.fromJson(Map<String, dynamic> json) =>
      _$UpdateFirebaseTokenFromJson(json);

  @JsonKey(name: 'firebase_token', includeIfNull: false, defaultValue: '')
  final String firebaseToken;
  static const fromJsonFactory = _$UpdateFirebaseTokenFromJson;
  static const toJsonFactory = _$UpdateFirebaseTokenToJson;
  Map<String, dynamic> toJson() => _$UpdateFirebaseTokenToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UpdateFirebaseToken &&
            (identical(other.firebaseToken, firebaseToken) ||
                const DeepCollectionEquality()
                    .equals(other.firebaseToken, firebaseToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(firebaseToken) ^ runtimeType.hashCode;
}

extension $UpdateFirebaseTokenExtension on UpdateFirebaseToken {
  UpdateFirebaseToken copyWith({String? firebaseToken}) {
    return UpdateFirebaseToken(
        firebaseToken: firebaseToken ?? this.firebaseToken);
  }

  UpdateFirebaseToken copyWithWrapped({Wrapped<String>? firebaseToken}) {
    return UpdateFirebaseToken(
        firebaseToken:
            (firebaseToken != null ? firebaseToken.value : this.firebaseToken));
  }
}

@JsonSerializable(explicitToJson: true)
class UploaderDeleteRequest {
  UploaderDeleteRequest({
    required this.id,
  });

  factory UploaderDeleteRequest.fromJson(Map<String, dynamic> json) =>
      _$UploaderDeleteRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$UploaderDeleteRequestFromJson;
  static const toJsonFactory = _$UploaderDeleteRequestToJson;
  Map<String, dynamic> toJson() => _$UploaderDeleteRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UploaderDeleteRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $UploaderDeleteRequestExtension on UploaderDeleteRequest {
  UploaderDeleteRequest copyWith({int? id}) {
    return UploaderDeleteRequest(id: id ?? this.id);
  }

  UploaderDeleteRequest copyWithWrapped({Wrapped<int>? id}) {
    return UploaderDeleteRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class UploaderMediaDeleteRequest {
  UploaderMediaDeleteRequest({
    required this.id,
  });

  factory UploaderMediaDeleteRequest.fromJson(Map<String, dynamic> json) =>
      _$UploaderMediaDeleteRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int id;
  static const fromJsonFactory = _$UploaderMediaDeleteRequestFromJson;
  static const toJsonFactory = _$UploaderMediaDeleteRequestToJson;
  Map<String, dynamic> toJson() => _$UploaderMediaDeleteRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UploaderMediaDeleteRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $UploaderMediaDeleteRequestExtension on UploaderMediaDeleteRequest {
  UploaderMediaDeleteRequest copyWith({int? id}) {
    return UploaderMediaDeleteRequest(id: id ?? this.id);
  }

  UploaderMediaDeleteRequest copyWithWrapped({Wrapped<int>? id}) {
    return UploaderMediaDeleteRequest(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class UploadRequest {
  UploadRequest({
    required this.file,
    required this.collectionName,
  });

  factory UploadRequest.fromJson(Map<String, dynamic> json) =>
      _$UploadRequestFromJson(json);

  @JsonKey(name: 'file', includeIfNull: false)
  final Object file;
  @JsonKey(name: 'collection_name', includeIfNull: false, defaultValue: '')
  final String collectionName;
  static const fromJsonFactory = _$UploadRequestFromJson;
  static const toJsonFactory = _$UploadRequestToJson;
  Map<String, dynamic> toJson() => _$UploadRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UploadRequest &&
            (identical(other.file, file) ||
                const DeepCollectionEquality().equals(other.file, file)) &&
            (identical(other.collectionName, collectionName) ||
                const DeepCollectionEquality()
                    .equals(other.collectionName, collectionName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(file) ^
      const DeepCollectionEquality().hash(collectionName) ^
      runtimeType.hashCode;
}

extension $UploadRequestExtension on UploadRequest {
  UploadRequest copyWith({Object? file, String? collectionName}) {
    return UploadRequest(
        file: file ?? this.file,
        collectionName: collectionName ?? this.collectionName);
  }

  UploadRequest copyWithWrapped(
      {Wrapped<Object>? file, Wrapped<String>? collectionName}) {
    return UploadRequest(
        file: (file != null ? file.value : this.file),
        collectionName: (collectionName != null
            ? collectionName.value
            : this.collectionName));
  }
}

@JsonSerializable(explicitToJson: true)
class UserUpdateRequest {
  UserUpdateRequest({
    required this.name,
    required this.username,
    required this.email,
    this.password,
    this.newPassword,
    this.avatarId,
  });

  factory UserUpdateRequest.fromJson(Map<String, dynamic> json) =>
      _$UserUpdateRequestFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String username;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  @JsonKey(name: 'new_password', includeIfNull: false, defaultValue: '')
  final String? newPassword;
  @JsonKey(name: 'avatar_id', includeIfNull: false)
  final int? avatarId;
  static const fromJsonFactory = _$UserUpdateRequestFromJson;
  static const toJsonFactory = _$UserUpdateRequestToJson;
  Map<String, dynamic> toJson() => _$UserUpdateRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserUpdateRequest &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.newPassword, newPassword) ||
                const DeepCollectionEquality()
                    .equals(other.newPassword, newPassword)) &&
            (identical(other.avatarId, avatarId) ||
                const DeepCollectionEquality()
                    .equals(other.avatarId, avatarId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(newPassword) ^
      const DeepCollectionEquality().hash(avatarId) ^
      runtimeType.hashCode;
}

extension $UserUpdateRequestExtension on UserUpdateRequest {
  UserUpdateRequest copyWith(
      {String? name,
      String? username,
      String? email,
      String? password,
      String? newPassword,
      int? avatarId}) {
    return UserUpdateRequest(
        name: name ?? this.name,
        username: username ?? this.username,
        email: email ?? this.email,
        password: password ?? this.password,
        newPassword: newPassword ?? this.newPassword,
        avatarId: avatarId ?? this.avatarId);
  }

  UserUpdateRequest copyWithWrapped(
      {Wrapped<String>? name,
      Wrapped<String>? username,
      Wrapped<String>? email,
      Wrapped<String?>? password,
      Wrapped<String?>? newPassword,
      Wrapped<int?>? avatarId}) {
    return UserUpdateRequest(
        name: (name != null ? name.value : this.name),
        username: (username != null ? username.value : this.username),
        email: (email != null ? email.value : this.email),
        password: (password != null ? password.value : this.password),
        newPassword:
            (newPassword != null ? newPassword.value : this.newPassword),
        avatarId: (avatarId != null ? avatarId.value : this.avatarId));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenResource {
  TokenResource({
    this.tokenType,
    this.expiresIn,
    this.accessToken,
    this.refreshToken,
  });

  factory TokenResource.fromJson(Map<String, dynamic> json) =>
      _$TokenResourceFromJson(json);

  @JsonKey(name: 'token_type', includeIfNull: false, defaultValue: '')
  final String? tokenType;
  @JsonKey(name: 'expires_in', includeIfNull: false)
  final int? expiresIn;
  @JsonKey(name: 'access_token', includeIfNull: false, defaultValue: '')
  final String? accessToken;
  @JsonKey(name: 'refresh_token', includeIfNull: false, defaultValue: '')
  final String? refreshToken;
  static const fromJsonFactory = _$TokenResourceFromJson;
  static const toJsonFactory = _$TokenResourceToJson;
  Map<String, dynamic> toJson() => _$TokenResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenResource &&
            (identical(other.tokenType, tokenType) ||
                const DeepCollectionEquality()
                    .equals(other.tokenType, tokenType)) &&
            (identical(other.expiresIn, expiresIn) ||
                const DeepCollectionEquality()
                    .equals(other.expiresIn, expiresIn)) &&
            (identical(other.accessToken, accessToken) ||
                const DeepCollectionEquality()
                    .equals(other.accessToken, accessToken)) &&
            (identical(other.refreshToken, refreshToken) ||
                const DeepCollectionEquality()
                    .equals(other.refreshToken, refreshToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(expiresIn) ^
      const DeepCollectionEquality().hash(accessToken) ^
      const DeepCollectionEquality().hash(refreshToken) ^
      runtimeType.hashCode;
}

extension $TokenResourceExtension on TokenResource {
  TokenResource copyWith(
      {String? tokenType,
      int? expiresIn,
      String? accessToken,
      String? refreshToken}) {
    return TokenResource(
        tokenType: tokenType ?? this.tokenType,
        expiresIn: expiresIn ?? this.expiresIn,
        accessToken: accessToken ?? this.accessToken,
        refreshToken: refreshToken ?? this.refreshToken);
  }

  TokenResource copyWithWrapped(
      {Wrapped<String?>? tokenType,
      Wrapped<int?>? expiresIn,
      Wrapped<String?>? accessToken,
      Wrapped<String?>? refreshToken}) {
    return TokenResource(
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        expiresIn: (expiresIn != null ? expiresIn.value : this.expiresIn),
        accessToken:
            (accessToken != null ? accessToken.value : this.accessToken),
        refreshToken:
            (refreshToken != null ? refreshToken.value : this.refreshToken));
  }
}

@JsonSerializable(explicitToJson: true)
class MediaResource {
  MediaResource({
    this.id,
    this.url,
  });

  factory MediaResource.fromJson(Map<String, dynamic> json) =>
      _$MediaResourceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final int? id;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$MediaResourceFromJson;
  static const toJsonFactory = _$MediaResourceToJson;
  Map<String, dynamic> toJson() => _$MediaResourceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MediaResource &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $MediaResourceExtension on MediaResource {
  MediaResource copyWith({int? id, String? url}) {
    return MediaResource(id: id ?? this.id, url: url ?? this.url);
  }

  MediaResource copyWithWrapped({Wrapped<int?>? id, Wrapped<String?>? url}) {
    return MediaResource(
        id: (id != null ? id.value : this.id),
        url: (url != null ? url.value : this.url));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
