// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'discovery_service.enums.swagger.dart' as enums;
export 'discovery_service.enums.swagger.dart';

part 'discovery_service.swagger.chopper.dart';
part 'discovery_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class DiscoveryService extends ChopperService {
  static DiscoveryService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$DiscoveryService(client);
    }

    final newClient = ChopperClient(
        services: [_$DiscoveryService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http:///');
    return _$DiscoveryService(newClient);
  }

  ///Handles learn action events
  ///@param
  ///@param
  ///@param
  ///@param body Learn Action Payload
  Future<chopper.Response> v2LearnActionsPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xDiscoveryServiceExplicitLogging,
    required LearnAction? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LearnAction, () => LearnAction.fromJsonFactory);

    return _v2LearnActionsPost(
        xDev: xDev,
        xCus: xCus,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        body: body,
        cacheControl: cacheControl);
  }

  ///Handles learn action events
  ///@param
  ///@param
  ///@param
  ///@param body Learn Action Payload
  @Post(path: '/v2/learn-actions')
  Future<chopper.Response> _v2LearnActionsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Body() required LearnAction? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve recommendations related to a given content.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  Future<chopper.Response<MoreLikeThisResponse>>
      v2RecommendationsMoreLikeThisGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? clientType,
    List<String>? contentSourceId,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    required String? resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    String? maxRes,
    String? channelId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisResponse, () => MoreLikeThisResponse.fromJsonFactory);

    return _v2RecommendationsMoreLikeThisGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId,
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        channelId: channelId,
        cacheControl: cacheControl);
  }

  ///Retrieve recommendations related to a given content.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  @Get(path: '/v2/recommendations/more-like-this')
  Future<chopper.Response<MoreLikeThisResponse>>
      _v2RecommendationsMoreLikeThisGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('clientType') required String? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('resourceContentSourceId') required String? resourceContentSourceId,
    @Query('resourceId') required String? resourceId,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations') bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Query('channelId') String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve the most popular searches.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<TopSearchResponse>>
      v2RecommendationsTopSearchListGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? clientType,
    List<String>? contentSourceId,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    required int? maxResults,
    required bool? includeNotEntitled,
    String? queryLanguage,
    String? maxRes,
    int? cityId,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopSearchResponse, () => TopSearchResponse.fromJsonFactory);

    return _v2RecommendationsTopSearchListGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///Retrieve the most popular searches.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v2/recommendations/top-search-list')
  Future<chopper.Response<TopSearchResponse>>
      _v2RecommendationsTopSearchListGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('clientType') required String? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve recommendations related to a given content.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  Future<chopper.Response<MoreLikeThisResponseV3>>
      v3RecommendationsMoreLikeThisGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? clientType,
    List<String>? contentSourceId,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    required String? resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    String? maxRes,
    String? channelId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisResponseV3, () => MoreLikeThisResponseV3.fromJsonFactory);

    return _v3RecommendationsMoreLikeThisGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId,
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        channelId: channelId,
        cacheControl: cacheControl);
  }

  ///Retrieve recommendations related to a given content.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 1(LTV), 2(VOD). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 102(Replay), 1(LTV), 2(VOD) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR), 102(Replay).
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param channelId Channel id which is used to get broadcaster name using Hollow, and then compared with broadcaster filter, defined as application setting
  @Get(path: '/v3/recommendations/more-like-this')
  Future<chopper.Response<MoreLikeThisResponseV3>>
      _v3RecommendationsMoreLikeThisGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('clientType') required String? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('resourceContentSourceId') required String? resourceContentSourceId,
    @Query('resourceId') required String? resourceId,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations') bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Query('channelId') String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve the most popular searches.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<TopSearchResponseV3>>
      v3RecommendationsTopSearchListGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? clientType,
    List<String>? contentSourceId,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    required int? maxResults,
    required bool? includeNotEntitled,
    String? queryLanguage,
    String? maxRes,
    int? cityId,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopSearchResponseV3, () => TopSearchResponseV3.fromJsonFactory);

    return _v3RecommendationsTopSearchListGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cityId: cityId,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///Retrieve the most popular searches.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD), 1(LTV), 2(VOD)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v3/recommendations/top-search-list')
  Future<chopper.Response<TopSearchResponseV3>>
      _v3RecommendationsTopSearchListGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('clientType') required String? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for content
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<StbSearchResponse>> v2SearchContentsGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    required int? clientType,
    List<String>? contentSourceId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    required bool? includeNotEntitled,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? maxRes,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponse, () => StbSearchResponse.fromJsonFactory);

    return _v2SearchContentsGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        clientType: clientType,
        contentSourceId: contentSourceId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///Search for content
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v2/search/contents')
  Future<chopper.Response<StbSearchResponse>> _v2SearchContentsGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('includeDetails') bool? includeDetails,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('cityId') int? cityId,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('searchTerm') required String? searchTerm,
    @Query('queryLanguage') String? queryLanguage,
    @Query('startResults') required int? startResults,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('maxRes') String? maxRes,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for content as anonymous user
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 2(VOD), 1(LTV), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 2(VOD), 102(Replay), 1(LTV), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<StbSearchResponse>> v2SearchContentsAnonymousGet({
    String? xSessionId,
    String? xDiscoveryServiceExplicitLogging,
    bool? includeDetails,
    required int? clientType,
    List<String>? contentSourceId,
    required String? sessionId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? maxRes,
    bool? goPlayableOnly,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponse, () => StbSearchResponse.fromJsonFactory);

    return _v2SearchContentsAnonymousGet(
        xSessionId: xSessionId,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        includeDetails: includeDetails,
        clientType: clientType,
        contentSourceId: contentSourceId,
        sessionId: sessionId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///Search for content as anonymous user
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 2(VOD), 1(LTV), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 2(VOD), 102(Replay), 1(LTV), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v2/search/contents-anonymous')
  Future<chopper.Response<StbSearchResponse>> _v2SearchContentsAnonymousGet({
    @Header('X-Session-Id') String? xSessionId,
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('includeDetails') bool? includeDetails,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('sessionId') required String? sessionId,
    @Query('searchTerm') required String? searchTerm,
    @Query('queryLanguage') String? queryLanguage,
    @Query('startResults') required int? startResults,
    @Query('maxResults') required int? maxResults,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('maxRes') String? maxRes,
    @Query('goPlayableOnly') bool? goPlayableOnly,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param body Voice Search Payload
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  Future<chopper.Response<VoiceSearchResponse>> v2SearchVoicePost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    required int? maxResults,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    String? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    bool? applyMarketingBias,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    required NuanceResponse? body,
    bool? debug,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NuanceResponse, () => NuanceResponse.fromJsonFactory);
    generatedMapping.putIfAbsent(
        VoiceSearchResponse, () => VoiceSearchResponse.fromJsonFactory);

    return _v2SearchVoicePost(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        maxRes: maxRes,
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        applyMarketingBias: applyMarketingBias,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        body: body,
        debug: debug,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param body Voice Search Payload
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  @Post(path: '/v2/search/voice')
  Future<chopper.Response<VoiceSearchResponse>> _v2SearchVoicePost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('maxResults') required int? maxResults,
    @Query('includeDetails') bool? includeDetails,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('cityId') int? cityId,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('queryLanguage') String? queryLanguage,
    @Query('applyMarketingBias') bool? applyMarketingBias,
    @Query('searchLiteral') String? searchLiteral,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('nuanceSessionId') required String? nuanceSessionId,
    @Body() required NuanceResponse? body,
    @Query('debug') bool? debug,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Anonymous search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  ///@param
  ///@param body Voice Search Payload
  Future<chopper.Response<VoiceSearchResponse>> v2SearchVoiceAnonymousPost({
    String? xSessionId,
    String? xDiscoveryServiceExplicitLogging,
    required String? sessionId,
    required int? maxResults,
    bool? includeDetails,
    String? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    bool? debug,
    bool? goPlayableOnly,
    bool? mergingOn,
    required NuanceResponse? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NuanceResponse, () => NuanceResponse.fromJsonFactory);
    generatedMapping.putIfAbsent(
        VoiceSearchResponse, () => VoiceSearchResponse.fromJsonFactory);

    return _v2SearchVoiceAnonymousPost(
        xSessionId: xSessionId,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        sessionId: sessionId,
        maxResults: maxResults,
        includeDetails: includeDetails,
        maxRes: maxRes,
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        debug: debug,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        body: body,
        cacheControl: cacheControl);
  }

  ///Anonymous search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  ///@param
  ///@param body Voice Search Payload
  @Post(path: '/v2/search/voice-anonymous')
  Future<chopper.Response<VoiceSearchResponse>> _v2SearchVoiceAnonymousPost({
    @Header('X-Session-Id') String? xSessionId,
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('sessionId') required String? sessionId,
    @Query('maxResults') required int? maxResults,
    @Query('includeDetails') bool? includeDetails,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('queryLanguage') String? queryLanguage,
    @Query('searchLiteral') String? searchLiteral,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('nuanceSessionId') required String? nuanceSessionId,
    @Query('debug') bool? debug,
    @Query('goPlayableOnly') bool? goPlayableOnly,
    @Query('mergingOn') bool? mergingOn,
    @Body() required NuanceResponse? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for content
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<StbSearchResponseV3>> v3SearchContentsGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    required int? clientType,
    List<String>? contentSourceId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    required bool? includeNotEntitled,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? maxRes,
    bool? mergingOn,
    String? includeExternalProvider,
    bool? includeYoutube,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponseV3, () => StbSearchResponseV3.fromJsonFactory);

    return _v3SearchContentsGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        clientType: clientType,
        contentSourceId: contentSourceId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        includeYoutube: includeYoutube,
        cacheControl: cacheControl);
  }

  ///Search for content
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 3(PVR), 2(VOD), 1(LTV), 100(Application), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 3(PVR), 2(VOD), 102(Replay), 1(LTV), 100(Application), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v3/search/contents')
  Future<chopper.Response<StbSearchResponseV3>> _v3SearchContentsGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('includeDetails') bool? includeDetails,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('cityId') int? cityId,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('searchTerm') required String? searchTerm,
    @Query('queryLanguage') String? queryLanguage,
    @Query('startResults') required int? startResults,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('maxRes') String? maxRes,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('includeYoutube') bool? includeYoutube,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for content as anonymous user
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 2(VOD), 1(LTV), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 2(VOD), 102(Replay), 1(LTV), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<StbSearchResponseV3>> v3SearchContentsAnonymousGet({
    String? xSessionId,
    String? xDiscoveryServiceExplicitLogging,
    bool? includeDetails,
    required int? clientType,
    List<String>? contentSourceId,
    required String? sessionId,
    required String? searchTerm,
    String? queryLanguage,
    required int? startResults,
    required int? maxResults,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? maxRes,
    bool? goPlayableOnly,
    bool? mergingOn,
    String? includeExternalProvider,
    bool? includeYoutube,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponseV3, () => StbSearchResponseV3.fromJsonFactory);

    return _v3SearchContentsAnonymousGet(
        xSessionId: xSessionId,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        includeDetails: includeDetails,
        clientType: clientType,
        contentSourceId: contentSourceId,
        sessionId: sessionId,
        searchTerm: searchTerm,
        queryLanguage: queryLanguage,
        startResults: startResults,
        maxResults: maxResults,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        maxRes: maxRes,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        includeYoutube: includeYoutube,
        cacheControl: cacheControl);
  }

  ///Search for content as anonymous user
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel), 102(Replay). Default values depends on RENG_MODE flag. If RENG_MODE is set to "LEGACY", default values are 2(VOD), 1(LTV), 101(Channel). If RENG_MODE is set to "COMPATIBILITY" or "NEW_RENG", default values are 2(VOD), 102(Replay), 1(LTV), 101(Channel) Discovery-service does not validate these parameters.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v3/search/contents-anonymous')
  Future<chopper.Response<StbSearchResponseV3>> _v3SearchContentsAnonymousGet({
    @Header('X-Session-Id') String? xSessionId,
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('includeDetails') bool? includeDetails,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('sessionId') required String? sessionId,
    @Query('searchTerm') required String? searchTerm,
    @Query('queryLanguage') String? queryLanguage,
    @Query('startResults') required int? startResults,
    @Query('maxResults') required int? maxResults,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('maxRes') String? maxRes,
    @Query('goPlayableOnly') bool? goPlayableOnly,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('includeYoutube') bool? includeYoutube,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  ///@param
  ///@param body Voice Search Payload
  Future<chopper.Response<VoiceSearchResponseV3>> v3SearchVoicePost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xDiscoveryServiceExplicitLogging,
    required String? profileId,
    required String? customerId,
    bool? sharedProfile,
    required int? maxResults,
    bool? includeDetails,
    int? replayOptedInTime,
    int? cityId,
    String? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    bool? applyMarketingBias,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    bool? debug,
    bool? mergingOn,
    bool? includeYoutube,
    required NuanceResponse? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NuanceResponse, () => NuanceResponse.fromJsonFactory);
    generatedMapping.putIfAbsent(
        VoiceSearchResponseV3, () => VoiceSearchResponseV3.fromJsonFactory);

    return _v3SearchVoicePost(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeDetails: includeDetails,
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        maxRes: maxRes,
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        applyMarketingBias: applyMarketingBias,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        debug: debug,
        mergingOn: mergingOn,
        includeYoutube: includeYoutube,
        body: body,
        cacheControl: cacheControl);
  }

  ///Search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  ///@param
  ///@param body Voice Search Payload
  @Post(path: '/v3/search/voice')
  Future<chopper.Response<VoiceSearchResponseV3>> _v3SearchVoicePost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('profileId') required String? profileId,
    @Query('customerId') required String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('maxResults') required int? maxResults,
    @Query('includeDetails') bool? includeDetails,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('cityId') int? cityId,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('queryLanguage') String? queryLanguage,
    @Query('applyMarketingBias') bool? applyMarketingBias,
    @Query('searchLiteral') String? searchLiteral,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('nuanceSessionId') required String? nuanceSessionId,
    @Query('debug') bool? debug,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeYoutube') bool? includeYoutube,
    @Body() required NuanceResponse? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Anonymous search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param body Voice Search Payload
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<VoiceSearchResponseV3>> v3SearchVoiceAnonymousPost({
    String? xSessionId,
    String? xDiscoveryServiceExplicitLogging,
    required String? sessionId,
    required int? maxResults,
    bool? includeDetails,
    String? maxRes,
    String? includeExternalProvider,
    String? queryLanguage,
    String? searchLiteral,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    required String? nuanceSessionId,
    required NuanceResponse? body,
    bool? debug,
    bool? goPlayableOnly,
    bool? mergingOn,
    bool? includeYoutube,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NuanceResponse, () => NuanceResponse.fromJsonFactory);
    generatedMapping.putIfAbsent(
        VoiceSearchResponseV3, () => VoiceSearchResponseV3.fromJsonFactory);

    return _v3SearchVoiceAnonymousPost(
        xSessionId: xSessionId,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        sessionId: sessionId,
        maxResults: maxResults,
        includeDetails: includeDetails,
        maxRes: maxRes,
        includeExternalProvider: includeExternalProvider,
        queryLanguage: queryLanguage,
        searchLiteral: searchLiteral,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        nuanceSessionId: nuanceSessionId,
        body: body,
        debug: debug,
        goPlayableOnly: goPlayableOnly,
        mergingOn: mergingOn,
        includeYoutube: includeYoutube,
        cacheControl: cacheControl);
  }

  ///Anonymous search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param queryLanguage UI language
  ///@param searchLiteral This is the main literal speech string mainly used for logging and tracking
  ///@param filterTimeWindowStart Specifies the start time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, highest start time is used
  ///@param filterTimeWindowEnd Specifies the end time of the time window (number of seconds since January 1, 1970, 00:00 GMT). If calendarX is given, lowest end time is used
  ///@param
  ///@param body Voice Search Payload
  ///@param debug If set to true the postdata to RENG will be logged to Kibana
  ///@param
  ///@param
  ///@param
  @Post(path: '/v3/search/voice-anonymous')
  Future<chopper.Response<VoiceSearchResponseV3>> _v3SearchVoiceAnonymousPost({
    @Header('X-Session-Id') String? xSessionId,
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('sessionId') required String? sessionId,
    @Query('maxResults') required int? maxResults,
    @Query('includeDetails') bool? includeDetails,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('queryLanguage') String? queryLanguage,
    @Query('searchLiteral') String? searchLiteral,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('nuanceSessionId') required String? nuanceSessionId,
    @Body() required NuanceResponse? body,
    @Query('debug') bool? debug,
    @Query('goPlayableOnly') bool? goPlayableOnly,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeYoutube') bool? includeYoutube,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for content
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId Default (LTV, VOD, PVR, Channel), 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel)
  ///@param sessionId Session identifier.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<List<StbSearchResponseV1>>> v15SearchContentsGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    required int? clientType,
    List<String>? contentSourceId,
    String? sessionId,
    String? profileId,
    String? customerId,
    bool? sharedProfile,
    required String? searchTerm,
    required int? startResults,
    required int? maxResults,
    required bool? includeNotEntitled,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    String? maxRes,
    int? cityId,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        StbSearchResponseV1, () => StbSearchResponseV1.fromJsonFactory);

    return _v15SearchContentsGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        clientType: clientType,
        contentSourceId: contentSourceId,
        sessionId: sessionId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        searchTerm: searchTerm,
        startResults: startResults,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cityId: cityId,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Search for content
  ///@param
  ///@param
  ///@param
  ///@param clientType 399 (Adaptive Search), 209 (Web), 219 (iPhone), 229 (iPad), 239 (Android Phone), 249 (Android Tablet)
  ///@param contentSourceId Default (LTV, VOD, PVR, Channel), 1(LTV), 2(VOD), 3(PVR), 100(Application), 101(Channel)
  ///@param sessionId Session identifier.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v1_5/search/contents')
  Future<chopper.Response<List<StbSearchResponseV1>>> _v15SearchContentsGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Query('clientType') required int? clientType,
    @Query('contentSourceId') List<String>? contentSourceId,
    @Query('sessionId') String? sessionId,
    @Query('profileId') String? profileId,
    @Query('customerId') String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('searchTerm') required String? searchTerm,
    @Query('startResults') required int? startResults,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param uiLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param
  ///@param body Voice Search Payload
  Future<chopper.Response<List<VoiceSearchResponseV1>>> v15SearchVoicePost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xDiscoveryServiceExplicitLogging,
    bool? sharedProfile,
    required String? profileId,
    String? customerId,
    required int? maxResults,
    int? cityId,
    bool? mergingOn,
    String? uiLanguage,
    bool? applyMarketingBias,
    String? maxRes,
    required NuanceResponseV1? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NuanceResponseV1, () => NuanceResponseV1.fromJsonFactory);
    generatedMapping.putIfAbsent(
        VoiceSearchResponseV1, () => VoiceSearchResponseV1.fromJsonFactory);

    return _v15SearchVoicePost(
        xDev: xDev,
        xCus: xCus,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        sharedProfile: sharedProfile,
        profileId: profileId,
        customerId: customerId,
        maxResults: maxResults,
        cityId: cityId,
        mergingOn: mergingOn,
        uiLanguage: uiLanguage,
        applyMarketingBias: applyMarketingBias,
        maxRes: maxRes,
        body: body,
        cacheControl: cacheControl);
  }

  ///Search using voice info.
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param uiLanguage UI language
  ///@param applyMarketingBias Apply marketing bias
  ///@param
  ///@param body Voice Search Payload
  @Post(path: '/v1_5/search/voice')
  Future<chopper.Response<List<VoiceSearchResponseV1>>> _v15SearchVoicePost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('profileId') required String? profileId,
    @Query('customerId') String? customerId,
    @Query('maxResults') required int? maxResults,
    @Query('cityId') int? cityId,
    @Query('mergingOn') bool? mergingOn,
    @Query('uiLanguage') String? uiLanguage,
    @Query('applyMarketingBias') bool? applyMarketingBias,
    @Query('maxRes') String? maxRes,
    @Body() required NuanceResponseV1? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Handles learn action events
  ///@param
  ///@param
  ///@param
  ///@param body Learn Action Payload
  Future<chopper.Response> v15LearnActionsPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xDiscoveryServiceExplicitLogging,
    required LearnAction? body,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LearnAction, () => LearnAction.fromJsonFactory);

    return _v15LearnActionsPost(
        xDev: xDev,
        xCus: xCus,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        body: body,
        cacheControl: cacheControl);
  }

  ///Handles learn action events
  ///@param
  ///@param
  ///@param
  ///@param body Learn Action Payload
  @Post(path: '/v1_5/learn-actions')
  Future<chopper.Response> _v15LearnActionsPost({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Body() required LearnAction? body,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve the most popular searches.
  ///@param
  ///@param
  ///@param
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<List<TopSearchResponseV1>>>
      v15RecommendationsTopSearchListGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xDiscoveryServiceExplicitLogging,
    required String? clientType,
    List<Object>? contentSourceId,
    required String? profileId,
    String? customerId,
    bool? sharedProfile,
    required int? maxResults,
    required bool? includeNotEntitled,
    String? queryLanguage,
    String? maxRes,
    int? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        TopSearchResponseV1, () => TopSearchResponseV1.fromJsonFactory);

    return _v15RecommendationsTopSearchListGet(
        xDev: xDev,
        xCus: xCus,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Retrieve the most popular searches.
  ///@param
  ///@param
  ///@param
  ///@param clientType 340 (Most Clicked on Search Item)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v1_5/recommendations/top-search-list')
  Future<chopper.Response<List<TopSearchResponseV1>>>
      _v15RecommendationsTopSearchListGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('clientType') required String? clientType,
    @Query('contentSourceId') List<Object>? contentSourceId,
    @Query('profileId') required String? profileId,
    @Query('customerId') String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve recommendations related to a given content.
  ///@param
  ///@param
  ///@param
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param
  ///@param
  ///@param
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  Future<chopper.Response<List<MoreLikeThisResponseV1>>>
      v15RecommendationsMoreLikeThisGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xDiscoveryServiceExplicitLogging,
    required String? clientType,
    List<Object>? contentSourceId,
    required String? profileId,
    String? customerId,
    bool? sharedProfile,
    required String? resourceContentSourceId,
    required String? resourceId,
    required int? maxResults,
    required bool? includeNotEntitled,
    bool? allowPreviousRecommendations,
    int? filterTimeWindowStart,
    int? filterTimeWindowEnd,
    String? queryLanguage,
    String? maxRes,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        MoreLikeThisResponseV1, () => MoreLikeThisResponseV1.fromJsonFactory);

    return _v15RecommendationsMoreLikeThisGet(
        xDev: xDev,
        xCus: xCus,
        xDiscoveryServiceExplicitLogging: xDiscoveryServiceExplicitLogging,
        clientType: clientType,
        contentSourceId: contentSourceId,
        profileId: profileId,
        customerId: customerId,
        sharedProfile: sharedProfile,
        resourceContentSourceId: resourceContentSourceId,
        resourceId: resourceId,
        maxResults: maxResults,
        includeNotEntitled: includeNotEntitled,
        allowPreviousRecommendations: allowPreviousRecommendations,
        filterTimeWindowStart: filterTimeWindowStart,
        filterTimeWindowEnd: filterTimeWindowEnd,
        queryLanguage: queryLanguage,
        maxRes: maxRes,
        cacheControl: cacheControl);
  }

  ///Retrieve recommendations related to a given content.
  ///@param
  ///@param
  ///@param
  ///@param clientType 305 (Content Related Showcase)
  ///@param contentSourceId Default (LTV, VOD, PVR), 1(LTV), 2(VOD), 3(PVR)
  ///@param
  ///@param
  ///@param
  ///@param resourceContentSourceId 1(LTV), 2(VOD), 3(PVR)
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  ///@param
  @Get(path: '/v1_5/recommendations/more-like-this')
  Future<chopper.Response<List<MoreLikeThisResponseV1>>>
      _v15RecommendationsMoreLikeThisGet({
    @Header('X-Dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-DiscoveryService-Explicit-Logging')
        String? xDiscoveryServiceExplicitLogging,
    @Query('clientType') required String? clientType,
    @Query('contentSourceId') List<Object>? contentSourceId,
    @Query('profileId') required String? profileId,
    @Query('customerId') String? customerId,
    @Query('sharedProfile') bool? sharedProfile,
    @Query('resourceContentSourceId') required String? resourceContentSourceId,
    @Query('resourceId') required String? resourceId,
    @Query('maxResults') required int? maxResults,
    @Query('includeNotEntitled') required bool? includeNotEntitled,
    @Query('allowPreviousRecommendations') bool? allowPreviousRecommendations,
    @Query('filterTimeWindowStart') int? filterTimeWindowStart,
    @Query('filterTimeWindowEnd') int? filterTimeWindowEnd,
    @Query('queryLanguage') String? queryLanguage,
    @Query('maxRes') String? maxRes,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponse {
  LTVSearchResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    required this.channel,
    this.ageRating,
    this.isAdult,
    this.series,
    this.replayAvailable,
    this.eventReplay,
  });

  factory LTVSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse channel;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  static const fromJsonFactory = _$LTVSearchResponseFromJson;
  static const toJsonFactory = _$LTVSearchResponseToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseExtension on LTVSearchResponse {
  LTVSearchResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      String? ageRating,
      bool? isAdult,
      SeriesResponse? series,
      bool? replayAvailable,
      EventReplayResponse? eventReplay}) {
    return LTVSearchResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        series: series ?? this.series,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay);
  }

  LTVSearchResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse>? channel,
      Wrapped<String?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay}) {
    return LTVSearchResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        series: (series != null ? series.value : this.series),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponseV3 {
  LTVSearchResponseV3({
    this.mergedId,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    required this.channel,
    this.ageRating,
    this.isAdult,
    this.series,
    this.replayAvailable,
    this.eventReplay,
  });

  factory LTVSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseV3FromJson(json);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse channel;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  static const fromJsonFactory = _$LTVSearchResponseV3FromJson;
  static const toJsonFactory = _$LTVSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseV3Extension on LTVSearchResponseV3 {
  LTVSearchResponseV3 copyWith(
      {String? mergedId,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      String? ageRating,
      bool? isAdult,
      SeriesResponse? series,
      bool? replayAvailable,
      EventReplayResponse? eventReplay}) {
    return LTVSearchResponseV3(
        mergedId: mergedId ?? this.mergedId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        series: series ?? this.series,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay);
  }

  LTVSearchResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse>? channel,
      Wrapped<String?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<SeriesResponse?>? series,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay}) {
    return LTVSearchResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        series: (series != null ? series.value : this.series),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVRecommendationResponse {
  LTVRecommendationResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.series,
    this.associatedPicture,
    this.associatedPictureType,
    this.replayAvailable,
    this.eventReplay,
    this.imageVersion,
  });

  factory LTVRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$LTVRecommendationResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final num bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$LTVRecommendationResponseFromJson;
  static const toJsonFactory = _$LTVRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$LTVRecommendationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVRecommendationResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $LTVRecommendationResponseExtension on LTVRecommendationResponse {
  LTVRecommendationResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      num? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      SeriesResponse? series,
      String? associatedPicture,
      String? associatedPictureType,
      bool? replayAvailable,
      EventReplayResponse? eventReplay,
      String? imageVersion}) {
    return LTVRecommendationResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        series: series ?? this.series,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        eventReplay: eventReplay ?? this.eventReplay,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  LTVRecommendationResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<num>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<SeriesResponse?>? series,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? replayAvailable,
      Wrapped<EventReplayResponse?>? eventReplay,
      Wrapped<String?>? imageVersion}) {
    return LTVRecommendationResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        series: (series != null ? series.value : this.series),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class VODResponse {
  VODResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.bookmark,
    this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.series,
    required this.est,
    this.estOnly,
    this.associatedPicture,
    this.associatedPictureType,
    this.productType,
  });

  factory VODResponse.fromJson(Map<String, dynamic> json) =>
      _$VODResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse> est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODResponseProductTypeToJson,
    fromJson: vODResponseProductTypeFromJson,
  )
  final enums.VODResponseProductType? productType;
  static const fromJsonFactory = _$VODResponseFromJson;
  static const toJsonFactory = _$VODResponseToJson;
  Map<String, dynamic> toJson() => _$VODResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      runtimeType.hashCode;
}

extension $VODResponseExtension on VODResponse {
  VODResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      SeriesResponse? series,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODResponseProductType? productType}) {
    return VODResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        series: series ?? this.series,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType);
  }

  VODResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<SeriesResponse?>? series,
      Wrapped<List<EstResponse>>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<enums.VODResponseProductType?>? productType}) {
    return VODResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        series: (series != null ? series.value : this.series),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType));
  }
}

@JsonSerializable(explicitToJson: true)
class VODResponseV3 {
  VODResponseV3({
    this.mergedId,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.bookmark,
    this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.series,
    required this.est,
    this.estOnly,
    this.associatedPicture,
    this.associatedPictureType,
    this.productType,
  });

  factory VODResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VODResponseV3FromJson(json);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse> est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODResponseV3ProductTypeToJson,
    fromJson: vODResponseV3ProductTypeFromJson,
  )
  final enums.VODResponseV3ProductType? productType;
  static const fromJsonFactory = _$VODResponseV3FromJson;
  static const toJsonFactory = _$VODResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VODResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality().equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) || const DeepCollectionEquality().equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      runtimeType.hashCode;
}

extension $VODResponseV3Extension on VODResponseV3 {
  VODResponseV3 copyWith(
      {String? mergedId,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      SeriesResponse? series,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODResponseV3ProductType? productType}) {
    return VODResponseV3(
        mergedId: mergedId ?? this.mergedId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        series: series ?? this.series,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType);
  }

  VODResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<SeriesResponse?>? series,
      Wrapped<List<EstResponse>>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<enums.VODResponseV3ProductType?>? productType}) {
    return VODResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        series: (series != null ? series.value : this.series),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType));
  }
}

@JsonSerializable(explicitToJson: true)
class VODRecommendationResponse {
  VODRecommendationResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.bookmark,
    this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.series,
    required this.est,
    this.estOnly,
    this.associatedPicture,
    this.associatedPictureType,
    this.productType,
    this.imageVersion,
  });

  factory VODRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$VODRecommendationResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponse? series;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse> est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODRecommendationResponseProductTypeToJson,
    fromJson: vODRecommendationResponseProductTypeFromJson,
  )
  final enums.VODRecommendationResponseProductType? productType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$VODRecommendationResponseFromJson;
  static const toJsonFactory = _$VODRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$VODRecommendationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODRecommendationResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $VODRecommendationResponseExtension on VODRecommendationResponse {
  VODRecommendationResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      SeriesRecommendationResponse? series,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODRecommendationResponseProductType? productType,
      String? imageVersion}) {
    return VODRecommendationResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        series: series ?? this.series,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  VODRecommendationResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<SeriesRecommendationResponse?>? series,
      Wrapped<List<EstResponse>>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<enums.VODRecommendationResponseProductType?>? productType,
      Wrapped<String?>? imageVersion}) {
    return VODRecommendationResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        series: (series != null ? series.value : this.series),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class VODRecommendationResponseV3 {
  VODRecommendationResponseV3({
    this.mergedId,
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.bookmark,
    this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.channel,
    this.ageRating,
    this.isAdult,
    this.minPrice,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.entitlementEnd,
    this.entitlementState,
    this.series,
    required this.est,
    this.estOnly,
    this.associatedPicture,
    this.associatedPictureType,
    this.productType,
    this.imageVersion,
  });

  factory VODRecommendationResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VODRecommendationResponseV3FromJson(json);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponse? series;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse> est;
  @JsonKey(name: 'estOnly', includeIfNull: false)
  final bool? estOnly;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(
    name: 'productType',
    includeIfNull: false,
    toJson: vODRecommendationResponseV3ProductTypeToJson,
    fromJson: vODRecommendationResponseV3ProductTypeFromJson,
  )
  final enums.VODRecommendationResponseV3ProductType? productType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$VODRecommendationResponseV3FromJson;
  static const toJsonFactory = _$VODRecommendationResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VODRecommendationResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODRecommendationResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.estOnly, estOnly) ||
                const DeepCollectionEquality()
                    .equals(other.estOnly, estOnly)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality().equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) || const DeepCollectionEquality().equals(other.associatedPictureType, associatedPictureType)) &&
            (identical(other.productType, productType) || const DeepCollectionEquality().equals(other.productType, productType)) &&
            (identical(other.imageVersion, imageVersion) || const DeepCollectionEquality().equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(estOnly) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(productType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $VODRecommendationResponseV3Extension on VODRecommendationResponseV3 {
  VODRecommendationResponseV3 copyWith(
      {String? mergedId,
      String? contentType,
      int? contentSource,
      String? id,
      String? name,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? ageRating,
      bool? isAdult,
      String? minPrice,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      String? entitlementEnd,
      String? entitlementState,
      SeriesRecommendationResponse? series,
      List<EstResponse>? est,
      bool? estOnly,
      String? associatedPicture,
      String? associatedPictureType,
      enums.VODRecommendationResponseV3ProductType? productType,
      String? imageVersion}) {
    return VODRecommendationResponseV3(
        mergedId: mergedId ?? this.mergedId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        series: series ?? this.series,
        est: est ?? this.est,
        estOnly: estOnly ?? this.estOnly,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        productType: productType ?? this.productType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  VODRecommendationResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minPrice,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<SeriesRecommendationResponse?>? series,
      Wrapped<List<EstResponse>>? est,
      Wrapped<bool?>? estOnly,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<enums.VODRecommendationResponseV3ProductType?>? productType,
      Wrapped<String?>? imageVersion}) {
    return VODRecommendationResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        series: (series != null ? series.value : this.series),
        est: (est != null ? est.value : this.est),
        estOnly: (estOnly != null ? estOnly.value : this.estOnly),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        productType:
            (productType != null ? productType.value : this.productType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleChannelResponse {
  SimpleChannelResponse({
    required this.channelId,
    required this.channelName,
  });

  factory SimpleChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$SimpleChannelResponseFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String channelName;
  static const fromJsonFactory = _$SimpleChannelResponseFromJson;
  static const toJsonFactory = _$SimpleChannelResponseToJson;
  Map<String, dynamic> toJson() => _$SimpleChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleChannelResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      runtimeType.hashCode;
}

extension $SimpleChannelResponseExtension on SimpleChannelResponse {
  SimpleChannelResponse copyWith({String? channelId, String? channelName}) {
    return SimpleChannelResponse(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName);
  }

  SimpleChannelResponse copyWithWrapped(
      {Wrapped<String>? channelId, Wrapped<String>? channelName}) {
    return SimpleChannelResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponse {
  ChannelResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    required this.name,
    this.event,
  });

  factory ChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'event', includeIfNull: false)
  final ChannelEventResponse? event;
  static const fromJsonFactory = _$ChannelResponseFromJson;
  static const toJsonFactory = _$ChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.event, event) ||
                const DeepCollectionEquality().equals(other.event, event)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(event) ^
      runtimeType.hashCode;
}

extension $ChannelResponseExtension on ChannelResponse {
  ChannelResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      ChannelEventResponse? event}) {
    return ChannelResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        event: event ?? this.event);
  }

  ChannelResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<ChannelEventResponse?>? event}) {
    return ChannelResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        event: (event != null ? event.value : this.event));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelEventResponse {
  ChannelEventResponse({
    required this.id,
    this.name,
    required this.startTime,
    required this.endTime,
    this.duration,
    this.ageRating,
    this.isAdult,
  });

  factory ChannelEventResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelEventResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  static const fromJsonFactory = _$ChannelEventResponseFromJson;
  static const toJsonFactory = _$ChannelEventResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelEventResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelEventResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality().equals(other.isAdult, isAdult)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      runtimeType.hashCode;
}

extension $ChannelEventResponseExtension on ChannelEventResponse {
  ChannelEventResponse copyWith(
      {String? id,
      String? name,
      String? startTime,
      String? endTime,
      num? duration,
      int? ageRating,
      bool? isAdult}) {
    return ChannelEventResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult);
  }

  ChannelEventResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<num?>? duration,
      Wrapped<int?>? ageRating,
      Wrapped<bool?>? isAdult}) {
    return ChannelEventResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult));
  }
}

@JsonSerializable(explicitToJson: true)
class ApplicationResponse {
  ApplicationResponse({
    required this.contentType,
    required this.contentSource,
    required this.id,
    this.name,
    this.appLogo,
  });

  factory ApplicationResponse.fromJson(Map<String, dynamic> json) =>
      _$ApplicationResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'appLogo', includeIfNull: false, defaultValue: '')
  final String? appLogo;
  static const fromJsonFactory = _$ApplicationResponseFromJson;
  static const toJsonFactory = _$ApplicationResponseToJson;
  Map<String, dynamic> toJson() => _$ApplicationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ApplicationResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.appLogo, appLogo) ||
                const DeepCollectionEquality().equals(other.appLogo, appLogo)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(appLogo) ^
      runtimeType.hashCode;
}

extension $ApplicationResponseExtension on ApplicationResponse {
  ApplicationResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? id,
      String? name,
      String? appLogo}) {
    return ApplicationResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        id: id ?? this.id,
        name: name ?? this.name,
        appLogo: appLogo ?? this.appLogo);
  }

  ApplicationResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? appLogo}) {
    return ApplicationResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        appLogo: (appLogo != null ? appLogo.value : this.appLogo));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRSearchResponse {
  PVRSearchResponse({
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    required this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.isRestricted,
    this.series,
  });

  factory PVRSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$PVRSearchResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  static const fromJsonFactory = _$PVRSearchResponseFromJson;
  static const toJsonFactory = _$PVRSearchResponseToJson;
  Map<String, dynamic> toJson() => _$PVRSearchResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRSearchResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $PVRSearchResponseExtension on PVRSearchResponse {
  PVRSearchResponse copyWith(
      {String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      bool? isRestricted,
      SeriesResponse? series}) {
    return PVRSearchResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series);
  }

  PVRSearchResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series}) {
    return PVRSearchResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRSearchResponseV3 {
  PVRSearchResponseV3({
    this.mergedId,
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    this.bookmark,
    this.viewState,
    required this.startTime,
    required this.endTime,
    this.duration,
    required this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.isRestricted,
    this.series,
  });

  factory PVRSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$PVRSearchResponseV3FromJson(json);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String? viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  static const fromJsonFactory = _$PVRSearchResponseV3FromJson;
  static const toJsonFactory = _$PVRSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$PVRSearchResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRSearchResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $PVRSearchResponseV3Extension on PVRSearchResponseV3 {
  PVRSearchResponseV3 copyWith(
      {String? mergedId,
      String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      bool? isRestricted,
      SeriesResponse? series}) {
    return PVRSearchResponseV3(
        mergedId: mergedId ?? this.mergedId,
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series);
  }

  PVRSearchResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? viewState,
      Wrapped<String>? startTime,
      Wrapped<String>? endTime,
      Wrapped<num?>? duration,
      Wrapped<SimpleChannelResponse>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series}) {
    return PVRSearchResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRRecommendationResponse {
  PVRRecommendationResponse({
    required this.id,
    this.name,
    required this.contentType,
    required this.contentSource,
    this.cpeId,
    required this.bookmark,
    required this.viewState,
    this.startTime,
    this.endTime,
    this.duration,
    this.technicalDuration,
    this.channel,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    required this.isRestricted,
    this.series,
    this.associatedPicture,
    this.associatedPictureType,
    this.imageVersion,
  });

  factory PVRRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$PVRRecommendationResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'viewState', includeIfNull: false, defaultValue: '')
  final String viewState;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  @JsonKey(name: 'duration', includeIfNull: false)
  final num? duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final num? technicalDuration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final SimpleChannelResponse? channel;
  @JsonKey(name: 'minimumAge', includeIfNull: false)
  final int? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isRestricted', includeIfNull: false)
  final bool isRestricted;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$PVRRecommendationResponseFromJson;
  static const toJsonFactory = _$PVRRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$PVRRecommendationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRRecommendationResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isRestricted, isRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.isRestricted, isRestricted)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isRestricted) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $PVRRecommendationResponseExtension on PVRRecommendationResponse {
  PVRRecommendationResponse copyWith(
      {String? id,
      String? name,
      String? contentType,
      int? contentSource,
      String? cpeId,
      int? bookmark,
      String? viewState,
      String? startTime,
      String? endTime,
      num? duration,
      num? technicalDuration,
      SimpleChannelResponse? channel,
      int? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      bool? isRestricted,
      SeriesResponse? series,
      String? associatedPicture,
      String? associatedPictureType,
      String? imageVersion}) {
    return PVRRecommendationResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        cpeId: cpeId ?? this.cpeId,
        bookmark: bookmark ?? this.bookmark,
        viewState: viewState ?? this.viewState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        channel: channel ?? this.channel,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        isRestricted: isRestricted ?? this.isRestricted,
        series: series ?? this.series,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  PVRRecommendationResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? cpeId,
      Wrapped<int>? bookmark,
      Wrapped<String>? viewState,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime,
      Wrapped<num?>? duration,
      Wrapped<num?>? technicalDuration,
      Wrapped<SimpleChannelResponse?>? channel,
      Wrapped<int?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool>? isRestricted,
      Wrapped<SeriesResponse?>? series,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? imageVersion}) {
    return PVRRecommendationResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        viewState: (viewState != null ? viewState.value : this.viewState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        channel: (channel != null ? channel.value : this.channel),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isRestricted:
            (isRestricted != null ? isRestricted.value : this.isRestricted),
        series: (series != null ? series.value : this.series),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedMultisourceResponse {
  GroupedMultisourceResponse({
    required this.groupType,
    required this.id,
    required this.name,
    this.channels,
    this.selectedEventId,
    this.series,
    this.associatedPicture,
    this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
  });

  factory GroupedMultisourceResponse.fromJson(Map<String, dynamic> json) =>
      _$GroupedMultisourceResponseFromJson(json);

  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <SimpleChannelResponse>[])
  final List<SimpleChannelResponse>? channels;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedMultisourceResponseSeriesContentTypeToJson,
    fromJson: groupedMultisourceResponseSeriesContentTypeFromJson,
  )
  final enums.GroupedMultisourceResponseSeriesContentType? seriesContentType;
  static const fromJsonFactory = _$GroupedMultisourceResponseFromJson;
  static const toJsonFactory = _$GroupedMultisourceResponseToJson;
  Map<String, dynamic> toJson() => _$GroupedMultisourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedMultisourceResponse &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      runtimeType.hashCode;
}

extension $GroupedMultisourceResponseExtension on GroupedMultisourceResponse {
  GroupedMultisourceResponse copyWith(
      {String? groupType,
      String? id,
      String? name,
      List<SimpleChannelResponse>? channels,
      String? selectedEventId,
      SeriesResponse? series,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedMultisourceResponseSeriesContentType? seriesContentType}) {
    return GroupedMultisourceResponse(
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        series: series ?? this.series,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType);
  }

  GroupedMultisourceResponse copyWithWrapped(
      {Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<List<SimpleChannelResponse>?>? channels,
      Wrapped<String?>? selectedEventId,
      Wrapped<SeriesResponse?>? series,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedMultisourceResponseSeriesContentType?>?
          seriesContentType}) {
    return GroupedMultisourceResponse(
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        series: (series != null ? series.value : this.series),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedMultisourceResponseV3 {
  GroupedMultisourceResponseV3({
    this.mergedId,
    required this.groupType,
    required this.id,
    required this.name,
    this.channels,
    this.selectedEventId,
    this.series,
    this.associatedPicture,
    this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
  });

  factory GroupedMultisourceResponseV3.fromJson(Map<String, dynamic> json) =>
      _$GroupedMultisourceResponseV3FromJson(json);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <SimpleChannelResponse>[])
  final List<SimpleChannelResponse>? channels;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesResponse? series;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedMultisourceResponseV3SeriesContentTypeToJson,
    fromJson: groupedMultisourceResponseV3SeriesContentTypeFromJson,
  )
  final enums.GroupedMultisourceResponseV3SeriesContentType? seriesContentType;
  static const fromJsonFactory = _$GroupedMultisourceResponseV3FromJson;
  static const toJsonFactory = _$GroupedMultisourceResponseV3ToJson;
  Map<String, dynamic> toJson() => _$GroupedMultisourceResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedMultisourceResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      runtimeType.hashCode;
}

extension $GroupedMultisourceResponseV3Extension
    on GroupedMultisourceResponseV3 {
  GroupedMultisourceResponseV3 copyWith(
      {String? mergedId,
      String? groupType,
      String? id,
      String? name,
      List<SimpleChannelResponse>? channels,
      String? selectedEventId,
      SeriesResponse? series,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedMultisourceResponseV3SeriesContentType? seriesContentType}) {
    return GroupedMultisourceResponseV3(
        mergedId: mergedId ?? this.mergedId,
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        series: series ?? this.series,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType);
  }

  GroupedMultisourceResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<List<SimpleChannelResponse>?>? channels,
      Wrapped<String?>? selectedEventId,
      Wrapped<SeriesResponse?>? series,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedMultisourceResponseV3SeriesContentType?>?
          seriesContentType}) {
    return GroupedMultisourceResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        series: (series != null ? series.value : this.series),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedSeriesResponse {
  GroupedSeriesResponse({
    required this.groupType,
    required this.id,
    required this.name,
    this.channels,
    this.hasInteracted,
    this.selectedEventId,
    this.associatedPicture,
    this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
    this.episodeCount,
    this.seasonCount,
    this.specialsCount,
  });

  factory GroupedSeriesResponse.fromJson(Map<String, dynamic> json) =>
      _$GroupedSeriesResponseFromJson(json);

  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <SimpleChannelResponse>[])
  final List<SimpleChannelResponse>? channels;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool? hasInteracted;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedSeriesResponseSeriesContentTypeToJson,
    fromJson: groupedSeriesResponseSeriesContentTypeFromJson,
  )
  final enums.GroupedSeriesResponseSeriesContentType? seriesContentType;
  @JsonKey(name: 'episodeCount', includeIfNull: false)
  final int? episodeCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  static const fromJsonFactory = _$GroupedSeriesResponseFromJson;
  static const toJsonFactory = _$GroupedSeriesResponseToJson;
  Map<String, dynamic> toJson() => _$GroupedSeriesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedSeriesResponse &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)) &&
            (identical(other.episodeCount, episodeCount) ||
                const DeepCollectionEquality()
                    .equals(other.episodeCount, episodeCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      const DeepCollectionEquality().hash(episodeCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      runtimeType.hashCode;
}

extension $GroupedSeriesResponseExtension on GroupedSeriesResponse {
  GroupedSeriesResponse copyWith(
      {String? groupType,
      String? id,
      String? name,
      List<SimpleChannelResponse>? channels,
      bool? hasInteracted,
      String? selectedEventId,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedSeriesResponseSeriesContentType? seriesContentType,
      int? episodeCount,
      int? seasonCount,
      int? specialsCount}) {
    return GroupedSeriesResponse(
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType,
        episodeCount: episodeCount ?? this.episodeCount,
        seasonCount: seasonCount ?? this.seasonCount,
        specialsCount: specialsCount ?? this.specialsCount);
  }

  GroupedSeriesResponse copyWithWrapped(
      {Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<List<SimpleChannelResponse>?>? channels,
      Wrapped<bool?>? hasInteracted,
      Wrapped<String?>? selectedEventId,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedSeriesResponseSeriesContentType?>? seriesContentType,
      Wrapped<int?>? episodeCount,
      Wrapped<int?>? seasonCount,
      Wrapped<int?>? specialsCount}) {
    return GroupedSeriesResponse(
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType),
        episodeCount:
            (episodeCount != null ? episodeCount.value : this.episodeCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount));
  }
}

@JsonSerializable(explicitToJson: true)
class GroupedSeriesResponseV3 {
  GroupedSeriesResponseV3({
    this.mergedId,
    required this.groupType,
    required this.id,
    required this.name,
    this.channels,
    this.hasInteracted,
    this.selectedEventId,
    this.associatedPicture,
    this.associatedPictureType,
    this.isAdult,
    this.seriesContentType,
    this.episodeCount,
    this.seasonCount,
    this.specialsCount,
  });

  factory GroupedSeriesResponseV3.fromJson(Map<String, dynamic> json) =>
      _$GroupedSeriesResponseV3FromJson(json);

  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'groupType', includeIfNull: false, defaultValue: '')
  final String groupType;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(
      name: 'channels',
      includeIfNull: false,
      defaultValue: <SimpleChannelResponse>[])
  final List<SimpleChannelResponse>? channels;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool? hasInteracted;
  @JsonKey(name: 'selectedEventId', includeIfNull: false, defaultValue: '')
  final String? selectedEventId;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(
    name: 'seriesContentType',
    includeIfNull: false,
    toJson: groupedSeriesResponseV3SeriesContentTypeToJson,
    fromJson: groupedSeriesResponseV3SeriesContentTypeFromJson,
  )
  final enums.GroupedSeriesResponseV3SeriesContentType? seriesContentType;
  @JsonKey(name: 'episodeCount', includeIfNull: false)
  final int? episodeCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  static const fromJsonFactory = _$GroupedSeriesResponseV3FromJson;
  static const toJsonFactory = _$GroupedSeriesResponseV3ToJson;
  Map<String, dynamic> toJson() => _$GroupedSeriesResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GroupedSeriesResponseV3 &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.groupType, groupType) ||
                const DeepCollectionEquality()
                    .equals(other.groupType, groupType)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.selectedEventId, selectedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEventId, selectedEventId)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.seriesContentType, seriesContentType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesContentType, seriesContentType)) &&
            (identical(other.episodeCount, episodeCount) ||
                const DeepCollectionEquality()
                    .equals(other.episodeCount, episodeCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(groupType) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(selectedEventId) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(seriesContentType) ^
      const DeepCollectionEquality().hash(episodeCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      runtimeType.hashCode;
}

extension $GroupedSeriesResponseV3Extension on GroupedSeriesResponseV3 {
  GroupedSeriesResponseV3 copyWith(
      {String? mergedId,
      String? groupType,
      String? id,
      String? name,
      List<SimpleChannelResponse>? channels,
      bool? hasInteracted,
      String? selectedEventId,
      String? associatedPicture,
      String? associatedPictureType,
      bool? isAdult,
      enums.GroupedSeriesResponseV3SeriesContentType? seriesContentType,
      int? episodeCount,
      int? seasonCount,
      int? specialsCount}) {
    return GroupedSeriesResponseV3(
        mergedId: mergedId ?? this.mergedId,
        groupType: groupType ?? this.groupType,
        id: id ?? this.id,
        name: name ?? this.name,
        channels: channels ?? this.channels,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        selectedEventId: selectedEventId ?? this.selectedEventId,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        isAdult: isAdult ?? this.isAdult,
        seriesContentType: seriesContentType ?? this.seriesContentType,
        episodeCount: episodeCount ?? this.episodeCount,
        seasonCount: seasonCount ?? this.seasonCount,
        specialsCount: specialsCount ?? this.specialsCount);
  }

  GroupedSeriesResponseV3 copyWithWrapped(
      {Wrapped<String?>? mergedId,
      Wrapped<String>? groupType,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<List<SimpleChannelResponse>?>? channels,
      Wrapped<bool?>? hasInteracted,
      Wrapped<String?>? selectedEventId,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? isAdult,
      Wrapped<enums.GroupedSeriesResponseV3SeriesContentType?>?
          seriesContentType,
      Wrapped<int?>? episodeCount,
      Wrapped<int?>? seasonCount,
      Wrapped<int?>? specialsCount}) {
    return GroupedSeriesResponseV3(
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        groupType: (groupType != null ? groupType.value : this.groupType),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        channels: (channels != null ? channels.value : this.channels),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        selectedEventId: (selectedEventId != null
            ? selectedEventId.value
            : this.selectedEventId),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        seriesContentType: (seriesContentType != null
            ? seriesContentType.value
            : this.seriesContentType),
        episodeCount:
            (episodeCount != null ? episodeCount.value : this.episodeCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorWrapper {
  ErrorWrapper({
    required this.error,
  });

  factory ErrorWrapper.fromJson(Map<String, dynamic> json) =>
      _$ErrorWrapperFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError error;
  static const fromJsonFactory = _$ErrorWrapperFromJson;
  static const toJsonFactory = _$ErrorWrapperToJson;
  Map<String, dynamic> toJson() => _$ErrorWrapperToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorWrapper &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorWrapperExtension on ErrorWrapper {
  ErrorWrapper copyWith({KrakenError? error}) {
    return ErrorWrapper(error: error ?? this.error);
  }

  ErrorWrapper copyWithWrapped({Wrapped<KrakenError>? error}) {
    return ErrorWrapper(error: (error != null ? error.value : this.error));
  }
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class LearnAction {
  LearnAction({
    required this.profileId,
    this.sharedProfile,
    required this.clientType,
    this.contentSourceId,
    this.resourceId,
    this.actionId,
    this.actionTime,
    this.subgenre,
    this.features,
  });

  factory LearnAction.fromJson(Map<String, dynamic> json) =>
      _$LearnActionFromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String profileId;
  @JsonKey(name: 'sharedProfile', includeIfNull: false)
  final bool? sharedProfile;
  @JsonKey(name: 'clientType', includeIfNull: false, defaultValue: '')
  final String clientType;
  @JsonKey(
    name: 'contentSourceId',
    includeIfNull: false,
    toJson: learnActionContentSourceIdToJson,
    fromJson: learnActionContentSourceIdFromJson,
  )
  final enums.LearnActionContentSourceId? contentSourceId;
  @JsonKey(name: 'resourceId', includeIfNull: false, defaultValue: '')
  final String? resourceId;
  @JsonKey(name: 'actionId', includeIfNull: false)
  final int? actionId;
  @JsonKey(name: 'actionTime', includeIfNull: false)
  final num? actionTime;
  @JsonKey(name: 'subgenre', includeIfNull: false, defaultValue: <String>[])
  final List<String>? subgenre;
  @JsonKey(name: 'features', includeIfNull: false, defaultValue: <String>[])
  final List<String>? features;
  static const fromJsonFactory = _$LearnActionFromJson;
  static const toJsonFactory = _$LearnActionToJson;
  Map<String, dynamic> toJson() => _$LearnActionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LearnAction &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.sharedProfile, sharedProfile) ||
                const DeepCollectionEquality()
                    .equals(other.sharedProfile, sharedProfile)) &&
            (identical(other.clientType, clientType) ||
                const DeepCollectionEquality()
                    .equals(other.clientType, clientType)) &&
            (identical(other.contentSourceId, contentSourceId) ||
                const DeepCollectionEquality()
                    .equals(other.contentSourceId, contentSourceId)) &&
            (identical(other.resourceId, resourceId) ||
                const DeepCollectionEquality()
                    .equals(other.resourceId, resourceId)) &&
            (identical(other.actionId, actionId) ||
                const DeepCollectionEquality()
                    .equals(other.actionId, actionId)) &&
            (identical(other.actionTime, actionTime) ||
                const DeepCollectionEquality()
                    .equals(other.actionTime, actionTime)) &&
            (identical(other.subgenre, subgenre) ||
                const DeepCollectionEquality()
                    .equals(other.subgenre, subgenre)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(sharedProfile) ^
      const DeepCollectionEquality().hash(clientType) ^
      const DeepCollectionEquality().hash(contentSourceId) ^
      const DeepCollectionEquality().hash(resourceId) ^
      const DeepCollectionEquality().hash(actionId) ^
      const DeepCollectionEquality().hash(actionTime) ^
      const DeepCollectionEquality().hash(subgenre) ^
      const DeepCollectionEquality().hash(features) ^
      runtimeType.hashCode;
}

extension $LearnActionExtension on LearnAction {
  LearnAction copyWith(
      {String? profileId,
      bool? sharedProfile,
      String? clientType,
      enums.LearnActionContentSourceId? contentSourceId,
      String? resourceId,
      int? actionId,
      num? actionTime,
      List<String>? subgenre,
      List<String>? features}) {
    return LearnAction(
        profileId: profileId ?? this.profileId,
        sharedProfile: sharedProfile ?? this.sharedProfile,
        clientType: clientType ?? this.clientType,
        contentSourceId: contentSourceId ?? this.contentSourceId,
        resourceId: resourceId ?? this.resourceId,
        actionId: actionId ?? this.actionId,
        actionTime: actionTime ?? this.actionTime,
        subgenre: subgenre ?? this.subgenre,
        features: features ?? this.features);
  }

  LearnAction copyWithWrapped(
      {Wrapped<String>? profileId,
      Wrapped<bool?>? sharedProfile,
      Wrapped<String>? clientType,
      Wrapped<enums.LearnActionContentSourceId?>? contentSourceId,
      Wrapped<String?>? resourceId,
      Wrapped<int?>? actionId,
      Wrapped<num?>? actionTime,
      Wrapped<List<String>?>? subgenre,
      Wrapped<List<String>?>? features}) {
    return LearnAction(
        profileId: (profileId != null ? profileId.value : this.profileId),
        sharedProfile:
            (sharedProfile != null ? sharedProfile.value : this.sharedProfile),
        clientType: (clientType != null ? clientType.value : this.clientType),
        contentSourceId: (contentSourceId != null
            ? contentSourceId.value
            : this.contentSourceId),
        resourceId: (resourceId != null ? resourceId.value : this.resourceId),
        actionId: (actionId != null ? actionId.value : this.actionId),
        actionTime: (actionTime != null ? actionTime.value : this.actionTime),
        subgenre: (subgenre != null ? subgenre.value : this.subgenre),
        features: (features != null ? features.value : this.features));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceResponse {
  NuanceResponse({
    required this.payload,
  });

  factory NuanceResponse.fromJson(Map<String, dynamic> json) =>
      _$NuanceResponseFromJson(json);

  @JsonKey(name: 'payload', includeIfNull: false)
  final NuancePayload payload;
  static const fromJsonFactory = _$NuanceResponseFromJson;
  static const toJsonFactory = _$NuanceResponseToJson;
  Map<String, dynamic> toJson() => _$NuanceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceResponse &&
            (identical(other.payload, payload) ||
                const DeepCollectionEquality().equals(other.payload, payload)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(payload) ^ runtimeType.hashCode;
}

extension $NuanceResponseExtension on NuanceResponse {
  NuanceResponse copyWith({NuancePayload? payload}) {
    return NuanceResponse(payload: payload ?? this.payload);
  }

  NuanceResponse copyWithWrapped({Wrapped<NuancePayload>? payload}) {
    return NuanceResponse(
        payload: (payload != null ? payload.value : this.payload));
  }
}

@JsonSerializable(explicitToJson: true)
class NuancePayload {
  NuancePayload({
    required this.interpretations,
  });

  factory NuancePayload.fromJson(Map<String, dynamic> json) =>
      _$NuancePayloadFromJson(json);

  @JsonKey(
      name: 'interpretations',
      includeIfNull: false,
      defaultValue: <NuanceInterpretations>[])
  final List<NuanceInterpretations> interpretations;
  static const fromJsonFactory = _$NuancePayloadFromJson;
  static const toJsonFactory = _$NuancePayloadToJson;
  Map<String, dynamic> toJson() => _$NuancePayloadToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuancePayload &&
            (identical(other.interpretations, interpretations) ||
                const DeepCollectionEquality()
                    .equals(other.interpretations, interpretations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(interpretations) ^
      runtimeType.hashCode;
}

extension $NuancePayloadExtension on NuancePayload {
  NuancePayload copyWith({List<NuanceInterpretations>? interpretations}) {
    return NuancePayload(
        interpretations: interpretations ?? this.interpretations);
  }

  NuancePayload copyWithWrapped(
      {Wrapped<List<NuanceInterpretations>>? interpretations}) {
    return NuancePayload(
        interpretations: (interpretations != null
            ? interpretations.value
            : this.interpretations));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretations {
  NuanceInterpretations({
    required this.concepts,
    required this.action,
    required this.literal,
  });

  factory NuanceInterpretations.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationsFromJson(json);

  @JsonKey(name: 'concepts', includeIfNull: false)
  final NuanceConcepts concepts;
  @JsonKey(name: 'action', includeIfNull: false)
  final NuanceAction action;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  static const fromJsonFactory = _$NuanceInterpretationsFromJson;
  static const toJsonFactory = _$NuanceInterpretationsToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretations &&
            (identical(other.concepts, concepts) ||
                const DeepCollectionEquality()
                    .equals(other.concepts, concepts)) &&
            (identical(other.action, action) ||
                const DeepCollectionEquality().equals(other.action, action)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality().equals(other.literal, literal)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(concepts) ^
      const DeepCollectionEquality().hash(action) ^
      const DeepCollectionEquality().hash(literal) ^
      runtimeType.hashCode;
}

extension $NuanceInterpretationsExtension on NuanceInterpretations {
  NuanceInterpretations copyWith(
      {NuanceConcepts? concepts, NuanceAction? action, String? literal}) {
    return NuanceInterpretations(
        concepts: concepts ?? this.concepts,
        action: action ?? this.action,
        literal: literal ?? this.literal);
  }

  NuanceInterpretations copyWithWrapped(
      {Wrapped<NuanceConcepts>? concepts,
      Wrapped<NuanceAction>? action,
      Wrapped<String>? literal}) {
    return NuanceInterpretations(
        concepts: (concepts != null ? concepts.value : this.concepts),
        action: (action != null ? action.value : this.action),
        literal: (literal != null ? literal.value : this.literal));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConcepts {
  NuanceConcepts({
    this.nuanceTvQuery,
    this.nuanceTvMediatype,
    this.nuanceTvModifier,
    this.nuanceTvYear,
    this.nuanceTvGenre,
    this.nuanceTvProvider,
    this.nuanceTvStation,
    this.lgiTvAgeRating,
    this.nuanceCALENDARX,
    this.lgiTvEasterEggSearch,
  });

  factory NuanceConcepts.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptsFromJson(json);

  @JsonKey(
      name: 'nuance_tv_query',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvQuery;
  @JsonKey(
      name: 'nuance_tv_mediatype',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvMediatype;
  @JsonKey(
      name: 'nuance_tv_modifier',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvModifier;
  @JsonKey(
      name: 'nuance_tv_year',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvYear;
  @JsonKey(
      name: 'nuance_tv_genre',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvGenre;
  @JsonKey(
      name: 'nuance_tv_provider',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvProvider;
  @JsonKey(
      name: 'nuance_tv_station',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceTvStation;
  @JsonKey(
      name: 'lgi_tv_ageRating',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? lgiTvAgeRating;
  @JsonKey(
      name: 'nuance_CALENDARX',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? nuanceCALENDARX;
  @JsonKey(
      name: 'lgi_tv_easter_egg_search',
      includeIfNull: false,
      defaultValue: <NuanceConcept>[])
  final List<NuanceConcept>? lgiTvEasterEggSearch;
  static const fromJsonFactory = _$NuanceConceptsFromJson;
  static const toJsonFactory = _$NuanceConceptsToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConcepts &&
            (identical(other.nuanceTvQuery, nuanceTvQuery) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvQuery, nuanceTvQuery)) &&
            (identical(other.nuanceTvMediatype, nuanceTvMediatype) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvMediatype, nuanceTvMediatype)) &&
            (identical(other.nuanceTvModifier, nuanceTvModifier) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvModifier, nuanceTvModifier)) &&
            (identical(other.nuanceTvYear, nuanceTvYear) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvYear, nuanceTvYear)) &&
            (identical(other.nuanceTvGenre, nuanceTvGenre) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvGenre, nuanceTvGenre)) &&
            (identical(other.nuanceTvProvider, nuanceTvProvider) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvProvider, nuanceTvProvider)) &&
            (identical(other.nuanceTvStation, nuanceTvStation) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvStation, nuanceTvStation)) &&
            (identical(other.lgiTvAgeRating, lgiTvAgeRating) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvAgeRating, lgiTvAgeRating)) &&
            (identical(other.nuanceCALENDARX, nuanceCALENDARX) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDARX, nuanceCALENDARX)) &&
            (identical(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceTvQuery) ^
      const DeepCollectionEquality().hash(nuanceTvMediatype) ^
      const DeepCollectionEquality().hash(nuanceTvModifier) ^
      const DeepCollectionEquality().hash(nuanceTvYear) ^
      const DeepCollectionEquality().hash(nuanceTvGenre) ^
      const DeepCollectionEquality().hash(nuanceTvProvider) ^
      const DeepCollectionEquality().hash(nuanceTvStation) ^
      const DeepCollectionEquality().hash(lgiTvAgeRating) ^
      const DeepCollectionEquality().hash(nuanceCALENDARX) ^
      const DeepCollectionEquality().hash(lgiTvEasterEggSearch) ^
      runtimeType.hashCode;
}

extension $NuanceConceptsExtension on NuanceConcepts {
  NuanceConcepts copyWith(
      {List<NuanceConcept>? nuanceTvQuery,
      List<NuanceConcept>? nuanceTvMediatype,
      List<NuanceConcept>? nuanceTvModifier,
      List<NuanceConcept>? nuanceTvYear,
      List<NuanceConcept>? nuanceTvGenre,
      List<NuanceConcept>? nuanceTvProvider,
      List<NuanceConcept>? nuanceTvStation,
      List<NuanceConcept>? lgiTvAgeRating,
      List<NuanceConcept>? nuanceCALENDARX,
      List<NuanceConcept>? lgiTvEasterEggSearch}) {
    return NuanceConcepts(
        nuanceTvQuery: nuanceTvQuery ?? this.nuanceTvQuery,
        nuanceTvMediatype: nuanceTvMediatype ?? this.nuanceTvMediatype,
        nuanceTvModifier: nuanceTvModifier ?? this.nuanceTvModifier,
        nuanceTvYear: nuanceTvYear ?? this.nuanceTvYear,
        nuanceTvGenre: nuanceTvGenre ?? this.nuanceTvGenre,
        nuanceTvProvider: nuanceTvProvider ?? this.nuanceTvProvider,
        nuanceTvStation: nuanceTvStation ?? this.nuanceTvStation,
        lgiTvAgeRating: lgiTvAgeRating ?? this.lgiTvAgeRating,
        nuanceCALENDARX: nuanceCALENDARX ?? this.nuanceCALENDARX,
        lgiTvEasterEggSearch:
            lgiTvEasterEggSearch ?? this.lgiTvEasterEggSearch);
  }

  NuanceConcepts copyWithWrapped(
      {Wrapped<List<NuanceConcept>?>? nuanceTvQuery,
      Wrapped<List<NuanceConcept>?>? nuanceTvMediatype,
      Wrapped<List<NuanceConcept>?>? nuanceTvModifier,
      Wrapped<List<NuanceConcept>?>? nuanceTvYear,
      Wrapped<List<NuanceConcept>?>? nuanceTvGenre,
      Wrapped<List<NuanceConcept>?>? nuanceTvProvider,
      Wrapped<List<NuanceConcept>?>? nuanceTvStation,
      Wrapped<List<NuanceConcept>?>? lgiTvAgeRating,
      Wrapped<List<NuanceConcept>?>? nuanceCALENDARX,
      Wrapped<List<NuanceConcept>?>? lgiTvEasterEggSearch}) {
    return NuanceConcepts(
        nuanceTvQuery:
            (nuanceTvQuery != null ? nuanceTvQuery.value : this.nuanceTvQuery),
        nuanceTvMediatype: (nuanceTvMediatype != null
            ? nuanceTvMediatype.value
            : this.nuanceTvMediatype),
        nuanceTvModifier: (nuanceTvModifier != null
            ? nuanceTvModifier.value
            : this.nuanceTvModifier),
        nuanceTvYear:
            (nuanceTvYear != null ? nuanceTvYear.value : this.nuanceTvYear),
        nuanceTvGenre:
            (nuanceTvGenre != null ? nuanceTvGenre.value : this.nuanceTvGenre),
        nuanceTvProvider: (nuanceTvProvider != null
            ? nuanceTvProvider.value
            : this.nuanceTvProvider),
        nuanceTvStation: (nuanceTvStation != null
            ? nuanceTvStation.value
            : this.nuanceTvStation),
        lgiTvAgeRating: (lgiTvAgeRating != null
            ? lgiTvAgeRating.value
            : this.lgiTvAgeRating),
        nuanceCALENDARX: (nuanceCALENDARX != null
            ? nuanceCALENDARX.value
            : this.nuanceCALENDARX),
        lgiTvEasterEggSearch: (lgiTvEasterEggSearch != null
            ? lgiTvEasterEggSearch.value
            : this.lgiTvEasterEggSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConcept {
  NuanceConcept({
    required this.value,
    required this.literal,
    required this.ranges,
  });

  factory NuanceConcept.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptFromJson(json);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String value;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  @JsonKey(name: 'ranges', includeIfNull: false, defaultValue: <List<num>>[])
  final List<List<num>> ranges;
  static const fromJsonFactory = _$NuanceConceptFromJson;
  static const toJsonFactory = _$NuanceConceptToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConcept &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality()
                    .equals(other.literal, literal)) &&
            (identical(other.ranges, ranges) ||
                const DeepCollectionEquality().equals(other.ranges, ranges)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(literal) ^
      const DeepCollectionEquality().hash(ranges) ^
      runtimeType.hashCode;
}

extension $NuanceConceptExtension on NuanceConcept {
  NuanceConcept copyWith(
      {String? value, String? literal, List<List<num>>? ranges}) {
    return NuanceConcept(
        value: value ?? this.value,
        literal: literal ?? this.literal,
        ranges: ranges ?? this.ranges);
  }

  NuanceConcept copyWithWrapped(
      {Wrapped<String>? value,
      Wrapped<String>? literal,
      Wrapped<List<List<num>>>? ranges}) {
    return NuanceConcept(
        value: (value != null ? value.value : this.value),
        literal: (literal != null ? literal.value : this.literal),
        ranges: (ranges != null ? ranges.value : this.ranges));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceAction {
  NuanceAction({
    this.intent,
  });

  factory NuanceAction.fromJson(Map<String, dynamic> json) =>
      _$NuanceActionFromJson(json);

  @JsonKey(name: 'intent', includeIfNull: false)
  final NuanceIntent? intent;
  static const fromJsonFactory = _$NuanceActionFromJson;
  static const toJsonFactory = _$NuanceActionToJson;
  Map<String, dynamic> toJson() => _$NuanceActionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceAction &&
            (identical(other.intent, intent) ||
                const DeepCollectionEquality().equals(other.intent, intent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intent) ^ runtimeType.hashCode;
}

extension $NuanceActionExtension on NuanceAction {
  NuanceAction copyWith({NuanceIntent? intent}) {
    return NuanceAction(intent: intent ?? this.intent);
  }

  NuanceAction copyWithWrapped({Wrapped<NuanceIntent?>? intent}) {
    return NuanceAction(intent: (intent != null ? intent.value : this.intent));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceIntent {
  NuanceIntent({
    this.value,
    this.confidence,
  });

  factory NuanceIntent.fromJson(Map<String, dynamic> json) =>
      _$NuanceIntentFromJson(json);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  @JsonKey(name: 'confidence', includeIfNull: false)
  final int? confidence;
  static const fromJsonFactory = _$NuanceIntentFromJson;
  static const toJsonFactory = _$NuanceIntentToJson;
  Map<String, dynamic> toJson() => _$NuanceIntentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceIntent &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.confidence, confidence) ||
                const DeepCollectionEquality()
                    .equals(other.confidence, confidence)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(confidence) ^
      runtimeType.hashCode;
}

extension $NuanceIntentExtension on NuanceIntent {
  NuanceIntent copyWith({String? value, int? confidence}) {
    return NuanceIntent(
        value: value ?? this.value, confidence: confidence ?? this.confidence);
  }

  NuanceIntent copyWithWrapped(
      {Wrapped<String?>? value, Wrapped<int?>? confidence}) {
    return NuanceIntent(
        value: (value != null ? value.value : this.value),
        confidence: (confidence != null ? confidence.value : this.confidence));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesResponse {
  SeriesResponse({
    this.seriesId,
    this.seriesName,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.episodeNumber,
    this.interacted,
    this.isBoxset,
  });

  factory SeriesResponse.fromJson(Map<String, dynamic> json) =>
      _$SeriesResponseFromJson(json);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'interacted', includeIfNull: false)
  final bool? interacted;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  static const fromJsonFactory = _$SeriesResponseFromJson;
  static const toJsonFactory = _$SeriesResponseToJson;
  Map<String, dynamic> toJson() => _$SeriesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesResponse &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.interacted, interacted) ||
                const DeepCollectionEquality()
                    .equals(other.interacted, interacted)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(interacted) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      runtimeType.hashCode;
}

extension $SeriesResponseExtension on SeriesResponse {
  SeriesResponse copyWith(
      {String? seriesId,
      String? seriesName,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      int? episodeNumber,
      bool? interacted,
      bool? isBoxset}) {
    return SeriesResponse(
        seriesId: seriesId ?? this.seriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        interacted: interacted ?? this.interacted,
        isBoxset: isBoxset ?? this.isBoxset);
  }

  SeriesResponse copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<bool?>? interacted,
      Wrapped<bool?>? isBoxset}) {
    return SeriesResponse(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        interacted: (interacted != null ? interacted.value : this.interacted),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesRecommendationResponse {
  SeriesRecommendationResponse({
    this.seriesId,
    this.seriesName,
    this.seasonId,
    this.seasonName,
    this.seasonNumber,
    this.episodeNumber,
    this.interacted,
    this.isBoxset,
  });

  factory SeriesRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$SeriesRecommendationResponseFromJson(json);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'interacted', includeIfNull: false)
  final bool? interacted;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool? isBoxset;
  static const fromJsonFactory = _$SeriesRecommendationResponseFromJson;
  static const toJsonFactory = _$SeriesRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$SeriesRecommendationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesRecommendationResponse &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.interacted, interacted) ||
                const DeepCollectionEquality()
                    .equals(other.interacted, interacted)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(interacted) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      runtimeType.hashCode;
}

extension $SeriesRecommendationResponseExtension
    on SeriesRecommendationResponse {
  SeriesRecommendationResponse copyWith(
      {String? seriesId,
      String? seriesName,
      String? seasonId,
      String? seasonName,
      int? seasonNumber,
      int? episodeNumber,
      bool? interacted,
      bool? isBoxset}) {
    return SeriesRecommendationResponse(
        seriesId: seriesId ?? this.seriesId,
        seriesName: seriesName ?? this.seriesName,
        seasonId: seasonId ?? this.seasonId,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        interacted: interacted ?? this.interacted,
        isBoxset: isBoxset ?? this.isBoxset);
  }

  SeriesRecommendationResponse copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<bool?>? interacted,
      Wrapped<bool?>? isBoxset}) {
    return SeriesRecommendationResponse(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        interacted: (interacted != null ? interacted.value : this.interacted),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceSearchResponse {
  VoiceSearchResponse({
    this.results,
  });

  factory VoiceSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$VoiceSearchResponseFromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$VoiceSearchResponseFromJson;
  static const toJsonFactory = _$VoiceSearchResponseToJson;
  Map<String, dynamic> toJson() => _$VoiceSearchResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoiceSearchResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $VoiceSearchResponseExtension on VoiceSearchResponse {
  VoiceSearchResponse copyWith({List<Object>? results}) {
    return VoiceSearchResponse(results: results ?? this.results);
  }

  VoiceSearchResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return VoiceSearchResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceSearchResponseV3 {
  VoiceSearchResponseV3({
    this.results,
    this.youtube,
  });

  factory VoiceSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$VoiceSearchResponseV3FromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  @JsonKey(name: 'youtube', includeIfNull: false)
  final YoutubeResults? youtube;
  static const fromJsonFactory = _$VoiceSearchResponseV3FromJson;
  static const toJsonFactory = _$VoiceSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$VoiceSearchResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VoiceSearchResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.youtube, youtube) ||
                const DeepCollectionEquality().equals(other.youtube, youtube)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(youtube) ^
      runtimeType.hashCode;
}

extension $VoiceSearchResponseV3Extension on VoiceSearchResponseV3 {
  VoiceSearchResponseV3 copyWith(
      {List<Object>? results, YoutubeResults? youtube}) {
    return VoiceSearchResponseV3(
        results: results ?? this.results, youtube: youtube ?? this.youtube);
  }

  VoiceSearchResponseV3 copyWithWrapped(
      {Wrapped<List<Object>?>? results, Wrapped<YoutubeResults?>? youtube}) {
    return VoiceSearchResponseV3(
        results: (results != null ? results.value : this.results),
        youtube: (youtube != null ? youtube.value : this.youtube));
  }
}

@JsonSerializable(explicitToJson: true)
class StbSearchResponse {
  StbSearchResponse({
    this.results,
  });

  factory StbSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$StbSearchResponseFromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$StbSearchResponseFromJson;
  static const toJsonFactory = _$StbSearchResponseToJson;
  Map<String, dynamic> toJson() => _$StbSearchResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StbSearchResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $StbSearchResponseExtension on StbSearchResponse {
  StbSearchResponse copyWith({List<Object>? results}) {
    return StbSearchResponse(results: results ?? this.results);
  }

  StbSearchResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return StbSearchResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class StbSearchResponseV3 {
  StbSearchResponseV3({
    this.results,
    this.youtube,
  });

  factory StbSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$StbSearchResponseV3FromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  @JsonKey(name: 'youtube', includeIfNull: false)
  final YoutubeResults? youtube;
  static const fromJsonFactory = _$StbSearchResponseV3FromJson;
  static const toJsonFactory = _$StbSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$StbSearchResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StbSearchResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality()
                    .equals(other.results, results)) &&
            (identical(other.youtube, youtube) ||
                const DeepCollectionEquality().equals(other.youtube, youtube)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^
      const DeepCollectionEquality().hash(youtube) ^
      runtimeType.hashCode;
}

extension $StbSearchResponseV3Extension on StbSearchResponseV3 {
  StbSearchResponseV3 copyWith(
      {List<Object>? results, YoutubeResults? youtube}) {
    return StbSearchResponseV3(
        results: results ?? this.results, youtube: youtube ?? this.youtube);
  }

  StbSearchResponseV3 copyWithWrapped(
      {Wrapped<List<Object>?>? results, Wrapped<YoutubeResults?>? youtube}) {
    return StbSearchResponseV3(
        results: (results != null ? results.value : this.results),
        youtube: (youtube != null ? youtube.value : this.youtube));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisResponse {
  MoreLikeThisResponse({
    this.results,
  });

  factory MoreLikeThisResponse.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisResponseFromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$MoreLikeThisResponseFromJson;
  static const toJsonFactory = _$MoreLikeThisResponseToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MoreLikeThisResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $MoreLikeThisResponseExtension on MoreLikeThisResponse {
  MoreLikeThisResponse copyWith({List<Object>? results}) {
    return MoreLikeThisResponse(results: results ?? this.results);
  }

  MoreLikeThisResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return MoreLikeThisResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisResponseV3 {
  MoreLikeThisResponseV3({
    this.results,
  });

  factory MoreLikeThisResponseV3.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisResponseV3FromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$MoreLikeThisResponseV3FromJson;
  static const toJsonFactory = _$MoreLikeThisResponseV3ToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MoreLikeThisResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $MoreLikeThisResponseV3Extension on MoreLikeThisResponseV3 {
  MoreLikeThisResponseV3 copyWith({List<Object>? results}) {
    return MoreLikeThisResponseV3(results: results ?? this.results);
  }

  MoreLikeThisResponseV3 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return MoreLikeThisResponseV3(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class TopSearchResponse {
  TopSearchResponse({
    this.results,
  });

  factory TopSearchResponse.fromJson(Map<String, dynamic> json) =>
      _$TopSearchResponseFromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$TopSearchResponseFromJson;
  static const toJsonFactory = _$TopSearchResponseToJson;
  Map<String, dynamic> toJson() => _$TopSearchResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopSearchResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $TopSearchResponseExtension on TopSearchResponse {
  TopSearchResponse copyWith({List<Object>? results}) {
    return TopSearchResponse(results: results ?? this.results);
  }

  TopSearchResponse copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return TopSearchResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class TopSearchResponseV3 {
  TopSearchResponseV3({
    this.results,
  });

  factory TopSearchResponseV3.fromJson(Map<String, dynamic> json) =>
      _$TopSearchResponseV3FromJson(json);

  @JsonKey(name: 'results', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? results;
  static const fromJsonFactory = _$TopSearchResponseV3FromJson;
  static const toJsonFactory = _$TopSearchResponseV3ToJson;
  Map<String, dynamic> toJson() => _$TopSearchResponseV3ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TopSearchResponseV3 &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $TopSearchResponseV3Extension on TopSearchResponseV3 {
  TopSearchResponseV3 copyWith({List<Object>? results}) {
    return TopSearchResponseV3(results: results ?? this.results);
  }

  TopSearchResponseV3 copyWithWrapped({Wrapped<List<Object>?>? results}) {
    return TopSearchResponseV3(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class EstResponse {
  EstResponse({
    this.minPrice,
    required this.minPriceDisplay,
    required this.currency,
    required this.videoHost,
    required this.videoUrl,
  });

  factory EstResponse.fromJson(Map<String, dynamic> json) =>
      _$EstResponseFromJson(json);

  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String? minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  static const fromJsonFactory = _$EstResponseFromJson;
  static const toJsonFactory = _$EstResponseToJson;
  Map<String, dynamic> toJson() => _$EstResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstResponse &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      runtimeType.hashCode;
}

extension $EstResponseExtension on EstResponse {
  EstResponse copyWith(
      {String? minPrice,
      String? minPriceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl}) {
    return EstResponse(
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl);
  }

  EstResponse copyWithWrapped(
      {Wrapped<String?>? minPrice,
      Wrapped<String>? minPriceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl}) {
    return EstResponse(
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class OTTResponse {
  OTTResponse({
    required this.contentType,
    required this.contentSource,
    required this.titleId,
    this.mergedId,
    required this.name,
    this.ageRating,
    required this.isAdult,
    required this.videoHost,
    required this.videoUrl,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.isEst,
  });

  factory OTTResponse.fromJson(Map<String, dynamic> json) =>
      _$OTTResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'isEst', includeIfNull: false)
  final bool? isEst;
  static const fromJsonFactory = _$OTTResponseFromJson;
  static const toJsonFactory = _$OTTResponseToJson;
  Map<String, dynamic> toJson() => _$OTTResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OTTResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(
                    other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.isEst, isEst) ||
                const DeepCollectionEquality().equals(other.isEst, isEst)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(isEst) ^
      runtimeType.hashCode;
}

extension $OTTResponseExtension on OTTResponse {
  OTTResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? titleId,
      String? mergedId,
      String? name,
      int? ageRating,
      bool? isAdult,
      String? videoHost,
      String? videoUrl,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      bool? isEst}) {
    return OTTResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        titleId: titleId ?? this.titleId,
        mergedId: mergedId ?? this.mergedId,
        name: name ?? this.name,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        isEst: isEst ?? this.isEst);
  }

  OTTResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? titleId,
      Wrapped<String?>? mergedId,
      Wrapped<String>? name,
      Wrapped<int?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<bool?>? isEst}) {
    return OTTResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        titleId: (titleId != null ? titleId.value : this.titleId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        name: (name != null ? name.value : this.name),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        isEst: (isEst != null ? isEst.value : this.isEst));
  }
}

@JsonSerializable(explicitToJson: true)
class OTTRecommendationResponse {
  OTTRecommendationResponse({
    required this.contentType,
    required this.contentSource,
    required this.titleId,
    this.mergedId,
    required this.name,
    this.ageRating,
    required this.isAdult,
    required this.videoHost,
    required this.videoUrl,
    this.minPriceDisplay,
    this.minPriceCurrency,
    this.multiplePricesAvailable,
    this.isEst,
    this.imageVersion,
  });

  factory OTTRecommendationResponse.fromJson(Map<String, dynamic> json) =>
      _$OTTRecommendationResponseFromJson(json);

  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'minPriceCurrency', includeIfNull: false, defaultValue: '')
  final String? minPriceCurrency;
  @JsonKey(name: 'multiplePricesAvailable', includeIfNull: false)
  final bool? multiplePricesAvailable;
  @JsonKey(name: 'isEst', includeIfNull: false)
  final bool? isEst;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$OTTRecommendationResponseFromJson;
  static const toJsonFactory = _$OTTRecommendationResponseToJson;
  Map<String, dynamic> toJson() => _$OTTRecommendationResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OTTRecommendationResponse &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.minPriceCurrency, minPriceCurrency) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceCurrency, minPriceCurrency)) &&
            (identical(
                    other.multiplePricesAvailable, multiplePricesAvailable) ||
                const DeepCollectionEquality().equals(
                    other.multiplePricesAvailable, multiplePricesAvailable)) &&
            (identical(other.isEst, isEst) ||
                const DeepCollectionEquality().equals(other.isEst, isEst)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(minPriceCurrency) ^
      const DeepCollectionEquality().hash(multiplePricesAvailable) ^
      const DeepCollectionEquality().hash(isEst) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $OTTRecommendationResponseExtension on OTTRecommendationResponse {
  OTTRecommendationResponse copyWith(
      {String? contentType,
      int? contentSource,
      String? titleId,
      String? mergedId,
      String? name,
      int? ageRating,
      bool? isAdult,
      String? videoHost,
      String? videoUrl,
      String? minPriceDisplay,
      String? minPriceCurrency,
      bool? multiplePricesAvailable,
      bool? isEst,
      String? imageVersion}) {
    return OTTRecommendationResponse(
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        titleId: titleId ?? this.titleId,
        mergedId: mergedId ?? this.mergedId,
        name: name ?? this.name,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        minPriceCurrency: minPriceCurrency ?? this.minPriceCurrency,
        multiplePricesAvailable:
            multiplePricesAvailable ?? this.multiplePricesAvailable,
        isEst: isEst ?? this.isEst,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  OTTRecommendationResponse copyWithWrapped(
      {Wrapped<String>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String>? titleId,
      Wrapped<String?>? mergedId,
      Wrapped<String>? name,
      Wrapped<int?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? minPriceCurrency,
      Wrapped<bool?>? multiplePricesAvailable,
      Wrapped<bool?>? isEst,
      Wrapped<String?>? imageVersion}) {
    return OTTRecommendationResponse(
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        titleId: (titleId != null ? titleId.value : this.titleId),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        name: (name != null ? name.value : this.name),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        minPriceCurrency: (minPriceCurrency != null
            ? minPriceCurrency.value
            : this.minPriceCurrency),
        multiplePricesAvailable: (multiplePricesAvailable != null
            ? multiplePricesAvailable.value
            : this.multiplePricesAvailable),
        isEst: (isEst != null ? isEst.value : this.isEst),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EventReplayResponse {
  EventReplayResponse({
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.isGoPlayable,
  });

  factory EventReplayResponse.fromJson(Map<String, dynamic> json) =>
      _$EventReplayResponseFromJson(json);

  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final int? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final int? replayAvailabilityEnd;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  static const fromJsonFactory = _$EventReplayResponseFromJson;
  static const toJsonFactory = _$EventReplayResponseToJson;
  Map<String, dynamic> toJson() => _$EventReplayResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventReplayResponse &&
            (identical(
                    other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      runtimeType.hashCode;
}

extension $EventReplayResponseExtension on EventReplayResponse {
  EventReplayResponse copyWith(
      {int? replayAvailabilityStart,
      int? replayAvailabilityEnd,
      bool? isGoPlayable}) {
    return EventReplayResponse(
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable);
  }

  EventReplayResponse copyWithWrapped(
      {Wrapped<int?>? replayAvailabilityStart,
      Wrapped<int?>? replayAvailabilityEnd,
      Wrapped<bool?>? isGoPlayable}) {
    return EventReplayResponse(
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable));
  }
}

@JsonSerializable(explicitToJson: true)
class StbSearchResponseV1 {
  StbSearchResponseV1();

  factory StbSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$StbSearchResponseV1FromJson(json);

  static const fromJsonFactory = _$StbSearchResponseV1FromJson;
  static const toJsonFactory = _$StbSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$StbSearchResponseV1ToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class VODSearchResponseV1 {
  VODSearchResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    required this.contentId,
    required this.titleId,
    required this.isViewedCompletely,
    this.minimumAge,
    required this.bookmark,
    this.isAdult,
    this.isReplay,
    this.eventId,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.availabilityStart,
    this.availabilityEnd,
    this.userInteractedWithSeries,
    this.collapseSeries,
    this.collapseInstance,
    required this.product,
    this.hasMultipleProducts,
    this.series,
  });

  factory VODSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$VODSearchResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'isViewedCompletely', includeIfNull: false)
  final bool isViewedCompletely;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int bookmark;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String? availabilityEnd;
  @JsonKey(
      name: 'userInteractedWithSeries',
      includeIfNull: false,
      defaultValue: false)
  final bool? userInteractedWithSeries;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'product', includeIfNull: false)
  final ProductResponseV1 product;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesSearchResponseV1? series;
  static const fromJsonFactory = _$VODSearchResponseV1FromJson;
  static const toJsonFactory = _$VODSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$VODSearchResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODSearchResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.isViewedCompletely, isViewedCompletely) ||
                const DeepCollectionEquality()
                    .equals(other.isViewedCompletely, isViewedCompletely)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.userInteractedWithSeries, userInteractedWithSeries) ||
                const DeepCollectionEquality().equals(
                    other.userInteractedWithSeries,
                    userInteractedWithSeries)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.product, product) ||
                const DeepCollectionEquality()
                    .equals(other.product, product)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) ||
                const DeepCollectionEquality()
                    .equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(isViewedCompletely) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(userInteractedWithSeries) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(product) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $VODSearchResponseV1Extension on VODSearchResponseV1 {
  VODSearchResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? contentId,
      String? titleId,
      bool? isViewedCompletely,
      String? minimumAge,
      int? bookmark,
      bool? isAdult,
      bool? isReplay,
      String? eventId,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      String? availabilityStart,
      String? availabilityEnd,
      bool? userInteractedWithSeries,
      bool? collapseSeries,
      bool? collapseInstance,
      ProductResponseV1? product,
      bool? hasMultipleProducts,
      SeriesSearchResponseV1? series}) {
    return VODSearchResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        isViewedCompletely: isViewedCompletely ?? this.isViewedCompletely,
        minimumAge: minimumAge ?? this.minimumAge,
        bookmark: bookmark ?? this.bookmark,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        eventId: eventId ?? this.eventId,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        userInteractedWithSeries:
            userInteractedWithSeries ?? this.userInteractedWithSeries,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        product: product ?? this.product,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        series: series ?? this.series);
  }

  VODSearchResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String>? contentId,
      Wrapped<String>? titleId,
      Wrapped<bool>? isViewedCompletely,
      Wrapped<String?>? minimumAge,
      Wrapped<int>? bookmark,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? isReplay,
      Wrapped<String?>? eventId,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? availabilityStart,
      Wrapped<String?>? availabilityEnd,
      Wrapped<bool?>? userInteractedWithSeries,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<ProductResponseV1>? product,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<SeriesSearchResponseV1?>? series}) {
    return VODSearchResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        isViewedCompletely: (isViewedCompletely != null
            ? isViewedCompletely.value
            : this.isViewedCompletely),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        eventId: (eventId != null ? eventId.value : this.eventId),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        userInteractedWithSeries: (userInteractedWithSeries != null
            ? userInteractedWithSeries.value
            : this.userInteractedWithSeries),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        product: (product != null ? product.value : this.product),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class LTVSearchResponseV1 {
  LTVSearchResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.isAdult,
    this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.series,
  });

  factory LTVSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$LTVSearchResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesSearchResponseV1? series;
  static const fromJsonFactory = _$LTVSearchResponseV1FromJson;
  static const toJsonFactory = _$LTVSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$LTVSearchResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVSearchResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $LTVSearchResponseV1Extension on LTVSearchResponseV1 {
  LTVSearchResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      SeriesSearchResponseV1? series}) {
    return LTVSearchResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        series: series ?? this.series);
  }

  LTVSearchResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<SeriesSearchResponseV1?>? series}) {
    return LTVSearchResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponseV1 {
  ChannelResponseV1({
    required this.contentSource,
    this.contentType,
    required this.channelName,
    required this.channelId,
    this.eventId,
    this.name,
    this.minimumAge,
    this.isReplay,
    this.isAdult,
    this.associatedPicture,
    this.associatedPictureType,
    this.startTime,
    this.endTime,
  });

  factory ChannelResponseV1.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String channelName;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool? isReplay;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'startTime', includeIfNull: false, defaultValue: '')
  final String? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false, defaultValue: '')
  final String? endTime;
  static const fromJsonFactory = _$ChannelResponseV1FromJson;
  static const toJsonFactory = _$ChannelResponseV1ToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality().equals(other.endTime, endTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      runtimeType.hashCode;
}

extension $ChannelResponseV1Extension on ChannelResponseV1 {
  ChannelResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? channelName,
      String? channelId,
      String? eventId,
      String? name,
      String? minimumAge,
      bool? isReplay,
      bool? isAdult,
      String? associatedPicture,
      String? associatedPictureType,
      String? startTime,
      String? endTime}) {
    return ChannelResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        channelName: channelName ?? this.channelName,
        channelId: channelId ?? this.channelId,
        eventId: eventId ?? this.eventId,
        name: name ?? this.name,
        minimumAge: minimumAge ?? this.minimumAge,
        isReplay: isReplay ?? this.isReplay,
        isAdult: isAdult ?? this.isAdult,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime);
  }

  ChannelResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String>? channelName,
      Wrapped<String>? channelId,
      Wrapped<String?>? eventId,
      Wrapped<String?>? name,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isReplay,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? startTime,
      Wrapped<String?>? endTime}) {
    return ChannelResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        name: (name != null ? name.value : this.name),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRSearchResponseV1 {
  PVRSearchResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.containsAdult,
    this.isAdult,
    required this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.bookmark,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.recordingState,
    this.localRecordingId,
    this.cpeId,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.series,
  });

  factory PVRSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$PVRSearchResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: pVRSearchResponseV1RecordingStateToJson,
    fromJson: pVRSearchResponseV1RecordingStateFromJson,
  )
  final enums.PVRSearchResponseV1RecordingState? recordingState;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesSearchResponseV1? series;
  static const fromJsonFactory = _$PVRSearchResponseV1FromJson;
  static const toJsonFactory = _$PVRSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$PVRSearchResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRSearchResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality().equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) || const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $PVRSearchResponseV1Extension on PVRSearchResponseV1 {
  PVRSearchResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? containsAdult,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      int? bookmark,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      enums.PVRSearchResponseV1RecordingState? recordingState,
      String? localRecordingId,
      String? cpeId,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      SeriesSearchResponseV1? series}) {
    return PVRSearchResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        bookmark: bookmark ?? this.bookmark,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        recordingState: recordingState ?? this.recordingState,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        series: series ?? this.series);
  }

  PVRSearchResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<enums.PVRSearchResponseV1RecordingState?>? recordingState,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<SeriesSearchResponseV1?>? series}) {
    return PVRSearchResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class ApplicationResponseV1 {
  ApplicationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    required this.appId,
    this.appUrl,
    this.image,
  });

  factory ApplicationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$ApplicationResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'appId', includeIfNull: false, defaultValue: '')
  final String appId;
  @JsonKey(name: 'appUrl', includeIfNull: false, defaultValue: '')
  final String? appUrl;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  static const fromJsonFactory = _$ApplicationResponseV1FromJson;
  static const toJsonFactory = _$ApplicationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$ApplicationResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ApplicationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.appId, appId) ||
                const DeepCollectionEquality().equals(other.appId, appId)) &&
            (identical(other.appUrl, appUrl) ||
                const DeepCollectionEquality().equals(other.appUrl, appUrl)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(appId) ^
      const DeepCollectionEquality().hash(appUrl) ^
      const DeepCollectionEquality().hash(image) ^
      runtimeType.hashCode;
}

extension $ApplicationResponseV1Extension on ApplicationResponseV1 {
  ApplicationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? appId,
      String? appUrl,
      String? image}) {
    return ApplicationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        appId: appId ?? this.appId,
        appUrl: appUrl ?? this.appUrl,
        image: image ?? this.image);
  }

  ApplicationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String>? appId,
      Wrapped<String?>? appUrl,
      Wrapped<String?>? image}) {
    return ApplicationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        appId: (appId != null ? appId.value : this.appId),
        appUrl: (appUrl != null ? appUrl.value : this.appUrl),
        image: (image != null ? image.value : this.image));
  }
}

@JsonSerializable(explicitToJson: true)
class ProductResponseV1 {
  ProductResponseV1({
    this.availabilityStart,
    this.availabilityEnd,
    this.entitlementState,
    this.entitlementEnd,
    this.rentalPeriod,
    this.currency,
    this.offerPrice,
    this.channelId,
  });

  factory ProductResponseV1.fromJson(Map<String, dynamic> json) =>
      _$ProductResponseV1FromJson(json);

  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String? availabilityEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String? entitlementState;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'rentalPeriod', includeIfNull: false, defaultValue: '')
  final String? rentalPeriod;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'offerPrice', includeIfNull: false, defaultValue: '')
  final String? offerPrice;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  static const fromJsonFactory = _$ProductResponseV1FromJson;
  static const toJsonFactory = _$ProductResponseV1ToJson;
  Map<String, dynamic> toJson() => _$ProductResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProductResponseV1 &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.rentalPeriod, rentalPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rentalPeriod, rentalPeriod)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.offerPrice, offerPrice) ||
                const DeepCollectionEquality()
                    .equals(other.offerPrice, offerPrice)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(rentalPeriod) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(offerPrice) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $ProductResponseV1Extension on ProductResponseV1 {
  ProductResponseV1 copyWith(
      {String? availabilityStart,
      String? availabilityEnd,
      String? entitlementState,
      String? entitlementEnd,
      String? rentalPeriod,
      String? currency,
      String? offerPrice,
      String? channelId}) {
    return ProductResponseV1(
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        rentalPeriod: rentalPeriod ?? this.rentalPeriod,
        currency: currency ?? this.currency,
        offerPrice: offerPrice ?? this.offerPrice,
        channelId: channelId ?? this.channelId);
  }

  ProductResponseV1 copyWithWrapped(
      {Wrapped<String?>? availabilityStart,
      Wrapped<String?>? availabilityEnd,
      Wrapped<String?>? entitlementState,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String?>? rentalPeriod,
      Wrapped<String?>? currency,
      Wrapped<String?>? offerPrice,
      Wrapped<String?>? channelId}) {
    return ProductResponseV1(
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        rentalPeriod:
            (rentalPeriod != null ? rentalPeriod.value : this.rentalPeriod),
        currency: (currency != null ? currency.value : this.currency),
        offerPrice: (offerPrice != null ? offerPrice.value : this.offerPrice),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesSearchResponseV1 {
  SeriesSearchResponseV1({
    this.seriesId,
    this.episodeName,
    this.episodeNumber,
    this.numberOfEpisodeTitles,
    this.specialsCount,
    this.seasonCount,
    this.seasonName,
    this.seasonNumber,
    this.seriesName,
    this.parentSeriesId,
    this.seriesType,
  });

  factory SeriesSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$SeriesSearchResponseV1FromJson(json);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final num? episodeNumber;
  @JsonKey(name: 'numberOfEpisodeTitles', includeIfNull: false)
  final int? numberOfEpisodeTitles;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final num? seasonNumber;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesType', includeIfNull: false, defaultValue: '')
  final String? seriesType;
  static const fromJsonFactory = _$SeriesSearchResponseV1FromJson;
  static const toJsonFactory = _$SeriesSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$SeriesSearchResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesSearchResponseV1 &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.episodeName, episodeName) ||
                const DeepCollectionEquality()
                    .equals(other.episodeName, episodeName)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.numberOfEpisodeTitles, numberOfEpisodeTitles) ||
                const DeepCollectionEquality().equals(
                    other.numberOfEpisodeTitles, numberOfEpisodeTitles)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesType, seriesType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesType, seriesType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(numberOfEpisodeTitles) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesType) ^
      runtimeType.hashCode;
}

extension $SeriesSearchResponseV1Extension on SeriesSearchResponseV1 {
  SeriesSearchResponseV1 copyWith(
      {String? seriesId,
      String? episodeName,
      num? episodeNumber,
      int? numberOfEpisodeTitles,
      int? specialsCount,
      int? seasonCount,
      String? seasonName,
      num? seasonNumber,
      String? seriesName,
      String? parentSeriesId,
      String? seriesType}) {
    return SeriesSearchResponseV1(
        seriesId: seriesId ?? this.seriesId,
        episodeName: episodeName ?? this.episodeName,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        numberOfEpisodeTitles:
            numberOfEpisodeTitles ?? this.numberOfEpisodeTitles,
        specialsCount: specialsCount ?? this.specialsCount,
        seasonCount: seasonCount ?? this.seasonCount,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        seriesName: seriesName ?? this.seriesName,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesType: seriesType ?? this.seriesType);
  }

  SeriesSearchResponseV1 copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? episodeName,
      Wrapped<num?>? episodeNumber,
      Wrapped<int?>? numberOfEpisodeTitles,
      Wrapped<int?>? specialsCount,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? seasonName,
      Wrapped<num?>? seasonNumber,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesType}) {
    return SeriesSearchResponseV1(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        numberOfEpisodeTitles: (numberOfEpisodeTitles != null
            ? numberOfEpisodeTitles.value
            : this.numberOfEpisodeTitles),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesType: (seriesType != null ? seriesType.value : this.seriesType));
  }
}

typedef YoutubeResults = List<YoutubeResults$Item>;

@JsonSerializable(explicitToJson: true)
class YoutubeResults$Item {
  YoutubeResults$Item();

  factory YoutubeResults$Item.fromJson(Map<String, dynamic> json) =>
      _$YoutubeResults$ItemFromJson(json);

  static const fromJsonFactory = _$YoutubeResults$ItemFromJson;
  static const toJsonFactory = _$YoutubeResults$ItemToJson;
  Map<String, dynamic> toJson() => _$YoutubeResults$ItemToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class NuanceResponseV1 {
  NuanceResponseV1({
    required this.nluInterpretationResults,
  });

  factory NuanceResponseV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceResponseV1FromJson(json);

  @JsonKey(name: 'nlu_interpretation_results', includeIfNull: false)
  final NuanceInterpretationResultsV1 nluInterpretationResults;
  static const fromJsonFactory = _$NuanceResponseV1FromJson;
  static const toJsonFactory = _$NuanceResponseV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceResponseV1 &&
            (identical(
                    other.nluInterpretationResults, nluInterpretationResults) ||
                const DeepCollectionEquality().equals(
                    other.nluInterpretationResults, nluInterpretationResults)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nluInterpretationResults) ^
      runtimeType.hashCode;
}

extension $NuanceResponseV1Extension on NuanceResponseV1 {
  NuanceResponseV1 copyWith(
      {NuanceInterpretationResultsV1? nluInterpretationResults}) {
    return NuanceResponseV1(
        nluInterpretationResults:
            nluInterpretationResults ?? this.nluInterpretationResults);
  }

  NuanceResponseV1 copyWithWrapped(
      {Wrapped<NuanceInterpretationResultsV1>? nluInterpretationResults}) {
    return NuanceResponseV1(
        nluInterpretationResults: (nluInterpretationResults != null
            ? nluInterpretationResults.value
            : this.nluInterpretationResults));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretationResultsV1 {
  NuanceInterpretationResultsV1({
    required this.payload,
  });

  factory NuanceInterpretationResultsV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationResultsV1FromJson(json);

  @JsonKey(name: 'payload', includeIfNull: false)
  final NuancePayloadV1 payload;
  static const fromJsonFactory = _$NuanceInterpretationResultsV1FromJson;
  static const toJsonFactory = _$NuanceInterpretationResultsV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationResultsV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretationResultsV1 &&
            (identical(other.payload, payload) ||
                const DeepCollectionEquality().equals(other.payload, payload)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(payload) ^ runtimeType.hashCode;
}

extension $NuanceInterpretationResultsV1Extension
    on NuanceInterpretationResultsV1 {
  NuanceInterpretationResultsV1 copyWith({NuancePayloadV1? payload}) {
    return NuanceInterpretationResultsV1(payload: payload ?? this.payload);
  }

  NuanceInterpretationResultsV1 copyWithWrapped(
      {Wrapped<NuancePayloadV1>? payload}) {
    return NuanceInterpretationResultsV1(
        payload: (payload != null ? payload.value : this.payload));
  }
}

@JsonSerializable(explicitToJson: true)
class NuancePayloadV1 {
  NuancePayloadV1({
    required this.interpretations,
  });

  factory NuancePayloadV1.fromJson(Map<String, dynamic> json) =>
      _$NuancePayloadV1FromJson(json);

  @JsonKey(
      name: 'interpretations',
      includeIfNull: false,
      defaultValue: <NuanceInterpretationsV1>[])
  final List<NuanceInterpretationsV1> interpretations;
  static const fromJsonFactory = _$NuancePayloadV1FromJson;
  static const toJsonFactory = _$NuancePayloadV1ToJson;
  Map<String, dynamic> toJson() => _$NuancePayloadV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuancePayloadV1 &&
            (identical(other.interpretations, interpretations) ||
                const DeepCollectionEquality()
                    .equals(other.interpretations, interpretations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(interpretations) ^
      runtimeType.hashCode;
}

extension $NuancePayloadV1Extension on NuancePayloadV1 {
  NuancePayloadV1 copyWith({List<NuanceInterpretationsV1>? interpretations}) {
    return NuancePayloadV1(
        interpretations: interpretations ?? this.interpretations);
  }

  NuancePayloadV1 copyWithWrapped(
      {Wrapped<List<NuanceInterpretationsV1>>? interpretations}) {
    return NuancePayloadV1(
        interpretations: (interpretations != null
            ? interpretations.value
            : this.interpretations));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceInterpretationsV1 {
  NuanceInterpretationsV1({
    required this.concepts,
    required this.action,
    required this.literal,
  });

  factory NuanceInterpretationsV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceInterpretationsV1FromJson(json);

  @JsonKey(name: 'concepts', includeIfNull: false)
  final NuanceConceptsV1 concepts;
  @JsonKey(name: 'action', includeIfNull: false)
  final NuanceActionV1 action;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  static const fromJsonFactory = _$NuanceInterpretationsV1FromJson;
  static const toJsonFactory = _$NuanceInterpretationsV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceInterpretationsV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceInterpretationsV1 &&
            (identical(other.concepts, concepts) ||
                const DeepCollectionEquality()
                    .equals(other.concepts, concepts)) &&
            (identical(other.action, action) ||
                const DeepCollectionEquality().equals(other.action, action)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality().equals(other.literal, literal)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(concepts) ^
      const DeepCollectionEquality().hash(action) ^
      const DeepCollectionEquality().hash(literal) ^
      runtimeType.hashCode;
}

extension $NuanceInterpretationsV1Extension on NuanceInterpretationsV1 {
  NuanceInterpretationsV1 copyWith(
      {NuanceConceptsV1? concepts, NuanceActionV1? action, String? literal}) {
    return NuanceInterpretationsV1(
        concepts: concepts ?? this.concepts,
        action: action ?? this.action,
        literal: literal ?? this.literal);
  }

  NuanceInterpretationsV1 copyWithWrapped(
      {Wrapped<NuanceConceptsV1>? concepts,
      Wrapped<NuanceActionV1>? action,
      Wrapped<String>? literal}) {
    return NuanceInterpretationsV1(
        concepts: (concepts != null ? concepts.value : this.concepts),
        action: (action != null ? action.value : this.action),
        literal: (literal != null ? literal.value : this.literal));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConceptsV1 {
  NuanceConceptsV1({
    this.nuanceTvQuery,
    this.nuanceTvMediatype,
    this.nuanceTvModifier,
    this.nuanceTvYear,
    this.nuanceTvGenre,
    this.nuanceTvProvider,
    this.nuanceTvStation,
    this.lgiTvAgeRating,
    this.nuanceCALENDARX,
    this.lgiTvEasterEggSearch,
  });

  factory NuanceConceptsV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptsV1FromJson(json);

  @JsonKey(
      name: 'nuance_tv_query',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvQuery;
  @JsonKey(
      name: 'nuance_tv_mediatype',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvMediatype;
  @JsonKey(
      name: 'nuance_tv_modifier',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvModifier;
  @JsonKey(
      name: 'nuance_tv_year',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvYear;
  @JsonKey(
      name: 'nuance_tv_genre',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvGenre;
  @JsonKey(
      name: 'nuance_tv_provider',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvProvider;
  @JsonKey(
      name: 'nuance_tv_station',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceTvStation;
  @JsonKey(
      name: 'lgi_tv_ageRating',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? lgiTvAgeRating;
  @JsonKey(
      name: 'nuance_CALENDARX',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? nuanceCALENDARX;
  @JsonKey(
      name: 'lgi_tv_easter_egg_search',
      includeIfNull: false,
      defaultValue: <NuanceConceptV1>[])
  final List<NuanceConceptV1>? lgiTvEasterEggSearch;
  static const fromJsonFactory = _$NuanceConceptsV1FromJson;
  static const toJsonFactory = _$NuanceConceptsV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptsV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConceptsV1 &&
            (identical(other.nuanceTvQuery, nuanceTvQuery) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvQuery, nuanceTvQuery)) &&
            (identical(other.nuanceTvMediatype, nuanceTvMediatype) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvMediatype, nuanceTvMediatype)) &&
            (identical(other.nuanceTvModifier, nuanceTvModifier) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvModifier, nuanceTvModifier)) &&
            (identical(other.nuanceTvYear, nuanceTvYear) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvYear, nuanceTvYear)) &&
            (identical(other.nuanceTvGenre, nuanceTvGenre) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvGenre, nuanceTvGenre)) &&
            (identical(other.nuanceTvProvider, nuanceTvProvider) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvProvider, nuanceTvProvider)) &&
            (identical(other.nuanceTvStation, nuanceTvStation) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceTvStation, nuanceTvStation)) &&
            (identical(other.lgiTvAgeRating, lgiTvAgeRating) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvAgeRating, lgiTvAgeRating)) &&
            (identical(other.nuanceCALENDARX, nuanceCALENDARX) ||
                const DeepCollectionEquality()
                    .equals(other.nuanceCALENDARX, nuanceCALENDARX)) &&
            (identical(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch) ||
                const DeepCollectionEquality()
                    .equals(other.lgiTvEasterEggSearch, lgiTvEasterEggSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(nuanceTvQuery) ^
      const DeepCollectionEquality().hash(nuanceTvMediatype) ^
      const DeepCollectionEquality().hash(nuanceTvModifier) ^
      const DeepCollectionEquality().hash(nuanceTvYear) ^
      const DeepCollectionEquality().hash(nuanceTvGenre) ^
      const DeepCollectionEquality().hash(nuanceTvProvider) ^
      const DeepCollectionEquality().hash(nuanceTvStation) ^
      const DeepCollectionEquality().hash(lgiTvAgeRating) ^
      const DeepCollectionEquality().hash(nuanceCALENDARX) ^
      const DeepCollectionEquality().hash(lgiTvEasterEggSearch) ^
      runtimeType.hashCode;
}

extension $NuanceConceptsV1Extension on NuanceConceptsV1 {
  NuanceConceptsV1 copyWith(
      {List<NuanceConceptV1>? nuanceTvQuery,
      List<NuanceConceptV1>? nuanceTvMediatype,
      List<NuanceConceptV1>? nuanceTvModifier,
      List<NuanceConceptV1>? nuanceTvYear,
      List<NuanceConceptV1>? nuanceTvGenre,
      List<NuanceConceptV1>? nuanceTvProvider,
      List<NuanceConceptV1>? nuanceTvStation,
      List<NuanceConceptV1>? lgiTvAgeRating,
      List<NuanceConceptV1>? nuanceCALENDARX,
      List<NuanceConceptV1>? lgiTvEasterEggSearch}) {
    return NuanceConceptsV1(
        nuanceTvQuery: nuanceTvQuery ?? this.nuanceTvQuery,
        nuanceTvMediatype: nuanceTvMediatype ?? this.nuanceTvMediatype,
        nuanceTvModifier: nuanceTvModifier ?? this.nuanceTvModifier,
        nuanceTvYear: nuanceTvYear ?? this.nuanceTvYear,
        nuanceTvGenre: nuanceTvGenre ?? this.nuanceTvGenre,
        nuanceTvProvider: nuanceTvProvider ?? this.nuanceTvProvider,
        nuanceTvStation: nuanceTvStation ?? this.nuanceTvStation,
        lgiTvAgeRating: lgiTvAgeRating ?? this.lgiTvAgeRating,
        nuanceCALENDARX: nuanceCALENDARX ?? this.nuanceCALENDARX,
        lgiTvEasterEggSearch:
            lgiTvEasterEggSearch ?? this.lgiTvEasterEggSearch);
  }

  NuanceConceptsV1 copyWithWrapped(
      {Wrapped<List<NuanceConceptV1>?>? nuanceTvQuery,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvMediatype,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvModifier,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvYear,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvGenre,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvProvider,
      Wrapped<List<NuanceConceptV1>?>? nuanceTvStation,
      Wrapped<List<NuanceConceptV1>?>? lgiTvAgeRating,
      Wrapped<List<NuanceConceptV1>?>? nuanceCALENDARX,
      Wrapped<List<NuanceConceptV1>?>? lgiTvEasterEggSearch}) {
    return NuanceConceptsV1(
        nuanceTvQuery:
            (nuanceTvQuery != null ? nuanceTvQuery.value : this.nuanceTvQuery),
        nuanceTvMediatype: (nuanceTvMediatype != null
            ? nuanceTvMediatype.value
            : this.nuanceTvMediatype),
        nuanceTvModifier: (nuanceTvModifier != null
            ? nuanceTvModifier.value
            : this.nuanceTvModifier),
        nuanceTvYear:
            (nuanceTvYear != null ? nuanceTvYear.value : this.nuanceTvYear),
        nuanceTvGenre:
            (nuanceTvGenre != null ? nuanceTvGenre.value : this.nuanceTvGenre),
        nuanceTvProvider: (nuanceTvProvider != null
            ? nuanceTvProvider.value
            : this.nuanceTvProvider),
        nuanceTvStation: (nuanceTvStation != null
            ? nuanceTvStation.value
            : this.nuanceTvStation),
        lgiTvAgeRating: (lgiTvAgeRating != null
            ? lgiTvAgeRating.value
            : this.lgiTvAgeRating),
        nuanceCALENDARX: (nuanceCALENDARX != null
            ? nuanceCALENDARX.value
            : this.nuanceCALENDARX),
        lgiTvEasterEggSearch: (lgiTvEasterEggSearch != null
            ? lgiTvEasterEggSearch.value
            : this.lgiTvEasterEggSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceConceptV1 {
  NuanceConceptV1({
    required this.value,
    required this.literal,
    required this.ranges,
  });

  factory NuanceConceptV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceConceptV1FromJson(json);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String value;
  @JsonKey(name: 'literal', includeIfNull: false, defaultValue: '')
  final String literal;
  @JsonKey(name: 'ranges', includeIfNull: false, defaultValue: <List<num>>[])
  final List<List<num>> ranges;
  static const fromJsonFactory = _$NuanceConceptV1FromJson;
  static const toJsonFactory = _$NuanceConceptV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceConceptV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceConceptV1 &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.literal, literal) ||
                const DeepCollectionEquality()
                    .equals(other.literal, literal)) &&
            (identical(other.ranges, ranges) ||
                const DeepCollectionEquality().equals(other.ranges, ranges)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(literal) ^
      const DeepCollectionEquality().hash(ranges) ^
      runtimeType.hashCode;
}

extension $NuanceConceptV1Extension on NuanceConceptV1 {
  NuanceConceptV1 copyWith(
      {String? value, String? literal, List<List<num>>? ranges}) {
    return NuanceConceptV1(
        value: value ?? this.value,
        literal: literal ?? this.literal,
        ranges: ranges ?? this.ranges);
  }

  NuanceConceptV1 copyWithWrapped(
      {Wrapped<String>? value,
      Wrapped<String>? literal,
      Wrapped<List<List<num>>>? ranges}) {
    return NuanceConceptV1(
        value: (value != null ? value.value : this.value),
        literal: (literal != null ? literal.value : this.literal),
        ranges: (ranges != null ? ranges.value : this.ranges));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceActionV1 {
  NuanceActionV1({
    this.intent,
  });

  factory NuanceActionV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceActionV1FromJson(json);

  @JsonKey(name: 'intent', includeIfNull: false)
  final NuanceIntentV1? intent;
  static const fromJsonFactory = _$NuanceActionV1FromJson;
  static const toJsonFactory = _$NuanceActionV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceActionV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceActionV1 &&
            (identical(other.intent, intent) ||
                const DeepCollectionEquality().equals(other.intent, intent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(intent) ^ runtimeType.hashCode;
}

extension $NuanceActionV1Extension on NuanceActionV1 {
  NuanceActionV1 copyWith({NuanceIntentV1? intent}) {
    return NuanceActionV1(intent: intent ?? this.intent);
  }

  NuanceActionV1 copyWithWrapped({Wrapped<NuanceIntentV1?>? intent}) {
    return NuanceActionV1(
        intent: (intent != null ? intent.value : this.intent));
  }
}

@JsonSerializable(explicitToJson: true)
class NuanceIntentV1 {
  NuanceIntentV1({
    this.value,
    this.confidence,
  });

  factory NuanceIntentV1.fromJson(Map<String, dynamic> json) =>
      _$NuanceIntentV1FromJson(json);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  @JsonKey(name: 'confidence', includeIfNull: false)
  final int? confidence;
  static const fromJsonFactory = _$NuanceIntentV1FromJson;
  static const toJsonFactory = _$NuanceIntentV1ToJson;
  Map<String, dynamic> toJson() => _$NuanceIntentV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NuanceIntentV1 &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.confidence, confidence) ||
                const DeepCollectionEquality()
                    .equals(other.confidence, confidence)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(confidence) ^
      runtimeType.hashCode;
}

extension $NuanceIntentV1Extension on NuanceIntentV1 {
  NuanceIntentV1 copyWith({String? value, int? confidence}) {
    return NuanceIntentV1(
        value: value ?? this.value, confidence: confidence ?? this.confidence);
  }

  NuanceIntentV1 copyWithWrapped(
      {Wrapped<String?>? value, Wrapped<int?>? confidence}) {
    return NuanceIntentV1(
        value: (value != null ? value.value : this.value),
        confidence: (confidence != null ? confidence.value : this.confidence));
  }
}

@JsonSerializable(explicitToJson: true)
class VoiceSearchResponseV1 {
  VoiceSearchResponseV1();

  factory VoiceSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$VoiceSearchResponseV1FromJson(json);

  static const fromJsonFactory = _$VoiceSearchResponseV1FromJson;
  static const toJsonFactory = _$VoiceSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$VoiceSearchResponseV1ToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class TopSearchResponseV1 {
  TopSearchResponseV1();

  factory TopSearchResponseV1.fromJson(Map<String, dynamic> json) =>
      _$TopSearchResponseV1FromJson(json);

  static const fromJsonFactory = _$TopSearchResponseV1FromJson;
  static const toJsonFactory = _$TopSearchResponseV1ToJson;
  Map<String, dynamic> toJson() => _$TopSearchResponseV1ToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class LTVRecommendationResponseV1 {
  LTVRecommendationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.isAdult,
    required this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.series,
  });

  factory LTVRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$LTVRecommendationResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponseV1? series;
  static const fromJsonFactory = _$LTVRecommendationResponseV1FromJson;
  static const toJsonFactory = _$LTVRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$LTVRecommendationResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LTVRecommendationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $LTVRecommendationResponseV1Extension on LTVRecommendationResponseV1 {
  LTVRecommendationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      SeriesRecommendationResponseV1? series}) {
    return LTVRecommendationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        series: series ?? this.series);
  }

  LTVRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<SeriesRecommendationResponseV1?>? series}) {
    return LTVRecommendationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class VODRecommendationResponseV1 {
  VODRecommendationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    required this.contentId,
    required this.titleId,
    required this.isViewedCompletely,
    this.minimumAge,
    required this.bookmark,
    this.isAdult,
    required this.isReplay,
    this.eventId,
    required this.durationInSeconds,
    this.associatedPicture,
    this.associatedPictureType,
    this.availabilityStart,
    this.availabilityEnd,
    this.userInteractedWithSeries,
    this.collapseSeries,
    this.collapseInstance,
    required this.product,
    this.hasMultipleProducts,
    this.series,
  });

  factory VODRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$VODRecommendationResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'contentId', includeIfNull: false, defaultValue: '')
  final String contentId;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'isViewedCompletely', includeIfNull: false)
  final bool isViewedCompletely;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'bookmark', includeIfNull: false, defaultValue: '')
  final String bookmark;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String? availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String? availabilityEnd;
  @JsonKey(
      name: 'userInteractedWithSeries',
      includeIfNull: false,
      defaultValue: false)
  final bool? userInteractedWithSeries;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'product', includeIfNull: false)
  final ProductResponseV1 product;
  @JsonKey(name: 'hasMultipleProducts', includeIfNull: false)
  final bool? hasMultipleProducts;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponseV1? series;
  static const fromJsonFactory = _$VODRecommendationResponseV1FromJson;
  static const toJsonFactory = _$VODRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$VODRecommendationResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VODRecommendationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.contentId, contentId) ||
                const DeepCollectionEquality()
                    .equals(other.contentId, contentId)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.isViewedCompletely, isViewedCompletely) ||
                const DeepCollectionEquality()
                    .equals(other.isViewedCompletely, isViewedCompletely)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.userInteractedWithSeries, userInteractedWithSeries) ||
                const DeepCollectionEquality().equals(
                    other.userInteractedWithSeries,
                    userInteractedWithSeries)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.product, product) ||
                const DeepCollectionEquality()
                    .equals(other.product, product)) &&
            (identical(other.hasMultipleProducts, hasMultipleProducts) ||
                const DeepCollectionEquality()
                    .equals(other.hasMultipleProducts, hasMultipleProducts)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(contentId) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(isViewedCompletely) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(userInteractedWithSeries) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(product) ^
      const DeepCollectionEquality().hash(hasMultipleProducts) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $VODRecommendationResponseV1Extension on VODRecommendationResponseV1 {
  VODRecommendationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? contentId,
      String? titleId,
      bool? isViewedCompletely,
      String? minimumAge,
      String? bookmark,
      bool? isAdult,
      bool? isReplay,
      String? eventId,
      int? durationInSeconds,
      String? associatedPicture,
      String? associatedPictureType,
      String? availabilityStart,
      String? availabilityEnd,
      bool? userInteractedWithSeries,
      bool? collapseSeries,
      bool? collapseInstance,
      ProductResponseV1? product,
      bool? hasMultipleProducts,
      SeriesRecommendationResponseV1? series}) {
    return VODRecommendationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        contentId: contentId ?? this.contentId,
        titleId: titleId ?? this.titleId,
        isViewedCompletely: isViewedCompletely ?? this.isViewedCompletely,
        minimumAge: minimumAge ?? this.minimumAge,
        bookmark: bookmark ?? this.bookmark,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        eventId: eventId ?? this.eventId,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        userInteractedWithSeries:
            userInteractedWithSeries ?? this.userInteractedWithSeries,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        product: product ?? this.product,
        hasMultipleProducts: hasMultipleProducts ?? this.hasMultipleProducts,
        series: series ?? this.series);
  }

  VODRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String>? contentId,
      Wrapped<String>? titleId,
      Wrapped<bool>? isViewedCompletely,
      Wrapped<String?>? minimumAge,
      Wrapped<String>? bookmark,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<String?>? eventId,
      Wrapped<int>? durationInSeconds,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<String?>? availabilityStart,
      Wrapped<String?>? availabilityEnd,
      Wrapped<bool?>? userInteractedWithSeries,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<ProductResponseV1>? product,
      Wrapped<bool?>? hasMultipleProducts,
      Wrapped<SeriesRecommendationResponseV1?>? series}) {
    return VODRecommendationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        contentId: (contentId != null ? contentId.value : this.contentId),
        titleId: (titleId != null ? titleId.value : this.titleId),
        isViewedCompletely: (isViewedCompletely != null
            ? isViewedCompletely.value
            : this.isViewedCompletely),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        eventId: (eventId != null ? eventId.value : this.eventId),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        userInteractedWithSeries: (userInteractedWithSeries != null
            ? userInteractedWithSeries.value
            : this.userInteractedWithSeries),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        product: (product != null ? product.value : this.product),
        hasMultipleProducts: (hasMultipleProducts != null
            ? hasMultipleProducts.value
            : this.hasMultipleProducts),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class PVRRecommendationResponseV1 {
  PVRRecommendationResponseV1({
    required this.contentSource,
    this.contentType,
    this.name,
    this.channelId,
    required this.channels,
    required this.eventId,
    this.minimumAge,
    this.containsAdult,
    this.isAdult,
    required this.isReplay,
    this.isRecording,
    required this.availabilityStart,
    required this.availabilityEnd,
    required this.durationInSeconds,
    this.bookmark,
    this.associatedPicture,
    this.associatedPictureType,
    this.collapseSeries,
    this.collapseInstance,
    this.localRecordingId,
    this.cpeId,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.series,
  });

  factory PVRRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$PVRRecommendationResponseV1FromJson(json);

  @JsonKey(name: 'contentSource', includeIfNull: false, defaultValue: '')
  final String contentSource;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String? contentType;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channels', includeIfNull: false, defaultValue: <String>[])
  final List<String> channels;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false, defaultValue: false)
  final bool? containsAdult;
  @JsonKey(name: 'isAdult', includeIfNull: false, defaultValue: false)
  final bool? isAdult;
  @JsonKey(name: 'isReplay', includeIfNull: false, defaultValue: false)
  final bool isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false, defaultValue: false)
  final bool? isRecording;
  @JsonKey(name: 'availabilityStart', includeIfNull: false, defaultValue: '')
  final String availabilityStart;
  @JsonKey(name: 'availabilityEnd', includeIfNull: false, defaultValue: '')
  final String availabilityEnd;
  @JsonKey(name: 'durationInSeconds', includeIfNull: false)
  final int durationInSeconds;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'associatedPicture', includeIfNull: false, defaultValue: '')
  final String? associatedPicture;
  @JsonKey(
      name: 'associatedPictureType', includeIfNull: false, defaultValue: '')
  final String? associatedPictureType;
  @JsonKey(name: 'collapseSeries', includeIfNull: false)
  final bool? collapseSeries;
  @JsonKey(name: 'collapseInstance', includeIfNull: false)
  final bool? collapseInstance;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'series', includeIfNull: false)
  final SeriesRecommendationResponseV1? series;
  static const fromJsonFactory = _$PVRRecommendationResponseV1FromJson;
  static const toJsonFactory = _$PVRRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$PVRRecommendationResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PVRRecommendationResponseV1 &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channels, channels) ||
                const DeepCollectionEquality()
                    .equals(other.channels, channels)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.availabilityStart, availabilityStart) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityStart, availabilityStart)) &&
            (identical(other.availabilityEnd, availabilityEnd) ||
                const DeepCollectionEquality()
                    .equals(other.availabilityEnd, availabilityEnd)) &&
            (identical(other.durationInSeconds, durationInSeconds) ||
                const DeepCollectionEquality()
                    .equals(other.durationInSeconds, durationInSeconds)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.associatedPicture, associatedPicture) ||
                const DeepCollectionEquality()
                    .equals(other.associatedPicture, associatedPicture)) &&
            (identical(other.associatedPictureType, associatedPictureType) ||
                const DeepCollectionEquality().equals(
                    other.associatedPictureType, associatedPictureType)) &&
            (identical(other.collapseSeries, collapseSeries) ||
                const DeepCollectionEquality()
                    .equals(other.collapseSeries, collapseSeries)) &&
            (identical(other.collapseInstance, collapseInstance) ||
                const DeepCollectionEquality()
                    .equals(other.collapseInstance, collapseInstance)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality().equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) || const DeepCollectionEquality().equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) || const DeepCollectionEquality().equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.series, series) || const DeepCollectionEquality().equals(other.series, series)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channels) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(availabilityStart) ^
      const DeepCollectionEquality().hash(availabilityEnd) ^
      const DeepCollectionEquality().hash(durationInSeconds) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(associatedPicture) ^
      const DeepCollectionEquality().hash(associatedPictureType) ^
      const DeepCollectionEquality().hash(collapseSeries) ^
      const DeepCollectionEquality().hash(collapseInstance) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(series) ^
      runtimeType.hashCode;
}

extension $PVRRecommendationResponseV1Extension on PVRRecommendationResponseV1 {
  PVRRecommendationResponseV1 copyWith(
      {String? contentSource,
      String? contentType,
      String? name,
      String? channelId,
      List<String>? channels,
      String? eventId,
      String? minimumAge,
      bool? containsAdult,
      bool? isAdult,
      bool? isReplay,
      bool? isRecording,
      String? availabilityStart,
      String? availabilityEnd,
      int? durationInSeconds,
      int? bookmark,
      String? associatedPicture,
      String? associatedPictureType,
      bool? collapseSeries,
      bool? collapseInstance,
      String? localRecordingId,
      String? cpeId,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      SeriesRecommendationResponseV1? series}) {
    return PVRRecommendationResponseV1(
        contentSource: contentSource ?? this.contentSource,
        contentType: contentType ?? this.contentType,
        name: name ?? this.name,
        channelId: channelId ?? this.channelId,
        channels: channels ?? this.channels,
        eventId: eventId ?? this.eventId,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        isAdult: isAdult ?? this.isAdult,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        availabilityStart: availabilityStart ?? this.availabilityStart,
        availabilityEnd: availabilityEnd ?? this.availabilityEnd,
        durationInSeconds: durationInSeconds ?? this.durationInSeconds,
        bookmark: bookmark ?? this.bookmark,
        associatedPicture: associatedPicture ?? this.associatedPicture,
        associatedPictureType:
            associatedPictureType ?? this.associatedPictureType,
        collapseSeries: collapseSeries ?? this.collapseSeries,
        collapseInstance: collapseInstance ?? this.collapseInstance,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        series: series ?? this.series);
  }

  PVRRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String>? contentSource,
      Wrapped<String?>? contentType,
      Wrapped<String?>? name,
      Wrapped<String?>? channelId,
      Wrapped<List<String>>? channels,
      Wrapped<String>? eventId,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<bool?>? isAdult,
      Wrapped<bool>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String>? availabilityStart,
      Wrapped<String>? availabilityEnd,
      Wrapped<int>? durationInSeconds,
      Wrapped<int?>? bookmark,
      Wrapped<String?>? associatedPicture,
      Wrapped<String?>? associatedPictureType,
      Wrapped<bool?>? collapseSeries,
      Wrapped<bool?>? collapseInstance,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<SeriesRecommendationResponseV1?>? series}) {
    return PVRRecommendationResponseV1(
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        name: (name != null ? name.value : this.name),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channels: (channels != null ? channels.value : this.channels),
        eventId: (eventId != null ? eventId.value : this.eventId),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        availabilityStart: (availabilityStart != null
            ? availabilityStart.value
            : this.availabilityStart),
        availabilityEnd: (availabilityEnd != null
            ? availabilityEnd.value
            : this.availabilityEnd),
        durationInSeconds: (durationInSeconds != null
            ? durationInSeconds.value
            : this.durationInSeconds),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        associatedPicture: (associatedPicture != null
            ? associatedPicture.value
            : this.associatedPicture),
        associatedPictureType: (associatedPictureType != null
            ? associatedPictureType.value
            : this.associatedPictureType),
        collapseSeries: (collapseSeries != null
            ? collapseSeries.value
            : this.collapseSeries),
        collapseInstance: (collapseInstance != null
            ? collapseInstance.value
            : this.collapseInstance),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        series: (series != null ? series.value : this.series));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesRecommendationResponseV1 {
  SeriesRecommendationResponseV1({
    this.seriesId,
    this.episodeName,
    this.episodeNumber,
    this.numberOfEpisodeTitles,
    this.specialsCount,
    this.seasonCount,
    this.seasonName,
    this.seasonNumber,
    this.seriesName,
    this.parentSeriesId,
    this.seriesType,
  });

  factory SeriesRecommendationResponseV1.fromJson(Map<String, dynamic> json) =>
      _$SeriesRecommendationResponseV1FromJson(json);

  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'episodeName', includeIfNull: false, defaultValue: '')
  final String? episodeName;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final num? episodeNumber;
  @JsonKey(name: 'numberOfEpisodeTitles', includeIfNull: false)
  final int? numberOfEpisodeTitles;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int? specialsCount;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final num? seasonNumber;
  @JsonKey(name: 'seriesName', includeIfNull: false, defaultValue: '')
  final String? seriesName;
  @JsonKey(name: 'parentSeriesId', includeIfNull: false, defaultValue: '')
  final String? parentSeriesId;
  @JsonKey(name: 'seriesType', includeIfNull: false, defaultValue: '')
  final String? seriesType;
  static const fromJsonFactory = _$SeriesRecommendationResponseV1FromJson;
  static const toJsonFactory = _$SeriesRecommendationResponseV1ToJson;
  Map<String, dynamic> toJson() => _$SeriesRecommendationResponseV1ToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesRecommendationResponseV1 &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.episodeName, episodeName) ||
                const DeepCollectionEquality()
                    .equals(other.episodeName, episodeName)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.numberOfEpisodeTitles, numberOfEpisodeTitles) ||
                const DeepCollectionEquality().equals(
                    other.numberOfEpisodeTitles, numberOfEpisodeTitles)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.seasonName, seasonName) ||
                const DeepCollectionEquality()
                    .equals(other.seasonName, seasonName)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.seriesName, seriesName) ||
                const DeepCollectionEquality()
                    .equals(other.seriesName, seriesName)) &&
            (identical(other.parentSeriesId, parentSeriesId) ||
                const DeepCollectionEquality()
                    .equals(other.parentSeriesId, parentSeriesId)) &&
            (identical(other.seriesType, seriesType) ||
                const DeepCollectionEquality()
                    .equals(other.seriesType, seriesType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(episodeName) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(numberOfEpisodeTitles) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(seriesName) ^
      const DeepCollectionEquality().hash(parentSeriesId) ^
      const DeepCollectionEquality().hash(seriesType) ^
      runtimeType.hashCode;
}

extension $SeriesRecommendationResponseV1Extension
    on SeriesRecommendationResponseV1 {
  SeriesRecommendationResponseV1 copyWith(
      {String? seriesId,
      String? episodeName,
      num? episodeNumber,
      int? numberOfEpisodeTitles,
      int? specialsCount,
      int? seasonCount,
      String? seasonName,
      num? seasonNumber,
      String? seriesName,
      String? parentSeriesId,
      String? seriesType}) {
    return SeriesRecommendationResponseV1(
        seriesId: seriesId ?? this.seriesId,
        episodeName: episodeName ?? this.episodeName,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        numberOfEpisodeTitles:
            numberOfEpisodeTitles ?? this.numberOfEpisodeTitles,
        specialsCount: specialsCount ?? this.specialsCount,
        seasonCount: seasonCount ?? this.seasonCount,
        seasonName: seasonName ?? this.seasonName,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        seriesName: seriesName ?? this.seriesName,
        parentSeriesId: parentSeriesId ?? this.parentSeriesId,
        seriesType: seriesType ?? this.seriesType);
  }

  SeriesRecommendationResponseV1 copyWithWrapped(
      {Wrapped<String?>? seriesId,
      Wrapped<String?>? episodeName,
      Wrapped<num?>? episodeNumber,
      Wrapped<int?>? numberOfEpisodeTitles,
      Wrapped<int?>? specialsCount,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? seasonName,
      Wrapped<num?>? seasonNumber,
      Wrapped<String?>? seriesName,
      Wrapped<String?>? parentSeriesId,
      Wrapped<String?>? seriesType}) {
    return SeriesRecommendationResponseV1(
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        episodeName:
            (episodeName != null ? episodeName.value : this.episodeName),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        numberOfEpisodeTitles: (numberOfEpisodeTitles != null
            ? numberOfEpisodeTitles.value
            : this.numberOfEpisodeTitles),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        seriesName: (seriesName != null ? seriesName.value : this.seriesName),
        parentSeriesId: (parentSeriesId != null
            ? parentSeriesId.value
            : this.parentSeriesId),
        seriesType: (seriesType != null ? seriesType.value : this.seriesType));
  }
}

@JsonSerializable(explicitToJson: true)
class MoreLikeThisResponseV1 {
  MoreLikeThisResponseV1();

  factory MoreLikeThisResponseV1.fromJson(Map<String, dynamic> json) =>
      _$MoreLikeThisResponseV1FromJson(json);

  static const fromJsonFactory = _$MoreLikeThisResponseV1FromJson;
  static const toJsonFactory = _$MoreLikeThisResponseV1ToJson;
  Map<String, dynamic> toJson() => _$MoreLikeThisResponseV1ToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

String? vODResponseProductTypeToJson(
    enums.VODResponseProductType? vODResponseProductType) {
  return enums.$VODResponseProductTypeMap[vODResponseProductType];
}

enums.VODResponseProductType vODResponseProductTypeFromJson(
  Object? vODResponseProductType, [
  enums.VODResponseProductType? defaultValue,
]) {
  if (vODResponseProductType is String) {
    return enums.$VODResponseProductTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                vODResponseProductType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VODResponseProductType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VODResponseProductTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VODResponseProductType.swaggerGeneratedUnknown;
}

List<String> vODResponseProductTypeListToJson(
    List<enums.VODResponseProductType>? vODResponseProductType) {
  if (vODResponseProductType == null) {
    return [];
  }

  return vODResponseProductType
      .map((e) => enums.$VODResponseProductTypeMap[e]!)
      .toList();
}

List<enums.VODResponseProductType> vODResponseProductTypeListFromJson(
  List? vODResponseProductType, [
  List<enums.VODResponseProductType>? defaultValue,
]) {
  if (vODResponseProductType == null) {
    return defaultValue ?? [];
  }

  return vODResponseProductType
      .map((e) => vODResponseProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODResponseProductType>? vODResponseProductTypeNullableListFromJson(
  List? vODResponseProductType, [
  List<enums.VODResponseProductType>? defaultValue,
]) {
  if (vODResponseProductType == null) {
    return defaultValue;
  }

  return vODResponseProductType
      .map((e) => vODResponseProductTypeFromJson(e.toString()))
      .toList();
}

String? vODResponseV3ProductTypeToJson(
    enums.VODResponseV3ProductType? vODResponseV3ProductType) {
  return enums.$VODResponseV3ProductTypeMap[vODResponseV3ProductType];
}

enums.VODResponseV3ProductType vODResponseV3ProductTypeFromJson(
  Object? vODResponseV3ProductType, [
  enums.VODResponseV3ProductType? defaultValue,
]) {
  if (vODResponseV3ProductType is String) {
    return enums.$VODResponseV3ProductTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                vODResponseV3ProductType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VODResponseV3ProductType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VODResponseV3ProductTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VODResponseV3ProductType.swaggerGeneratedUnknown;
}

List<String> vODResponseV3ProductTypeListToJson(
    List<enums.VODResponseV3ProductType>? vODResponseV3ProductType) {
  if (vODResponseV3ProductType == null) {
    return [];
  }

  return vODResponseV3ProductType
      .map((e) => enums.$VODResponseV3ProductTypeMap[e]!)
      .toList();
}

List<enums.VODResponseV3ProductType> vODResponseV3ProductTypeListFromJson(
  List? vODResponseV3ProductType, [
  List<enums.VODResponseV3ProductType>? defaultValue,
]) {
  if (vODResponseV3ProductType == null) {
    return defaultValue ?? [];
  }

  return vODResponseV3ProductType
      .map((e) => vODResponseV3ProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODResponseV3ProductType>?
    vODResponseV3ProductTypeNullableListFromJson(
  List? vODResponseV3ProductType, [
  List<enums.VODResponseV3ProductType>? defaultValue,
]) {
  if (vODResponseV3ProductType == null) {
    return defaultValue;
  }

  return vODResponseV3ProductType
      .map((e) => vODResponseV3ProductTypeFromJson(e.toString()))
      .toList();
}

String? vODRecommendationResponseProductTypeToJson(
    enums.VODRecommendationResponseProductType?
        vODRecommendationResponseProductType) {
  return enums.$VODRecommendationResponseProductTypeMap[
      vODRecommendationResponseProductType];
}

enums.VODRecommendationResponseProductType
    vODRecommendationResponseProductTypeFromJson(
  Object? vODRecommendationResponseProductType, [
  enums.VODRecommendationResponseProductType? defaultValue,
]) {
  if (vODRecommendationResponseProductType is String) {
    return enums.$VODRecommendationResponseProductTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                vODRecommendationResponseProductType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VODRecommendationResponseProductType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VODRecommendationResponseProductTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VODRecommendationResponseProductType.swaggerGeneratedUnknown;
}

List<String> vODRecommendationResponseProductTypeListToJson(
    List<enums.VODRecommendationResponseProductType>?
        vODRecommendationResponseProductType) {
  if (vODRecommendationResponseProductType == null) {
    return [];
  }

  return vODRecommendationResponseProductType
      .map((e) => enums.$VODRecommendationResponseProductTypeMap[e]!)
      .toList();
}

List<enums.VODRecommendationResponseProductType>
    vODRecommendationResponseProductTypeListFromJson(
  List? vODRecommendationResponseProductType, [
  List<enums.VODRecommendationResponseProductType>? defaultValue,
]) {
  if (vODRecommendationResponseProductType == null) {
    return defaultValue ?? [];
  }

  return vODRecommendationResponseProductType
      .map((e) => vODRecommendationResponseProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODRecommendationResponseProductType>?
    vODRecommendationResponseProductTypeNullableListFromJson(
  List? vODRecommendationResponseProductType, [
  List<enums.VODRecommendationResponseProductType>? defaultValue,
]) {
  if (vODRecommendationResponseProductType == null) {
    return defaultValue;
  }

  return vODRecommendationResponseProductType
      .map((e) => vODRecommendationResponseProductTypeFromJson(e.toString()))
      .toList();
}

String? vODRecommendationResponseV3ProductTypeToJson(
    enums.VODRecommendationResponseV3ProductType?
        vODRecommendationResponseV3ProductType) {
  return enums.$VODRecommendationResponseV3ProductTypeMap[
      vODRecommendationResponseV3ProductType];
}

enums.VODRecommendationResponseV3ProductType
    vODRecommendationResponseV3ProductTypeFromJson(
  Object? vODRecommendationResponseV3ProductType, [
  enums.VODRecommendationResponseV3ProductType? defaultValue,
]) {
  if (vODRecommendationResponseV3ProductType is String) {
    return enums.$VODRecommendationResponseV3ProductTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                vODRecommendationResponseV3ProductType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VODRecommendationResponseV3ProductType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VODRecommendationResponseV3ProductTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VODRecommendationResponseV3ProductType.swaggerGeneratedUnknown;
}

List<String> vODRecommendationResponseV3ProductTypeListToJson(
    List<enums.VODRecommendationResponseV3ProductType>?
        vODRecommendationResponseV3ProductType) {
  if (vODRecommendationResponseV3ProductType == null) {
    return [];
  }

  return vODRecommendationResponseV3ProductType
      .map((e) => enums.$VODRecommendationResponseV3ProductTypeMap[e]!)
      .toList();
}

List<enums.VODRecommendationResponseV3ProductType>
    vODRecommendationResponseV3ProductTypeListFromJson(
  List? vODRecommendationResponseV3ProductType, [
  List<enums.VODRecommendationResponseV3ProductType>? defaultValue,
]) {
  if (vODRecommendationResponseV3ProductType == null) {
    return defaultValue ?? [];
  }

  return vODRecommendationResponseV3ProductType
      .map((e) => vODRecommendationResponseV3ProductTypeFromJson(e.toString()))
      .toList();
}

List<enums.VODRecommendationResponseV3ProductType>?
    vODRecommendationResponseV3ProductTypeNullableListFromJson(
  List? vODRecommendationResponseV3ProductType, [
  List<enums.VODRecommendationResponseV3ProductType>? defaultValue,
]) {
  if (vODRecommendationResponseV3ProductType == null) {
    return defaultValue;
  }

  return vODRecommendationResponseV3ProductType
      .map((e) => vODRecommendationResponseV3ProductTypeFromJson(e.toString()))
      .toList();
}

String? groupedMultisourceResponseSeriesContentTypeToJson(
    enums.GroupedMultisourceResponseSeriesContentType?
        groupedMultisourceResponseSeriesContentType) {
  return enums.$GroupedMultisourceResponseSeriesContentTypeMap[
      groupedMultisourceResponseSeriesContentType];
}

enums.GroupedMultisourceResponseSeriesContentType
    groupedMultisourceResponseSeriesContentTypeFromJson(
  Object? groupedMultisourceResponseSeriesContentType, [
  enums.GroupedMultisourceResponseSeriesContentType? defaultValue,
]) {
  if (groupedMultisourceResponseSeriesContentType is String) {
    return enums.$GroupedMultisourceResponseSeriesContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                groupedMultisourceResponseSeriesContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.GroupedMultisourceResponseSeriesContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$GroupedMultisourceResponseSeriesContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.GroupedMultisourceResponseSeriesContentType.swaggerGeneratedUnknown;
}

List<String> groupedMultisourceResponseSeriesContentTypeListToJson(
    List<enums.GroupedMultisourceResponseSeriesContentType>?
        groupedMultisourceResponseSeriesContentType) {
  if (groupedMultisourceResponseSeriesContentType == null) {
    return [];
  }

  return groupedMultisourceResponseSeriesContentType
      .map((e) => enums.$GroupedMultisourceResponseSeriesContentTypeMap[e]!)
      .toList();
}

List<enums.GroupedMultisourceResponseSeriesContentType>
    groupedMultisourceResponseSeriesContentTypeListFromJson(
  List? groupedMultisourceResponseSeriesContentType, [
  List<enums.GroupedMultisourceResponseSeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseSeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedMultisourceResponseSeriesContentType
      .map((e) =>
          groupedMultisourceResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedMultisourceResponseSeriesContentType>?
    groupedMultisourceResponseSeriesContentTypeNullableListFromJson(
  List? groupedMultisourceResponseSeriesContentType, [
  List<enums.GroupedMultisourceResponseSeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseSeriesContentType == null) {
    return defaultValue;
  }

  return groupedMultisourceResponseSeriesContentType
      .map((e) =>
          groupedMultisourceResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? groupedMultisourceResponseV3SeriesContentTypeToJson(
    enums.GroupedMultisourceResponseV3SeriesContentType?
        groupedMultisourceResponseV3SeriesContentType) {
  return enums.$GroupedMultisourceResponseV3SeriesContentTypeMap[
      groupedMultisourceResponseV3SeriesContentType];
}

enums.GroupedMultisourceResponseV3SeriesContentType
    groupedMultisourceResponseV3SeriesContentTypeFromJson(
  Object? groupedMultisourceResponseV3SeriesContentType, [
  enums.GroupedMultisourceResponseV3SeriesContentType? defaultValue,
]) {
  if (groupedMultisourceResponseV3SeriesContentType is String) {
    return enums.$GroupedMultisourceResponseV3SeriesContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                groupedMultisourceResponseV3SeriesContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.GroupedMultisourceResponseV3SeriesContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$GroupedMultisourceResponseV3SeriesContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.GroupedMultisourceResponseV3SeriesContentType
          .swaggerGeneratedUnknown;
}

List<String> groupedMultisourceResponseV3SeriesContentTypeListToJson(
    List<enums.GroupedMultisourceResponseV3SeriesContentType>?
        groupedMultisourceResponseV3SeriesContentType) {
  if (groupedMultisourceResponseV3SeriesContentType == null) {
    return [];
  }

  return groupedMultisourceResponseV3SeriesContentType
      .map((e) => enums.$GroupedMultisourceResponseV3SeriesContentTypeMap[e]!)
      .toList();
}

List<enums.GroupedMultisourceResponseV3SeriesContentType>
    groupedMultisourceResponseV3SeriesContentTypeListFromJson(
  List? groupedMultisourceResponseV3SeriesContentType, [
  List<enums.GroupedMultisourceResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseV3SeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedMultisourceResponseV3SeriesContentType
      .map((e) =>
          groupedMultisourceResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedMultisourceResponseV3SeriesContentType>?
    groupedMultisourceResponseV3SeriesContentTypeNullableListFromJson(
  List? groupedMultisourceResponseV3SeriesContentType, [
  List<enums.GroupedMultisourceResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedMultisourceResponseV3SeriesContentType == null) {
    return defaultValue;
  }

  return groupedMultisourceResponseV3SeriesContentType
      .map((e) =>
          groupedMultisourceResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? groupedSeriesResponseSeriesContentTypeToJson(
    enums.GroupedSeriesResponseSeriesContentType?
        groupedSeriesResponseSeriesContentType) {
  return enums.$GroupedSeriesResponseSeriesContentTypeMap[
      groupedSeriesResponseSeriesContentType];
}

enums.GroupedSeriesResponseSeriesContentType
    groupedSeriesResponseSeriesContentTypeFromJson(
  Object? groupedSeriesResponseSeriesContentType, [
  enums.GroupedSeriesResponseSeriesContentType? defaultValue,
]) {
  if (groupedSeriesResponseSeriesContentType is String) {
    return enums.$GroupedSeriesResponseSeriesContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                groupedSeriesResponseSeriesContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.GroupedSeriesResponseSeriesContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$GroupedSeriesResponseSeriesContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.GroupedSeriesResponseSeriesContentType.swaggerGeneratedUnknown;
}

List<String> groupedSeriesResponseSeriesContentTypeListToJson(
    List<enums.GroupedSeriesResponseSeriesContentType>?
        groupedSeriesResponseSeriesContentType) {
  if (groupedSeriesResponseSeriesContentType == null) {
    return [];
  }

  return groupedSeriesResponseSeriesContentType
      .map((e) => enums.$GroupedSeriesResponseSeriesContentTypeMap[e]!)
      .toList();
}

List<enums.GroupedSeriesResponseSeriesContentType>
    groupedSeriesResponseSeriesContentTypeListFromJson(
  List? groupedSeriesResponseSeriesContentType, [
  List<enums.GroupedSeriesResponseSeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseSeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedSeriesResponseSeriesContentType
      .map((e) => groupedSeriesResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedSeriesResponseSeriesContentType>?
    groupedSeriesResponseSeriesContentTypeNullableListFromJson(
  List? groupedSeriesResponseSeriesContentType, [
  List<enums.GroupedSeriesResponseSeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseSeriesContentType == null) {
    return defaultValue;
  }

  return groupedSeriesResponseSeriesContentType
      .map((e) => groupedSeriesResponseSeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? groupedSeriesResponseV3SeriesContentTypeToJson(
    enums.GroupedSeriesResponseV3SeriesContentType?
        groupedSeriesResponseV3SeriesContentType) {
  return enums.$GroupedSeriesResponseV3SeriesContentTypeMap[
      groupedSeriesResponseV3SeriesContentType];
}

enums.GroupedSeriesResponseV3SeriesContentType
    groupedSeriesResponseV3SeriesContentTypeFromJson(
  Object? groupedSeriesResponseV3SeriesContentType, [
  enums.GroupedSeriesResponseV3SeriesContentType? defaultValue,
]) {
  if (groupedSeriesResponseV3SeriesContentType is String) {
    return enums.$GroupedSeriesResponseV3SeriesContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                groupedSeriesResponseV3SeriesContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.GroupedSeriesResponseV3SeriesContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$GroupedSeriesResponseV3SeriesContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.GroupedSeriesResponseV3SeriesContentType.swaggerGeneratedUnknown;
}

List<String> groupedSeriesResponseV3SeriesContentTypeListToJson(
    List<enums.GroupedSeriesResponseV3SeriesContentType>?
        groupedSeriesResponseV3SeriesContentType) {
  if (groupedSeriesResponseV3SeriesContentType == null) {
    return [];
  }

  return groupedSeriesResponseV3SeriesContentType
      .map((e) => enums.$GroupedSeriesResponseV3SeriesContentTypeMap[e]!)
      .toList();
}

List<enums.GroupedSeriesResponseV3SeriesContentType>
    groupedSeriesResponseV3SeriesContentTypeListFromJson(
  List? groupedSeriesResponseV3SeriesContentType, [
  List<enums.GroupedSeriesResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseV3SeriesContentType == null) {
    return defaultValue ?? [];
  }

  return groupedSeriesResponseV3SeriesContentType
      .map(
          (e) => groupedSeriesResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.GroupedSeriesResponseV3SeriesContentType>?
    groupedSeriesResponseV3SeriesContentTypeNullableListFromJson(
  List? groupedSeriesResponseV3SeriesContentType, [
  List<enums.GroupedSeriesResponseV3SeriesContentType>? defaultValue,
]) {
  if (groupedSeriesResponseV3SeriesContentType == null) {
    return defaultValue;
  }

  return groupedSeriesResponseV3SeriesContentType
      .map(
          (e) => groupedSeriesResponseV3SeriesContentTypeFromJson(e.toString()))
      .toList();
}

String? learnActionContentSourceIdToJson(
    enums.LearnActionContentSourceId? learnActionContentSourceId) {
  return enums.$LearnActionContentSourceIdMap[learnActionContentSourceId];
}

enums.LearnActionContentSourceId learnActionContentSourceIdFromJson(
  Object? learnActionContentSourceId, [
  enums.LearnActionContentSourceId? defaultValue,
]) {
  if (learnActionContentSourceId is String) {
    return enums.$LearnActionContentSourceIdMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                learnActionContentSourceId.toLowerCase(),
            orElse: () => const MapEntry(
                enums.LearnActionContentSourceId.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LearnActionContentSourceIdMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LearnActionContentSourceId.swaggerGeneratedUnknown;
}

List<String> learnActionContentSourceIdListToJson(
    List<enums.LearnActionContentSourceId>? learnActionContentSourceId) {
  if (learnActionContentSourceId == null) {
    return [];
  }

  return learnActionContentSourceId
      .map((e) => enums.$LearnActionContentSourceIdMap[e]!)
      .toList();
}

List<enums.LearnActionContentSourceId> learnActionContentSourceIdListFromJson(
  List? learnActionContentSourceId, [
  List<enums.LearnActionContentSourceId>? defaultValue,
]) {
  if (learnActionContentSourceId == null) {
    return defaultValue ?? [];
  }

  return learnActionContentSourceId
      .map((e) => learnActionContentSourceIdFromJson(e.toString()))
      .toList();
}

List<enums.LearnActionContentSourceId>?
    learnActionContentSourceIdNullableListFromJson(
  List? learnActionContentSourceId, [
  List<enums.LearnActionContentSourceId>? defaultValue,
]) {
  if (learnActionContentSourceId == null) {
    return defaultValue;
  }

  return learnActionContentSourceId
      .map((e) => learnActionContentSourceIdFromJson(e.toString()))
      .toList();
}

int? learnActionActionIdToJson(enums.LearnActionActionId? learnActionActionId) {
  return enums.$LearnActionActionIdMap[learnActionActionId];
}

enums.LearnActionActionId learnActionActionIdFromJson(
  Object? learnActionActionId, [
  enums.LearnActionActionId? defaultValue,
]) {
  if (learnActionActionId is int) {
    return enums.$LearnActionActionIdMap.entries
        .firstWhere((element) => element.value == learnActionActionId,
            orElse: () => const MapEntry(
                enums.LearnActionActionId.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LearnActionActionIdMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LearnActionActionId.swaggerGeneratedUnknown;
}

List<int> learnActionActionIdListToJson(
    List<enums.LearnActionActionId>? learnActionActionId) {
  if (learnActionActionId == null) {
    return [];
  }

  return learnActionActionId
      .map((e) => enums.$LearnActionActionIdMap[e]!)
      .toList();
}

List<enums.LearnActionActionId> learnActionActionIdListFromJson(
  List? learnActionActionId, [
  List<enums.LearnActionActionId>? defaultValue,
]) {
  if (learnActionActionId == null) {
    return defaultValue ?? [];
  }

  return learnActionActionId
      .map((e) => learnActionActionIdFromJson(e.toString()))
      .toList();
}

List<enums.LearnActionActionId>? learnActionActionIdNullableListFromJson(
  List? learnActionActionId, [
  List<enums.LearnActionActionId>? defaultValue,
]) {
  if (learnActionActionId == null) {
    return defaultValue;
  }

  return learnActionActionId
      .map((e) => learnActionActionIdFromJson(e.toString()))
      .toList();
}

String? pVRSearchResponseV1RecordingStateToJson(
    enums.PVRSearchResponseV1RecordingState?
        pVRSearchResponseV1RecordingState) {
  return enums
      .$PVRSearchResponseV1RecordingStateMap[pVRSearchResponseV1RecordingState];
}

enums.PVRSearchResponseV1RecordingState
    pVRSearchResponseV1RecordingStateFromJson(
  Object? pVRSearchResponseV1RecordingState, [
  enums.PVRSearchResponseV1RecordingState? defaultValue,
]) {
  if (pVRSearchResponseV1RecordingState is String) {
    return enums.$PVRSearchResponseV1RecordingStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                pVRSearchResponseV1RecordingState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PVRSearchResponseV1RecordingState.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PVRSearchResponseV1RecordingStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PVRSearchResponseV1RecordingState.swaggerGeneratedUnknown;
}

List<String> pVRSearchResponseV1RecordingStateListToJson(
    List<enums.PVRSearchResponseV1RecordingState>?
        pVRSearchResponseV1RecordingState) {
  if (pVRSearchResponseV1RecordingState == null) {
    return [];
  }

  return pVRSearchResponseV1RecordingState
      .map((e) => enums.$PVRSearchResponseV1RecordingStateMap[e]!)
      .toList();
}

List<enums.PVRSearchResponseV1RecordingState>
    pVRSearchResponseV1RecordingStateListFromJson(
  List? pVRSearchResponseV1RecordingState, [
  List<enums.PVRSearchResponseV1RecordingState>? defaultValue,
]) {
  if (pVRSearchResponseV1RecordingState == null) {
    return defaultValue ?? [];
  }

  return pVRSearchResponseV1RecordingState
      .map((e) => pVRSearchResponseV1RecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.PVRSearchResponseV1RecordingState>?
    pVRSearchResponseV1RecordingStateNullableListFromJson(
  List? pVRSearchResponseV1RecordingState, [
  List<enums.PVRSearchResponseV1RecordingState>? defaultValue,
]) {
  if (pVRSearchResponseV1RecordingState == null) {
    return defaultValue;
  }

  return pVRSearchResponseV1RecordingState
      .map((e) => pVRSearchResponseV1RecordingStateFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
