// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'picker_service.enums.swagger.dart' as enums;
export 'picker_service.enums.swagger.dart';

part 'picker_service.swagger.chopper.dart';
part 'picker_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class PickerService extends ChopperService {
  static PickerService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$PickerService(client);
    }

    final newClient = ChopperClient(
        services: [_$PickerService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$PickerService(newClient);
  }

  ///Retrieve series details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param customerId CustomerId with country code (eg: 'C001869_pl').
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param showCrid Show's crid. Should be used only, when ''seriesCrid'' is a season's crid.
  ///@param seasonCrid Series crid to retrieve episodes. Season's crid or show's (in case if show doesn't have seasons)
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedEventId The ''CRID'' and ''IMI'' of the selected event.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  Future<chopper.Response<SeriesDetailResponse>> v1SeriesDetailSeasonCridGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? customerId,
    required String? profileId,
    String? showCrid,
    required String? seasonCrid,
    required String? country,
    required String? language,
    String? selectedEventId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SeriesDetailResponse, () => SeriesDetailResponse.fromJsonFactory);

    return _v1SeriesDetailSeasonCridGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        customerId: customerId,
        profileId: profileId,
        showCrid: showCrid,
        seasonCrid: seasonCrid,
        country: country,
        language: language,
        selectedEventId: selectedEventId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        cacheControl: cacheControl);
  }

  ///Retrieve series details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param customerId CustomerId with country code (eg: 'C001869_pl').
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param showCrid Show's crid. Should be used only, when ''seriesCrid'' is a season's crid.
  ///@param seasonCrid Series crid to retrieve episodes. Season's crid or show's (in case if show doesn't have seasons)
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedEventId The ''CRID'' and ''IMI'' of the selected event.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  @Get(path: '/v1/seriesDetail/{seasonCrid}')
  Future<chopper.Response<SeriesDetailResponse>> _v1SeriesDetailSeasonCridGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('customerId') required String? customerId,
    @Query('profileId') required String? profileId,
    @Query('showCrid') String? showCrid,
    @Path('seasonCrid') required String? seasonCrid,
    @Query('country') required String? country,
    @Query('language') required String? language,
    @Query('selectedEventId') String? selectedEventId,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve event details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param customerId CustomerId with country code (eg: 'C001869_pl').
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Series Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param titleCrid Title Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param eventId Event Instance Metadata Identifier (eg: 'imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxRes Highest possible maxResolution.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  Future<chopper.Response<EventDetailResponse>> v1EventDetailGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? customerId,
    required String? profileId,
    required String? language,
    required String? country,
    String? seriesId,
    String? titleCrid,
    String? eventId,
    enums.MaxRes? maxRes,
    int? replayOptedInTime,
    int? cityId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EventDetailResponse, () => EventDetailResponse.fromJsonFactory);

    return _v1EventDetailGet(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        customerId: customerId,
        profileId: profileId,
        language: language,
        country: country,
        seriesId: seriesId,
        titleCrid: titleCrid,
        eventId: eventId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        replayOptedInTime: replayOptedInTime,
        cityId: cityId,
        cacheControl: cacheControl);
  }

  ///Retrieve event details
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param customerId CustomerId with country code (eg: 'C001869_pl').
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Series Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param titleCrid Title Content Reference Identifier(eg: 'crid://bds.tv/162392685').
  ///@param eventId Event Instance Metadata Identifier (eg: 'imi:51a4f05fc8421e6346e80099d6173921').
  ///@param maxRes Highest possible maxResolution.
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param cityId City id linked with given customerId
  @Get(path: '/v1/eventDetail')
  Future<chopper.Response<EventDetailResponse>> _v1EventDetailGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('customerId') required String? customerId,
    @Query('profileId') required String? profileId,
    @Query('language') required String? language,
    @Query('country') required String? country,
    @Query('seriesId') String? seriesId,
    @Query('titleCrid') String? titleCrid,
    @Query('eventId') String? eventId,
    @Query('maxRes') String? maxRes,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('cityId') int? cityId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve episode, season, special counts and corresponding channels for a list of series.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  Future<chopper.Response<SearchDetailsResponse>> v1SearchDetailsPost({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xSessionId,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
    required SearchDetails? body,
  }) {
    generatedMapping.putIfAbsent(
        SearchDetailsResponse, () => SearchDetailsResponse.fromJsonFactory);

    return _v1SearchDetailsPost(
        xDev: xDev,
        xCus: xCus,
        xSessionId: xSessionId,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl,
        body: body);
  }

  ///Retrieve episode, season, special counts and corresponding channels for a list of series.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param X-Session-Id Session-Id header used for load balancing toward upstream systems
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  @Post(path: '/v1/searchDetails')
  Future<chopper.Response<SearchDetailsResponse>> _v1SearchDetailsPost({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Session-Id') String? xSessionId,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SearchDetails? body,
  });

  ///Return most relevant source for given title
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Used to filter content by a specific provider
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<MostRelevantSourceResponse>> v1MostRelevantSourceGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    String? profileId,
    required String? language,
    required String? country,
    required String? titleId,
    int? cityId,
    int? replayOptedInTime,
    enums.MaxRes? maxRes,
    String? brandingProviderId,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(MostRelevantSourceResponse,
        () => MostRelevantSourceResponse.fromJsonFactory);

    return _v1MostRelevantSourceGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        titleId: titleId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        brandingProviderId: brandingProviderId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Return most relevant source for given title
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Used to filter content by a specific provider
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/mostRelevantSource')
  Future<chopper.Response<MostRelevantSourceResponse>>
      _v1MostRelevantSourceGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('country') required String? country,
    @Query('titleId') required String? titleId,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('maxRes') String? maxRes,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///DEPRECATED. Please use /v2/mostRelevantEpisode . Returns a title crid of the most relevant episode of a series
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Crid of a show
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param noSource Boolean to signal to not get the most relevant source or not for the most relevant episode. (mainly used for testing and debugging)
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  Future<chopper.Response<MostRelevantEpisodeResponse>>
      v1MostRelevantEpisodeGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    String? profileId,
    required String? language,
    required String? country,
    required String? seriesId,
    int? cityId,
    int? replayOptedInTime,
    bool? noSource,
    enums.MaxRes? maxRes,
    String? brandingProviderId,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(MostRelevantEpisodeResponse,
        () => MostRelevantEpisodeResponse.fromJsonFactory);

    return _v1MostRelevantEpisodeGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        seriesId: seriesId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        noSource: noSource,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        brandingProviderId: brandingProviderId,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///DEPRECATED. Please use /v2/mostRelevantEpisode . Returns a title crid of the most relevant episode of a series
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param seriesId Crid of a show
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param noSource Boolean to signal to not get the most relevant source or not for the most relevant episode. (mainly used for testing and debugging)
  ///@param maxRes Highest possible maxResolution.
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  @Get(path: '/v1/mostRelevantEpisode')
  Future<chopper.Response<MostRelevantEpisodeResponse>>
      _v1MostRelevantEpisodeGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('country') required String? country,
    @Query('seriesId') required String? seriesId,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('noSource') bool? noSource,
    @Query('maxRes') String? maxRes,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns most relevant episode of a series with related metadata
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param seriesId Show crid or season crid
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<Object>> v2MostRelevantEpisodeGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? seriesId,
    required String? language,
    required String? country,
    String? brandingProviderId,
    int? cityId,
    int? replayOptedInTime,
    String? profileId,
    enums.MaxRes? maxRes,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    return _v2MostRelevantEpisodeGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        seriesId: seriesId,
        language: language,
        country: country,
        brandingProviderId: brandingProviderId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        profileId: profileId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Returns most relevant episode of a series with related metadata
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param seriesId Show crid or season crid
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param brandingProviderId Get vod results only from given branding provider id
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param maxRes Highest possible maxResolution.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v2/mostRelevantEpisode')
  Future<chopper.Response<Object>> _v2MostRelevantEpisodeGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('seriesId') required String? seriesId,
    @Query('language') required String? language,
    @Query('country') required String? country,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('profileId') String? profileId,
    @Query('maxRes') String? maxRes,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Shows the other sources where the content is available
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param excludedBrandingProviderId Exclude VOD contents for specified branding provider. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param excludedChannelId Exclude events and recordings played on specified channel id. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param selectedEventId The ''CRID'' and ''IMI''. Parameter used for deduplication of vod sources in combination with excludedChannelid.
  Future<chopper.Response<Object>> v1TitleAlsoAvailableOnGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    String? profileId,
    required String? language,
    required String? country,
    required String? titleId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? excludedBrandingProviderId,
    String? excludedChannelId,
    String? includeExternalProvider,
    bool? mergingOn,
    String? selectedEventId,
    String? cacheControl,
  }) {
    return _v1TitleAlsoAvailableOnGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        profileId: profileId,
        language: language,
        country: country,
        titleId: titleId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        excludedBrandingProviderId: excludedBrandingProviderId,
        excludedChannelId: excludedChannelId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        selectedEventId: selectedEventId,
        cacheControl: cacheControl);
  }

  ///Shows the other sources where the content is available
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param titleId Title's crid.
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param excludedBrandingProviderId Exclude VOD contents for specified branding provider. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param excludedChannelId Exclude events and recordings played on specified channel id. Either excludedBrandingProviderId or excludedChannelId can be used.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param selectedEventId The ''CRID'' and ''IMI''. Parameter used for deduplication of vod sources in combination with excludedChannelid.
  @Get(path: '/v1/titleAlsoAvailableOn')
  Future<chopper.Response<Object>> _v1TitleAlsoAvailableOnGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('profileId') String? profileId,
    @Query('language') required String? language,
    @Query('country') required String? country,
    @Query('titleId') required String? titleId,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('excludedBrandingProviderId') String? excludedBrandingProviderId,
    @Query('excludedChannelId') String? excludedChannelId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Query('selectedEventId') String? selectedEventId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Provides details of the show.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param country Country in ISO3166
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<ShowPageResponse>> v1ShowPageShowCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? showCrid,
    required String? language,
    int? cityId,
    required String? country,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ShowPageResponse, () => ShowPageResponse.fromJsonFactory);

    return _v1ShowPageShowCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        showCrid: showCrid,
        language: language,
        cityId: cityId,
        country: country,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Provides details of the show.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param country Country in ISO3166
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/showPage/{showCrid}/{language}')
  Future<chopper.Response<ShowPageResponse>> _v1ShowPageShowCridLanguageGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Path('showCrid') required String? showCrid,
    @Path('language') required String? language,
    @Query('cityId') int? cityId,
    @Query('country') required String? country,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Responds with the Show information and a list of all the seasons
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<EpisodePickerResponse>> v1EpisodePickerGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    String? profileId,
    required String? seriesCrid,
    required String? country,
    required String? language,
    String? selectedAssetId,
    String? selectedBrandingProviderId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? channelId,
    String? brandingProviderId,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EpisodePickerResponse, () => EpisodePickerResponse.fromJsonFactory);

    return _v1EpisodePickerGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        profileId: profileId,
        seriesCrid: seriesCrid,
        country: country,
        language: language,
        selectedAssetId: selectedAssetId,
        selectedBrandingProviderId: selectedBrandingProviderId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        channelId: channelId,
        brandingProviderId: brandingProviderId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Responds with the Show information and a list of all the seasons
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/episodePicker')
  Future<chopper.Response<EpisodePickerResponse>> _v1EpisodePickerGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('profileId') String? profileId,
    @Query('seriesCrid') required String? seriesCrid,
    @Query('country') required String? country,
    @Query('language') required String? language,
    @Query('selectedAssetId') String? selectedAssetId,
    @Query('selectedBrandingProviderId') String? selectedBrandingProviderId,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('channelId') String? channelId,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Responds with the Show information and a list of all the seasons or episodes or episodes grouped by the year of production
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<EpisodePickerV2Response>> v2EpisodePickerGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    String? profileId,
    required String? seriesCrid,
    required String? country,
    required String? language,
    String? selectedAssetId,
    String? selectedBrandingProviderId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? channelId,
    String? brandingProviderId,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        EpisodePickerV2Response, () => EpisodePickerV2Response.fromJsonFactory);

    return _v2EpisodePickerGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        profileId: profileId,
        seriesCrid: seriesCrid,
        country: country,
        language: language,
        selectedAssetId: selectedAssetId,
        selectedBrandingProviderId: selectedBrandingProviderId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        channelId: channelId,
        brandingProviderId: brandingProviderId,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Responds with the Show information and a list of all the seasons or episodes or episodes grouped by the year of production
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param profileId Profile consisting of customerId, country code and 'MasterProfile' (eg: 'C001869_pl~~23MasterProfile').
  ///@param seriesCrid Crid of a show.
  ///@param country Country in ISO3166
  ///@param language Language in ISO639-1
  ///@param selectedAssetId The ''CRID'' and ''IMI'' of recording/event or ''CRID'' of content.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param channelId Return only events and recordings played on specified channel id. Either brandingProviderId or channelId can be used.
  ///@param brandingProviderId Return only contents for specified branding provider. Either brandingProviderId or channelId can be used.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v2/episodePicker')
  Future<chopper.Response<EpisodePickerV2Response>> _v2EpisodePickerGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('profileId') String? profileId,
    @Query('seriesCrid') required String? seriesCrid,
    @Query('country') required String? country,
    @Query('language') required String? language,
    @Query('selectedAssetId') String? selectedAssetId,
    @Query('selectedBrandingProviderId') String? selectedBrandingProviderId,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('channelId') String? channelId,
    @Query('brandingProviderId') String? brandingProviderId,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Allows for resolving which seasons are available per source
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param showCrid Show's crid.
  ///@param selectedResource Crid and imi (linear) or Crid (VOD) of the selected item.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<SaaoResponse>> v1ShowAlsoAvailableOnGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? language,
    required String? country,
    required String? showCrid,
    String? selectedResource,
    String? selectedBrandingProviderId,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    String? includeExternalProvider,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SaaoResponse, () => SaaoResponse.fromJsonFactory);

    return _v1ShowAlsoAvailableOnGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        language: language,
        country: country,
        showCrid: showCrid,
        selectedResource: selectedResource,
        selectedBrandingProviderId: selectedBrandingProviderId,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        includeExternalProvider: includeExternalProvider,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///Allows for resolving which seasons are available per source
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param showCrid Show's crid.
  ///@param selectedResource Crid and imi (linear) or Crid (VOD) of the selected item.
  ///@param selectedBrandingProviderId Used to select content by a specific provider. Mandatory only for VoD type crid when given in selectedAssetId parameter
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param includeExternalProvider external provider whose content has to be included
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/showAlsoAvailableOn')
  Future<chopper.Response<SaaoResponse>> _v1ShowAlsoAvailableOnGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Query('language') required String? language,
    @Query('country') required String? country,
    @Query('showCrid') required String? showCrid,
    @Query('selectedResource') String? selectedResource,
    @Query('selectedBrandingProviderId') String? selectedBrandingProviderId,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has VoD showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  Future<chopper.Response<SpaResponse>> v1ShowPageAvailableShowCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? showCrid,
    required String? language,
    int? cityId,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SpaResponse, () => SpaResponse.fromJsonFactory);

    return _v1ShowPageAvailableShowCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        showCrid: showCrid,
        language: language,
        cityId: cityId,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has VoD showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  @Get(path: '/v1/showPageAvailable/{showCrid}/{language}')
  Future<chopper.Response<SpaResponse>>
      _v1ShowPageAvailableShowCridLanguageGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Path('showCrid') required String? showCrid,
    @Path('language') required String? language,
    @Query('cityId') int? cityId,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has at least one VOD or one OTT or one EST showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  Future<chopper.Response<SpaResponse>> v2ShowPageAvailableShowCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? showCrid,
    required String? language,
    int? cityId,
    bool? mergingOn,
    String? includeExternalProvider,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SpaResponse, () => SpaResponse.fromJsonFactory);

    return _v2ShowPageAvailableShowCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        showCrid: showCrid,
        language: language,
        cityId: cityId,
        mergingOn: mergingOn,
        includeExternalProvider: includeExternalProvider,
        cacheControl: cacheControl);
  }

  ///This endpoint accepts VOD show crid or linear show crid and returns whether the given show crid has at least one VOD or one OTT or one EST showPage available for the user.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param showCrid Show's crid.
  ///@param language Language in ISO639-1
  ///@param cityId City id linked with given customerId
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeExternalProvider external provider whose content has to be included
  @Get(path: '/v2/showPageAvailable/{showCrid}/{language}')
  Future<chopper.Response<SpaResponse>>
      _v2ShowPageAvailableShowCridLanguageGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Path('showCrid') required String? showCrid,
    @Path('language') required String? language,
    @Query('cityId') int? cityId,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeExternalProvider') String? includeExternalProvider,
    @Header('Cache-Control') String? cacheControl,
  });

  ///This endpoint basically calculates the seed episode for the given show. Seed episode are always calculated within sources of the same channel and applies only for linear sources. VOD contents are ignored. This endpoint basically uses Most Relevant Episode Logic underneath it.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param crid Show's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param channelId Channel id of the source.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  Future<chopper.Response<RreResponse>>
      v1ResolveRecordableEpisodeCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required String? crid,
    required String? language,
    required String? country,
    required String? channelId,
    int? cityId,
    int? replayOptedInTime,
    bool? mergingOn,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RreResponse, () => RreResponse.fromJsonFactory);

    return _v1ResolveRecordableEpisodeCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        crid: crid,
        language: language,
        country: country,
        channelId: channelId,
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        cacheControl: cacheControl);
  }

  ///This endpoint basically calculates the seed episode for the given show. Seed episode are always calculated within sources of the same channel and applies only for linear sources. VOD contents are ignored. This endpoint basically uses Most Relevant Episode Logic underneath it.
  ///@param X-dev Custom header containing the device id
  ///@param X-Cus Custom HTTP header containing the customer number. If x-entitlements-token is not provided, this header is required.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param crid Show's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param channelId Channel id of the source.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  @Get(path: '/v1/resolveRecordableEpisode/{crid}/{language}')
  Future<chopper.Response<RreResponse>>
      _v1ResolveRecordableEpisodeCridLanguageGet({
    @Header('X-dev') String? xDev,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Path('crid') required String? crid,
    @Path('language') required String? language,
    @Query('country') required String? country,
    @Query('channelId') required String? channelId,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('mergingOn') bool? mergingOn,
    @Header('Cache-Control') String? cacheControl,
  });

  ///GET /recordingSources endpoint basically retrieves various channel sources of a series (or) title that can be recorded. The information provided by this endpoint will help the UI to overlay information indicating the available sources to record. Customer can choose preferred source to be recorded from the returned list
  ///@param X-dev Custom header containing the device id
  ///@param X-cus Custom HTTP header containing the customer number.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param type Indication of what type of crid is passed
  ///@param crid Show's or title's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeSeedEvent boolean flag indicating to return seedEvent information along with the existing response
  Future<chopper.Response<RecordingSourcesResponse>>
      v1RecordingSourcesTypeCridLanguageGet({
    String? xDev,
    String? xCus = 'X-Cus',
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? xPickerServiceExplicitLogging,
    required enums.V1RecordingSourcesTypeCridLanguageGetType? type,
    required String? crid,
    required String? language,
    required String? country,
    enums.MaxRes? maxRes,
    int? cityId,
    int? replayOptedInTime,
    bool? mergingOn,
    bool? includeSeedEvent,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(RecordingSourcesResponse,
        () => RecordingSourcesResponse.fromJsonFactory);

    return _v1RecordingSourcesTypeCridLanguageGet(
        xDev: xDev,
        xCus: xCus,
        xEntitlementsToken: xEntitlementsToken,
        xPickerServiceExplicitLogging: xPickerServiceExplicitLogging,
        type: enums.$V1RecordingSourcesTypeCridLanguageGetTypeMap[type]
            ?.toString(),
        crid: crid,
        language: language,
        country: country,
        maxRes: enums.$MaxResMap[maxRes]?.toString(),
        cityId: cityId,
        replayOptedInTime: replayOptedInTime,
        mergingOn: mergingOn,
        includeSeedEvent: includeSeedEvent,
        cacheControl: cacheControl);
  }

  ///GET /recordingSources endpoint basically retrieves various channel sources of a series (or) title that can be recorded. The information provided by this endpoint will help the UI to overlay information indicating the available sources to record. Customer can choose preferred source to be recorded from the returned list
  ///@param X-dev Custom header containing the device id
  ///@param X-cus Custom HTTP header containing the customer number.
  ///@param x-entitlements-token Header with entitlements token from purchase-service. If not provided, X-Cus header is mandatory to make proper fallback for entitlements
  ///@param X-PickerService-Explicit-Logging ONLY for debugging.  If set to true, then logs from below INFO will appear on INFO level for Picker-Service components.
  ///@param type Indication of what type of crid is passed
  ///@param crid Show's or title's crid.
  ///@param language Language in ISO639-1
  ///@param country Country in ISO3166
  ///@param maxRes Highest possible maxResolution.
  ///@param cityId City id linked with given customerId
  ///@param replayOptedInTime Date of starting period of replay opt-in, given in Epoch timestamp in seconds.
  ///@param mergingOn Parameter to indicate whether merging has to be done by picker service
  ///@param includeSeedEvent boolean flag indicating to return seedEvent information along with the existing response
  @Get(path: '/v1/recordingSources/{type}/{crid}/{language}')
  Future<chopper.Response<RecordingSourcesResponse>>
      _v1RecordingSourcesTypeCridLanguageGet({
    @Header('X-dev') String? xDev,
    @Header('X-cus') String? xCus = 'X-Cus',
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('X-PickerService-Explicit-Logging')
        String? xPickerServiceExplicitLogging,
    @Path('type') required String? type,
    @Path('crid') required String? crid,
    @Path('language') required String? language,
    @Query('country') required String? country,
    @Query('maxRes') String? maxRes,
    @Query('cityId') int? cityId,
    @Query('replayOptedInTime') int? replayOptedInTime,
    @Query('mergingOn') bool? mergingOn,
    @Query('includeSeedEvent') bool? includeSeedEvent,
    @Header('Cache-Control') String? cacheControl,
  });
}

@JsonSerializable(explicitToJson: true)
class KrakenError {
  KrakenError({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
    this.allErrors,
    this.correlationId,
  });

  factory KrakenError.fromJson(Map<String, dynamic> json) =>
      _$KrakenErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  @JsonKey(name: 'allErrors', includeIfNull: false, defaultValue: <String>[])
  final List<String>? allErrors;
  @JsonKey(name: 'correlationId', includeIfNull: false, defaultValue: '')
  final String? correlationId;
  static const fromJsonFactory = _$KrakenErrorFromJson;
  static const toJsonFactory = _$KrakenErrorToJson;
  Map<String, dynamic> toJson() => _$KrakenErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KrakenError &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality()
                    .equals(other.details, details)) &&
            (identical(other.allErrors, allErrors) ||
                const DeepCollectionEquality()
                    .equals(other.allErrors, allErrors)) &&
            (identical(other.correlationId, correlationId) ||
                const DeepCollectionEquality()
                    .equals(other.correlationId, correlationId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      const DeepCollectionEquality().hash(allErrors) ^
      const DeepCollectionEquality().hash(correlationId) ^
      runtimeType.hashCode;
}

extension $KrakenErrorExtension on KrakenError {
  KrakenError copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details,
      List<String>? allErrors,
      String? correlationId}) {
    return KrakenError(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details,
        allErrors: allErrors ?? this.allErrors,
        correlationId: correlationId ?? this.correlationId);
  }

  KrakenError copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details,
      Wrapped<List<String>?>? allErrors,
      Wrapped<String?>? correlationId}) {
    return KrakenError(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details),
        allErrors: (allErrors != null ? allErrors.value : this.allErrors),
        correlationId:
            (correlationId != null ? correlationId.value : this.correlationId));
  }
}

@JsonSerializable(explicitToJson: true)
class SeasonResponse {
  SeasonResponse({
    required this.id,
    required this.title,
    this.synopsis,
    this.image,
    this.landscape,
    this.landscapeTile,
    required this.totalEpisodes,
    this.type,
    this.season,
    this.episodes,
    this.imageVersion,
    this.genres,
  });

  factory SeasonResponse.fromJson(Map<String, dynamic> json) =>
      _$SeasonResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'landscape', includeIfNull: false, defaultValue: '')
  final String? landscape;
  @JsonKey(name: 'landscapeTile', includeIfNull: false, defaultValue: '')
  final String? landscapeTile;
  @JsonKey(name: 'totalEpisodes', includeIfNull: false)
  final int totalEpisodes;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'season', includeIfNull: false)
  final int? season;
  @JsonKey(name: 'episodes', includeIfNull: false)
  final EpisodeResponse? episodes;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  static const fromJsonFactory = _$SeasonResponseFromJson;
  static const toJsonFactory = _$SeasonResponseToJson;
  Map<String, dynamic> toJson() => _$SeasonResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeasonResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.landscape, landscape) ||
                const DeepCollectionEquality()
                    .equals(other.landscape, landscape)) &&
            (identical(other.landscapeTile, landscapeTile) ||
                const DeepCollectionEquality()
                    .equals(other.landscapeTile, landscapeTile)) &&
            (identical(other.totalEpisodes, totalEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.totalEpisodes, totalEpisodes)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(landscape) ^
      const DeepCollectionEquality().hash(landscapeTile) ^
      const DeepCollectionEquality().hash(totalEpisodes) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(genres) ^
      runtimeType.hashCode;
}

extension $SeasonResponseExtension on SeasonResponse {
  SeasonResponse copyWith(
      {String? id,
      String? title,
      String? synopsis,
      String? image,
      String? landscape,
      String? landscapeTile,
      int? totalEpisodes,
      String? type,
      int? season,
      EpisodeResponse? episodes,
      String? imageVersion,
      List<String>? genres}) {
    return SeasonResponse(
        id: id ?? this.id,
        title: title ?? this.title,
        synopsis: synopsis ?? this.synopsis,
        image: image ?? this.image,
        landscape: landscape ?? this.landscape,
        landscapeTile: landscapeTile ?? this.landscapeTile,
        totalEpisodes: totalEpisodes ?? this.totalEpisodes,
        type: type ?? this.type,
        season: season ?? this.season,
        episodes: episodes ?? this.episodes,
        imageVersion: imageVersion ?? this.imageVersion,
        genres: genres ?? this.genres);
  }

  SeasonResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? image,
      Wrapped<String?>? landscape,
      Wrapped<String?>? landscapeTile,
      Wrapped<int>? totalEpisodes,
      Wrapped<String?>? type,
      Wrapped<int?>? season,
      Wrapped<EpisodeResponse?>? episodes,
      Wrapped<String?>? imageVersion,
      Wrapped<List<String>?>? genres}) {
    return SeasonResponse(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        image: (image != null ? image.value : this.image),
        landscape: (landscape != null ? landscape.value : this.landscape),
        landscapeTile:
            (landscapeTile != null ? landscapeTile.value : this.landscapeTile),
        totalEpisodes:
            (totalEpisodes != null ? totalEpisodes.value : this.totalEpisodes),
        type: (type != null ? type.value : this.type),
        season: (season != null ? season.value : this.season),
        episodes: (episodes != null ? episodes.value : this.episodes),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        genres: (genres != null ? genres.value : this.genres));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodeResponse {
  EpisodeResponse({
    required this.id,
    this.episode,
    required this.title,
    this.image,
    this.landscape,
    this.landscapeTile,
    this.ageRating,
    this.synopsis,
    required this.isAdult,
    this.isWatchedCompletely,
    this.replayContainsAdult,
    this.replayMinAge,
    this.bookmark,
    this.duration,
    this.broadcastDate,
    this.type,
    this.isReplay,
    this.isRecording,
    this.eventId,
    this.channelId,
    required this.est,
    this.replayAvailable,
    this.vod,
    this.imageVersion,
  });

  factory EpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodeResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'episode', includeIfNull: false)
  final int? episode;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'landscape', includeIfNull: false, defaultValue: '')
  final String? landscape;
  @JsonKey(name: 'landscapeTile', includeIfNull: false, defaultValue: '')
  final String? landscapeTile;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'isWatchedCompletely', includeIfNull: false)
  final bool? isWatchedCompletely;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int? duration;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'isRecording', includeIfNull: false)
  final bool? isRecording;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'est', includeIfNull: false, defaultValue: <EstResponse>[])
  final List<EstResponse> est;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'vod', includeIfNull: false)
  final VodResponse? vod;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodeResponseFromJson;
  static const toJsonFactory = _$EpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodeResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodeResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.landscape, landscape) ||
                const DeepCollectionEquality()
                    .equals(other.landscape, landscape)) &&
            (identical(other.landscapeTile, landscapeTile) ||
                const DeepCollectionEquality()
                    .equals(other.landscapeTile, landscapeTile)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.isWatchedCompletely, isWatchedCompletely) ||
                const DeepCollectionEquality()
                    .equals(other.isWatchedCompletely, isWatchedCompletely)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.est, est) ||
                const DeepCollectionEquality().equals(other.est, est)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.vod, vod) ||
                const DeepCollectionEquality().equals(other.vod, vod)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(landscape) ^
      const DeepCollectionEquality().hash(landscapeTile) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(isWatchedCompletely) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(est) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(vod) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodeResponseExtension on EpisodeResponse {
  EpisodeResponse copyWith(
      {String? id,
      int? episode,
      String? title,
      String? image,
      String? landscape,
      String? landscapeTile,
      String? ageRating,
      String? synopsis,
      bool? isAdult,
      bool? isWatchedCompletely,
      bool? replayContainsAdult,
      int? replayMinAge,
      int? bookmark,
      int? duration,
      String? broadcastDate,
      String? type,
      bool? isReplay,
      bool? isRecording,
      String? eventId,
      String? channelId,
      List<EstResponse>? est,
      bool? replayAvailable,
      VodResponse? vod,
      String? imageVersion}) {
    return EpisodeResponse(
        id: id ?? this.id,
        episode: episode ?? this.episode,
        title: title ?? this.title,
        image: image ?? this.image,
        landscape: landscape ?? this.landscape,
        landscapeTile: landscapeTile ?? this.landscapeTile,
        ageRating: ageRating ?? this.ageRating,
        synopsis: synopsis ?? this.synopsis,
        isAdult: isAdult ?? this.isAdult,
        isWatchedCompletely: isWatchedCompletely ?? this.isWatchedCompletely,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        bookmark: bookmark ?? this.bookmark,
        duration: duration ?? this.duration,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        type: type ?? this.type,
        isReplay: isReplay ?? this.isReplay,
        isRecording: isRecording ?? this.isRecording,
        eventId: eventId ?? this.eventId,
        channelId: channelId ?? this.channelId,
        est: est ?? this.est,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        vod: vod ?? this.vod,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodeResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<int?>? episode,
      Wrapped<String>? title,
      Wrapped<String?>? image,
      Wrapped<String?>? landscape,
      Wrapped<String?>? landscapeTile,
      Wrapped<String?>? ageRating,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? isAdult,
      Wrapped<bool?>? isWatchedCompletely,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<int?>? bookmark,
      Wrapped<int?>? duration,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? type,
      Wrapped<bool?>? isReplay,
      Wrapped<bool?>? isRecording,
      Wrapped<String?>? eventId,
      Wrapped<String?>? channelId,
      Wrapped<List<EstResponse>>? est,
      Wrapped<bool?>? replayAvailable,
      Wrapped<VodResponse?>? vod,
      Wrapped<String?>? imageVersion}) {
    return EpisodeResponse(
        id: (id != null ? id.value : this.id),
        episode: (episode != null ? episode.value : this.episode),
        title: (title != null ? title.value : this.title),
        image: (image != null ? image.value : this.image),
        landscape: (landscape != null ? landscape.value : this.landscape),
        landscapeTile:
            (landscapeTile != null ? landscapeTile.value : this.landscapeTile),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        isWatchedCompletely: (isWatchedCompletely != null
            ? isWatchedCompletely.value
            : this.isWatchedCompletely),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        duration: (duration != null ? duration.value : this.duration),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        type: (type != null ? type.value : this.type),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        est: (est != null ? est.value : this.est),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        vod: (vod != null ? vod.value : this.vod),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class VodResponse {
  VodResponse({
    required this.type,
    this.entitlemendEnd,
    this.entitlementState,
  });

  factory VodResponse.fromJson(Map<String, dynamic> json) =>
      _$VodResponseFromJson(json);

  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: vodResponseTypeToJson,
    fromJson: vodResponseTypeFromJson,
  )
  final enums.VodResponseType type;
  @JsonKey(name: 'entitlemendEnd', includeIfNull: false, defaultValue: '')
  final String? entitlemendEnd;
  @JsonKey(
    name: 'entitlementState',
    includeIfNull: false,
    toJson: vodResponseEntitlementStateToJson,
    fromJson: vodResponseEntitlementStateFromJson,
  )
  final enums.VodResponseEntitlementState? entitlementState;
  static const fromJsonFactory = _$VodResponseFromJson;
  static const toJsonFactory = _$VodResponseToJson;
  Map<String, dynamic> toJson() => _$VodResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodResponse &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlemendEnd, entitlemendEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlemendEnd, entitlemendEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlemendEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      runtimeType.hashCode;
}

extension $VodResponseExtension on VodResponse {
  VodResponse copyWith(
      {enums.VodResponseType? type,
      String? entitlemendEnd,
      enums.VodResponseEntitlementState? entitlementState}) {
    return VodResponse(
        type: type ?? this.type,
        entitlemendEnd: entitlemendEnd ?? this.entitlemendEnd,
        entitlementState: entitlementState ?? this.entitlementState);
  }

  VodResponse copyWithWrapped(
      {Wrapped<enums.VodResponseType>? type,
      Wrapped<String?>? entitlemendEnd,
      Wrapped<enums.VodResponseEntitlementState?>? entitlementState}) {
    return VodResponse(
        type: (type != null ? type.value : this.type),
        entitlemendEnd: (entitlemendEnd != null
            ? entitlemendEnd.value
            : this.entitlemendEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelEventDetailResponse {
  ChannelEventDetailResponse({
    required this.channelId,
    required this.eventId,
    required this.contentType,
    this.broadcastDate,
    this.broadcastEndDate,
    this.isRecording,
    this.isReplay,
    this.bookmark,
  });

  factory ChannelEventDetailResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelEventDetailResponseFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'broadcastEndDate', includeIfNull: false, defaultValue: '')
  final String? broadcastEndDate;
  @JsonKey(name: 'isRecording', includeIfNull: false)
  final bool? isRecording;
  @JsonKey(name: 'isReplay', includeIfNull: false)
  final bool? isReplay;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  static const fromJsonFactory = _$ChannelEventDetailResponseFromJson;
  static const toJsonFactory = _$ChannelEventDetailResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelEventDetailResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelEventDetailResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.broadcastEndDate, broadcastEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastEndDate, broadcastEndDate)) &&
            (identical(other.isRecording, isRecording) ||
                const DeepCollectionEquality()
                    .equals(other.isRecording, isRecording)) &&
            (identical(other.isReplay, isReplay) ||
                const DeepCollectionEquality()
                    .equals(other.isReplay, isReplay)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(broadcastEndDate) ^
      const DeepCollectionEquality().hash(isRecording) ^
      const DeepCollectionEquality().hash(isReplay) ^
      const DeepCollectionEquality().hash(bookmark) ^
      runtimeType.hashCode;
}

extension $ChannelEventDetailResponseExtension on ChannelEventDetailResponse {
  ChannelEventDetailResponse copyWith(
      {String? channelId,
      String? eventId,
      String? contentType,
      String? broadcastDate,
      String? broadcastEndDate,
      bool? isRecording,
      bool? isReplay,
      int? bookmark}) {
    return ChannelEventDetailResponse(
        channelId: channelId ?? this.channelId,
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        broadcastEndDate: broadcastEndDate ?? this.broadcastEndDate,
        isRecording: isRecording ?? this.isRecording,
        isReplay: isReplay ?? this.isReplay,
        bookmark: bookmark ?? this.bookmark);
  }

  ChannelEventDetailResponse copyWithWrapped(
      {Wrapped<String>? channelId,
      Wrapped<String>? eventId,
      Wrapped<String>? contentType,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? broadcastEndDate,
      Wrapped<bool?>? isRecording,
      Wrapped<bool?>? isReplay,
      Wrapped<int?>? bookmark}) {
    return ChannelEventDetailResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        broadcastEndDate: (broadcastEndDate != null
            ? broadcastEndDate.value
            : this.broadcastEndDate),
        isRecording:
            (isRecording != null ? isRecording.value : this.isRecording),
        isReplay: (isReplay != null ? isReplay.value : this.isReplay),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark));
  }
}

@JsonSerializable(explicitToJson: true)
class SimpleChannelResponse {
  SimpleChannelResponse({
    this.id,
    this.name,
  });

  factory SimpleChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$SimpleChannelResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$SimpleChannelResponseFromJson;
  static const toJsonFactory = _$SimpleChannelResponseToJson;
  Map<String, dynamic> toJson() => _$SimpleChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimpleChannelResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $SimpleChannelResponseExtension on SimpleChannelResponse {
  SimpleChannelResponse copyWith({String? id, String? name}) {
    return SimpleChannelResponse(id: id ?? this.id, name: name ?? this.name);
  }

  SimpleChannelResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<String?>? name}) {
    return SimpleChannelResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class EstResponse {
  EstResponse({
    required this.minPrice,
    required this.minPriceDisplay,
    required this.currency,
    required this.videoHost,
    required this.videoUrl,
  });

  factory EstResponse.fromJson(Map<String, dynamic> json) =>
      _$EstResponseFromJson(json);

  @JsonKey(name: 'minPrice', includeIfNull: false, defaultValue: '')
  final String minPrice;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  static const fromJsonFactory = _$EstResponseFromJson;
  static const toJsonFactory = _$EstResponseToJson;
  Map<String, dynamic> toJson() => _$EstResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EstResponse &&
            (identical(other.minPrice, minPrice) ||
                const DeepCollectionEquality()
                    .equals(other.minPrice, minPrice)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(minPrice) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      runtimeType.hashCode;
}

extension $EstResponseExtension on EstResponse {
  EstResponse copyWith(
      {String? minPrice,
      String? minPriceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl}) {
    return EstResponse(
        minPrice: minPrice ?? this.minPrice,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl);
  }

  EstResponse copyWithWrapped(
      {Wrapped<String>? minPrice,
      Wrapped<String>? minPriceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl}) {
    return EstResponse(
        minPrice: (minPrice != null ? minPrice.value : this.minPrice),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoLinearResponse {
  TaaoLinearResponse({
    this.viewProgress,
    required this.sourceType,
    required this.source,
  });

  factory TaaoLinearResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoLinearResponseFromJson(json);

  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final LinearSourceResponse source;
  static const fromJsonFactory = _$TaaoLinearResponseFromJson;
  static const toJsonFactory = _$TaaoLinearResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoLinearResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoLinearResponse &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoLinearResponseExtension on TaaoLinearResponse {
  TaaoLinearResponse copyWith(
      {ViewProgressResponse? viewProgress,
      enums.SourceTypeResponse? sourceType,
      LinearSourceResponse? source}) {
    return TaaoLinearResponse(
        viewProgress: viewProgress ?? this.viewProgress,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoLinearResponse copyWithWrapped(
      {Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<LinearSourceResponse>? source}) {
    return TaaoLinearResponse(
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoRecordingResponse {
  TaaoRecordingResponse({
    this.viewProgress,
    required this.sourceType,
    required this.source,
  });

  factory TaaoRecordingResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoRecordingResponseFromJson(json);

  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final RecordingSourceResponse source;
  static const fromJsonFactory = _$TaaoRecordingResponseFromJson;
  static const toJsonFactory = _$TaaoRecordingResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoRecordingResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoRecordingResponse &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoRecordingResponseExtension on TaaoRecordingResponse {
  TaaoRecordingResponse copyWith(
      {ViewProgressResponse? viewProgress,
      enums.SourceTypeResponse? sourceType,
      RecordingSourceResponse? source}) {
    return TaaoRecordingResponse(
        viewProgress: viewProgress ?? this.viewProgress,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoRecordingResponse copyWithWrapped(
      {Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<RecordingSourceResponse>? source}) {
    return TaaoRecordingResponse(
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoVodResponse {
  TaaoVodResponse({
    this.viewProgress,
    required this.sourceType,
    required this.source,
  });

  factory TaaoVodResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoVodResponseFromJson(json);

  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final VodSourceResponse source;
  static const fromJsonFactory = _$TaaoVodResponseFromJson;
  static const toJsonFactory = _$TaaoVodResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoVodResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoVodResponse &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoVodResponseExtension on TaaoVodResponse {
  TaaoVodResponse copyWith(
      {ViewProgressResponse? viewProgress,
      enums.SourceTypeResponse? sourceType,
      VodSourceResponse? source}) {
    return TaaoVodResponse(
        viewProgress: viewProgress ?? this.viewProgress,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoVodResponse copyWithWrapped(
      {Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<VodSourceResponse>? source}) {
    return TaaoVodResponse(
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class TaaoOttResponse {
  TaaoOttResponse({
    required this.sourceType,
    required this.source,
  });

  factory TaaoOttResponse.fromJson(Map<String, dynamic> json) =>
      _$TaaoOttResponseFromJson(json);

  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final OttSourceResponse source;
  static const fromJsonFactory = _$TaaoOttResponseFromJson;
  static const toJsonFactory = _$TaaoOttResponseToJson;
  Map<String, dynamic> toJson() => _$TaaoOttResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaaoOttResponse &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $TaaoOttResponseExtension on TaaoOttResponse {
  TaaoOttResponse copyWith(
      {enums.SourceTypeResponse? sourceType, OttSourceResponse? source}) {
    return TaaoOttResponse(
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  TaaoOttResponse copyWithWrapped(
      {Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<OttSourceResponse>? source}) {
    return TaaoOttResponse(
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class ViewProgressResponse {
  ViewProgressResponse({
    required this.viewState,
    required this.position,
    required this.duration,
  });

  factory ViewProgressResponse.fromJson(Map<String, dynamic> json) =>
      _$ViewProgressResponseFromJson(json);

  @JsonKey(
    name: 'viewState',
    includeIfNull: false,
    toJson: viewProgressResponseViewStateToJson,
    fromJson: viewProgressResponseViewStateFromJson,
  )
  final enums.ViewProgressResponseViewState viewState;
  @JsonKey(name: 'position', includeIfNull: false)
  final int position;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  static const fromJsonFactory = _$ViewProgressResponseFromJson;
  static const toJsonFactory = _$ViewProgressResponseToJson;
  Map<String, dynamic> toJson() => _$ViewProgressResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ViewProgressResponse &&
            (identical(other.viewState, viewState) ||
                const DeepCollectionEquality()
                    .equals(other.viewState, viewState)) &&
            (identical(other.position, position) ||
                const DeepCollectionEquality()
                    .equals(other.position, position)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(viewState) ^
      const DeepCollectionEquality().hash(position) ^
      const DeepCollectionEquality().hash(duration) ^
      runtimeType.hashCode;
}

extension $ViewProgressResponseExtension on ViewProgressResponse {
  ViewProgressResponse copyWith(
      {enums.ViewProgressResponseViewState? viewState,
      int? position,
      int? duration}) {
    return ViewProgressResponse(
        viewState: viewState ?? this.viewState,
        position: position ?? this.position,
        duration: duration ?? this.duration);
  }

  ViewProgressResponse copyWithWrapped(
      {Wrapped<enums.ViewProgressResponseViewState>? viewState,
      Wrapped<int>? position,
      Wrapped<int>? duration}) {
    return ViewProgressResponse(
        viewState: (viewState != null ? viewState.value : this.viewState),
        position: (position != null ? position.value : this.position),
        duration: (duration != null ? duration.value : this.duration));
  }
}

@JsonSerializable(explicitToJson: true)
class LinearSourceResponse {
  LinearSourceResponse({
    required this.titleId,
    required this.eventId,
    required this.channel,
    required this.broadcastDate,
    required this.duration,
    this.eventReplay,
    this.imageVersion,
    this.audioQuality,
    this.hasLiveTVOTT,
  });

  factory LinearSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$LinearSourceResponseFromJson(json);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'channel', includeIfNull: false)
  final ChannelResponse channel;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'eventReplay', includeIfNull: false)
  final EventReplayResponse? eventReplay;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'hasLiveTVOTT', includeIfNull: false)
  final bool? hasLiveTVOTT;
  static const fromJsonFactory = _$LinearSourceResponseFromJson;
  static const toJsonFactory = _$LinearSourceResponseToJson;
  Map<String, dynamic> toJson() => _$LinearSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LinearSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.eventReplay, eventReplay) ||
                const DeepCollectionEquality()
                    .equals(other.eventReplay, eventReplay)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.hasLiveTVOTT, hasLiveTVOTT) ||
                const DeepCollectionEquality()
                    .equals(other.hasLiveTVOTT, hasLiveTVOTT)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(eventReplay) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(hasLiveTVOTT) ^
      runtimeType.hashCode;
}

extension $LinearSourceResponseExtension on LinearSourceResponse {
  LinearSourceResponse copyWith(
      {String? titleId,
      String? eventId,
      ChannelResponse? channel,
      String? broadcastDate,
      int? duration,
      EventReplayResponse? eventReplay,
      String? imageVersion,
      String? audioQuality,
      bool? hasLiveTVOTT}) {
    return LinearSourceResponse(
        titleId: titleId ?? this.titleId,
        eventId: eventId ?? this.eventId,
        channel: channel ?? this.channel,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        duration: duration ?? this.duration,
        eventReplay: eventReplay ?? this.eventReplay,
        imageVersion: imageVersion ?? this.imageVersion,
        audioQuality: audioQuality ?? this.audioQuality,
        hasLiveTVOTT: hasLiveTVOTT ?? this.hasLiveTVOTT);
  }

  LinearSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? eventId,
      Wrapped<ChannelResponse>? channel,
      Wrapped<String>? broadcastDate,
      Wrapped<int>? duration,
      Wrapped<EventReplayResponse?>? eventReplay,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? audioQuality,
      Wrapped<bool?>? hasLiveTVOTT}) {
    return LinearSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        eventId: (eventId != null ? eventId.value : this.eventId),
        channel: (channel != null ? channel.value : this.channel),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        duration: (duration != null ? duration.value : this.duration),
        eventReplay:
            (eventReplay != null ? eventReplay.value : this.eventReplay),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        hasLiveTVOTT:
            (hasLiveTVOTT != null ? hasLiveTVOTT.value : this.hasLiveTVOTT));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingSourceResponse {
  RecordingSourceResponse({
    required this.titleId,
    required this.recordingId,
    this.cpeId,
    required this.broadcastDate,
    required this.duration,
    this.technicalDuration,
    required this.channel,
    this.containsAdult,
    this.imageVersion,
    this.audioQuality,
    this.isOttBlackout,
    this.restricted,
    this.resolution,
    this.recordingState,
  });

  factory RecordingSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingSourceResponseFromJson(json);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String recordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'technicalDuration', includeIfNull: false)
  final int? technicalDuration;
  @JsonKey(name: 'channel', includeIfNull: false)
  final ChannelResponse channel;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingSourceResponseRecordingStateToJson,
    fromJson: recordingSourceResponseRecordingStateFromJson,
  )
  final enums.RecordingSourceResponseRecordingState? recordingState;
  static const fromJsonFactory = _$RecordingSourceResponseFromJson;
  static const toJsonFactory = _$RecordingSourceResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.technicalDuration, technicalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.technicalDuration, technicalDuration)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.isOttBlackout, isOttBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isOttBlackout, isOttBlackout)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(technicalDuration) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(recordingState) ^
      runtimeType.hashCode;
}

extension $RecordingSourceResponseExtension on RecordingSourceResponse {
  RecordingSourceResponse copyWith(
      {String? titleId,
      String? recordingId,
      String? cpeId,
      String? broadcastDate,
      int? duration,
      int? technicalDuration,
      ChannelResponse? channel,
      bool? containsAdult,
      String? imageVersion,
      String? audioQuality,
      bool? isOttBlackout,
      bool? restricted,
      String? resolution,
      enums.RecordingSourceResponseRecordingState? recordingState}) {
    return RecordingSourceResponse(
        titleId: titleId ?? this.titleId,
        recordingId: recordingId ?? this.recordingId,
        cpeId: cpeId ?? this.cpeId,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        duration: duration ?? this.duration,
        technicalDuration: technicalDuration ?? this.technicalDuration,
        channel: channel ?? this.channel,
        containsAdult: containsAdult ?? this.containsAdult,
        imageVersion: imageVersion ?? this.imageVersion,
        audioQuality: audioQuality ?? this.audioQuality,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout,
        restricted: restricted ?? this.restricted,
        resolution: resolution ?? this.resolution,
        recordingState: recordingState ?? this.recordingState);
  }

  RecordingSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? recordingId,
      Wrapped<String?>? cpeId,
      Wrapped<String>? broadcastDate,
      Wrapped<int>? duration,
      Wrapped<int?>? technicalDuration,
      Wrapped<ChannelResponse>? channel,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? audioQuality,
      Wrapped<bool?>? isOttBlackout,
      Wrapped<bool?>? restricted,
      Wrapped<String?>? resolution,
      Wrapped<enums.RecordingSourceResponseRecordingState?>? recordingState}) {
    return RecordingSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        duration: (duration != null ? duration.value : this.duration),
        technicalDuration: (technicalDuration != null
            ? technicalDuration.value
            : this.technicalDuration),
        channel: (channel != null ? channel.value : this.channel),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout),
        restricted: (restricted != null ? restricted.value : this.restricted),
        resolution: (resolution != null ? resolution.value : this.resolution),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState));
  }
}

@JsonSerializable(explicitToJson: true)
class VodSourceResponse {
  VodSourceResponse({
    required this.titleId,
    required this.type,
    this.entitlementEnd,
    required this.entitlementState,
    required this.brandingProviderId,
    this.priceDisplay,
    this.minPriceDisplay,
    this.currency,
    required this.isGoPlayable,
    required this.duration,
    this.audioQuality,
    this.imageVersion,
  });

  factory VodSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$VodSourceResponseFromJson(json);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: vodSourceResponseTypeToJson,
    fromJson: vodSourceResponseTypeFromJson,
  )
  final enums.VodSourceResponseType type;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String entitlementState;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String brandingProviderId;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$VodSourceResponseFromJson;
  static const toJsonFactory = _$VodSourceResponseToJson;
  Map<String, dynamic> toJson() => _$VodSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $VodSourceResponseExtension on VodSourceResponse {
  VodSourceResponse copyWith(
      {String? titleId,
      enums.VodSourceResponseType? type,
      String? entitlementEnd,
      String? entitlementState,
      String? brandingProviderId,
      String? priceDisplay,
      String? minPriceDisplay,
      String? currency,
      bool? isGoPlayable,
      int? duration,
      String? audioQuality,
      String? imageVersion}) {
    return VodSourceResponse(
        titleId: titleId ?? this.titleId,
        type: type ?? this.type,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        duration: duration ?? this.duration,
        audioQuality: audioQuality ?? this.audioQuality,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  VodSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<enums.VodSourceResponseType>? type,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String>? entitlementState,
      Wrapped<String>? brandingProviderId,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? currency,
      Wrapped<bool>? isGoPlayable,
      Wrapped<int>? duration,
      Wrapped<String?>? audioQuality,
      Wrapped<String?>? imageVersion}) {
    return VodSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        type: (type != null ? type.value : this.type),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        duration: (duration != null ? duration.value : this.duration),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerVodSourceResponse {
  EpisodePickerVodSourceResponse({
    this.goDownloadable,
    required this.titleId,
    required this.type,
    this.entitlementEnd,
    required this.entitlementState,
    required this.brandingProviderId,
    this.priceDisplay,
    this.minPriceDisplay,
    this.currency,
    required this.isGoPlayable,
    required this.duration,
    this.audioQuality,
    this.imageVersion,
  });

  factory EpisodePickerVodSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerVodSourceResponseFromJson(json);

  @JsonKey(name: 'goDownloadable', includeIfNull: false)
  final bool? goDownloadable;
  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: episodePickerVodSourceResponseTypeToJson,
    fromJson: episodePickerVodSourceResponseTypeFromJson,
  )
  final enums.EpisodePickerVodSourceResponseType type;
  @JsonKey(name: 'entitlementEnd', includeIfNull: false, defaultValue: '')
  final String? entitlementEnd;
  @JsonKey(name: 'entitlementState', includeIfNull: false, defaultValue: '')
  final String entitlementState;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String brandingProviderId;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String? priceDisplay;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String? minPriceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'duration', includeIfNull: false)
  final int duration;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodePickerVodSourceResponseFromJson;
  static const toJsonFactory = _$EpisodePickerVodSourceResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerVodSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerVodSourceResponse &&
            (identical(other.goDownloadable, goDownloadable) ||
                const DeepCollectionEquality()
                    .equals(other.goDownloadable, goDownloadable)) &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.entitlementEnd, entitlementEnd) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementEnd, entitlementEnd)) &&
            (identical(other.entitlementState, entitlementState) ||
                const DeepCollectionEquality()
                    .equals(other.entitlementState, entitlementState)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(goDownloadable) ^
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(entitlementEnd) ^
      const DeepCollectionEquality().hash(entitlementState) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodePickerVodSourceResponseExtension
    on EpisodePickerVodSourceResponse {
  EpisodePickerVodSourceResponse copyWith(
      {bool? goDownloadable,
      String? titleId,
      enums.EpisodePickerVodSourceResponseType? type,
      String? entitlementEnd,
      String? entitlementState,
      String? brandingProviderId,
      String? priceDisplay,
      String? minPriceDisplay,
      String? currency,
      bool? isGoPlayable,
      int? duration,
      String? audioQuality,
      String? imageVersion}) {
    return EpisodePickerVodSourceResponse(
        goDownloadable: goDownloadable ?? this.goDownloadable,
        titleId: titleId ?? this.titleId,
        type: type ?? this.type,
        entitlementEnd: entitlementEnd ?? this.entitlementEnd,
        entitlementState: entitlementState ?? this.entitlementState,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        currency: currency ?? this.currency,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        duration: duration ?? this.duration,
        audioQuality: audioQuality ?? this.audioQuality,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodePickerVodSourceResponse copyWithWrapped(
      {Wrapped<bool?>? goDownloadable,
      Wrapped<String>? titleId,
      Wrapped<enums.EpisodePickerVodSourceResponseType>? type,
      Wrapped<String?>? entitlementEnd,
      Wrapped<String>? entitlementState,
      Wrapped<String>? brandingProviderId,
      Wrapped<String?>? priceDisplay,
      Wrapped<String?>? minPriceDisplay,
      Wrapped<String?>? currency,
      Wrapped<bool>? isGoPlayable,
      Wrapped<int>? duration,
      Wrapped<String?>? audioQuality,
      Wrapped<String?>? imageVersion}) {
    return EpisodePickerVodSourceResponse(
        goDownloadable: (goDownloadable != null
            ? goDownloadable.value
            : this.goDownloadable),
        titleId: (titleId != null ? titleId.value : this.titleId),
        type: (type != null ? type.value : this.type),
        entitlementEnd: (entitlementEnd != null
            ? entitlementEnd.value
            : this.entitlementEnd),
        entitlementState: (entitlementState != null
            ? entitlementState.value
            : this.entitlementState),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        duration: (duration != null ? duration.value : this.duration),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class OttSourceResponse {
  OttSourceResponse({
    required this.titleId,
    required this.minPriceDisplay,
    required this.priceDisplay,
    required this.currency,
    required this.videoHost,
    required this.videoUrl,
    required this.isEST,
    required this.brandingProviderId,
    this.audioQuality,
    this.imageVersion,
  });

  factory OttSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$OttSourceResponseFromJson(json);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'minPriceDisplay', includeIfNull: false, defaultValue: '')
  final String minPriceDisplay;
  @JsonKey(name: 'priceDisplay', includeIfNull: false, defaultValue: '')
  final String priceDisplay;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'videoHost', includeIfNull: false, defaultValue: '')
  final String videoHost;
  @JsonKey(name: 'videoUrl', includeIfNull: false, defaultValue: '')
  final String videoUrl;
  @JsonKey(name: 'isEST', includeIfNull: false)
  final bool isEST;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String brandingProviderId;
  @JsonKey(name: 'audioQuality', includeIfNull: false, defaultValue: '')
  final String? audioQuality;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$OttSourceResponseFromJson;
  static const toJsonFactory = _$OttSourceResponseToJson;
  Map<String, dynamic> toJson() => _$OttSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OttSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.minPriceDisplay, minPriceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.minPriceDisplay, minPriceDisplay)) &&
            (identical(other.priceDisplay, priceDisplay) ||
                const DeepCollectionEquality()
                    .equals(other.priceDisplay, priceDisplay)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.videoHost, videoHost) ||
                const DeepCollectionEquality()
                    .equals(other.videoHost, videoHost)) &&
            (identical(other.videoUrl, videoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.videoUrl, videoUrl)) &&
            (identical(other.isEST, isEST) ||
                const DeepCollectionEquality().equals(other.isEST, isEST)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.audioQuality, audioQuality) ||
                const DeepCollectionEquality()
                    .equals(other.audioQuality, audioQuality)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(minPriceDisplay) ^
      const DeepCollectionEquality().hash(priceDisplay) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(videoHost) ^
      const DeepCollectionEquality().hash(videoUrl) ^
      const DeepCollectionEquality().hash(isEST) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(audioQuality) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $OttSourceResponseExtension on OttSourceResponse {
  OttSourceResponse copyWith(
      {String? titleId,
      String? minPriceDisplay,
      String? priceDisplay,
      String? currency,
      String? videoHost,
      String? videoUrl,
      bool? isEST,
      String? brandingProviderId,
      String? audioQuality,
      String? imageVersion}) {
    return OttSourceResponse(
        titleId: titleId ?? this.titleId,
        minPriceDisplay: minPriceDisplay ?? this.minPriceDisplay,
        priceDisplay: priceDisplay ?? this.priceDisplay,
        currency: currency ?? this.currency,
        videoHost: videoHost ?? this.videoHost,
        videoUrl: videoUrl ?? this.videoUrl,
        isEST: isEST ?? this.isEST,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        audioQuality: audioQuality ?? this.audioQuality,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  OttSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? minPriceDisplay,
      Wrapped<String>? priceDisplay,
      Wrapped<String>? currency,
      Wrapped<String>? videoHost,
      Wrapped<String>? videoUrl,
      Wrapped<bool>? isEST,
      Wrapped<String>? brandingProviderId,
      Wrapped<String?>? audioQuality,
      Wrapped<String?>? imageVersion}) {
    return OttSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        minPriceDisplay: (minPriceDisplay != null
            ? minPriceDisplay.value
            : this.minPriceDisplay),
        priceDisplay:
            (priceDisplay != null ? priceDisplay.value : this.priceDisplay),
        currency: (currency != null ? currency.value : this.currency),
        videoHost: (videoHost != null ? videoHost.value : this.videoHost),
        videoUrl: (videoUrl != null ? videoUrl.value : this.videoUrl),
        isEST: (isEST != null ? isEST.value : this.isEST),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        audioQuality:
            (audioQuality != null ? audioQuality.value : this.audioQuality),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponse {
  ChannelResponse({
    required this.channelId,
    required this.channelName,
  });

  factory ChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String channelName;
  static const fromJsonFactory = _$ChannelResponseFromJson;
  static const toJsonFactory = _$ChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      runtimeType.hashCode;
}

extension $ChannelResponseExtension on ChannelResponse {
  ChannelResponse copyWith({String? channelId, String? channelName}) {
    return ChannelResponse(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName);
  }

  ChannelResponse copyWithWrapped(
      {Wrapped<String>? channelId, Wrapped<String>? channelName}) {
    return ChannelResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName));
  }
}

@JsonSerializable(explicitToJson: true)
class EventReplayResponse {
  EventReplayResponse({
    this.replayAvailabilityStart,
    this.replayAvailabilityEnd,
    this.replayContainsAdult,
    this.replayMinAge,
    required this.isGoPlayable,
    required this.displayAgeRating,
    required this.goPlayableViaExternalApp,
    this.externalAppUrls,
  });

  factory EventReplayResponse.fromJson(Map<String, dynamic> json) =>
      _$EventReplayResponseFromJson(json);

  @JsonKey(name: 'replayAvailabilityStart', includeIfNull: false)
  final int? replayAvailabilityStart;
  @JsonKey(name: 'replayAvailabilityEnd', includeIfNull: false)
  final int? replayAvailabilityEnd;
  @JsonKey(name: 'replayContainsAdult', includeIfNull: false)
  final bool? replayContainsAdult;
  @JsonKey(name: 'replayMinAge', includeIfNull: false)
  final int? replayMinAge;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool isGoPlayable;
  @JsonKey(name: 'displayAgeRating', includeIfNull: false)
  final bool displayAgeRating;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool goPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrlResponse>[])
  final List<ExternalAppUrlResponse>? externalAppUrls;
  static const fromJsonFactory = _$EventReplayResponseFromJson;
  static const toJsonFactory = _$EventReplayResponseToJson;
  Map<String, dynamic> toJson() => _$EventReplayResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventReplayResponse &&
            (identical(
                    other.replayAvailabilityStart, replayAvailabilityStart) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityStart, replayAvailabilityStart)) &&
            (identical(other.replayAvailabilityEnd, replayAvailabilityEnd) ||
                const DeepCollectionEquality().equals(
                    other.replayAvailabilityEnd, replayAvailabilityEnd)) &&
            (identical(other.replayContainsAdult, replayContainsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.replayContainsAdult, replayContainsAdult)) &&
            (identical(other.replayMinAge, replayMinAge) ||
                const DeepCollectionEquality()
                    .equals(other.replayMinAge, replayMinAge)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.displayAgeRating, displayAgeRating) ||
                const DeepCollectionEquality()
                    .equals(other.displayAgeRating, displayAgeRating)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) ||
                const DeepCollectionEquality()
                    .equals(other.externalAppUrls, externalAppUrls)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(replayAvailabilityStart) ^
      const DeepCollectionEquality().hash(replayAvailabilityEnd) ^
      const DeepCollectionEquality().hash(replayContainsAdult) ^
      const DeepCollectionEquality().hash(replayMinAge) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(displayAgeRating) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      runtimeType.hashCode;
}

extension $EventReplayResponseExtension on EventReplayResponse {
  EventReplayResponse copyWith(
      {int? replayAvailabilityStart,
      int? replayAvailabilityEnd,
      bool? replayContainsAdult,
      int? replayMinAge,
      bool? isGoPlayable,
      bool? displayAgeRating,
      bool? goPlayableViaExternalApp,
      List<ExternalAppUrlResponse>? externalAppUrls}) {
    return EventReplayResponse(
        replayAvailabilityStart:
            replayAvailabilityStart ?? this.replayAvailabilityStart,
        replayAvailabilityEnd:
            replayAvailabilityEnd ?? this.replayAvailabilityEnd,
        replayContainsAdult: replayContainsAdult ?? this.replayContainsAdult,
        replayMinAge: replayMinAge ?? this.replayMinAge,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        displayAgeRating: displayAgeRating ?? this.displayAgeRating,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls);
  }

  EventReplayResponse copyWithWrapped(
      {Wrapped<int?>? replayAvailabilityStart,
      Wrapped<int?>? replayAvailabilityEnd,
      Wrapped<bool?>? replayContainsAdult,
      Wrapped<int?>? replayMinAge,
      Wrapped<bool>? isGoPlayable,
      Wrapped<bool>? displayAgeRating,
      Wrapped<bool>? goPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrlResponse>?>? externalAppUrls}) {
    return EventReplayResponse(
        replayAvailabilityStart: (replayAvailabilityStart != null
            ? replayAvailabilityStart.value
            : this.replayAvailabilityStart),
        replayAvailabilityEnd: (replayAvailabilityEnd != null
            ? replayAvailabilityEnd.value
            : this.replayAvailabilityEnd),
        replayContainsAdult: (replayContainsAdult != null
            ? replayContainsAdult.value
            : this.replayContainsAdult),
        replayMinAge:
            (replayMinAge != null ? replayMinAge.value : this.replayMinAge),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        displayAgeRating: (displayAgeRating != null
            ? displayAgeRating.value
            : this.displayAgeRating),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerSeasonResponse {
  EpisodePickerSeasonResponse({
    this.id,
    this.episodes,
    required this.season,
    this.synopsis,
    required this.title,
    required this.totalEpisodes,
    this.imageVersion,
  });

  factory EpisodePickerSeasonResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerSeasonResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? episodes;
  @JsonKey(name: 'season', includeIfNull: false)
  final int season;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'totalEpisodes', includeIfNull: false)
  final int totalEpisodes;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodePickerSeasonResponseFromJson;
  static const toJsonFactory = _$EpisodePickerSeasonResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerSeasonResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerSeasonResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.season, season) ||
                const DeepCollectionEquality().equals(other.season, season)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.totalEpisodes, totalEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.totalEpisodes, totalEpisodes)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(season) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(totalEpisodes) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodePickerSeasonResponseExtension on EpisodePickerSeasonResponse {
  EpisodePickerSeasonResponse copyWith(
      {String? id,
      List<EpisodePickerEpisodeResponse>? episodes,
      int? season,
      String? synopsis,
      String? title,
      int? totalEpisodes,
      String? imageVersion}) {
    return EpisodePickerSeasonResponse(
        id: id ?? this.id,
        episodes: episodes ?? this.episodes,
        season: season ?? this.season,
        synopsis: synopsis ?? this.synopsis,
        title: title ?? this.title,
        totalEpisodes: totalEpisodes ?? this.totalEpisodes,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodePickerSeasonResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? episodes,
      Wrapped<int>? season,
      Wrapped<String?>? synopsis,
      Wrapped<String>? title,
      Wrapped<int>? totalEpisodes,
      Wrapped<String?>? imageVersion}) {
    return EpisodePickerSeasonResponse(
        id: (id != null ? id.value : this.id),
        episodes: (episodes != null ? episodes.value : this.episodes),
        season: (season != null ? season.value : this.season),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        title: (title != null ? title.value : this.title),
        totalEpisodes:
            (totalEpisodes != null ? totalEpisodes.value : this.totalEpisodes),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerEpisodeResponse {
  EpisodePickerEpisodeResponse({
    required this.id,
    this.episode,
    this.episodePart,
    this.title,
    this.ageRating,
    this.synopsis,
    required this.isAdult,
    this.viewProgress,
    required this.type,
    required this.sourceType,
    required this.source,
    this.mergedId,
    this.recordingId,
    this.imageVersion,
  });

  factory EpisodePickerEpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerEpisodeResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'episode', includeIfNull: false)
  final int? episode;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: episodePickerEpisodeResponseTypeToJson,
    fromJson: episodePickerEpisodeResponseTypeFromJson,
  )
  final enums.EpisodePickerEpisodeResponseType type;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: sourceTypeResponseToJson,
    fromJson: sourceTypeResponseFromJson,
  )
  final enums.SourceTypeResponse sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final Object source;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String? recordingId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EpisodePickerEpisodeResponseFromJson;
  static const toJsonFactory = _$EpisodePickerEpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerEpisodeResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerEpisodeResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.episode, episode) ||
                const DeepCollectionEquality()
                    .equals(other.episode, episode)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(episode) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(mergedId) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EpisodePickerEpisodeResponseExtension
    on EpisodePickerEpisodeResponse {
  EpisodePickerEpisodeResponse copyWith(
      {String? id,
      int? episode,
      int? episodePart,
      String? title,
      String? ageRating,
      String? synopsis,
      bool? isAdult,
      ViewProgressResponse? viewProgress,
      enums.EpisodePickerEpisodeResponseType? type,
      enums.SourceTypeResponse? sourceType,
      Object? source,
      String? mergedId,
      String? recordingId,
      String? imageVersion}) {
    return EpisodePickerEpisodeResponse(
        id: id ?? this.id,
        episode: episode ?? this.episode,
        episodePart: episodePart ?? this.episodePart,
        title: title ?? this.title,
        ageRating: ageRating ?? this.ageRating,
        synopsis: synopsis ?? this.synopsis,
        isAdult: isAdult ?? this.isAdult,
        viewProgress: viewProgress ?? this.viewProgress,
        type: type ?? this.type,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source,
        mergedId: mergedId ?? this.mergedId,
        recordingId: recordingId ?? this.recordingId,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EpisodePickerEpisodeResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<int?>? episode,
      Wrapped<int?>? episodePart,
      Wrapped<String?>? title,
      Wrapped<String?>? ageRating,
      Wrapped<String?>? synopsis,
      Wrapped<bool>? isAdult,
      Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<enums.EpisodePickerEpisodeResponseType>? type,
      Wrapped<enums.SourceTypeResponse>? sourceType,
      Wrapped<Object>? source,
      Wrapped<String?>? mergedId,
      Wrapped<String?>? recordingId,
      Wrapped<String?>? imageVersion}) {
    return EpisodePickerEpisodeResponse(
        id: (id != null ? id.value : this.id),
        episode: (episode != null ? episode.value : this.episode),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        title: (title != null ? title.value : this.title),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        type: (type != null ? type.value : this.type),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerYearOfProductionResponse {
  EpisodePickerYearOfProductionResponse({
    required this.year,
    required this.episodes,
  });

  factory EpisodePickerYearOfProductionResponse.fromJson(
          Map<String, dynamic> json) =>
      _$EpisodePickerYearOfProductionResponseFromJson(json);

  @JsonKey(name: 'year', includeIfNull: false, defaultValue: '')
  final String year;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse> episodes;
  static const fromJsonFactory =
      _$EpisodePickerYearOfProductionResponseFromJson;
  static const toJsonFactory = _$EpisodePickerYearOfProductionResponseToJson;
  Map<String, dynamic> toJson() =>
      _$EpisodePickerYearOfProductionResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerYearOfProductionResponse &&
            (identical(other.year, year) ||
                const DeepCollectionEquality().equals(other.year, year)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(year) ^
      const DeepCollectionEquality().hash(episodes) ^
      runtimeType.hashCode;
}

extension $EpisodePickerYearOfProductionResponseExtension
    on EpisodePickerYearOfProductionResponse {
  EpisodePickerYearOfProductionResponse copyWith(
      {String? year, List<EpisodePickerEpisodeResponse>? episodes}) {
    return EpisodePickerYearOfProductionResponse(
        year: year ?? this.year, episodes: episodes ?? this.episodes);
  }

  EpisodePickerYearOfProductionResponse copyWithWrapped(
      {Wrapped<String>? year,
      Wrapped<List<EpisodePickerEpisodeResponse>>? episodes}) {
    return EpisodePickerYearOfProductionResponse(
        year: (year != null ? year.value : this.year),
        episodes: (episodes != null ? episodes.value : this.episodes));
  }
}

@JsonSerializable(explicitToJson: true)
class SaaoSourceResponse {
  SaaoSourceResponse({
    required this.showId,
    required this.contentType,
    this.brandingProviderId,
    this.channel,
    required this.seasonList,
    required this.episodeCount,
    required this.specialsCount,
    this.imageVersion,
    this.mepSeriesFinale,
    this.premiereAirings,
  });

  factory SaaoSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$SaaoSourceResponseFromJson(json);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: saaoSourceResponseContentTypeToJson,
    fromJson: saaoSourceResponseContentTypeFromJson,
  )
  final enums.SaaoSourceResponseContentType contentType;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'channel', includeIfNull: false)
  final ChannelResponse? channel;
  @JsonKey(name: 'seasonList', includeIfNull: false, defaultValue: <int>[])
  final List<int> seasonList;
  @JsonKey(name: 'episodeCount', includeIfNull: false)
  final int episodeCount;
  @JsonKey(name: 'specialsCount', includeIfNull: false)
  final int specialsCount;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  static const fromJsonFactory = _$SaaoSourceResponseFromJson;
  static const toJsonFactory = _$SaaoSourceResponseToJson;
  Map<String, dynamic> toJson() => _$SaaoSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SaaoSourceResponse &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.seasonList, seasonList) ||
                const DeepCollectionEquality()
                    .equals(other.seasonList, seasonList)) &&
            (identical(other.episodeCount, episodeCount) ||
                const DeepCollectionEquality()
                    .equals(other.episodeCount, episodeCount)) &&
            (identical(other.specialsCount, specialsCount) ||
                const DeepCollectionEquality()
                    .equals(other.specialsCount, specialsCount)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(seasonList) ^
      const DeepCollectionEquality().hash(episodeCount) ^
      const DeepCollectionEquality().hash(specialsCount) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      runtimeType.hashCode;
}

extension $SaaoSourceResponseExtension on SaaoSourceResponse {
  SaaoSourceResponse copyWith(
      {String? showId,
      enums.SaaoSourceResponseContentType? contentType,
      String? brandingProviderId,
      ChannelResponse? channel,
      List<int>? seasonList,
      int? episodeCount,
      int? specialsCount,
      String? imageVersion,
      String? mepSeriesFinale,
      bool? premiereAirings}) {
    return SaaoSourceResponse(
        showId: showId ?? this.showId,
        contentType: contentType ?? this.contentType,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        channel: channel ?? this.channel,
        seasonList: seasonList ?? this.seasonList,
        episodeCount: episodeCount ?? this.episodeCount,
        specialsCount: specialsCount ?? this.specialsCount,
        imageVersion: imageVersion ?? this.imageVersion,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings);
  }

  SaaoSourceResponse copyWithWrapped(
      {Wrapped<String>? showId,
      Wrapped<enums.SaaoSourceResponseContentType>? contentType,
      Wrapped<String?>? brandingProviderId,
      Wrapped<ChannelResponse?>? channel,
      Wrapped<List<int>>? seasonList,
      Wrapped<int>? episodeCount,
      Wrapped<int>? specialsCount,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings}) {
    return SaaoSourceResponse(
        showId: (showId != null ? showId.value : this.showId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        channel: (channel != null ? channel.value : this.channel),
        seasonList: (seasonList != null ? seasonList.value : this.seasonList),
        episodeCount:
            (episodeCount != null ? episodeCount.value : this.episodeCount),
        specialsCount:
            (specialsCount != null ? specialsCount.value : this.specialsCount),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings));
  }
}

@JsonSerializable(explicitToJson: true)
class TrailerInfoResponse {
  TrailerInfoResponse({
    required this.id,
  });

  factory TrailerInfoResponse.fromJson(Map<String, dynamic> json) =>
      _$TrailerInfoResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  static const fromJsonFactory = _$TrailerInfoResponseFromJson;
  static const toJsonFactory = _$TrailerInfoResponseToJson;
  Map<String, dynamic> toJson() => _$TrailerInfoResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TrailerInfoResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $TrailerInfoResponseExtension on TrailerInfoResponse {
  TrailerInfoResponse copyWith({String? id}) {
    return TrailerInfoResponse(id: id ?? this.id);
  }

  TrailerInfoResponse copyWithWrapped({Wrapped<String>? id}) {
    return TrailerInfoResponse(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class LanguagesResponse {
  LanguagesResponse({
    required this.audio,
    required this.audioDescription,
    required this.subtitle,
    required this.sign,
  });

  factory LanguagesResponse.fromJson(Map<String, dynamic> json) =>
      _$LanguagesResponseFromJson(json);

  @JsonKey(name: 'audio', includeIfNull: false, defaultValue: <String>[])
  final List<String> audio;
  @JsonKey(
      name: 'audioDescription', includeIfNull: false, defaultValue: <String>[])
  final List<String> audioDescription;
  @JsonKey(name: 'subtitle', includeIfNull: false, defaultValue: <String>[])
  final List<String> subtitle;
  @JsonKey(name: 'sign', includeIfNull: false, defaultValue: <String>[])
  final List<String> sign;
  static const fromJsonFactory = _$LanguagesResponseFromJson;
  static const toJsonFactory = _$LanguagesResponseToJson;
  Map<String, dynamic> toJson() => _$LanguagesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LanguagesResponse &&
            (identical(other.audio, audio) ||
                const DeepCollectionEquality().equals(other.audio, audio)) &&
            (identical(other.audioDescription, audioDescription) ||
                const DeepCollectionEquality()
                    .equals(other.audioDescription, audioDescription)) &&
            (identical(other.subtitle, subtitle) ||
                const DeepCollectionEquality()
                    .equals(other.subtitle, subtitle)) &&
            (identical(other.sign, sign) ||
                const DeepCollectionEquality().equals(other.sign, sign)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(audio) ^
      const DeepCollectionEquality().hash(audioDescription) ^
      const DeepCollectionEquality().hash(subtitle) ^
      const DeepCollectionEquality().hash(sign) ^
      runtimeType.hashCode;
}

extension $LanguagesResponseExtension on LanguagesResponse {
  LanguagesResponse copyWith(
      {List<String>? audio,
      List<String>? audioDescription,
      List<String>? subtitle,
      List<String>? sign}) {
    return LanguagesResponse(
        audio: audio ?? this.audio,
        audioDescription: audioDescription ?? this.audioDescription,
        subtitle: subtitle ?? this.subtitle,
        sign: sign ?? this.sign);
  }

  LanguagesResponse copyWithWrapped(
      {Wrapped<List<String>>? audio,
      Wrapped<List<String>>? audioDescription,
      Wrapped<List<String>>? subtitle,
      Wrapped<List<String>>? sign}) {
    return LanguagesResponse(
        audio: (audio != null ? audio.value : this.audio),
        audioDescription: (audioDescription != null
            ? audioDescription.value
            : this.audioDescription),
        subtitle: (subtitle != null ? subtitle.value : this.subtitle),
        sign: (sign != null ? sign.value : this.sign));
  }
}

@JsonSerializable(explicitToJson: true)
class PersonResponse {
  PersonResponse({
    this.personId,
    this.name,
  });

  factory PersonResponse.fromJson(Map<String, dynamic> json) =>
      _$PersonResponseFromJson(json);

  @JsonKey(name: 'personId', includeIfNull: false, defaultValue: '')
  final String? personId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$PersonResponseFromJson;
  static const toJsonFactory = _$PersonResponseToJson;
  Map<String, dynamic> toJson() => _$PersonResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PersonResponse &&
            (identical(other.personId, personId) ||
                const DeepCollectionEquality()
                    .equals(other.personId, personId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(personId) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $PersonResponseExtension on PersonResponse {
  PersonResponse copyWith({String? personId, String? name}) {
    return PersonResponse(
        personId: personId ?? this.personId, name: name ?? this.name);
  }

  PersonResponse copyWithWrapped(
      {Wrapped<String?>? personId, Wrapped<String?>? name}) {
    return PersonResponse(
        personId: (personId != null ? personId.value : this.personId),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class LinearContent {
  LinearContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory LinearContent.fromJson(Map<String, dynamic> json) =>
      _$LinearContentFromJson(json);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(
    name: 'sourceType',
    includeIfNull: false,
    toJson: linearContentSourceTypeToJson,
    fromJson: linearContentSourceTypeFromJson,
  )
  final enums.LinearContentSourceType sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final LinearSourceResponse source;
  static const fromJsonFactory = _$LinearContentFromJson;
  static const toJsonFactory = _$LinearContentToJson;
  Map<String, dynamic> toJson() => _$LinearContentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LinearContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $LinearContentExtension on LinearContent {
  LinearContent copyWith(
      {int? rengContentSource,
      enums.LinearContentSourceType? sourceType,
      LinearSourceResponse? source}) {
    return LinearContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  LinearContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<enums.LinearContentSourceType>? sourceType,
      Wrapped<LinearSourceResponse>? source}) {
    return LinearContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class VodContent {
  VodContent({
    required this.rengContenSource,
    required this.sourceType,
    required this.source,
  });

  factory VodContent.fromJson(Map<String, dynamic> json) =>
      _$VodContentFromJson(json);

  @JsonKey(name: 'rengContenSource', includeIfNull: false)
  final int rengContenSource;
  @JsonKey(name: 'sourceType', includeIfNull: false, defaultValue: '')
  final String sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final VodSourceResponse source;
  static const fromJsonFactory = _$VodContentFromJson;
  static const toJsonFactory = _$VodContentToJson;
  Map<String, dynamic> toJson() => _$VodContentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is VodContent &&
            (identical(other.rengContenSource, rengContenSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContenSource, rengContenSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContenSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $VodContentExtension on VodContent {
  VodContent copyWith(
      {int? rengContenSource, String? sourceType, VodSourceResponse? source}) {
    return VodContent(
        rengContenSource: rengContenSource ?? this.rengContenSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  VodContent copyWithWrapped(
      {Wrapped<int>? rengContenSource,
      Wrapped<String>? sourceType,
      Wrapped<VodSourceResponse>? source}) {
    return VodContent(
        rengContenSource: (rengContenSource != null
            ? rengContenSource.value
            : this.rengContenSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class OTTContent {
  OTTContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory OTTContent.fromJson(Map<String, dynamic> json) =>
      _$OTTContentFromJson(json);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(name: 'sourceType', includeIfNull: false, defaultValue: '')
  final String sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final OttSourceResponse source;
  static const fromJsonFactory = _$OTTContentFromJson;
  static const toJsonFactory = _$OTTContentToJson;
  Map<String, dynamic> toJson() => _$OTTContentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OTTContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $OTTContentExtension on OTTContent {
  OTTContent copyWith(
      {int? rengContentSource, String? sourceType, OttSourceResponse? source}) {
    return OTTContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  OTTContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<String>? sourceType,
      Wrapped<OttSourceResponse>? source}) {
    return OTTContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingContent {
  RecordingContent({
    required this.rengContentSource,
    required this.sourceType,
    required this.source,
  });

  factory RecordingContent.fromJson(Map<String, dynamic> json) =>
      _$RecordingContentFromJson(json);

  @JsonKey(name: 'rengContentSource', includeIfNull: false)
  final int rengContentSource;
  @JsonKey(name: 'sourceType', includeIfNull: false, defaultValue: '')
  final String sourceType;
  @JsonKey(name: 'source', includeIfNull: false)
  final RecordingSourceResponse source;
  static const fromJsonFactory = _$RecordingContentFromJson;
  static const toJsonFactory = _$RecordingContentToJson;
  Map<String, dynamic> toJson() => _$RecordingContentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingContent &&
            (identical(other.rengContentSource, rengContentSource) ||
                const DeepCollectionEquality()
                    .equals(other.rengContentSource, rengContentSource)) &&
            (identical(other.sourceType, sourceType) ||
                const DeepCollectionEquality()
                    .equals(other.sourceType, sourceType)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rengContentSource) ^
      const DeepCollectionEquality().hash(sourceType) ^
      const DeepCollectionEquality().hash(source) ^
      runtimeType.hashCode;
}

extension $RecordingContentExtension on RecordingContent {
  RecordingContent copyWith(
      {int? rengContentSource,
      String? sourceType,
      RecordingSourceResponse? source}) {
    return RecordingContent(
        rengContentSource: rengContentSource ?? this.rengContentSource,
        sourceType: sourceType ?? this.sourceType,
        source: source ?? this.source);
  }

  RecordingContent copyWithWrapped(
      {Wrapped<int>? rengContentSource,
      Wrapped<String>? sourceType,
      Wrapped<RecordingSourceResponse>? source}) {
    return RecordingContent(
        rengContentSource: (rengContentSource != null
            ? rengContentSource.value
            : this.rengContentSource),
        sourceType: (sourceType != null ? sourceType.value : this.sourceType),
        source: (source != null ? source.value : this.source));
  }
}

@JsonSerializable(explicitToJson: true)
class MRESeasonResponse {
  MRESeasonResponse({
    required this.id,
    this.name,
    this.number,
    this.imageVersion,
  });

  factory MRESeasonResponse.fromJson(Map<String, dynamic> json) =>
      _$MRESeasonResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'number', includeIfNull: false)
  final int? number;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$MRESeasonResponseFromJson;
  static const toJsonFactory = _$MRESeasonResponseToJson;
  Map<String, dynamic> toJson() => _$MRESeasonResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MRESeasonResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.number, number) ||
                const DeepCollectionEquality().equals(other.number, number)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(number) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $MRESeasonResponseExtension on MRESeasonResponse {
  MRESeasonResponse copyWith(
      {String? id, String? name, int? number, String? imageVersion}) {
    return MRESeasonResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        number: number ?? this.number,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  MRESeasonResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? number,
      Wrapped<String?>? imageVersion}) {
    return MRESeasonResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        number: (number != null ? number.value : this.number),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class MREShowResponse {
  MREShowResponse({
    required this.id,
    required this.name,
    required this.isBoxset,
    required this.includesVOD,
    required this.hasInteracted,
    this.imageVersion,
    this.showPageAvailable,
    this.mergedId,
  });

  factory MREShowResponse.fromJson(Map<String, dynamic> json) =>
      _$MREShowResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'isBoxset', includeIfNull: false)
  final bool isBoxset;
  @JsonKey(name: 'includesVOD', includeIfNull: false)
  final bool includesVOD;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool hasInteracted;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'showPageAvailable', includeIfNull: false)
  final bool? showPageAvailable;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$MREShowResponseFromJson;
  static const toJsonFactory = _$MREShowResponseToJson;
  Map<String, dynamic> toJson() => _$MREShowResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MREShowResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.isBoxset, isBoxset) ||
                const DeepCollectionEquality()
                    .equals(other.isBoxset, isBoxset)) &&
            (identical(other.includesVOD, includesVOD) ||
                const DeepCollectionEquality()
                    .equals(other.includesVOD, includesVOD)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.showPageAvailable, showPageAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.showPageAvailable, showPageAvailable)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(isBoxset) ^
      const DeepCollectionEquality().hash(includesVOD) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(showPageAvailable) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $MREShowResponseExtension on MREShowResponse {
  MREShowResponse copyWith(
      {String? id,
      String? name,
      bool? isBoxset,
      bool? includesVOD,
      bool? hasInteracted,
      String? imageVersion,
      bool? showPageAvailable,
      String? mergedId}) {
    return MREShowResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        isBoxset: isBoxset ?? this.isBoxset,
        includesVOD: includesVOD ?? this.includesVOD,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        imageVersion: imageVersion ?? this.imageVersion,
        showPageAvailable: showPageAvailable ?? this.showPageAvailable,
        mergedId: mergedId ?? this.mergedId);
  }

  MREShowResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<bool>? isBoxset,
      Wrapped<bool>? includesVOD,
      Wrapped<bool>? hasInteracted,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? showPageAvailable,
      Wrapped<String?>? mergedId}) {
    return MREShowResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        isBoxset: (isBoxset != null ? isBoxset.value : this.isBoxset),
        includesVOD:
            (includesVOD != null ? includesVOD.value : this.includesVOD),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        showPageAvailable: (showPageAvailable != null
            ? showPageAvailable.value
            : this.showPageAvailable),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class MREEpisodeResponse {
  MREEpisodeResponse({
    required this.id,
    this.name,
    this.number,
    this.episodePart,
    this.ageRating,
    this.viewProgress,
    this.parentalGuidanceText,
    this.description,
    this.longDescription,
    required this.genres,
    this.productionYear,
    this.resolution,
    required this.languages,
    this.cast,
    this.crew,
    this.mergedId,
  });

  factory MREEpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$MREEpisodeResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'number', includeIfNull: false)
  final int? number;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'ageRating', includeIfNull: false)
  final int? ageRating;
  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(name: 'parentalGuidanceText', includeIfNull: false, defaultValue: '')
  final String? parentalGuidanceText;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'longDescription', includeIfNull: false, defaultValue: '')
  final String? longDescription;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String> genres;
  @JsonKey(name: 'productionYear', includeIfNull: false)
  final int? productionYear;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: <String>[])
  final List<String>? resolution;
  @JsonKey(name: 'languages', includeIfNull: false)
  final LanguagesResponse languages;
  @JsonKey(name: 'cast', includeIfNull: false, defaultValue: <PersonResponse>[])
  final List<PersonResponse>? cast;
  @JsonKey(name: 'crew', includeIfNull: false, defaultValue: <PersonResponse>[])
  final List<PersonResponse>? crew;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$MREEpisodeResponseFromJson;
  static const toJsonFactory = _$MREEpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$MREEpisodeResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MREEpisodeResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.number, number) ||
                const DeepCollectionEquality().equals(other.number, number)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.parentalGuidanceText, parentalGuidanceText) ||
                const DeepCollectionEquality().equals(
                    other.parentalGuidanceText, parentalGuidanceText)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.longDescription, longDescription) ||
                const DeepCollectionEquality()
                    .equals(other.longDescription, longDescription)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.productionYear, productionYear) ||
                const DeepCollectionEquality()
                    .equals(other.productionYear, productionYear)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.languages, languages) ||
                const DeepCollectionEquality()
                    .equals(other.languages, languages)) &&
            (identical(other.cast, cast) ||
                const DeepCollectionEquality().equals(other.cast, cast)) &&
            (identical(other.crew, crew) ||
                const DeepCollectionEquality().equals(other.crew, crew)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(number) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(parentalGuidanceText) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(longDescription) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(productionYear) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(languages) ^
      const DeepCollectionEquality().hash(cast) ^
      const DeepCollectionEquality().hash(crew) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $MREEpisodeResponseExtension on MREEpisodeResponse {
  MREEpisodeResponse copyWith(
      {String? id,
      String? name,
      int? number,
      int? episodePart,
      int? ageRating,
      ViewProgressResponse? viewProgress,
      String? parentalGuidanceText,
      String? description,
      String? longDescription,
      List<String>? genres,
      int? productionYear,
      List<String>? resolution,
      LanguagesResponse? languages,
      List<PersonResponse>? cast,
      List<PersonResponse>? crew,
      String? mergedId}) {
    return MREEpisodeResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        number: number ?? this.number,
        episodePart: episodePart ?? this.episodePart,
        ageRating: ageRating ?? this.ageRating,
        viewProgress: viewProgress ?? this.viewProgress,
        parentalGuidanceText: parentalGuidanceText ?? this.parentalGuidanceText,
        description: description ?? this.description,
        longDescription: longDescription ?? this.longDescription,
        genres: genres ?? this.genres,
        productionYear: productionYear ?? this.productionYear,
        resolution: resolution ?? this.resolution,
        languages: languages ?? this.languages,
        cast: cast ?? this.cast,
        crew: crew ?? this.crew,
        mergedId: mergedId ?? this.mergedId);
  }

  MREEpisodeResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? name,
      Wrapped<int?>? number,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? ageRating,
      Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<String?>? parentalGuidanceText,
      Wrapped<String?>? description,
      Wrapped<String?>? longDescription,
      Wrapped<List<String>>? genres,
      Wrapped<int?>? productionYear,
      Wrapped<List<String>?>? resolution,
      Wrapped<LanguagesResponse>? languages,
      Wrapped<List<PersonResponse>?>? cast,
      Wrapped<List<PersonResponse>?>? crew,
      Wrapped<String?>? mergedId}) {
    return MREEpisodeResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        number: (number != null ? number.value : this.number),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        parentalGuidanceText: (parentalGuidanceText != null
            ? parentalGuidanceText.value
            : this.parentalGuidanceText),
        description:
            (description != null ? description.value : this.description),
        longDescription: (longDescription != null
            ? longDescription.value
            : this.longDescription),
        genres: (genres != null ? genres.value : this.genres),
        productionYear: (productionYear != null
            ? productionYear.value
            : this.productionYear),
        resolution: (resolution != null ? resolution.value : this.resolution),
        languages: (languages != null ? languages.value : this.languages),
        cast: (cast != null ? cast.value : this.cast),
        crew: (crew != null ? crew.value : this.crew),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class ExternalAppUrlResponse {
  ExternalAppUrlResponse({
    required this.deviceCode,
    required this.url,
  });

  factory ExternalAppUrlResponse.fromJson(Map<String, dynamic> json) =>
      _$ExternalAppUrlResponseFromJson(json);

  @JsonKey(name: 'deviceCode', includeIfNull: false, defaultValue: '')
  final String deviceCode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$ExternalAppUrlResponseFromJson;
  static const toJsonFactory = _$ExternalAppUrlResponseToJson;
  Map<String, dynamic> toJson() => _$ExternalAppUrlResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ExternalAppUrlResponse &&
            (identical(other.deviceCode, deviceCode) ||
                const DeepCollectionEquality()
                    .equals(other.deviceCode, deviceCode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deviceCode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $ExternalAppUrlResponseExtension on ExternalAppUrlResponse {
  ExternalAppUrlResponse copyWith({String? deviceCode, String? url}) {
    return ExternalAppUrlResponse(
        deviceCode: deviceCode ?? this.deviceCode, url: url ?? this.url);
  }

  ExternalAppUrlResponse copyWithWrapped(
      {Wrapped<String>? deviceCode, Wrapped<String>? url}) {
    return ExternalAppUrlResponse(
        deviceCode: (deviceCode != null ? deviceCode.value : this.deviceCode),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingSourcesSourceObjectResponse {
  RecordingSourcesSourceObjectResponse({
    this.channelId,
    this.channelName,
    this.containsLatestEpisode,
    this.seedEvent,
  });

  factory RecordingSourcesSourceObjectResponse.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingSourcesSourceObjectResponseFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'containsLatestEpisode', includeIfNull: false)
  final bool? containsLatestEpisode;
  @JsonKey(name: 'seedEvent', includeIfNull: false)
  final SeedEventResponse? seedEvent;
  static const fromJsonFactory = _$RecordingSourcesSourceObjectResponseFromJson;
  static const toJsonFactory = _$RecordingSourcesSourceObjectResponseToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingSourcesSourceObjectResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingSourcesSourceObjectResponse &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.containsLatestEpisode, containsLatestEpisode) ||
                const DeepCollectionEquality().equals(
                    other.containsLatestEpisode, containsLatestEpisode)) &&
            (identical(other.seedEvent, seedEvent) ||
                const DeepCollectionEquality()
                    .equals(other.seedEvent, seedEvent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(containsLatestEpisode) ^
      const DeepCollectionEquality().hash(seedEvent) ^
      runtimeType.hashCode;
}

extension $RecordingSourcesSourceObjectResponseExtension
    on RecordingSourcesSourceObjectResponse {
  RecordingSourcesSourceObjectResponse copyWith(
      {String? channelId,
      String? channelName,
      bool? containsLatestEpisode,
      SeedEventResponse? seedEvent}) {
    return RecordingSourcesSourceObjectResponse(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName,
        containsLatestEpisode:
            containsLatestEpisode ?? this.containsLatestEpisode,
        seedEvent: seedEvent ?? this.seedEvent);
  }

  RecordingSourcesSourceObjectResponse copyWithWrapped(
      {Wrapped<String?>? channelId,
      Wrapped<String?>? channelName,
      Wrapped<bool?>? containsLatestEpisode,
      Wrapped<SeedEventResponse?>? seedEvent}) {
    return RecordingSourcesSourceObjectResponse(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        containsLatestEpisode: (containsLatestEpisode != null
            ? containsLatestEpisode.value
            : this.containsLatestEpisode),
        seedEvent: (seedEvent != null ? seedEvent.value : this.seedEvent));
  }
}

@JsonSerializable(explicitToJson: true)
class SeedEventResponse {
  SeedEventResponse({
    required this.id,
    required this.eventId,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    required this.broadcastDate,
  });

  factory SeedEventResponse.fromJson(Map<String, dynamic> json) =>
      _$SeedEventResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  static const fromJsonFactory = _$SeedEventResponseFromJson;
  static const toJsonFactory = _$SeedEventResponseToJson;
  Map<String, dynamic> toJson() => _$SeedEventResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeedEventResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      runtimeType.hashCode;
}

extension $SeedEventResponseExtension on SeedEventResponse {
  SeedEventResponse copyWith(
      {String? id,
      String? eventId,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      String? broadcastDate}) {
    return SeedEventResponse(
        id: id ?? this.id,
        eventId: eventId ?? this.eventId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        broadcastDate: broadcastDate ?? this.broadcastDate);
  }

  SeedEventResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? eventId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<String>? broadcastDate}) {
    return SeedEventResponse(
        id: (id != null ? id.value : this.id),
        eventId: (eventId != null ? eventId.value : this.eventId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate));
  }
}

String? v1SeriesDetailSeasonCridGetMaxResToJson(
    enums.V1SeriesDetailSeasonCridGetMaxRes?
        v1SeriesDetailSeasonCridGetMaxRes) {
  return enums
      .$V1SeriesDetailSeasonCridGetMaxResMap[v1SeriesDetailSeasonCridGetMaxRes];
}

enums.V1SeriesDetailSeasonCridGetMaxRes
    v1SeriesDetailSeasonCridGetMaxResFromJson(
  Object? v1SeriesDetailSeasonCridGetMaxRes, [
  enums.V1SeriesDetailSeasonCridGetMaxRes? defaultValue,
]) {
  if (v1SeriesDetailSeasonCridGetMaxRes is String) {
    return enums.$V1SeriesDetailSeasonCridGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1SeriesDetailSeasonCridGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1SeriesDetailSeasonCridGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1SeriesDetailSeasonCridGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1SeriesDetailSeasonCridGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1SeriesDetailSeasonCridGetMaxResListToJson(
    List<enums.V1SeriesDetailSeasonCridGetMaxRes>?
        v1SeriesDetailSeasonCridGetMaxRes) {
  if (v1SeriesDetailSeasonCridGetMaxRes == null) {
    return [];
  }

  return v1SeriesDetailSeasonCridGetMaxRes
      .map((e) => enums.$V1SeriesDetailSeasonCridGetMaxResMap[e]!)
      .toList();
}

List<enums.V1SeriesDetailSeasonCridGetMaxRes>
    v1SeriesDetailSeasonCridGetMaxResListFromJson(
  List? v1SeriesDetailSeasonCridGetMaxRes, [
  List<enums.V1SeriesDetailSeasonCridGetMaxRes>? defaultValue,
]) {
  if (v1SeriesDetailSeasonCridGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1SeriesDetailSeasonCridGetMaxRes
      .map((e) => v1SeriesDetailSeasonCridGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1SeriesDetailSeasonCridGetMaxRes>?
    v1SeriesDetailSeasonCridGetMaxResNullableListFromJson(
  List? v1SeriesDetailSeasonCridGetMaxRes, [
  List<enums.V1SeriesDetailSeasonCridGetMaxRes>? defaultValue,
]) {
  if (v1SeriesDetailSeasonCridGetMaxRes == null) {
    return defaultValue;
  }

  return v1SeriesDetailSeasonCridGetMaxRes
      .map((e) => v1SeriesDetailSeasonCridGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1EventDetailGetMaxResToJson(
    enums.V1EventDetailGetMaxRes? v1EventDetailGetMaxRes) {
  return enums.$V1EventDetailGetMaxResMap[v1EventDetailGetMaxRes];
}

enums.V1EventDetailGetMaxRes v1EventDetailGetMaxResFromJson(
  Object? v1EventDetailGetMaxRes, [
  enums.V1EventDetailGetMaxRes? defaultValue,
]) {
  if (v1EventDetailGetMaxRes is String) {
    return enums.$V1EventDetailGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1EventDetailGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1EventDetailGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1EventDetailGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1EventDetailGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1EventDetailGetMaxResListToJson(
    List<enums.V1EventDetailGetMaxRes>? v1EventDetailGetMaxRes) {
  if (v1EventDetailGetMaxRes == null) {
    return [];
  }

  return v1EventDetailGetMaxRes
      .map((e) => enums.$V1EventDetailGetMaxResMap[e]!)
      .toList();
}

List<enums.V1EventDetailGetMaxRes> v1EventDetailGetMaxResListFromJson(
  List? v1EventDetailGetMaxRes, [
  List<enums.V1EventDetailGetMaxRes>? defaultValue,
]) {
  if (v1EventDetailGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1EventDetailGetMaxRes
      .map((e) => v1EventDetailGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1EventDetailGetMaxRes>? v1EventDetailGetMaxResNullableListFromJson(
  List? v1EventDetailGetMaxRes, [
  List<enums.V1EventDetailGetMaxRes>? defaultValue,
]) {
  if (v1EventDetailGetMaxRes == null) {
    return defaultValue;
  }

  return v1EventDetailGetMaxRes
      .map((e) => v1EventDetailGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1MostRelevantSourceGetMaxResToJson(
    enums.V1MostRelevantSourceGetMaxRes? v1MostRelevantSourceGetMaxRes) {
  return enums.$V1MostRelevantSourceGetMaxResMap[v1MostRelevantSourceGetMaxRes];
}

enums.V1MostRelevantSourceGetMaxRes v1MostRelevantSourceGetMaxResFromJson(
  Object? v1MostRelevantSourceGetMaxRes, [
  enums.V1MostRelevantSourceGetMaxRes? defaultValue,
]) {
  if (v1MostRelevantSourceGetMaxRes is String) {
    return enums.$V1MostRelevantSourceGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1MostRelevantSourceGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1MostRelevantSourceGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1MostRelevantSourceGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1MostRelevantSourceGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1MostRelevantSourceGetMaxResListToJson(
    List<enums.V1MostRelevantSourceGetMaxRes>? v1MostRelevantSourceGetMaxRes) {
  if (v1MostRelevantSourceGetMaxRes == null) {
    return [];
  }

  return v1MostRelevantSourceGetMaxRes
      .map((e) => enums.$V1MostRelevantSourceGetMaxResMap[e]!)
      .toList();
}

List<enums.V1MostRelevantSourceGetMaxRes>
    v1MostRelevantSourceGetMaxResListFromJson(
  List? v1MostRelevantSourceGetMaxRes, [
  List<enums.V1MostRelevantSourceGetMaxRes>? defaultValue,
]) {
  if (v1MostRelevantSourceGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1MostRelevantSourceGetMaxRes
      .map((e) => v1MostRelevantSourceGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1MostRelevantSourceGetMaxRes>?
    v1MostRelevantSourceGetMaxResNullableListFromJson(
  List? v1MostRelevantSourceGetMaxRes, [
  List<enums.V1MostRelevantSourceGetMaxRes>? defaultValue,
]) {
  if (v1MostRelevantSourceGetMaxRes == null) {
    return defaultValue;
  }

  return v1MostRelevantSourceGetMaxRes
      .map((e) => v1MostRelevantSourceGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1MostRelevantEpisodeGetMaxResToJson(
    enums.V1MostRelevantEpisodeGetMaxRes? v1MostRelevantEpisodeGetMaxRes) {
  return enums
      .$V1MostRelevantEpisodeGetMaxResMap[v1MostRelevantEpisodeGetMaxRes];
}

enums.V1MostRelevantEpisodeGetMaxRes v1MostRelevantEpisodeGetMaxResFromJson(
  Object? v1MostRelevantEpisodeGetMaxRes, [
  enums.V1MostRelevantEpisodeGetMaxRes? defaultValue,
]) {
  if (v1MostRelevantEpisodeGetMaxRes is String) {
    return enums.$V1MostRelevantEpisodeGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1MostRelevantEpisodeGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1MostRelevantEpisodeGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1MostRelevantEpisodeGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1MostRelevantEpisodeGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1MostRelevantEpisodeGetMaxResListToJson(
    List<enums.V1MostRelevantEpisodeGetMaxRes>?
        v1MostRelevantEpisodeGetMaxRes) {
  if (v1MostRelevantEpisodeGetMaxRes == null) {
    return [];
  }

  return v1MostRelevantEpisodeGetMaxRes
      .map((e) => enums.$V1MostRelevantEpisodeGetMaxResMap[e]!)
      .toList();
}

List<enums.V1MostRelevantEpisodeGetMaxRes>
    v1MostRelevantEpisodeGetMaxResListFromJson(
  List? v1MostRelevantEpisodeGetMaxRes, [
  List<enums.V1MostRelevantEpisodeGetMaxRes>? defaultValue,
]) {
  if (v1MostRelevantEpisodeGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1MostRelevantEpisodeGetMaxRes
      .map((e) => v1MostRelevantEpisodeGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1MostRelevantEpisodeGetMaxRes>?
    v1MostRelevantEpisodeGetMaxResNullableListFromJson(
  List? v1MostRelevantEpisodeGetMaxRes, [
  List<enums.V1MostRelevantEpisodeGetMaxRes>? defaultValue,
]) {
  if (v1MostRelevantEpisodeGetMaxRes == null) {
    return defaultValue;
  }

  return v1MostRelevantEpisodeGetMaxRes
      .map((e) => v1MostRelevantEpisodeGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2MostRelevantEpisodeGetMaxResToJson(
    enums.V2MostRelevantEpisodeGetMaxRes? v2MostRelevantEpisodeGetMaxRes) {
  return enums
      .$V2MostRelevantEpisodeGetMaxResMap[v2MostRelevantEpisodeGetMaxRes];
}

enums.V2MostRelevantEpisodeGetMaxRes v2MostRelevantEpisodeGetMaxResFromJson(
  Object? v2MostRelevantEpisodeGetMaxRes, [
  enums.V2MostRelevantEpisodeGetMaxRes? defaultValue,
]) {
  if (v2MostRelevantEpisodeGetMaxRes is String) {
    return enums.$V2MostRelevantEpisodeGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v2MostRelevantEpisodeGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V2MostRelevantEpisodeGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V2MostRelevantEpisodeGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V2MostRelevantEpisodeGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2MostRelevantEpisodeGetMaxResListToJson(
    List<enums.V2MostRelevantEpisodeGetMaxRes>?
        v2MostRelevantEpisodeGetMaxRes) {
  if (v2MostRelevantEpisodeGetMaxRes == null) {
    return [];
  }

  return v2MostRelevantEpisodeGetMaxRes
      .map((e) => enums.$V2MostRelevantEpisodeGetMaxResMap[e]!)
      .toList();
}

List<enums.V2MostRelevantEpisodeGetMaxRes>
    v2MostRelevantEpisodeGetMaxResListFromJson(
  List? v2MostRelevantEpisodeGetMaxRes, [
  List<enums.V2MostRelevantEpisodeGetMaxRes>? defaultValue,
]) {
  if (v2MostRelevantEpisodeGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2MostRelevantEpisodeGetMaxRes
      .map((e) => v2MostRelevantEpisodeGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2MostRelevantEpisodeGetMaxRes>?
    v2MostRelevantEpisodeGetMaxResNullableListFromJson(
  List? v2MostRelevantEpisodeGetMaxRes, [
  List<enums.V2MostRelevantEpisodeGetMaxRes>? defaultValue,
]) {
  if (v2MostRelevantEpisodeGetMaxRes == null) {
    return defaultValue;
  }

  return v2MostRelevantEpisodeGetMaxRes
      .map((e) => v2MostRelevantEpisodeGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1TitleAlsoAvailableOnGetMaxResToJson(
    enums.V1TitleAlsoAvailableOnGetMaxRes? v1TitleAlsoAvailableOnGetMaxRes) {
  return enums
      .$V1TitleAlsoAvailableOnGetMaxResMap[v1TitleAlsoAvailableOnGetMaxRes];
}

enums.V1TitleAlsoAvailableOnGetMaxRes v1TitleAlsoAvailableOnGetMaxResFromJson(
  Object? v1TitleAlsoAvailableOnGetMaxRes, [
  enums.V1TitleAlsoAvailableOnGetMaxRes? defaultValue,
]) {
  if (v1TitleAlsoAvailableOnGetMaxRes is String) {
    return enums.$V1TitleAlsoAvailableOnGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1TitleAlsoAvailableOnGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1TitleAlsoAvailableOnGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1TitleAlsoAvailableOnGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1TitleAlsoAvailableOnGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1TitleAlsoAvailableOnGetMaxResListToJson(
    List<enums.V1TitleAlsoAvailableOnGetMaxRes>?
        v1TitleAlsoAvailableOnGetMaxRes) {
  if (v1TitleAlsoAvailableOnGetMaxRes == null) {
    return [];
  }

  return v1TitleAlsoAvailableOnGetMaxRes
      .map((e) => enums.$V1TitleAlsoAvailableOnGetMaxResMap[e]!)
      .toList();
}

List<enums.V1TitleAlsoAvailableOnGetMaxRes>
    v1TitleAlsoAvailableOnGetMaxResListFromJson(
  List? v1TitleAlsoAvailableOnGetMaxRes, [
  List<enums.V1TitleAlsoAvailableOnGetMaxRes>? defaultValue,
]) {
  if (v1TitleAlsoAvailableOnGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1TitleAlsoAvailableOnGetMaxRes
      .map((e) => v1TitleAlsoAvailableOnGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1TitleAlsoAvailableOnGetMaxRes>?
    v1TitleAlsoAvailableOnGetMaxResNullableListFromJson(
  List? v1TitleAlsoAvailableOnGetMaxRes, [
  List<enums.V1TitleAlsoAvailableOnGetMaxRes>? defaultValue,
]) {
  if (v1TitleAlsoAvailableOnGetMaxRes == null) {
    return defaultValue;
  }

  return v1TitleAlsoAvailableOnGetMaxRes
      .map((e) => v1TitleAlsoAvailableOnGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1EpisodePickerGetMaxResToJson(
    enums.V1EpisodePickerGetMaxRes? v1EpisodePickerGetMaxRes) {
  return enums.$V1EpisodePickerGetMaxResMap[v1EpisodePickerGetMaxRes];
}

enums.V1EpisodePickerGetMaxRes v1EpisodePickerGetMaxResFromJson(
  Object? v1EpisodePickerGetMaxRes, [
  enums.V1EpisodePickerGetMaxRes? defaultValue,
]) {
  if (v1EpisodePickerGetMaxRes is String) {
    return enums.$V1EpisodePickerGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1EpisodePickerGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1EpisodePickerGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1EpisodePickerGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1EpisodePickerGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1EpisodePickerGetMaxResListToJson(
    List<enums.V1EpisodePickerGetMaxRes>? v1EpisodePickerGetMaxRes) {
  if (v1EpisodePickerGetMaxRes == null) {
    return [];
  }

  return v1EpisodePickerGetMaxRes
      .map((e) => enums.$V1EpisodePickerGetMaxResMap[e]!)
      .toList();
}

List<enums.V1EpisodePickerGetMaxRes> v1EpisodePickerGetMaxResListFromJson(
  List? v1EpisodePickerGetMaxRes, [
  List<enums.V1EpisodePickerGetMaxRes>? defaultValue,
]) {
  if (v1EpisodePickerGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1EpisodePickerGetMaxRes
      .map((e) => v1EpisodePickerGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1EpisodePickerGetMaxRes>?
    v1EpisodePickerGetMaxResNullableListFromJson(
  List? v1EpisodePickerGetMaxRes, [
  List<enums.V1EpisodePickerGetMaxRes>? defaultValue,
]) {
  if (v1EpisodePickerGetMaxRes == null) {
    return defaultValue;
  }

  return v1EpisodePickerGetMaxRes
      .map((e) => v1EpisodePickerGetMaxResFromJson(e.toString()))
      .toList();
}

String? v2EpisodePickerGetMaxResToJson(
    enums.V2EpisodePickerGetMaxRes? v2EpisodePickerGetMaxRes) {
  return enums.$V2EpisodePickerGetMaxResMap[v2EpisodePickerGetMaxRes];
}

enums.V2EpisodePickerGetMaxRes v2EpisodePickerGetMaxResFromJson(
  Object? v2EpisodePickerGetMaxRes, [
  enums.V2EpisodePickerGetMaxRes? defaultValue,
]) {
  if (v2EpisodePickerGetMaxRes is String) {
    return enums.$V2EpisodePickerGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v2EpisodePickerGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V2EpisodePickerGetMaxRes.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V2EpisodePickerGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V2EpisodePickerGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v2EpisodePickerGetMaxResListToJson(
    List<enums.V2EpisodePickerGetMaxRes>? v2EpisodePickerGetMaxRes) {
  if (v2EpisodePickerGetMaxRes == null) {
    return [];
  }

  return v2EpisodePickerGetMaxRes
      .map((e) => enums.$V2EpisodePickerGetMaxResMap[e]!)
      .toList();
}

List<enums.V2EpisodePickerGetMaxRes> v2EpisodePickerGetMaxResListFromJson(
  List? v2EpisodePickerGetMaxRes, [
  List<enums.V2EpisodePickerGetMaxRes>? defaultValue,
]) {
  if (v2EpisodePickerGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v2EpisodePickerGetMaxRes
      .map((e) => v2EpisodePickerGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V2EpisodePickerGetMaxRes>?
    v2EpisodePickerGetMaxResNullableListFromJson(
  List? v2EpisodePickerGetMaxRes, [
  List<enums.V2EpisodePickerGetMaxRes>? defaultValue,
]) {
  if (v2EpisodePickerGetMaxRes == null) {
    return defaultValue;
  }

  return v2EpisodePickerGetMaxRes
      .map((e) => v2EpisodePickerGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1ShowAlsoAvailableOnGetMaxResToJson(
    enums.V1ShowAlsoAvailableOnGetMaxRes? v1ShowAlsoAvailableOnGetMaxRes) {
  return enums
      .$V1ShowAlsoAvailableOnGetMaxResMap[v1ShowAlsoAvailableOnGetMaxRes];
}

enums.V1ShowAlsoAvailableOnGetMaxRes v1ShowAlsoAvailableOnGetMaxResFromJson(
  Object? v1ShowAlsoAvailableOnGetMaxRes, [
  enums.V1ShowAlsoAvailableOnGetMaxRes? defaultValue,
]) {
  if (v1ShowAlsoAvailableOnGetMaxRes is String) {
    return enums.$V1ShowAlsoAvailableOnGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1ShowAlsoAvailableOnGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1ShowAlsoAvailableOnGetMaxRes.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1ShowAlsoAvailableOnGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1ShowAlsoAvailableOnGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1ShowAlsoAvailableOnGetMaxResListToJson(
    List<enums.V1ShowAlsoAvailableOnGetMaxRes>?
        v1ShowAlsoAvailableOnGetMaxRes) {
  if (v1ShowAlsoAvailableOnGetMaxRes == null) {
    return [];
  }

  return v1ShowAlsoAvailableOnGetMaxRes
      .map((e) => enums.$V1ShowAlsoAvailableOnGetMaxResMap[e]!)
      .toList();
}

List<enums.V1ShowAlsoAvailableOnGetMaxRes>
    v1ShowAlsoAvailableOnGetMaxResListFromJson(
  List? v1ShowAlsoAvailableOnGetMaxRes, [
  List<enums.V1ShowAlsoAvailableOnGetMaxRes>? defaultValue,
]) {
  if (v1ShowAlsoAvailableOnGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1ShowAlsoAvailableOnGetMaxRes
      .map((e) => v1ShowAlsoAvailableOnGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1ShowAlsoAvailableOnGetMaxRes>?
    v1ShowAlsoAvailableOnGetMaxResNullableListFromJson(
  List? v1ShowAlsoAvailableOnGetMaxRes, [
  List<enums.V1ShowAlsoAvailableOnGetMaxRes>? defaultValue,
]) {
  if (v1ShowAlsoAvailableOnGetMaxRes == null) {
    return defaultValue;
  }

  return v1ShowAlsoAvailableOnGetMaxRes
      .map((e) => v1ShowAlsoAvailableOnGetMaxResFromJson(e.toString()))
      .toList();
}

String? v1RecordingSourcesTypeCridLanguageGetTypeToJson(
    enums.V1RecordingSourcesTypeCridLanguageGetType?
        v1RecordingSourcesTypeCridLanguageGetType) {
  return enums.$V1RecordingSourcesTypeCridLanguageGetTypeMap[
      v1RecordingSourcesTypeCridLanguageGetType];
}

enums.V1RecordingSourcesTypeCridLanguageGetType
    v1RecordingSourcesTypeCridLanguageGetTypeFromJson(
  Object? v1RecordingSourcesTypeCridLanguageGetType, [
  enums.V1RecordingSourcesTypeCridLanguageGetType? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetType is String) {
    return enums.$V1RecordingSourcesTypeCridLanguageGetTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1RecordingSourcesTypeCridLanguageGetType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1RecordingSourcesTypeCridLanguageGetType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1RecordingSourcesTypeCridLanguageGetTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1RecordingSourcesTypeCridLanguageGetType.swaggerGeneratedUnknown;
}

List<String> v1RecordingSourcesTypeCridLanguageGetTypeListToJson(
    List<enums.V1RecordingSourcesTypeCridLanguageGetType>?
        v1RecordingSourcesTypeCridLanguageGetType) {
  if (v1RecordingSourcesTypeCridLanguageGetType == null) {
    return [];
  }

  return v1RecordingSourcesTypeCridLanguageGetType
      .map((e) => enums.$V1RecordingSourcesTypeCridLanguageGetTypeMap[e]!)
      .toList();
}

List<enums.V1RecordingSourcesTypeCridLanguageGetType>
    v1RecordingSourcesTypeCridLanguageGetTypeListFromJson(
  List? v1RecordingSourcesTypeCridLanguageGetType, [
  List<enums.V1RecordingSourcesTypeCridLanguageGetType>? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetType == null) {
    return defaultValue ?? [];
  }

  return v1RecordingSourcesTypeCridLanguageGetType
      .map((e) =>
          v1RecordingSourcesTypeCridLanguageGetTypeFromJson(e.toString()))
      .toList();
}

List<enums.V1RecordingSourcesTypeCridLanguageGetType>?
    v1RecordingSourcesTypeCridLanguageGetTypeNullableListFromJson(
  List? v1RecordingSourcesTypeCridLanguageGetType, [
  List<enums.V1RecordingSourcesTypeCridLanguageGetType>? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetType == null) {
    return defaultValue;
  }

  return v1RecordingSourcesTypeCridLanguageGetType
      .map((e) =>
          v1RecordingSourcesTypeCridLanguageGetTypeFromJson(e.toString()))
      .toList();
}

String? v1RecordingSourcesTypeCridLanguageGetMaxResToJson(
    enums.V1RecordingSourcesTypeCridLanguageGetMaxRes?
        v1RecordingSourcesTypeCridLanguageGetMaxRes) {
  return enums.$V1RecordingSourcesTypeCridLanguageGetMaxResMap[
      v1RecordingSourcesTypeCridLanguageGetMaxRes];
}

enums.V1RecordingSourcesTypeCridLanguageGetMaxRes
    v1RecordingSourcesTypeCridLanguageGetMaxResFromJson(
  Object? v1RecordingSourcesTypeCridLanguageGetMaxRes, [
  enums.V1RecordingSourcesTypeCridLanguageGetMaxRes? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetMaxRes is String) {
    return enums.$V1RecordingSourcesTypeCridLanguageGetMaxResMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                v1RecordingSourcesTypeCridLanguageGetMaxRes.toLowerCase(),
            orElse: () => const MapEntry(
                enums.V1RecordingSourcesTypeCridLanguageGetMaxRes
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$V1RecordingSourcesTypeCridLanguageGetMaxResMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.V1RecordingSourcesTypeCridLanguageGetMaxRes.swaggerGeneratedUnknown;
}

List<String> v1RecordingSourcesTypeCridLanguageGetMaxResListToJson(
    List<enums.V1RecordingSourcesTypeCridLanguageGetMaxRes>?
        v1RecordingSourcesTypeCridLanguageGetMaxRes) {
  if (v1RecordingSourcesTypeCridLanguageGetMaxRes == null) {
    return [];
  }

  return v1RecordingSourcesTypeCridLanguageGetMaxRes
      .map((e) => enums.$V1RecordingSourcesTypeCridLanguageGetMaxResMap[e]!)
      .toList();
}

List<enums.V1RecordingSourcesTypeCridLanguageGetMaxRes>
    v1RecordingSourcesTypeCridLanguageGetMaxResListFromJson(
  List? v1RecordingSourcesTypeCridLanguageGetMaxRes, [
  List<enums.V1RecordingSourcesTypeCridLanguageGetMaxRes>? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetMaxRes == null) {
    return defaultValue ?? [];
  }

  return v1RecordingSourcesTypeCridLanguageGetMaxRes
      .map((e) =>
          v1RecordingSourcesTypeCridLanguageGetMaxResFromJson(e.toString()))
      .toList();
}

List<enums.V1RecordingSourcesTypeCridLanguageGetMaxRes>?
    v1RecordingSourcesTypeCridLanguageGetMaxResNullableListFromJson(
  List? v1RecordingSourcesTypeCridLanguageGetMaxRes, [
  List<enums.V1RecordingSourcesTypeCridLanguageGetMaxRes>? defaultValue,
]) {
  if (v1RecordingSourcesTypeCridLanguageGetMaxRes == null) {
    return defaultValue;
  }

  return v1RecordingSourcesTypeCridLanguageGetMaxRes
      .map((e) =>
          v1RecordingSourcesTypeCridLanguageGetMaxResFromJson(e.toString()))
      .toList();
}

String? vodResponseTypeToJson(enums.VodResponseType? vodResponseType) {
  return enums.$VodResponseTypeMap[vodResponseType];
}

enums.VodResponseType vodResponseTypeFromJson(
  Object? vodResponseType, [
  enums.VodResponseType? defaultValue,
]) {
  if (vodResponseType is String) {
    return enums.$VodResponseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == vodResponseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VodResponseType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VodResponseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VodResponseType.swaggerGeneratedUnknown;
}

List<String> vodResponseTypeListToJson(
    List<enums.VodResponseType>? vodResponseType) {
  if (vodResponseType == null) {
    return [];
  }

  return vodResponseType.map((e) => enums.$VodResponseTypeMap[e]!).toList();
}

List<enums.VodResponseType> vodResponseTypeListFromJson(
  List? vodResponseType, [
  List<enums.VodResponseType>? defaultValue,
]) {
  if (vodResponseType == null) {
    return defaultValue ?? [];
  }

  return vodResponseType
      .map((e) => vodResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.VodResponseType>? vodResponseTypeNullableListFromJson(
  List? vodResponseType, [
  List<enums.VodResponseType>? defaultValue,
]) {
  if (vodResponseType == null) {
    return defaultValue;
  }

  return vodResponseType
      .map((e) => vodResponseTypeFromJson(e.toString()))
      .toList();
}

String? vodResponseEntitlementStateToJson(
    enums.VodResponseEntitlementState? vodResponseEntitlementState) {
  return enums.$VodResponseEntitlementStateMap[vodResponseEntitlementState];
}

enums.VodResponseEntitlementState vodResponseEntitlementStateFromJson(
  Object? vodResponseEntitlementState, [
  enums.VodResponseEntitlementState? defaultValue,
]) {
  if (vodResponseEntitlementState is String) {
    return enums.$VodResponseEntitlementStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                vodResponseEntitlementState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VodResponseEntitlementState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VodResponseEntitlementStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VodResponseEntitlementState.swaggerGeneratedUnknown;
}

List<String> vodResponseEntitlementStateListToJson(
    List<enums.VodResponseEntitlementState>? vodResponseEntitlementState) {
  if (vodResponseEntitlementState == null) {
    return [];
  }

  return vodResponseEntitlementState
      .map((e) => enums.$VodResponseEntitlementStateMap[e]!)
      .toList();
}

List<enums.VodResponseEntitlementState> vodResponseEntitlementStateListFromJson(
  List? vodResponseEntitlementState, [
  List<enums.VodResponseEntitlementState>? defaultValue,
]) {
  if (vodResponseEntitlementState == null) {
    return defaultValue ?? [];
  }

  return vodResponseEntitlementState
      .map((e) => vodResponseEntitlementStateFromJson(e.toString()))
      .toList();
}

List<enums.VodResponseEntitlementState>?
    vodResponseEntitlementStateNullableListFromJson(
  List? vodResponseEntitlementState, [
  List<enums.VodResponseEntitlementState>? defaultValue,
]) {
  if (vodResponseEntitlementState == null) {
    return defaultValue;
  }

  return vodResponseEntitlementState
      .map((e) => vodResponseEntitlementStateFromJson(e.toString()))
      .toList();
}

String? viewProgressResponseViewStateToJson(
    enums.ViewProgressResponseViewState? viewProgressResponseViewState) {
  return enums.$ViewProgressResponseViewStateMap[viewProgressResponseViewState];
}

enums.ViewProgressResponseViewState viewProgressResponseViewStateFromJson(
  Object? viewProgressResponseViewState, [
  enums.ViewProgressResponseViewState? defaultValue,
]) {
  if (viewProgressResponseViewState is String) {
    return enums.$ViewProgressResponseViewStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                viewProgressResponseViewState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ViewProgressResponseViewState.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ViewProgressResponseViewStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ViewProgressResponseViewState.swaggerGeneratedUnknown;
}

List<String> viewProgressResponseViewStateListToJson(
    List<enums.ViewProgressResponseViewState>? viewProgressResponseViewState) {
  if (viewProgressResponseViewState == null) {
    return [];
  }

  return viewProgressResponseViewState
      .map((e) => enums.$ViewProgressResponseViewStateMap[e]!)
      .toList();
}

List<enums.ViewProgressResponseViewState>
    viewProgressResponseViewStateListFromJson(
  List? viewProgressResponseViewState, [
  List<enums.ViewProgressResponseViewState>? defaultValue,
]) {
  if (viewProgressResponseViewState == null) {
    return defaultValue ?? [];
  }

  return viewProgressResponseViewState
      .map((e) => viewProgressResponseViewStateFromJson(e.toString()))
      .toList();
}

List<enums.ViewProgressResponseViewState>?
    viewProgressResponseViewStateNullableListFromJson(
  List? viewProgressResponseViewState, [
  List<enums.ViewProgressResponseViewState>? defaultValue,
]) {
  if (viewProgressResponseViewState == null) {
    return defaultValue;
  }

  return viewProgressResponseViewState
      .map((e) => viewProgressResponseViewStateFromJson(e.toString()))
      .toList();
}

String? sourceTypeResponseToJson(enums.SourceTypeResponse? sourceTypeResponse) {
  return enums.$SourceTypeResponseMap[sourceTypeResponse];
}

enums.SourceTypeResponse sourceTypeResponseFromJson(
  Object? sourceTypeResponse, [
  enums.SourceTypeResponse? defaultValue,
]) {
  if (sourceTypeResponse is String) {
    return enums.$SourceTypeResponseMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == sourceTypeResponse.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SourceTypeResponse.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SourceTypeResponseMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SourceTypeResponse.swaggerGeneratedUnknown;
}

List<String> sourceTypeResponseListToJson(
    List<enums.SourceTypeResponse>? sourceTypeResponse) {
  if (sourceTypeResponse == null) {
    return [];
  }

  return sourceTypeResponse
      .map((e) => enums.$SourceTypeResponseMap[e]!)
      .toList();
}

List<enums.SourceTypeResponse> sourceTypeResponseListFromJson(
  List? sourceTypeResponse, [
  List<enums.SourceTypeResponse>? defaultValue,
]) {
  if (sourceTypeResponse == null) {
    return defaultValue ?? [];
  }

  return sourceTypeResponse
      .map((e) => sourceTypeResponseFromJson(e.toString()))
      .toList();
}

List<enums.SourceTypeResponse>? sourceTypeResponseNullableListFromJson(
  List? sourceTypeResponse, [
  List<enums.SourceTypeResponse>? defaultValue,
]) {
  if (sourceTypeResponse == null) {
    return defaultValue;
  }

  return sourceTypeResponse
      .map((e) => sourceTypeResponseFromJson(e.toString()))
      .toList();
}

String? recordingSourceResponseRecordingStateToJson(
    enums.RecordingSourceResponseRecordingState?
        recordingSourceResponseRecordingState) {
  return enums.$RecordingSourceResponseRecordingStateMap[
      recordingSourceResponseRecordingState];
}

enums.RecordingSourceResponseRecordingState
    recordingSourceResponseRecordingStateFromJson(
  Object? recordingSourceResponseRecordingState, [
  enums.RecordingSourceResponseRecordingState? defaultValue,
]) {
  if (recordingSourceResponseRecordingState is String) {
    return enums.$RecordingSourceResponseRecordingStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                recordingSourceResponseRecordingState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.RecordingSourceResponseRecordingState
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RecordingSourceResponseRecordingStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RecordingSourceResponseRecordingState.swaggerGeneratedUnknown;
}

List<String> recordingSourceResponseRecordingStateListToJson(
    List<enums.RecordingSourceResponseRecordingState>?
        recordingSourceResponseRecordingState) {
  if (recordingSourceResponseRecordingState == null) {
    return [];
  }

  return recordingSourceResponseRecordingState
      .map((e) => enums.$RecordingSourceResponseRecordingStateMap[e]!)
      .toList();
}

List<enums.RecordingSourceResponseRecordingState>
    recordingSourceResponseRecordingStateListFromJson(
  List? recordingSourceResponseRecordingState, [
  List<enums.RecordingSourceResponseRecordingState>? defaultValue,
]) {
  if (recordingSourceResponseRecordingState == null) {
    return defaultValue ?? [];
  }

  return recordingSourceResponseRecordingState
      .map((e) => recordingSourceResponseRecordingStateFromJson(e.toString()))
      .toList();
}

List<enums.RecordingSourceResponseRecordingState>?
    recordingSourceResponseRecordingStateNullableListFromJson(
  List? recordingSourceResponseRecordingState, [
  List<enums.RecordingSourceResponseRecordingState>? defaultValue,
]) {
  if (recordingSourceResponseRecordingState == null) {
    return defaultValue;
  }

  return recordingSourceResponseRecordingState
      .map((e) => recordingSourceResponseRecordingStateFromJson(e.toString()))
      .toList();
}

String? vodSourceResponseTypeToJson(
    enums.VodSourceResponseType? vodSourceResponseType) {
  return enums.$VodSourceResponseTypeMap[vodSourceResponseType];
}

enums.VodSourceResponseType vodSourceResponseTypeFromJson(
  Object? vodSourceResponseType, [
  enums.VodSourceResponseType? defaultValue,
]) {
  if (vodSourceResponseType is String) {
    return enums.$VodSourceResponseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                vodSourceResponseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.VodSourceResponseType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$VodSourceResponseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.VodSourceResponseType.swaggerGeneratedUnknown;
}

List<String> vodSourceResponseTypeListToJson(
    List<enums.VodSourceResponseType>? vodSourceResponseType) {
  if (vodSourceResponseType == null) {
    return [];
  }

  return vodSourceResponseType
      .map((e) => enums.$VodSourceResponseTypeMap[e]!)
      .toList();
}

List<enums.VodSourceResponseType> vodSourceResponseTypeListFromJson(
  List? vodSourceResponseType, [
  List<enums.VodSourceResponseType>? defaultValue,
]) {
  if (vodSourceResponseType == null) {
    return defaultValue ?? [];
  }

  return vodSourceResponseType
      .map((e) => vodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.VodSourceResponseType>? vodSourceResponseTypeNullableListFromJson(
  List? vodSourceResponseType, [
  List<enums.VodSourceResponseType>? defaultValue,
]) {
  if (vodSourceResponseType == null) {
    return defaultValue;
  }

  return vodSourceResponseType
      .map((e) => vodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

String? episodePickerVodSourceResponseTypeToJson(
    enums.EpisodePickerVodSourceResponseType?
        episodePickerVodSourceResponseType) {
  return enums.$EpisodePickerVodSourceResponseTypeMap[
      episodePickerVodSourceResponseType];
}

enums.EpisodePickerVodSourceResponseType
    episodePickerVodSourceResponseTypeFromJson(
  Object? episodePickerVodSourceResponseType, [
  enums.EpisodePickerVodSourceResponseType? defaultValue,
]) {
  if (episodePickerVodSourceResponseType is String) {
    return enums.$EpisodePickerVodSourceResponseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                episodePickerVodSourceResponseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums
                    .EpisodePickerVodSourceResponseType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EpisodePickerVodSourceResponseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EpisodePickerVodSourceResponseType.swaggerGeneratedUnknown;
}

List<String> episodePickerVodSourceResponseTypeListToJson(
    List<enums.EpisodePickerVodSourceResponseType>?
        episodePickerVodSourceResponseType) {
  if (episodePickerVodSourceResponseType == null) {
    return [];
  }

  return episodePickerVodSourceResponseType
      .map((e) => enums.$EpisodePickerVodSourceResponseTypeMap[e]!)
      .toList();
}

List<enums.EpisodePickerVodSourceResponseType>
    episodePickerVodSourceResponseTypeListFromJson(
  List? episodePickerVodSourceResponseType, [
  List<enums.EpisodePickerVodSourceResponseType>? defaultValue,
]) {
  if (episodePickerVodSourceResponseType == null) {
    return defaultValue ?? [];
  }

  return episodePickerVodSourceResponseType
      .map((e) => episodePickerVodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.EpisodePickerVodSourceResponseType>?
    episodePickerVodSourceResponseTypeNullableListFromJson(
  List? episodePickerVodSourceResponseType, [
  List<enums.EpisodePickerVodSourceResponseType>? defaultValue,
]) {
  if (episodePickerVodSourceResponseType == null) {
    return defaultValue;
  }

  return episodePickerVodSourceResponseType
      .map((e) => episodePickerVodSourceResponseTypeFromJson(e.toString()))
      .toList();
}

String? episodePickerEpisodeResponseTypeToJson(
    enums.EpisodePickerEpisodeResponseType? episodePickerEpisodeResponseType) {
  return enums
      .$EpisodePickerEpisodeResponseTypeMap[episodePickerEpisodeResponseType];
}

enums.EpisodePickerEpisodeResponseType episodePickerEpisodeResponseTypeFromJson(
  Object? episodePickerEpisodeResponseType, [
  enums.EpisodePickerEpisodeResponseType? defaultValue,
]) {
  if (episodePickerEpisodeResponseType is String) {
    return enums.$EpisodePickerEpisodeResponseTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                episodePickerEpisodeResponseType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.EpisodePickerEpisodeResponseType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EpisodePickerEpisodeResponseTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EpisodePickerEpisodeResponseType.swaggerGeneratedUnknown;
}

List<String> episodePickerEpisodeResponseTypeListToJson(
    List<enums.EpisodePickerEpisodeResponseType>?
        episodePickerEpisodeResponseType) {
  if (episodePickerEpisodeResponseType == null) {
    return [];
  }

  return episodePickerEpisodeResponseType
      .map((e) => enums.$EpisodePickerEpisodeResponseTypeMap[e]!)
      .toList();
}

List<enums.EpisodePickerEpisodeResponseType>
    episodePickerEpisodeResponseTypeListFromJson(
  List? episodePickerEpisodeResponseType, [
  List<enums.EpisodePickerEpisodeResponseType>? defaultValue,
]) {
  if (episodePickerEpisodeResponseType == null) {
    return defaultValue ?? [];
  }

  return episodePickerEpisodeResponseType
      .map((e) => episodePickerEpisodeResponseTypeFromJson(e.toString()))
      .toList();
}

List<enums.EpisodePickerEpisodeResponseType>?
    episodePickerEpisodeResponseTypeNullableListFromJson(
  List? episodePickerEpisodeResponseType, [
  List<enums.EpisodePickerEpisodeResponseType>? defaultValue,
]) {
  if (episodePickerEpisodeResponseType == null) {
    return defaultValue;
  }

  return episodePickerEpisodeResponseType
      .map((e) => episodePickerEpisodeResponseTypeFromJson(e.toString()))
      .toList();
}

String? saaoSourceResponseContentTypeToJson(
    enums.SaaoSourceResponseContentType? saaoSourceResponseContentType) {
  return enums.$SaaoSourceResponseContentTypeMap[saaoSourceResponseContentType];
}

enums.SaaoSourceResponseContentType saaoSourceResponseContentTypeFromJson(
  Object? saaoSourceResponseContentType, [
  enums.SaaoSourceResponseContentType? defaultValue,
]) {
  if (saaoSourceResponseContentType is String) {
    return enums.$SaaoSourceResponseContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                saaoSourceResponseContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SaaoSourceResponseContentType.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SaaoSourceResponseContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SaaoSourceResponseContentType.swaggerGeneratedUnknown;
}

List<String> saaoSourceResponseContentTypeListToJson(
    List<enums.SaaoSourceResponseContentType>? saaoSourceResponseContentType) {
  if (saaoSourceResponseContentType == null) {
    return [];
  }

  return saaoSourceResponseContentType
      .map((e) => enums.$SaaoSourceResponseContentTypeMap[e]!)
      .toList();
}

List<enums.SaaoSourceResponseContentType>
    saaoSourceResponseContentTypeListFromJson(
  List? saaoSourceResponseContentType, [
  List<enums.SaaoSourceResponseContentType>? defaultValue,
]) {
  if (saaoSourceResponseContentType == null) {
    return defaultValue ?? [];
  }

  return saaoSourceResponseContentType
      .map((e) => saaoSourceResponseContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.SaaoSourceResponseContentType>?
    saaoSourceResponseContentTypeNullableListFromJson(
  List? saaoSourceResponseContentType, [
  List<enums.SaaoSourceResponseContentType>? defaultValue,
]) {
  if (saaoSourceResponseContentType == null) {
    return defaultValue;
  }

  return saaoSourceResponseContentType
      .map((e) => saaoSourceResponseContentTypeFromJson(e.toString()))
      .toList();
}

String? linearContentSourceTypeToJson(
    enums.LinearContentSourceType? linearContentSourceType) {
  return enums.$LinearContentSourceTypeMap[linearContentSourceType];
}

enums.LinearContentSourceType linearContentSourceTypeFromJson(
  Object? linearContentSourceType, [
  enums.LinearContentSourceType? defaultValue,
]) {
  if (linearContentSourceType is String) {
    return enums.$LinearContentSourceTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                linearContentSourceType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.LinearContentSourceType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LinearContentSourceTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LinearContentSourceType.swaggerGeneratedUnknown;
}

List<String> linearContentSourceTypeListToJson(
    List<enums.LinearContentSourceType>? linearContentSourceType) {
  if (linearContentSourceType == null) {
    return [];
  }

  return linearContentSourceType
      .map((e) => enums.$LinearContentSourceTypeMap[e]!)
      .toList();
}

List<enums.LinearContentSourceType> linearContentSourceTypeListFromJson(
  List? linearContentSourceType, [
  List<enums.LinearContentSourceType>? defaultValue,
]) {
  if (linearContentSourceType == null) {
    return defaultValue ?? [];
  }

  return linearContentSourceType
      .map((e) => linearContentSourceTypeFromJson(e.toString()))
      .toList();
}

List<enums.LinearContentSourceType>?
    linearContentSourceTypeNullableListFromJson(
  List? linearContentSourceType, [
  List<enums.LinearContentSourceType>? defaultValue,
]) {
  if (linearContentSourceType == null) {
    return defaultValue;
  }

  return linearContentSourceType
      .map((e) => linearContentSourceTypeFromJson(e.toString()))
      .toList();
}

String? mostRelevantEpisodeResponseContentTypeToJson(
    enums.MostRelevantEpisodeResponseContentType?
        mostRelevantEpisodeResponseContentType) {
  return enums.$MostRelevantEpisodeResponseContentTypeMap[
      mostRelevantEpisodeResponseContentType];
}

enums.MostRelevantEpisodeResponseContentType
    mostRelevantEpisodeResponseContentTypeFromJson(
  Object? mostRelevantEpisodeResponseContentType, [
  enums.MostRelevantEpisodeResponseContentType? defaultValue,
]) {
  if (mostRelevantEpisodeResponseContentType is String) {
    return enums.$MostRelevantEpisodeResponseContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                mostRelevantEpisodeResponseContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MostRelevantEpisodeResponseContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MostRelevantEpisodeResponseContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MostRelevantEpisodeResponseContentType.swaggerGeneratedUnknown;
}

List<String> mostRelevantEpisodeResponseContentTypeListToJson(
    List<enums.MostRelevantEpisodeResponseContentType>?
        mostRelevantEpisodeResponseContentType) {
  if (mostRelevantEpisodeResponseContentType == null) {
    return [];
  }

  return mostRelevantEpisodeResponseContentType
      .map((e) => enums.$MostRelevantEpisodeResponseContentTypeMap[e]!)
      .toList();
}

List<enums.MostRelevantEpisodeResponseContentType>
    mostRelevantEpisodeResponseContentTypeListFromJson(
  List? mostRelevantEpisodeResponseContentType, [
  List<enums.MostRelevantEpisodeResponseContentType>? defaultValue,
]) {
  if (mostRelevantEpisodeResponseContentType == null) {
    return defaultValue ?? [];
  }

  return mostRelevantEpisodeResponseContentType
      .map((e) => mostRelevantEpisodeResponseContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.MostRelevantEpisodeResponseContentType>?
    mostRelevantEpisodeResponseContentTypeNullableListFromJson(
  List? mostRelevantEpisodeResponseContentType, [
  List<enums.MostRelevantEpisodeResponseContentType>? defaultValue,
]) {
  if (mostRelevantEpisodeResponseContentType == null) {
    return defaultValue;
  }

  return mostRelevantEpisodeResponseContentType
      .map((e) => mostRelevantEpisodeResponseContentTypeFromJson(e.toString()))
      .toList();
}

String? mostRelevantSourceResponseContentTypeToJson(
    enums.MostRelevantSourceResponseContentType?
        mostRelevantSourceResponseContentType) {
  return enums.$MostRelevantSourceResponseContentTypeMap[
      mostRelevantSourceResponseContentType];
}

enums.MostRelevantSourceResponseContentType
    mostRelevantSourceResponseContentTypeFromJson(
  Object? mostRelevantSourceResponseContentType, [
  enums.MostRelevantSourceResponseContentType? defaultValue,
]) {
  if (mostRelevantSourceResponseContentType is String) {
    return enums.$MostRelevantSourceResponseContentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                mostRelevantSourceResponseContentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.MostRelevantSourceResponseContentType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$MostRelevantSourceResponseContentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.MostRelevantSourceResponseContentType.swaggerGeneratedUnknown;
}

List<String> mostRelevantSourceResponseContentTypeListToJson(
    List<enums.MostRelevantSourceResponseContentType>?
        mostRelevantSourceResponseContentType) {
  if (mostRelevantSourceResponseContentType == null) {
    return [];
  }

  return mostRelevantSourceResponseContentType
      .map((e) => enums.$MostRelevantSourceResponseContentTypeMap[e]!)
      .toList();
}

List<enums.MostRelevantSourceResponseContentType>
    mostRelevantSourceResponseContentTypeListFromJson(
  List? mostRelevantSourceResponseContentType, [
  List<enums.MostRelevantSourceResponseContentType>? defaultValue,
]) {
  if (mostRelevantSourceResponseContentType == null) {
    return defaultValue ?? [];
  }

  return mostRelevantSourceResponseContentType
      .map((e) => mostRelevantSourceResponseContentTypeFromJson(e.toString()))
      .toList();
}

List<enums.MostRelevantSourceResponseContentType>?
    mostRelevantSourceResponseContentTypeNullableListFromJson(
  List? mostRelevantSourceResponseContentType, [
  List<enums.MostRelevantSourceResponseContentType>? defaultValue,
]) {
  if (mostRelevantSourceResponseContentType == null) {
    return defaultValue;
  }

  return mostRelevantSourceResponseContentType
      .map((e) => mostRelevantSourceResponseContentTypeFromJson(e.toString()))
      .toList();
}

@JsonSerializable(explicitToJson: true)
class SpaResponse {
  SpaResponse({
    this.id,
    required this.showPageAvailable,
  });

  factory SpaResponse.fromJson(Map<String, dynamic> json) =>
      _$SpaResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'showPageAvailable', includeIfNull: false)
  final bool showPageAvailable;
  static const fromJsonFactory = _$SpaResponseFromJson;
  static const toJsonFactory = _$SpaResponseToJson;
  Map<String, dynamic> toJson() => _$SpaResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SpaResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.showPageAvailable, showPageAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.showPageAvailable, showPageAvailable)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(showPageAvailable) ^
      runtimeType.hashCode;
}

extension $SpaResponseExtension on SpaResponse {
  SpaResponse copyWith({String? id, bool? showPageAvailable}) {
    return SpaResponse(
        id: id ?? this.id,
        showPageAvailable: showPageAvailable ?? this.showPageAvailable);
  }

  SpaResponse copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<bool>? showPageAvailable}) {
    return SpaResponse(
        id: (id != null ? id.value : this.id),
        showPageAvailable: (showPageAvailable != null
            ? showPageAvailable.value
            : this.showPageAvailable));
  }
}

@JsonSerializable(explicitToJson: true)
class SaaoResponse {
  SaaoResponse({
    this.selectedSources,
    required this.sources,
  });

  factory SaaoResponse.fromJson(Map<String, dynamic> json) =>
      _$SaaoResponseFromJson(json);

  @JsonKey(name: 'selectedSources', includeIfNull: false)
  final SaaoSourceResponse? selectedSources;
  @JsonKey(
      name: 'sources',
      includeIfNull: false,
      defaultValue: <SaaoSourceResponse>[])
  final List<SaaoSourceResponse> sources;
  static const fromJsonFactory = _$SaaoResponseFromJson;
  static const toJsonFactory = _$SaaoResponseToJson;
  Map<String, dynamic> toJson() => _$SaaoResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SaaoResponse &&
            (identical(other.selectedSources, selectedSources) ||
                const DeepCollectionEquality()
                    .equals(other.selectedSources, selectedSources)) &&
            (identical(other.sources, sources) ||
                const DeepCollectionEquality().equals(other.sources, sources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(selectedSources) ^
      const DeepCollectionEquality().hash(sources) ^
      runtimeType.hashCode;
}

extension $SaaoResponseExtension on SaaoResponse {
  SaaoResponse copyWith(
      {SaaoSourceResponse? selectedSources,
      List<SaaoSourceResponse>? sources}) {
    return SaaoResponse(
        selectedSources: selectedSources ?? this.selectedSources,
        sources: sources ?? this.sources);
  }

  SaaoResponse copyWithWrapped(
      {Wrapped<SaaoSourceResponse?>? selectedSources,
      Wrapped<List<SaaoSourceResponse>>? sources}) {
    return SaaoResponse(
        selectedSources: (selectedSources != null
            ? selectedSources.value
            : this.selectedSources),
        sources: (sources != null ? sources.value : this.sources));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerResponse {
  EpisodePickerResponse({
    required this.id,
    required this.title,
    this.startYear,
    this.endYear,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.seasons,
    this.episodes,
    this.specials,
    this.selectedEpisode,
    this.imageVersion,
    this.mergedId,
  });

  factory EpisodePickerResponse.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startYear', includeIfNull: false)
  final int? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false)
  final int? endYear;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(
      name: 'seasons',
      includeIfNull: false,
      defaultValue: <EpisodePickerSeasonResponse>[])
  final List<EpisodePickerSeasonResponse>? seasons;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? episodes;
  @JsonKey(
      name: 'specials',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? specials;
  @JsonKey(name: 'selectedEpisode', includeIfNull: false, defaultValue: '')
  final String? selectedEpisode;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$EpisodePickerResponseFromJson;
  static const toJsonFactory = _$EpisodePickerResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.specials, specials) ||
                const DeepCollectionEquality()
                    .equals(other.specials, specials)) &&
            (identical(other.selectedEpisode, selectedEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEpisode, selectedEpisode)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(specials) ^
      const DeepCollectionEquality().hash(selectedEpisode) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $EpisodePickerResponseExtension on EpisodePickerResponse {
  EpisodePickerResponse copyWith(
      {String? id,
      String? title,
      int? startYear,
      int? endYear,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      List<EpisodePickerSeasonResponse>? seasons,
      List<EpisodePickerEpisodeResponse>? episodes,
      List<EpisodePickerEpisodeResponse>? specials,
      String? selectedEpisode,
      String? imageVersion,
      String? mergedId}) {
    return EpisodePickerResponse(
        id: id ?? this.id,
        title: title ?? this.title,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        specials: specials ?? this.specials,
        selectedEpisode: selectedEpisode ?? this.selectedEpisode,
        imageVersion: imageVersion ?? this.imageVersion,
        mergedId: mergedId ?? this.mergedId);
  }

  EpisodePickerResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<int?>? startYear,
      Wrapped<int?>? endYear,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<List<EpisodePickerSeasonResponse>?>? seasons,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? episodes,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? specials,
      Wrapped<String?>? selectedEpisode,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mergedId}) {
    return EpisodePickerResponse(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        specials: (specials != null ? specials.value : this.specials),
        selectedEpisode: (selectedEpisode != null
            ? selectedEpisode.value
            : this.selectedEpisode),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class EpisodePickerV2Response {
  EpisodePickerV2Response({
    required this.id,
    required this.title,
    this.startYear,
    this.endYear,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.groupedBy,
    this.mepSeriesFinale,
    this.premiereAirings,
    this.seasons,
    this.episodes,
    this.specials,
    this.others,
    this.yearOfProduction,
    this.selectedEpisode,
    this.imageVersion,
    this.mergedId,
  });

  factory EpisodePickerV2Response.fromJson(Map<String, dynamic> json) =>
      _$EpisodePickerV2ResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startYear', includeIfNull: false)
  final int? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false)
  final int? endYear;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'groupedBy', includeIfNull: false, defaultValue: '')
  final String? groupedBy;
  @JsonKey(name: 'mepSeriesFinale', includeIfNull: false, defaultValue: '')
  final String? mepSeriesFinale;
  @JsonKey(name: 'premiereAirings', includeIfNull: false)
  final bool? premiereAirings;
  @JsonKey(
      name: 'seasons',
      includeIfNull: false,
      defaultValue: <EpisodePickerSeasonResponse>[])
  final List<EpisodePickerSeasonResponse>? seasons;
  @JsonKey(
      name: 'episodes',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? episodes;
  @JsonKey(
      name: 'specials',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? specials;
  @JsonKey(
      name: 'others',
      includeIfNull: false,
      defaultValue: <EpisodePickerEpisodeResponse>[])
  final List<EpisodePickerEpisodeResponse>? others;
  @JsonKey(
      name: 'yearOfProduction',
      includeIfNull: false,
      defaultValue: <EpisodePickerYearOfProductionResponse>[])
  final List<EpisodePickerYearOfProductionResponse>? yearOfProduction;
  @JsonKey(name: 'selectedEpisode', includeIfNull: false, defaultValue: '')
  final String? selectedEpisode;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$EpisodePickerV2ResponseFromJson;
  static const toJsonFactory = _$EpisodePickerV2ResponseToJson;
  Map<String, dynamic> toJson() => _$EpisodePickerV2ResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EpisodePickerV2Response &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.groupedBy, groupedBy) ||
                const DeepCollectionEquality()
                    .equals(other.groupedBy, groupedBy)) &&
            (identical(other.mepSeriesFinale, mepSeriesFinale) ||
                const DeepCollectionEquality()
                    .equals(other.mepSeriesFinale, mepSeriesFinale)) &&
            (identical(other.premiereAirings, premiereAirings) ||
                const DeepCollectionEquality()
                    .equals(other.premiereAirings, premiereAirings)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.specials, specials) ||
                const DeepCollectionEquality()
                    .equals(other.specials, specials)) &&
            (identical(other.others, others) ||
                const DeepCollectionEquality().equals(other.others, others)) &&
            (identical(other.yearOfProduction, yearOfProduction) ||
                const DeepCollectionEquality()
                    .equals(other.yearOfProduction, yearOfProduction)) &&
            (identical(other.selectedEpisode, selectedEpisode) ||
                const DeepCollectionEquality()
                    .equals(other.selectedEpisode, selectedEpisode)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(groupedBy) ^
      const DeepCollectionEquality().hash(mepSeriesFinale) ^
      const DeepCollectionEquality().hash(premiereAirings) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(specials) ^
      const DeepCollectionEquality().hash(others) ^
      const DeepCollectionEquality().hash(yearOfProduction) ^
      const DeepCollectionEquality().hash(selectedEpisode) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $EpisodePickerV2ResponseExtension on EpisodePickerV2Response {
  EpisodePickerV2Response copyWith(
      {String? id,
      String? title,
      int? startYear,
      int? endYear,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      String? groupedBy,
      String? mepSeriesFinale,
      bool? premiereAirings,
      List<EpisodePickerSeasonResponse>? seasons,
      List<EpisodePickerEpisodeResponse>? episodes,
      List<EpisodePickerEpisodeResponse>? specials,
      List<EpisodePickerEpisodeResponse>? others,
      List<EpisodePickerYearOfProductionResponse>? yearOfProduction,
      String? selectedEpisode,
      String? imageVersion,
      String? mergedId}) {
    return EpisodePickerV2Response(
        id: id ?? this.id,
        title: title ?? this.title,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        groupedBy: groupedBy ?? this.groupedBy,
        mepSeriesFinale: mepSeriesFinale ?? this.mepSeriesFinale,
        premiereAirings: premiereAirings ?? this.premiereAirings,
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        specials: specials ?? this.specials,
        others: others ?? this.others,
        yearOfProduction: yearOfProduction ?? this.yearOfProduction,
        selectedEpisode: selectedEpisode ?? this.selectedEpisode,
        imageVersion: imageVersion ?? this.imageVersion,
        mergedId: mergedId ?? this.mergedId);
  }

  EpisodePickerV2Response copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<int?>? startYear,
      Wrapped<int?>? endYear,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? groupedBy,
      Wrapped<String?>? mepSeriesFinale,
      Wrapped<bool?>? premiereAirings,
      Wrapped<List<EpisodePickerSeasonResponse>?>? seasons,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? episodes,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? specials,
      Wrapped<List<EpisodePickerEpisodeResponse>?>? others,
      Wrapped<List<EpisodePickerYearOfProductionResponse>?>? yearOfProduction,
      Wrapped<String?>? selectedEpisode,
      Wrapped<String?>? imageVersion,
      Wrapped<String?>? mergedId}) {
    return EpisodePickerV2Response(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        groupedBy: (groupedBy != null ? groupedBy.value : this.groupedBy),
        mepSeriesFinale: (mepSeriesFinale != null
            ? mepSeriesFinale.value
            : this.mepSeriesFinale),
        premiereAirings: (premiereAirings != null
            ? premiereAirings.value
            : this.premiereAirings),
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        specials: (specials != null ? specials.value : this.specials),
        others: (others != null ? others.value : this.others),
        yearOfProduction: (yearOfProduction != null
            ? yearOfProduction.value
            : this.yearOfProduction),
        selectedEpisode: (selectedEpisode != null
            ? selectedEpisode.value
            : this.selectedEpisode),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowPageResponse {
  ShowPageResponse({
    required this.id,
    required this.title,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.startYear,
    this.endYear,
    required this.previews,
    this.seasonCount,
    this.imageVersion,
    this.productionCountries,
    this.mergedId,
  });

  factory ShowPageResponse.fromJson(Map<String, dynamic> json) =>
      _$ShowPageResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'startYear', includeIfNull: false, defaultValue: '')
  final String? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false, defaultValue: '')
  final String? endYear;
  @JsonKey(
      name: 'previews',
      includeIfNull: false,
      defaultValue: <TrailerInfoResponse>[])
  final List<TrailerInfoResponse> previews;
  @JsonKey(name: 'seasonCount', includeIfNull: false)
  final int? seasonCount;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(
      name: 'productionCountries',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? productionCountries;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$ShowPageResponseFromJson;
  static const toJsonFactory = _$ShowPageResponseToJson;
  Map<String, dynamic> toJson() => _$ShowPageResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowPageResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.previews, previews) ||
                const DeepCollectionEquality()
                    .equals(other.previews, previews)) &&
            (identical(other.seasonCount, seasonCount) ||
                const DeepCollectionEquality()
                    .equals(other.seasonCount, seasonCount)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(other.productionCountries, productionCountries) ||
                const DeepCollectionEquality()
                    .equals(other.productionCountries, productionCountries)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(previews) ^
      const DeepCollectionEquality().hash(seasonCount) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(productionCountries) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $ShowPageResponseExtension on ShowPageResponse {
  ShowPageResponse copyWith(
      {String? id,
      String? title,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      String? startYear,
      String? endYear,
      List<TrailerInfoResponse>? previews,
      int? seasonCount,
      String? imageVersion,
      List<String>? productionCountries,
      String? mergedId}) {
    return ShowPageResponse(
        id: id ?? this.id,
        title: title ?? this.title,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        previews: previews ?? this.previews,
        seasonCount: seasonCount ?? this.seasonCount,
        imageVersion: imageVersion ?? this.imageVersion,
        productionCountries: productionCountries ?? this.productionCountries,
        mergedId: mergedId ?? this.mergedId);
  }

  ShowPageResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? startYear,
      Wrapped<String?>? endYear,
      Wrapped<List<TrailerInfoResponse>>? previews,
      Wrapped<int?>? seasonCount,
      Wrapped<String?>? imageVersion,
      Wrapped<List<String>?>? productionCountries,
      Wrapped<String?>? mergedId}) {
    return ShowPageResponse(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        previews: (previews != null ? previews.value : this.previews),
        seasonCount:
            (seasonCount != null ? seasonCount.value : this.seasonCount),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        productionCountries: (productionCountries != null
            ? productionCountries.value
            : this.productionCountries),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchDetailsResponse {
  SearchDetailsResponse({
    this.results,
  });

  factory SearchDetailsResponse.fromJson(Map<String, dynamic> json) =>
      _$SearchDetailsResponseFromJson(json);

  @JsonKey(
      name: 'results',
      includeIfNull: false,
      defaultValue: <SearchDetailsResponse$Results>[])
  final List<SearchDetailsResponse$Results>? results;
  static const fromJsonFactory = _$SearchDetailsResponseFromJson;
  static const toJsonFactory = _$SearchDetailsResponseToJson;
  Map<String, dynamic> toJson() => _$SearchDetailsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchDetailsResponse &&
            (identical(other.results, results) ||
                const DeepCollectionEquality().equals(other.results, results)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(results) ^ runtimeType.hashCode;
}

extension $SearchDetailsResponseExtension on SearchDetailsResponse {
  SearchDetailsResponse copyWith(
      {List<SearchDetailsResponse$Results>? results}) {
    return SearchDetailsResponse(results: results ?? this.results);
  }

  SearchDetailsResponse copyWithWrapped(
      {Wrapped<List<SearchDetailsResponse$Results>?>? results}) {
    return SearchDetailsResponse(
        results: (results != null ? results.value : this.results));
  }
}

@JsonSerializable(explicitToJson: true)
class EventDetailResponse {
  EventDetailResponse({
    required this.titleCrid,
    required this.eventId,
    required this.contentType,
    required this.channelId,
    this.broadcastDate,
    this.broadcastEndDate,
    this.bookmark,
    this.channel,
    this.replayAvailable,
    this.imageVersion,
  });

  factory EventDetailResponse.fromJson(Map<String, dynamic> json) =>
      _$EventDetailResponseFromJson(json);

  @JsonKey(name: 'titleCrid', includeIfNull: false, defaultValue: '')
  final String titleCrid;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'contentType', includeIfNull: false, defaultValue: '')
  final String contentType;
  @JsonKey(name: 'channelId', includeIfNull: false)
  final int channelId;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'broadcastEndDate', includeIfNull: false, defaultValue: '')
  final String? broadcastEndDate;
  @JsonKey(name: 'bookmark', includeIfNull: false)
  final int? bookmark;
  @JsonKey(
      name: 'channel',
      includeIfNull: false,
      defaultValue: <ChannelEventDetailResponse>[])
  final List<ChannelEventDetailResponse>? channel;
  @JsonKey(name: 'replayAvailable', includeIfNull: false)
  final bool? replayAvailable;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$EventDetailResponseFromJson;
  static const toJsonFactory = _$EventDetailResponseToJson;
  Map<String, dynamic> toJson() => _$EventDetailResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventDetailResponse &&
            (identical(other.titleCrid, titleCrid) ||
                const DeepCollectionEquality()
                    .equals(other.titleCrid, titleCrid)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.broadcastEndDate, broadcastEndDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastEndDate, broadcastEndDate)) &&
            (identical(other.bookmark, bookmark) ||
                const DeepCollectionEquality()
                    .equals(other.bookmark, bookmark)) &&
            (identical(other.channel, channel) ||
                const DeepCollectionEquality()
                    .equals(other.channel, channel)) &&
            (identical(other.replayAvailable, replayAvailable) ||
                const DeepCollectionEquality()
                    .equals(other.replayAvailable, replayAvailable)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleCrid) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(broadcastEndDate) ^
      const DeepCollectionEquality().hash(bookmark) ^
      const DeepCollectionEquality().hash(channel) ^
      const DeepCollectionEquality().hash(replayAvailable) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $EventDetailResponseExtension on EventDetailResponse {
  EventDetailResponse copyWith(
      {String? titleCrid,
      String? eventId,
      String? contentType,
      int? channelId,
      String? broadcastDate,
      String? broadcastEndDate,
      int? bookmark,
      List<ChannelEventDetailResponse>? channel,
      bool? replayAvailable,
      String? imageVersion}) {
    return EventDetailResponse(
        titleCrid: titleCrid ?? this.titleCrid,
        eventId: eventId ?? this.eventId,
        contentType: contentType ?? this.contentType,
        channelId: channelId ?? this.channelId,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        broadcastEndDate: broadcastEndDate ?? this.broadcastEndDate,
        bookmark: bookmark ?? this.bookmark,
        channel: channel ?? this.channel,
        replayAvailable: replayAvailable ?? this.replayAvailable,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  EventDetailResponse copyWithWrapped(
      {Wrapped<String>? titleCrid,
      Wrapped<String>? eventId,
      Wrapped<String>? contentType,
      Wrapped<int>? channelId,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? broadcastEndDate,
      Wrapped<int?>? bookmark,
      Wrapped<List<ChannelEventDetailResponse>?>? channel,
      Wrapped<bool?>? replayAvailable,
      Wrapped<String?>? imageVersion}) {
    return EventDetailResponse(
        titleCrid: (titleCrid != null ? titleCrid.value : this.titleCrid),
        eventId: (eventId != null ? eventId.value : this.eventId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        channelId: (channelId != null ? channelId.value : this.channelId),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        broadcastEndDate: (broadcastEndDate != null
            ? broadcastEndDate.value
            : this.broadcastEndDate),
        bookmark: (bookmark != null ? bookmark.value : this.bookmark),
        channel: (channel != null ? channel.value : this.channel),
        replayAvailable: (replayAvailable != null
            ? replayAvailable.value
            : this.replayAvailable),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class SeriesDetailResponse {
  SeriesDetailResponse({
    required this.id,
    required this.title,
    this.startYear,
    this.endYear,
    this.genres,
    this.ageRating,
    required this.isAdult,
    this.synopsis,
    this.image,
    this.seasons,
    this.episodes,
    this.imageVersion,
  });

  factory SeriesDetailResponse.fromJson(Map<String, dynamic> json) =>
      _$SeriesDetailResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'startYear', includeIfNull: false, defaultValue: '')
  final String? startYear;
  @JsonKey(name: 'endYear', includeIfNull: false, defaultValue: '')
  final String? endYear;
  @JsonKey(name: 'genres', includeIfNull: false, defaultValue: <String>[])
  final List<String>? genres;
  @JsonKey(name: 'ageRating', includeIfNull: false, defaultValue: '')
  final String? ageRating;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'synopsis', includeIfNull: false, defaultValue: '')
  final String? synopsis;
  @JsonKey(name: 'image', includeIfNull: false, defaultValue: '')
  final String? image;
  @JsonKey(name: 'seasons', includeIfNull: false)
  final SeasonResponse? seasons;
  @JsonKey(name: 'episodes', includeIfNull: false)
  final EpisodeResponse? episodes;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$SeriesDetailResponseFromJson;
  static const toJsonFactory = _$SeriesDetailResponseToJson;
  Map<String, dynamic> toJson() => _$SeriesDetailResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SeriesDetailResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.startYear, startYear) ||
                const DeepCollectionEquality()
                    .equals(other.startYear, startYear)) &&
            (identical(other.endYear, endYear) ||
                const DeepCollectionEquality()
                    .equals(other.endYear, endYear)) &&
            (identical(other.genres, genres) ||
                const DeepCollectionEquality().equals(other.genres, genres)) &&
            (identical(other.ageRating, ageRating) ||
                const DeepCollectionEquality()
                    .equals(other.ageRating, ageRating)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.synopsis, synopsis) ||
                const DeepCollectionEquality()
                    .equals(other.synopsis, synopsis)) &&
            (identical(other.image, image) ||
                const DeepCollectionEquality().equals(other.image, image)) &&
            (identical(other.seasons, seasons) ||
                const DeepCollectionEquality()
                    .equals(other.seasons, seasons)) &&
            (identical(other.episodes, episodes) ||
                const DeepCollectionEquality()
                    .equals(other.episodes, episodes)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(startYear) ^
      const DeepCollectionEquality().hash(endYear) ^
      const DeepCollectionEquality().hash(genres) ^
      const DeepCollectionEquality().hash(ageRating) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(synopsis) ^
      const DeepCollectionEquality().hash(image) ^
      const DeepCollectionEquality().hash(seasons) ^
      const DeepCollectionEquality().hash(episodes) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $SeriesDetailResponseExtension on SeriesDetailResponse {
  SeriesDetailResponse copyWith(
      {String? id,
      String? title,
      String? startYear,
      String? endYear,
      List<String>? genres,
      String? ageRating,
      bool? isAdult,
      String? synopsis,
      String? image,
      SeasonResponse? seasons,
      EpisodeResponse? episodes,
      String? imageVersion}) {
    return SeriesDetailResponse(
        id: id ?? this.id,
        title: title ?? this.title,
        startYear: startYear ?? this.startYear,
        endYear: endYear ?? this.endYear,
        genres: genres ?? this.genres,
        ageRating: ageRating ?? this.ageRating,
        isAdult: isAdult ?? this.isAdult,
        synopsis: synopsis ?? this.synopsis,
        image: image ?? this.image,
        seasons: seasons ?? this.seasons,
        episodes: episodes ?? this.episodes,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  SeriesDetailResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? title,
      Wrapped<String?>? startYear,
      Wrapped<String?>? endYear,
      Wrapped<List<String>?>? genres,
      Wrapped<String?>? ageRating,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? synopsis,
      Wrapped<String?>? image,
      Wrapped<SeasonResponse?>? seasons,
      Wrapped<EpisodeResponse?>? episodes,
      Wrapped<String?>? imageVersion}) {
    return SeriesDetailResponse(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        startYear: (startYear != null ? startYear.value : this.startYear),
        endYear: (endYear != null ? endYear.value : this.endYear),
        genres: (genres != null ? genres.value : this.genres),
        ageRating: (ageRating != null ? ageRating.value : this.ageRating),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        synopsis: (synopsis != null ? synopsis.value : this.synopsis),
        image: (image != null ? image.value : this.image),
        seasons: (seasons != null ? seasons.value : this.seasons),
        episodes: (episodes != null ? episodes.value : this.episodes),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisodeResponse {
  MostRelevantEpisodeResponse({
    required this.titleId,
    required this.seriesId,
    this.seasonId,
    this.episodeNumber,
    this.seasonNumber,
    this.instanceId,
    this.contentType,
    this.contentSource,
    this.includesVOD,
    this.hasInteracted,
    this.recordingId,
    this.brandingProviderId,
    this.isGoPlayable,
    this.viewProgress,
    this.channelId,
    this.imageVersion,
  });

  factory MostRelevantEpisodeResponse.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantEpisodeResponseFromJson(json);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String seriesId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'instanceId', includeIfNull: false, defaultValue: '')
  final String? instanceId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: mostRelevantEpisodeResponseContentTypeToJson,
    fromJson: mostRelevantEpisodeResponseContentTypeFromJson,
  )
  final enums.MostRelevantEpisodeResponseContentType? contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int? contentSource;
  @JsonKey(name: 'includesVOD', includeIfNull: false)
  final bool? includesVOD;
  @JsonKey(name: 'hasInteracted', includeIfNull: false)
  final bool? hasInteracted;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String? recordingId;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'viewProgress', includeIfNull: false)
  final ViewProgressResponse? viewProgress;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  static const fromJsonFactory = _$MostRelevantEpisodeResponseFromJson;
  static const toJsonFactory = _$MostRelevantEpisodeResponseToJson;
  Map<String, dynamic> toJson() => _$MostRelevantEpisodeResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisodeResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.instanceId, instanceId) ||
                const DeepCollectionEquality()
                    .equals(other.instanceId, instanceId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.includesVOD, includesVOD) ||
                const DeepCollectionEquality()
                    .equals(other.includesVOD, includesVOD)) &&
            (identical(other.hasInteracted, hasInteracted) ||
                const DeepCollectionEquality()
                    .equals(other.hasInteracted, hasInteracted)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.viewProgress, viewProgress) ||
                const DeepCollectionEquality()
                    .equals(other.viewProgress, viewProgress)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(instanceId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(includesVOD) ^
      const DeepCollectionEquality().hash(hasInteracted) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(viewProgress) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeResponseExtension on MostRelevantEpisodeResponse {
  MostRelevantEpisodeResponse copyWith(
      {String? titleId,
      String? seriesId,
      String? seasonId,
      int? episodeNumber,
      int? seasonNumber,
      String? instanceId,
      enums.MostRelevantEpisodeResponseContentType? contentType,
      int? contentSource,
      bool? includesVOD,
      bool? hasInteracted,
      String? recordingId,
      String? brandingProviderId,
      bool? isGoPlayable,
      ViewProgressResponse? viewProgress,
      String? channelId,
      String? imageVersion}) {
    return MostRelevantEpisodeResponse(
        titleId: titleId ?? this.titleId,
        seriesId: seriesId ?? this.seriesId,
        seasonId: seasonId ?? this.seasonId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        instanceId: instanceId ?? this.instanceId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        includesVOD: includesVOD ?? this.includesVOD,
        hasInteracted: hasInteracted ?? this.hasInteracted,
        recordingId: recordingId ?? this.recordingId,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        viewProgress: viewProgress ?? this.viewProgress,
        channelId: channelId ?? this.channelId,
        imageVersion: imageVersion ?? this.imageVersion);
  }

  MostRelevantEpisodeResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String>? seriesId,
      Wrapped<String?>? seasonId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? instanceId,
      Wrapped<enums.MostRelevantEpisodeResponseContentType?>? contentType,
      Wrapped<int?>? contentSource,
      Wrapped<bool?>? includesVOD,
      Wrapped<bool?>? hasInteracted,
      Wrapped<String?>? recordingId,
      Wrapped<String?>? brandingProviderId,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<ViewProgressResponse?>? viewProgress,
      Wrapped<String?>? channelId,
      Wrapped<String?>? imageVersion}) {
    return MostRelevantEpisodeResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        instanceId: (instanceId != null ? instanceId.value : this.instanceId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        includesVOD:
            (includesVOD != null ? includesVOD.value : this.includesVOD),
        hasInteracted:
            (hasInteracted != null ? hasInteracted.value : this.hasInteracted),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        viewProgress:
            (viewProgress != null ? viewProgress.value : this.viewProgress),
        channelId: (channelId != null ? channelId.value : this.channelId),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantSourceResponse {
  MostRelevantSourceResponse({
    required this.titleId,
    this.seriesId,
    this.seasonId,
    this.episodeNumber,
    this.episodePart,
    this.seasonNumber,
    required this.instanceId,
    this.recordingId,
    required this.contentType,
    required this.contentSource,
    this.brandingProviderId,
    this.channelId,
    this.isGoPlayable,
    this.broadcastDate,
    this.imageVersion,
    this.goPlayableViaExternalApp,
    this.externalAppUrls,
    this.mergedId,
  });

  factory MostRelevantSourceResponse.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantSourceResponseFromJson(json);

  @JsonKey(name: 'titleId', includeIfNull: false, defaultValue: '')
  final String titleId;
  @JsonKey(name: 'seriesId', includeIfNull: false, defaultValue: '')
  final String? seriesId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'instanceId', includeIfNull: false, defaultValue: '')
  final String instanceId;
  @JsonKey(name: 'recordingId', includeIfNull: false, defaultValue: '')
  final String? recordingId;
  @JsonKey(
    name: 'contentType',
    includeIfNull: false,
    toJson: mostRelevantSourceResponseContentTypeToJson,
    fromJson: mostRelevantSourceResponseContentTypeFromJson,
  )
  final enums.MostRelevantSourceResponseContentType contentType;
  @JsonKey(name: 'contentSource', includeIfNull: false)
  final int contentSource;
  @JsonKey(name: 'brandingProviderId', includeIfNull: false, defaultValue: '')
  final String? brandingProviderId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'isGoPlayable', includeIfNull: false)
  final bool? isGoPlayable;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String? broadcastDate;
  @JsonKey(name: 'imageVersion', includeIfNull: false, defaultValue: '')
  final String? imageVersion;
  @JsonKey(name: 'goPlayableViaExternalApp', includeIfNull: false)
  final bool? goPlayableViaExternalApp;
  @JsonKey(
      name: 'externalAppUrls',
      includeIfNull: false,
      defaultValue: <ExternalAppUrlResponse>[])
  final List<ExternalAppUrlResponse>? externalAppUrls;
  @JsonKey(name: 'mergedId', includeIfNull: false, defaultValue: '')
  final String? mergedId;
  static const fromJsonFactory = _$MostRelevantSourceResponseFromJson;
  static const toJsonFactory = _$MostRelevantSourceResponseToJson;
  Map<String, dynamic> toJson() => _$MostRelevantSourceResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantSourceResponse &&
            (identical(other.titleId, titleId) ||
                const DeepCollectionEquality()
                    .equals(other.titleId, titleId)) &&
            (identical(other.seriesId, seriesId) ||
                const DeepCollectionEquality()
                    .equals(other.seriesId, seriesId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.instanceId, instanceId) ||
                const DeepCollectionEquality()
                    .equals(other.instanceId, instanceId)) &&
            (identical(other.recordingId, recordingId) ||
                const DeepCollectionEquality()
                    .equals(other.recordingId, recordingId)) &&
            (identical(other.contentType, contentType) ||
                const DeepCollectionEquality()
                    .equals(other.contentType, contentType)) &&
            (identical(other.contentSource, contentSource) ||
                const DeepCollectionEquality()
                    .equals(other.contentSource, contentSource)) &&
            (identical(other.brandingProviderId, brandingProviderId) ||
                const DeepCollectionEquality()
                    .equals(other.brandingProviderId, brandingProviderId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.isGoPlayable, isGoPlayable) ||
                const DeepCollectionEquality()
                    .equals(other.isGoPlayable, isGoPlayable)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)) &&
            (identical(other.imageVersion, imageVersion) ||
                const DeepCollectionEquality()
                    .equals(other.imageVersion, imageVersion)) &&
            (identical(
                    other.goPlayableViaExternalApp, goPlayableViaExternalApp) ||
                const DeepCollectionEquality().equals(
                    other.goPlayableViaExternalApp,
                    goPlayableViaExternalApp)) &&
            (identical(other.externalAppUrls, externalAppUrls) ||
                const DeepCollectionEquality()
                    .equals(other.externalAppUrls, externalAppUrls)) &&
            (identical(other.mergedId, mergedId) ||
                const DeepCollectionEquality()
                    .equals(other.mergedId, mergedId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleId) ^
      const DeepCollectionEquality().hash(seriesId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(instanceId) ^
      const DeepCollectionEquality().hash(recordingId) ^
      const DeepCollectionEquality().hash(contentType) ^
      const DeepCollectionEquality().hash(contentSource) ^
      const DeepCollectionEquality().hash(brandingProviderId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(isGoPlayable) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      const DeepCollectionEquality().hash(imageVersion) ^
      const DeepCollectionEquality().hash(goPlayableViaExternalApp) ^
      const DeepCollectionEquality().hash(externalAppUrls) ^
      const DeepCollectionEquality().hash(mergedId) ^
      runtimeType.hashCode;
}

extension $MostRelevantSourceResponseExtension on MostRelevantSourceResponse {
  MostRelevantSourceResponse copyWith(
      {String? titleId,
      String? seriesId,
      String? seasonId,
      int? episodeNumber,
      int? episodePart,
      int? seasonNumber,
      String? instanceId,
      String? recordingId,
      enums.MostRelevantSourceResponseContentType? contentType,
      int? contentSource,
      String? brandingProviderId,
      String? channelId,
      bool? isGoPlayable,
      String? broadcastDate,
      String? imageVersion,
      bool? goPlayableViaExternalApp,
      List<ExternalAppUrlResponse>? externalAppUrls,
      String? mergedId}) {
    return MostRelevantSourceResponse(
        titleId: titleId ?? this.titleId,
        seriesId: seriesId ?? this.seriesId,
        seasonId: seasonId ?? this.seasonId,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        instanceId: instanceId ?? this.instanceId,
        recordingId: recordingId ?? this.recordingId,
        contentType: contentType ?? this.contentType,
        contentSource: contentSource ?? this.contentSource,
        brandingProviderId: brandingProviderId ?? this.brandingProviderId,
        channelId: channelId ?? this.channelId,
        isGoPlayable: isGoPlayable ?? this.isGoPlayable,
        broadcastDate: broadcastDate ?? this.broadcastDate,
        imageVersion: imageVersion ?? this.imageVersion,
        goPlayableViaExternalApp:
            goPlayableViaExternalApp ?? this.goPlayableViaExternalApp,
        externalAppUrls: externalAppUrls ?? this.externalAppUrls,
        mergedId: mergedId ?? this.mergedId);
  }

  MostRelevantSourceResponse copyWithWrapped(
      {Wrapped<String>? titleId,
      Wrapped<String?>? seriesId,
      Wrapped<String?>? seasonId,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<int?>? seasonNumber,
      Wrapped<String>? instanceId,
      Wrapped<String?>? recordingId,
      Wrapped<enums.MostRelevantSourceResponseContentType>? contentType,
      Wrapped<int>? contentSource,
      Wrapped<String?>? brandingProviderId,
      Wrapped<String?>? channelId,
      Wrapped<bool?>? isGoPlayable,
      Wrapped<String?>? broadcastDate,
      Wrapped<String?>? imageVersion,
      Wrapped<bool?>? goPlayableViaExternalApp,
      Wrapped<List<ExternalAppUrlResponse>?>? externalAppUrls,
      Wrapped<String?>? mergedId}) {
    return MostRelevantSourceResponse(
        titleId: (titleId != null ? titleId.value : this.titleId),
        seriesId: (seriesId != null ? seriesId.value : this.seriesId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        instanceId: (instanceId != null ? instanceId.value : this.instanceId),
        recordingId:
            (recordingId != null ? recordingId.value : this.recordingId),
        contentType:
            (contentType != null ? contentType.value : this.contentType),
        contentSource:
            (contentSource != null ? contentSource.value : this.contentSource),
        brandingProviderId: (brandingProviderId != null
            ? brandingProviderId.value
            : this.brandingProviderId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        isGoPlayable:
            (isGoPlayable != null ? isGoPlayable.value : this.isGoPlayable),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate),
        imageVersion:
            (imageVersion != null ? imageVersion.value : this.imageVersion),
        goPlayableViaExternalApp: (goPlayableViaExternalApp != null
            ? goPlayableViaExternalApp.value
            : this.goPlayableViaExternalApp),
        externalAppUrls: (externalAppUrls != null
            ? externalAppUrls.value
            : this.externalAppUrls),
        mergedId: (mergedId != null ? mergedId.value : this.mergedId));
  }
}

@JsonSerializable(explicitToJson: true)
class RreResponse {
  RreResponse({
    required this.id,
    required this.eventId,
    this.seasonNumber,
    this.episodeNumber,
    this.episodePart,
    required this.broadcastDate,
  });

  factory RreResponse.fromJson(Map<String, dynamic> json) =>
      _$RreResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'episodePart', includeIfNull: false)
  final int? episodePart;
  @JsonKey(name: 'broadcastDate', includeIfNull: false, defaultValue: '')
  final String broadcastDate;
  static const fromJsonFactory = _$RreResponseFromJson;
  static const toJsonFactory = _$RreResponseToJson;
  Map<String, dynamic> toJson() => _$RreResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RreResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.episodePart, episodePart) ||
                const DeepCollectionEquality()
                    .equals(other.episodePart, episodePart)) &&
            (identical(other.broadcastDate, broadcastDate) ||
                const DeepCollectionEquality()
                    .equals(other.broadcastDate, broadcastDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(episodePart) ^
      const DeepCollectionEquality().hash(broadcastDate) ^
      runtimeType.hashCode;
}

extension $RreResponseExtension on RreResponse {
  RreResponse copyWith(
      {String? id,
      String? eventId,
      int? seasonNumber,
      int? episodeNumber,
      int? episodePart,
      String? broadcastDate}) {
    return RreResponse(
        id: id ?? this.id,
        eventId: eventId ?? this.eventId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        episodePart: episodePart ?? this.episodePart,
        broadcastDate: broadcastDate ?? this.broadcastDate);
  }

  RreResponse copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? eventId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? episodePart,
      Wrapped<String>? broadcastDate}) {
    return RreResponse(
        id: (id != null ? id.value : this.id),
        eventId: (eventId != null ? eventId.value : this.eventId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        episodePart:
            (episodePart != null ? episodePart.value : this.episodePart),
        broadcastDate:
            (broadcastDate != null ? broadcastDate.value : this.broadcastDate));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingSourcesResponse {
  RecordingSourcesResponse({
    required this.sources,
  });

  factory RecordingSourcesResponse.fromJson(Map<String, dynamic> json) =>
      _$RecordingSourcesResponseFromJson(json);

  @JsonKey(
      name: 'sources',
      includeIfNull: false,
      defaultValue: <RecordingSourcesSourceObjectResponse>[])
  final List<RecordingSourcesSourceObjectResponse> sources;
  static const fromJsonFactory = _$RecordingSourcesResponseFromJson;
  static const toJsonFactory = _$RecordingSourcesResponseToJson;
  Map<String, dynamic> toJson() => _$RecordingSourcesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingSourcesResponse &&
            (identical(other.sources, sources) ||
                const DeepCollectionEquality().equals(other.sources, sources)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(sources) ^ runtimeType.hashCode;
}

extension $RecordingSourcesResponseExtension on RecordingSourcesResponse {
  RecordingSourcesResponse copyWith(
      {List<RecordingSourcesSourceObjectResponse>? sources}) {
    return RecordingSourcesResponse(sources: sources ?? this.sources);
  }

  RecordingSourcesResponse copyWithWrapped(
      {Wrapped<List<RecordingSourcesSourceObjectResponse>>? sources}) {
    return RecordingSourcesResponse(
        sources: (sources != null ? sources.value : this.sources));
  }
}

@JsonSerializable(explicitToJson: true)
class Error {
  Error({
    this.error,
  });

  factory Error.fromJson(Map<String, dynamic> json) => _$ErrorFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final KrakenError? error;
  static const fromJsonFactory = _$ErrorFromJson;
  static const toJsonFactory = _$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Error &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^ runtimeType.hashCode;
}

extension $ErrorExtension on Error {
  Error copyWith({KrakenError? error}) {
    return Error(error: error ?? this.error);
  }

  Error copyWithWrapped({Wrapped<KrakenError?>? error}) {
    return Error(error: (error != null ? error.value : this.error));
  }
}

typedef SearchDetailsResponse$Results
    = List<SearchDetailsResponse$Results$Item>;

@JsonSerializable(explicitToJson: true)
class SearchDetailsResponse$Results$Item {
  SearchDetailsResponse$Results$Item({
    required this.series,
    required this.multisource,
  });

  factory SearchDetailsResponse$Results$Item.fromJson(
          Map<String, dynamic> json) =>
      _$SearchDetailsResponse$Results$ItemFromJson(json);

  @JsonKey(name: 'series', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> series;
  @JsonKey(name: 'multisource', includeIfNull: false, defaultValue: <Object>[])
  final List<Object> multisource;
  static const fromJsonFactory = _$SearchDetailsResponse$Results$ItemFromJson;
  static const toJsonFactory = _$SearchDetailsResponse$Results$ItemToJson;
  Map<String, dynamic> toJson() =>
      _$SearchDetailsResponse$Results$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchDetailsResponse$Results$Item &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.multisource, multisource) ||
                const DeepCollectionEquality()
                    .equals(other.multisource, multisource)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(multisource) ^
      runtimeType.hashCode;
}

extension $SearchDetailsResponse$Results$ItemExtension
    on SearchDetailsResponse$Results$Item {
  SearchDetailsResponse$Results$Item copyWith(
      {List<Object>? series, List<Object>? multisource}) {
    return SearchDetailsResponse$Results$Item(
        series: series ?? this.series,
        multisource: multisource ?? this.multisource);
  }

  SearchDetailsResponse$Results$Item copyWithWrapped(
      {Wrapped<List<Object>>? series, Wrapped<List<Object>>? multisource}) {
    return SearchDetailsResponse$Results$Item(
        series: (series != null ? series.value : this.series),
        multisource:
            (multisource != null ? multisource.value : this.multisource));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchDetails {
  SearchDetails({
    this.profileId,
    this.seriesIds,
    this.multisourceIds,
    this.replayOptedInTime,
    this.cityId,
  });

  factory SearchDetails.fromJson(Map<String, dynamic> json) =>
      _$SearchDetailsFromJson(json);

  @JsonKey(name: 'profileId', includeIfNull: false, defaultValue: '')
  final String? profileId;
  @JsonKey(name: 'seriesIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesIds;
  @JsonKey(
      name: 'multisourceIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? multisourceIds;
  @JsonKey(name: 'replayOptedInTime', includeIfNull: false)
  final int? replayOptedInTime;
  @JsonKey(name: 'cityId', includeIfNull: false)
  final int? cityId;
  static const fromJsonFactory = _$SearchDetailsFromJson;
  static const toJsonFactory = _$SearchDetailsToJson;
  Map<String, dynamic> toJson() => _$SearchDetailsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchDetails &&
            (identical(other.profileId, profileId) ||
                const DeepCollectionEquality()
                    .equals(other.profileId, profileId)) &&
            (identical(other.seriesIds, seriesIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesIds, seriesIds)) &&
            (identical(other.multisourceIds, multisourceIds) ||
                const DeepCollectionEquality()
                    .equals(other.multisourceIds, multisourceIds)) &&
            (identical(other.replayOptedInTime, replayOptedInTime) ||
                const DeepCollectionEquality()
                    .equals(other.replayOptedInTime, replayOptedInTime)) &&
            (identical(other.cityId, cityId) ||
                const DeepCollectionEquality().equals(other.cityId, cityId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileId) ^
      const DeepCollectionEquality().hash(seriesIds) ^
      const DeepCollectionEquality().hash(multisourceIds) ^
      const DeepCollectionEquality().hash(replayOptedInTime) ^
      const DeepCollectionEquality().hash(cityId) ^
      runtimeType.hashCode;
}

extension $SearchDetailsExtension on SearchDetails {
  SearchDetails copyWith(
      {String? profileId,
      List<String>? seriesIds,
      List<String>? multisourceIds,
      int? replayOptedInTime,
      int? cityId}) {
    return SearchDetails(
        profileId: profileId ?? this.profileId,
        seriesIds: seriesIds ?? this.seriesIds,
        multisourceIds: multisourceIds ?? this.multisourceIds,
        replayOptedInTime: replayOptedInTime ?? this.replayOptedInTime,
        cityId: cityId ?? this.cityId);
  }

  SearchDetails copyWithWrapped(
      {Wrapped<String?>? profileId,
      Wrapped<List<String>?>? seriesIds,
      Wrapped<List<String>?>? multisourceIds,
      Wrapped<int?>? replayOptedInTime,
      Wrapped<int?>? cityId}) {
    return SearchDetails(
        profileId: (profileId != null ? profileId.value : this.profileId),
        seriesIds: (seriesIds != null ? seriesIds.value : this.seriesIds),
        multisourceIds: (multisourceIds != null
            ? multisourceIds.value
            : this.multisourceIds),
        replayOptedInTime: (replayOptedInTime != null
            ? replayOptedInTime.value
            : this.replayOptedInTime),
        cityId: (cityId != null ? cityId.value : this.cityId));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
