// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'recording_management_service.enums.swagger.dart' as enums;
export 'recording_management_service.enums.swagger.dart';

part 'recording_management_service.swagger.chopper.dart';
part 'recording_management_service.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class RecordingManagementService extends ChopperService {
  static RecordingManagementService create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$RecordingManagementService(client);
    }

    final newClient = ChopperClient(
        services: [_$RecordingManagementService()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$RecordingManagementService(newClient);
  }

  ///Upload a complete list of local recordings for specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<List<DuplicatedRecording>>>
      customersCustomerIdCpesCpeIdRecordingsPut({
    required String? customerId,
    required String? cpeId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required List<LocalRecording>? body,
  }) {
    generatedMapping.putIfAbsent(
        DuplicatedRecording, () => DuplicatedRecording.fromJsonFactory);

    return _customersCustomerIdCpesCpeIdRecordingsPut(
        customerId: customerId,
        cpeId: cpeId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Upload a complete list of local recordings for specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  @Put(path: '/customers/{customerId}/cpes/{cpeId}/recordings')
  Future<chopper.Response<List<DuplicatedRecording>>>
      _customersCustomerIdCpesCpeIdRecordingsPut({
    @Path('customerId') required String? customerId,
    @Path('cpeId') required String? cpeId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required List<LocalRecording>? body,
  });

  ///Upload a single local recording for a specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<List<DuplicatedRecording>>>
      customersCustomerIdCpesCpeIdRecordingsPost({
    required String? customerId,
    required String? cpeId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required LocalRecordingForHorizonGo? body,
  }) {
    generatedMapping.putIfAbsent(
        DuplicatedRecording, () => DuplicatedRecording.fromJsonFactory);

    return _customersCustomerIdCpesCpeIdRecordingsPost(
        customerId: customerId,
        cpeId: cpeId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Upload a single local recording for a specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  @Post(path: '/customers/{customerId}/cpes/{cpeId}/recordings')
  Future<chopper.Response<List<DuplicatedRecording>>>
      _customersCustomerIdCpesCpeIdRecordingsPost({
    @Path('customerId') required String? customerId,
    @Path('cpeId') required String? cpeId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required LocalRecordingForHorizonGo? body,
  });

  ///Delete all series and local recordings or only specific local recordings for a specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdCpesCpeIdRecordingsDelete({
    required String? customerId,
    required String? cpeId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    return _customersCustomerIdCpesCpeIdRecordingsDelete(
        customerId: customerId,
        cpeId: cpeId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Delete all series and local recordings or only specific local recordings for a specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/cpes/{cpeId}/recordings')
  Future<chopper.Response> _customersCustomerIdCpesCpeIdRecordingsDelete({
    @Path('customerId') required String? customerId,
    @Path('cpeId') required String? cpeId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Upload a delta list of local recordings for specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<List<DuplicatedRecording>>>
      customersCustomerIdCpesCpeIdRecordingsPatch({
    required String? customerId,
    required String? cpeId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DuplicatedRecording, () => DuplicatedRecording.fromJsonFactory);

    return _customersCustomerIdCpesCpeIdRecordingsPatch(
        customerId: customerId,
        cpeId: cpeId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Upload a delta list of local recordings for specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param X-Cus Contains customer identifier
  @Patch(path: '/customers/{customerId}/cpes/{cpeId}/recordings')
  Future<chopper.Response<List<DuplicatedRecording>>>
      _customersCustomerIdCpesCpeIdRecordingsPatch({
    @Path('customerId') required String? customerId,
    @Path('cpeId') required String? cpeId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete single local recording for a specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param eventId Event identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdCpesCpeIdRecordingsEventIdDelete({
    required String? customerId,
    required String? cpeId,
    required String? eventId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    return _customersCustomerIdCpesCpeIdRecordingsEventIdDelete(
        customerId: customerId,
        cpeId: cpeId,
        eventId: eventId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Delete single local recording for a specific CPE
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param eventId Event identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/cpes/{cpeId}/recordings/{eventId}')
  Future<chopper.Response>
      _customersCustomerIdCpesCpeIdRecordingsEventIdDelete({
    @Path('customerId') required String? customerId,
    @Path('cpeId') required String? cpeId,
    @Path('eventId') required String? eventId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns a list of recordings
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param collapsing Flag which specifies if shows are collapsed in response.
  ///@param cpeCollapsing Flag which specifies if shows should be additionally collapsed by cpe.
  ///@param mostRelevantEpisodeFor Determines how most relevant episode is calculated
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param seasonIds Comma separated list of season ids
  ///@param showIds Comma separated list of show ids
  ///@param channelIds Comma separated list of channel ids
  ///@param eventId Event id to return
  ///@param eventIds Event ids to be used for filtering
  ///@param groupIds Comma separated list of ids which match season or show id
  ///@param recordingStates Comma separated list of recording states, filter recordings before state transition, get recordings which status in database is equal to one of provided statuses
  ///@param recordingsKind Recordings kind  to return, filter recordings after status transition
  ///@param startTime Used to filter the records, to return only these which are on, or after the startTime.
  ///@param endTime Used to filter the records, to return only these which are before the endTime.
  ///@param startTimeFrom Used to filter the records, to return only these which have startTime after startTimeFrom.
  ///@param startTimeTo Used to filter the records, to return only these which have startTime before startTimeTo.
  ///@param restricted Used to filter the records, indicates that the recording requires an authorization criteria that is not met and cannot be played
  ///@param autoDeletionProtected Used to filter the records, to return only these which have autoDeletionProtected flag set to a corresponding value
  ///@param sort Contains the getEventName of a field which should be used in sorting entities - either time, title or used disk space.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time is used for sorting
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param calculateIsAdultContentAvailable Determines whether isAdultContentAvailable flag should be calculated
  ///@param fields Used to choose which recording fields will be returned.
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<RecordingsView>> customersCustomerIdRecordingsGet({
    required String? customerId,
    String? cpeId,
    bool? collapsing,
    bool? cpeCollapsing,
    enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor?
        mostRelevantEpisodeFor,
    bool? isAdult,
    String? seasonIds,
    String? showIds,
    String? channelIds,
    String? eventId,
    String? eventIds,
    String? groupIds,
    String? recordingStates,
    enums.CustomersCustomerIdRecordingsGetRecordingsKind? recordingsKind,
    String? startTime,
    String? endTime,
    String? startTimeFrom,
    String? startTimeTo,
    bool? restricted,
    bool? autoDeletionProtected,
    enums.CustomersCustomerIdRecordingsGetSort? sort,
    enums.CustomersCustomerIdRecordingsGetSortOrder? sortOrder,
    int? limit,
    int? offset,
    bool? calculateIsAdultContentAvailable,
    String? fields,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingsView, () => RecordingsView.fromJsonFactory);

    return _customersCustomerIdRecordingsGet(
        customerId: customerId,
        cpeId: cpeId,
        collapsing: collapsing,
        cpeCollapsing: cpeCollapsing,
        mostRelevantEpisodeFor: enums
            .$CustomersCustomerIdRecordingsGetMostRelevantEpisodeForMap[
                mostRelevantEpisodeFor]
            ?.toString(),
        isAdult: isAdult,
        seasonIds: seasonIds,
        showIds: showIds,
        channelIds: channelIds,
        eventId: eventId,
        eventIds: eventIds,
        groupIds: groupIds,
        recordingStates: recordingStates,
        recordingsKind: enums
            .$CustomersCustomerIdRecordingsGetRecordingsKindMap[recordingsKind]
            ?.toString(),
        startTime: startTime,
        endTime: endTime,
        startTimeFrom: startTimeFrom,
        startTimeTo: startTimeTo,
        restricted: restricted,
        autoDeletionProtected: autoDeletionProtected,
        sort: enums.$CustomersCustomerIdRecordingsGetSortMap[sort]?.toString(),
        sortOrder: enums
            .$CustomersCustomerIdRecordingsGetSortOrderMap[sortOrder]
            ?.toString(),
        limit: limit,
        offset: offset,
        calculateIsAdultContentAvailable: calculateIsAdultContentAvailable,
        fields: fields,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Returns a list of recordings
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param collapsing Flag which specifies if shows are collapsed in response.
  ///@param cpeCollapsing Flag which specifies if shows should be additionally collapsed by cpe.
  ///@param mostRelevantEpisodeFor Determines how most relevant episode is calculated
  ///@param isAdult Flag which specifies if the adult recordings should be returned, or not.
  ///@param seasonIds Comma separated list of season ids
  ///@param showIds Comma separated list of show ids
  ///@param channelIds Comma separated list of channel ids
  ///@param eventId Event id to return
  ///@param eventIds Event ids to be used for filtering
  ///@param groupIds Comma separated list of ids which match season or show id
  ///@param recordingStates Comma separated list of recording states, filter recordings before state transition, get recordings which status in database is equal to one of provided statuses
  ///@param recordingsKind Recordings kind  to return, filter recordings after status transition
  ///@param startTime Used to filter the records, to return only these which are on, or after the startTime.
  ///@param endTime Used to filter the records, to return only these which are before the endTime.
  ///@param startTimeFrom Used to filter the records, to return only these which have startTime after startTimeFrom.
  ///@param startTimeTo Used to filter the records, to return only these which have startTime before startTimeTo.
  ///@param restricted Used to filter the records, indicates that the recording requires an authorization criteria that is not met and cannot be played
  ///@param autoDeletionProtected Used to filter the records, to return only these which have autoDeletionProtected flag set to a corresponding value
  ///@param sort Contains the getEventName of a field which should be used in sorting entities - either time, title or used disk space.
  ///@param sortOrder Order of sorting, either ascending, or descending. Sort order is taken into account only when time is used for sorting
  ///@param limit Used in paging, means how many entities should be returned at once
  ///@param offset Used in paging, means how many entities should be skipped
  ///@param calculateIsAdultContentAvailable Determines whether isAdultContentAvailable flag should be calculated
  ///@param fields Used to choose which recording fields will be returned.
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}/recordings')
  Future<chopper.Response<RecordingsView>> _customersCustomerIdRecordingsGet({
    @Path('customerId') required String? customerId,
    @Query('cpeId') String? cpeId,
    @Query('collapsing') bool? collapsing,
    @Query('cpeCollapsing') bool? cpeCollapsing,
    @Query('mostRelevantEpisodeFor') String? mostRelevantEpisodeFor,
    @Query('isAdult') bool? isAdult,
    @Query('seasonIds') String? seasonIds,
    @Query('showIds') String? showIds,
    @Query('channelIds') String? channelIds,
    @Query('eventId') String? eventId,
    @Query('eventIds') String? eventIds,
    @Query('groupIds') String? groupIds,
    @Query('recordingStates') String? recordingStates,
    @Query('recordingsKind') String? recordingsKind,
    @Query('startTime') String? startTime,
    @Query('endTime') String? endTime,
    @Query('startTimeFrom') String? startTimeFrom,
    @Query('startTimeTo') String? startTimeTo,
    @Query('restricted') bool? restricted,
    @Query('autoDeletionProtected') bool? autoDeletionProtected,
    @Query('sort') String? sort,
    @Query('sortOrder') String? sortOrder,
    @Query('limit') int? limit,
    @Query('offset') int? offset,
    @Query('calculateIsAdultContentAvailable')
        bool? calculateIsAdultContentAvailable,
    @Query('fields') String? fields,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update multiple network recordings by uploading delta list
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsPatch({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required OpWithNetworkRecordings? body,
  }) {
    return _customersCustomerIdRecordingsPatch(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update multiple network recordings by uploading delta list
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Patch(path: '/customers/{customerId}/recordings')
  Future<chopper.Response> _customersCustomerIdRecordingsPatch({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required OpWithNetworkRecordings? body,
  });

  ///Delete customer specified recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsDelete({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required DeleteRecordingsParams? body,
  }) {
    return _customersCustomerIdRecordingsDelete(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Delete customer specified recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/recordings')
  Future<chopper.Response> _customersCustomerIdRecordingsDelete({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeleteRecordingsParams? body,
  });

  ///Schedule a recording of a single episode or event
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsSinglePost({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required SingleBookingParams? body,
  }) {
    return _customersCustomerIdRecordingsSinglePost(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Schedule a recording of a single episode or event
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Post(path: '/customers/{customerId}/recordings/single')
  Future<chopper.Response> _customersCustomerIdRecordingsSinglePost({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required SingleBookingParams? body,
  });

  ///Delete single recording
  ///@param customerId customer identifier
  ///@param eventId Identifier of single event
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsSingleEventIdDelete({
    required String? customerId,
    required String? eventId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    return _customersCustomerIdRecordingsSingleEventIdDelete(
        customerId: customerId,
        eventId: eventId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Delete single recording
  ///@param customerId customer identifier
  ///@param eventId Identifier of single event
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/recordings/single/{eventId}')
  Future<chopper.Response> _customersCustomerIdRecordingsSingleEventIdDelete({
    @Path('customerId') required String? customerId,
    @Path('eventId') required String? eventId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Cancels specified ongoing episode or removes single booking
  ///@param customerId customer identifier
  ///@param eventId Identifier of a booked episode or single event
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsOngoingEventIdDelete({
    required String? customerId,
    required String? eventId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    return _customersCustomerIdRecordingsOngoingEventIdDelete(
        customerId: customerId,
        eventId: eventId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Cancels specified ongoing episode or removes single booking
  ///@param customerId customer identifier
  ///@param eventId Identifier of a booked episode or single event
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/recordings/ongoing/{eventId}')
  Future<chopper.Response> _customersCustomerIdRecordingsOngoingEventIdDelete({
    @Path('customerId') required String? customerId,
    @Path('eventId') required String? eventId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Returns a list of scheduled shows
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param channelId Channel identifier
  ///@param showId Show identifier
  ///@param autoDeletionProtected Used to filter the records, to return only these which have autoDeletionProtected flag set to a corresponding value
  ///@param recordingType field to be able to distinguish between LDVR and nDVR.
  ///@param fields Used to choose which recording fields will be returned.
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<ShowRecordings>>
      customersCustomerIdRecordingsShowGet({
    required String? customerId,
    String? cpeId,
    String? channelId,
    String? showId,
    bool? autoDeletionProtected,
    enums.CustomersCustomerIdRecordingsShowGetRecordingType? recordingType,
    String? fields,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ShowRecordings, () => ShowRecordings.fromJsonFactory);

    return _customersCustomerIdRecordingsShowGet(
        customerId: customerId,
        cpeId: cpeId,
        channelId: channelId,
        showId: showId,
        autoDeletionProtected: autoDeletionProtected,
        recordingType: enums
            .$CustomersCustomerIdRecordingsShowGetRecordingTypeMap[
                recordingType]
            ?.toString(),
        fields: fields,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Returns a list of scheduled shows
  ///@param customerId customer identifier
  ///@param cpeId CPE identifier
  ///@param channelId Channel identifier
  ///@param showId Show identifier
  ///@param autoDeletionProtected Used to filter the records, to return only these which have autoDeletionProtected flag set to a corresponding value
  ///@param recordingType field to be able to distinguish between LDVR and nDVR.
  ///@param fields Used to choose which recording fields will be returned.
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}/recordings/show')
  Future<chopper.Response<ShowRecordings>>
      _customersCustomerIdRecordingsShowGet({
    @Path('customerId') required String? customerId,
    @Query('cpeId') String? cpeId,
    @Query('channelId') String? channelId,
    @Query('showId') String? showId,
    @Query('autoDeletionProtected') bool? autoDeletionProtected,
    @Query('recordingType') String? recordingType,
    @Query('fields') String? fields,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Schedule a recording of a show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsShowPost({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required ShowBookingParams? body,
  }) {
    return _customersCustomerIdRecordingsShowPost(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Schedule a recording of a show
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Post(path: '/customers/{customerId}/recordings/show')
  Future<chopper.Response> _customersCustomerIdRecordingsShowPost({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required ShowBookingParams? body,
  });

  ///Delete a list of shows
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsShowDelete({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required List<DeleteShowRecordingsParams>? body,
  }) {
    return _customersCustomerIdRecordingsShowDelete(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Delete a list of shows
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/recordings/show')
  Future<chopper.Response> _customersCustomerIdRecordingsShowDelete({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required List<DeleteShowRecordingsParams>? body,
  });

  ///Creating or updating a list of a shows. For nDVR update following fields are supported: retentionPeriod, autoDeletionProtection, expansionType and maxEpisodes
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<List<DuplicatedShowRecording>>>
      customersCustomerIdRecordingsShowPatch({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DuplicatedShowRecording, () => DuplicatedShowRecording.fromJsonFactory);

    return _customersCustomerIdRecordingsShowPatch(
        customerId: customerId, xCus: xCus, cacheControl: cacheControl);
  }

  ///Creating or updating a list of a shows. For nDVR update following fields are supported: retentionPeriod, autoDeletionProtection, expansionType and maxEpisodes
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Patch(path: '/customers/{customerId}/recordings/show')
  Future<chopper.Response<List<DuplicatedShowRecording>>>
      _customersCustomerIdRecordingsShowPatch({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete all recordings and/or cancels season booking
  ///@param customerId customer identifier
  ///@param seasonId season identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsSeasonSeasonIdDelete({
    required String? customerId,
    required String? seasonId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required DeleteGrouppedRecordingsParams? body,
  }) {
    return _customersCustomerIdRecordingsSeasonSeasonIdDelete(
        customerId: customerId,
        seasonId: seasonId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Delete all recordings and/or cancels season booking
  ///@param customerId customer identifier
  ///@param seasonId season identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/recordings/season/{seasonId}')
  Future<chopper.Response> _customersCustomerIdRecordingsSeasonSeasonIdDelete({
    @Path('customerId') required String? customerId,
    @Path('seasonId') required String? seasonId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeleteGrouppedRecordingsParams? body,
  });

  ///Create or update a single show
  ///@param customerId customer identifier
  ///@param showId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<List<DuplicatedShowRecording>>>
      customersCustomerIdRecordingsShowShowIdPut({
    required String? customerId,
    required String? showId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required UploadedSingleShowRecording? body,
  }) {
    generatedMapping.putIfAbsent(
        DuplicatedShowRecording, () => DuplicatedShowRecording.fromJsonFactory);

    return _customersCustomerIdRecordingsShowShowIdPut(
        customerId: customerId,
        showId: showId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create or update a single show
  ///@param customerId customer identifier
  ///@param showId customer identifier
  ///@param X-Cus Contains customer identifier
  @Put(path: '/customers/{customerId}/recordings/show/{showId}')
  Future<chopper.Response<List<DuplicatedShowRecording>>>
      _customersCustomerIdRecordingsShowShowIdPut({
    @Path('customerId') required String? customerId,
    @Path('showId') required String? showId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required UploadedSingleShowRecording? body,
  });

  ///Delete all recordings and/or cancels series booking
  ///@param customerId customer identifier
  ///@param showId show identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdRecordingsShowShowIdDelete({
    required String? customerId,
    required String? showId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required DeleteGrouppedRecordingsParams? body,
  }) {
    return _customersCustomerIdRecordingsShowShowIdDelete(
        customerId: customerId,
        showId: showId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Delete all recordings and/or cancels series booking
  ///@param customerId customer identifier
  ///@param showId show identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}/recordings/show/{showId}')
  Future<chopper.Response> _customersCustomerIdRecordingsShowShowIdDelete({
    @Path('customerId') required String? customerId,
    @Path('showId') required String? showId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required DeleteGrouppedRecordingsParams? body,
  });

  ///Search for recordings for given event ids, group ids or title ids
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<List<SearchRecording>>>
      customersCustomerIdRecordingsSearchPost({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required SearchParams? body,
  }) {
    generatedMapping.putIfAbsent(
        SearchRecording, () => SearchRecording.fromJsonFactory);

    return _customersCustomerIdRecordingsSearchPost(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search for recordings for given event ids, group ids or title ids
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Post(path: '/customers/{customerId}/recordings/search')
  Future<chopper.Response<List<SearchRecording>>>
      _customersCustomerIdRecordingsSearchPost({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required SearchParams? body,
  });

  ///Search for recordings for given titles ids or series ids - for picker service
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  Future<chopper.Response<List<SearchRecording>>>
      pickerServiceCustomersCustomerIdRecordingsSearchPost({
    required String? customerId,
    String? xCus = 'X-Cus',
    String? xDev,
    String? xEntitlementsToken = 'X-Entitlements-Token',
    String? cacheControl,
    required PickerSearchParams? body,
  }) {
    generatedMapping.putIfAbsent(
        SearchRecording, () => SearchRecording.fromJsonFactory);

    return _pickerServiceCustomersCustomerIdRecordingsSearchPost(
        customerId: customerId,
        xCus: xCus,
        xDev: xDev,
        xEntitlementsToken: xEntitlementsToken,
        cacheControl: cacheControl,
        body: body);
  }

  ///Search for recordings for given titles ids or series ids - for picker service
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  ///@param X-Dev Contains device identifier
  ///@param x-entitlements-token Entitlements token
  @Post(path: '/picker-service/customers/{customerId}/recordings/search')
  Future<chopper.Response<List<SearchRecording>>>
      _pickerServiceCustomersCustomerIdRecordingsSearchPost({
    @Path('customerId') required String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('X-Dev') String? xDev,
    @Header('x-entitlements-token')
        String? xEntitlementsToken = 'X-Entitlements-Token',
    @Header('Cache-Control') String? cacheControl,
    @Body() required PickerSearchParams? body,
  });

  ///Returns recording details with podName and streamerName for SeS
  ///@param customerId customer identifier
  ///@param eventId Event identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<RecordingDetails>>
      customersCustomerIdRecordingsEventIdGet({
    required String? customerId,
    required String? eventId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RecordingDetails, () => RecordingDetails.fromJsonFactory);

    return _customersCustomerIdRecordingsEventIdGet(
        customerId: customerId,
        eventId: eventId,
        xCus: xCus,
        cacheControl: cacheControl);
  }

  ///Returns recording details with podName and streamerName for SeS
  ///@param customerId customer identifier
  ///@param eventId Event identifier
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}/recordings/{eventId}')
  Future<chopper.Response<RecordingDetails>>
      _customersCustomerIdRecordingsEventIdGet({
    @Path('customerId') required String? customerId,
    @Path('eventId') required String? eventId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Return the specified customer (His quota, status and entitlements)
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response<CustomerView>> customersCustomerIdGet({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CustomerView, () => CustomerView.fromJsonFactory);

    return _customersCustomerIdGet(
        customerId: customerId, xCus: xCus, cacheControl: cacheControl);
  }

  ///Return the specified customer (His quota, status and entitlements)
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Get(path: '/customers/{customerId}')
  Future<chopper.Response<CustomerView>> _customersCustomerIdGet({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create or update a customer (His status, quota, suspended and/or his entitlements)
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdPut({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
    required CustomerParams? body,
  }) {
    return _customersCustomerIdPut(
        customerId: customerId,
        xCus: xCus,
        cacheControl: cacheControl,
        body: body);
  }

  ///Create or update a customer (His status, quota, suspended and/or his entitlements)
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Put(path: '/customers/{customerId}')
  Future<chopper.Response> _customersCustomerIdPut({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
    @Body() required CustomerParams? body,
  });

  ///Delete a specified customer including all his recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  Future<chopper.Response> customersCustomerIdDelete({
    String? customerId,
    String? xCus = 'X-Cus',
    String? cacheControl,
  }) {
    return _customersCustomerIdDelete(
        customerId: customerId, xCus: xCus, cacheControl: cacheControl);
  }

  ///Delete a specified customer including all his recordings
  ///@param customerId customer identifier
  ///@param X-Cus Contains customer identifier
  @Delete(path: '/customers/{customerId}')
  Future<chopper.Response> _customersCustomerIdDelete({
    @Path('customerId') String? customerId,
    @Header('X-Cus') String? xCus = 'X-Cus',
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get list of all channels
  Future<chopper.Response<List<Channel>>> channelsGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Channel, () => Channel.fromJsonFactory);

    return _channelsGet(cacheControl: cacheControl);
  }

  ///Get list of all channels
  @Get(path: '/channels')
  Future<chopper.Response<List<Channel>>> _channelsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Upload list of channels
  Future<chopper.Response> channelsPost({
    String? cacheControl,
    required List<ChannelCreateParams>? body,
  }) {
    return _channelsPost(cacheControl: cacheControl, body: body);
  }

  ///Upload list of channels
  @Post(path: '/channels')
  Future<chopper.Response> _channelsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required List<ChannelCreateParams>? body,
  });

  ///Return details of channel
  ///@param channelId channel identifier
  ///@param includeProductIds Flag to include channel product ids
  Future<chopper.Response<ChannelResponse>> channelsChannelIdGet({
    required String? channelId,
    bool? includeProductIds,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ChannelResponse, () => ChannelResponse.fromJsonFactory);

    return _channelsChannelIdGet(
        channelId: channelId,
        includeProductIds: includeProductIds,
        cacheControl: cacheControl);
  }

  ///Return details of channel
  ///@param channelId channel identifier
  ///@param includeProductIds Flag to include channel product ids
  @Get(path: '/channels/{channelId}')
  Future<chopper.Response<ChannelResponse>> _channelsChannelIdGet({
    @Path('channelId') required String? channelId,
    @Query('includeProductIds') bool? includeProductIds,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update details of channel
  ///@param channelId channel identifier
  Future<chopper.Response> channelsChannelIdPut({
    required String? channelId,
    String? cacheControl,
    required ChannelUpdateParams? body,
  }) {
    return _channelsChannelIdPut(
        channelId: channelId, cacheControl: cacheControl, body: body);
  }

  ///Update details of channel
  ///@param channelId channel identifier
  @Put(path: '/channels/{channelId}')
  Future<chopper.Response> _channelsChannelIdPut({
    @Path('channelId') required String? channelId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ChannelUpdateParams? body,
  });

  ///Delete specific channel
  ///@param channelId channel identifier
  Future<chopper.Response> channelsChannelIdDelete({
    required String? channelId,
    String? cacheControl,
  }) {
    return _channelsChannelIdDelete(
        channelId: channelId, cacheControl: cacheControl);
  }

  ///Delete specific channel
  ///@param channelId channel identifier
  @Delete(path: '/channels/{channelId}')
  Future<chopper.Response> _channelsChannelIdDelete({
    @Path('channelId') required String? channelId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Post notification
  Future<chopper.Response> notificationsAssetizationPost({
    String? cacheControl,
    required RecordingCompleteNotification? body,
  }) {
    return _notificationsAssetizationPost(
        cacheControl: cacheControl, body: body);
  }

  ///Post notification
  @Post(path: '/notifications/assetization')
  Future<chopper.Response> _notificationsAssetizationPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RecordingCompleteNotification? body,
  });

  ///Update recording data
  ///@param eventId event identifier
  Future<chopper.Response> recordingsEventIdPatch({
    required String? eventId,
    String? cacheControl,
    required RecordingParams? body,
  }) {
    return _recordingsEventIdPatch(
        eventId: eventId, cacheControl: cacheControl, body: body);
  }

  ///Update recording data
  ///@param eventId event identifier
  @Patch(path: '/recordings/{eventId}')
  Future<chopper.Response> _recordingsEventIdPatch({
    @Path('eventId') required String? eventId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required RecordingParams? body,
  });
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    this.error,
    this.code,
    this.message,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'error', includeIfNull: false)
  final ErrorResponse$Error? error;
  @JsonKey(name: 'code', includeIfNull: false)
  final int? code;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String? message;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.error, error) ||
                const DeepCollectionEquality().equals(other.error, error)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(error) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(message) ^
      runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith(
      {ErrorResponse$Error? error, int? code, String? message}) {
    return ErrorResponse(
        error: error ?? this.error,
        code: code ?? this.code,
        message: message ?? this.message);
  }

  ErrorResponse copyWithWrapped(
      {Wrapped<ErrorResponse$Error?>? error,
      Wrapped<int?>? code,
      Wrapped<String?>? message}) {
    return ErrorResponse(
        error: (error != null ? error.value : this.error),
        code: (code != null ? code.value : this.code),
        message: (message != null ? message.value : this.message));
  }
}

@JsonSerializable(explicitToJson: true)
class NetworkRecording {
  NetworkRecording({
    required this.eventId,
    this.retentionPeriod,
    this.autoDeletionProtected,
  });

  factory NetworkRecording.fromJson(Map<String, dynamic> json) =>
      _$NetworkRecordingFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  static const fromJsonFactory = _$NetworkRecordingFromJson;
  static const toJsonFactory = _$NetworkRecordingToJson;
  Map<String, dynamic> toJson() => _$NetworkRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NetworkRecording &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      runtimeType.hashCode;
}

extension $NetworkRecordingExtension on NetworkRecording {
  NetworkRecording copyWith(
      {String? eventId, int? retentionPeriod, bool? autoDeletionProtected}) {
    return NetworkRecording(
        eventId: eventId ?? this.eventId,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected);
  }

  NetworkRecording copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected}) {
    return NetworkRecording(
        eventId: (eventId != null ? eventId.value : this.eventId),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected));
  }
}

@JsonSerializable(explicitToJson: true)
class LocalRecording {
  LocalRecording({
    required this.eventId,
    required this.cpeId,
    this.localRecordingId,
    required this.originDeviceId,
    required this.recordingState,
    this.recStartTime,
    this.recEndTime,
    required this.isAdult,
    this.minimumAge,
    this.containsAdult,
    this.resolution,
    required this.prePaddingOffset,
    required this.postPaddingOffset,
    this.trickPlayControl,
    required this.channelId,
    required this.source,
    this.recordingType,
    this.pinProtected,
    this.failureReason,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.recDuration,
    this.restrictCpeStreaming,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.bookingTime,
  });

  factory LocalRecording.fromJson(Map<String, dynamic> json) =>
      _$LocalRecordingFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String cpeId;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'originDeviceId', includeIfNull: false, defaultValue: '')
  final String originDeviceId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceToJson,
    fromJson: sourceFromJson,
  )
  final enums.Source source;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'pinProtected', includeIfNull: false)
  final bool? pinProtected;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'recDuration', includeIfNull: false)
  final int? recDuration;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  static const fromJsonFactory = _$LocalRecordingFromJson;
  static const toJsonFactory = _$LocalRecordingToJson;
  Map<String, dynamic> toJson() => _$LocalRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalRecording &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.originDeviceId, originDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceId, originDeviceId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.pinProtected, pinProtected) ||
                const DeepCollectionEquality()
                    .equals(other.pinProtected, pinProtected)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.isContinuous, isContinuous) ||
                const DeepCollectionEquality()
                    .equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.recDuration, recDuration) || const DeepCollectionEquality().equals(other.recDuration, recDuration)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.bookingTime, bookingTime) || const DeepCollectionEquality().equals(other.bookingTime, bookingTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(originDeviceId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(pinProtected) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(recDuration) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      runtimeType.hashCode;
}

extension $LocalRecordingExtension on LocalRecording {
  LocalRecording copyWith(
      {String? eventId,
      String? cpeId,
      String? localRecordingId,
      String? originDeviceId,
      enums.RecordingState? recordingState,
      DateTime? recStartTime,
      DateTime? recEndTime,
      bool? isAdult,
      String? minimumAge,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      String? channelId,
      enums.Source? source,
      enums.RecordingType? recordingType,
      bool? pinProtected,
      enums.FailureReason? failureReason,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      int? recDuration,
      bool? restrictCpeStreaming,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      DateTime? bookingTime}) {
    return LocalRecording(
        eventId: eventId ?? this.eventId,
        cpeId: cpeId ?? this.cpeId,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        originDeviceId: originDeviceId ?? this.originDeviceId,
        recordingState: recordingState ?? this.recordingState,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        channelId: channelId ?? this.channelId,
        source: source ?? this.source,
        recordingType: recordingType ?? this.recordingType,
        pinProtected: pinProtected ?? this.pinProtected,
        failureReason: failureReason ?? this.failureReason,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        recDuration: recDuration ?? this.recDuration,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        bookingTime: bookingTime ?? this.bookingTime);
  }

  LocalRecording copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? cpeId,
      Wrapped<String?>? localRecordingId,
      Wrapped<String>? originDeviceId,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int>? prePaddingOffset,
      Wrapped<int>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<String>? channelId,
      Wrapped<enums.Source>? source,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? pinProtected,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<int?>? recDuration,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<DateTime?>? bookingTime}) {
    return LocalRecording(
        eventId: (eventId != null ? eventId.value : this.eventId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        originDeviceId: (originDeviceId != null
            ? originDeviceId.value
            : this.originDeviceId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        channelId: (channelId != null ? channelId.value : this.channelId),
        source: (source != null ? source.value : this.source),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        pinProtected:
            (pinProtected != null ? pinProtected.value : this.pinProtected),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        recDuration:
            (recDuration != null ? recDuration.value : this.recDuration),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime));
  }
}

@JsonSerializable(explicitToJson: true)
class LocalRecordingForHorizonGo {
  LocalRecordingForHorizonGo({
    required this.eventId,
    required this.cpeId,
    this.localRecordingId,
    required this.originDeviceId,
    required this.recordingState,
    this.recStartTime,
    this.recEndTime,
    required this.isAdult,
    this.minimumAge,
    this.containsAdult,
    this.resolution,
    required this.prePaddingOffset,
    required this.postPaddingOffset,
    this.trickPlayControl,
    required this.channelId,
    required this.source,
    this.recordingType,
    this.pinProtected,
    this.failureReason,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.recDuration,
    this.restrictCpeStreaming,
    this.wakeup,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.bookingTime,
  });

  factory LocalRecordingForHorizonGo.fromJson(Map<String, dynamic> json) =>
      _$LocalRecordingForHorizonGoFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String cpeId;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'originDeviceId', includeIfNull: false, defaultValue: '')
  final String originDeviceId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceToJson,
    fromJson: sourceFromJson,
  )
  final enums.Source source;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'pinProtected', includeIfNull: false)
  final bool? pinProtected;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'recDuration', includeIfNull: false)
  final int? recDuration;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'wakeup', includeIfNull: false)
  final bool? wakeup;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  static const fromJsonFactory = _$LocalRecordingForHorizonGoFromJson;
  static const toJsonFactory = _$LocalRecordingForHorizonGoToJson;
  Map<String, dynamic> toJson() => _$LocalRecordingForHorizonGoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalRecordingForHorizonGo &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.originDeviceId, originDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceId, originDeviceId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.pinProtected, pinProtected) ||
                const DeepCollectionEquality()
                    .equals(other.pinProtected, pinProtected)) &&
            (identical(other.failureReason, failureReason) ||
                const DeepCollectionEquality()
                    .equals(other.failureReason, failureReason)) &&
            (identical(other.isContinuous, isContinuous) ||
                const DeepCollectionEquality()
                    .equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.recDuration, recDuration) || const DeepCollectionEquality().equals(other.recDuration, recDuration)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.wakeup, wakeup) || const DeepCollectionEquality().equals(other.wakeup, wakeup)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.bookingTime, bookingTime) || const DeepCollectionEquality().equals(other.bookingTime, bookingTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(originDeviceId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(pinProtected) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(recDuration) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(wakeup) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      runtimeType.hashCode;
}

extension $LocalRecordingForHorizonGoExtension on LocalRecordingForHorizonGo {
  LocalRecordingForHorizonGo copyWith(
      {String? eventId,
      String? cpeId,
      String? localRecordingId,
      String? originDeviceId,
      enums.RecordingState? recordingState,
      DateTime? recStartTime,
      DateTime? recEndTime,
      bool? isAdult,
      String? minimumAge,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      String? channelId,
      enums.Source? source,
      enums.RecordingType? recordingType,
      bool? pinProtected,
      enums.FailureReason? failureReason,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      int? recDuration,
      bool? restrictCpeStreaming,
      bool? wakeup,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      DateTime? bookingTime}) {
    return LocalRecordingForHorizonGo(
        eventId: eventId ?? this.eventId,
        cpeId: cpeId ?? this.cpeId,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        originDeviceId: originDeviceId ?? this.originDeviceId,
        recordingState: recordingState ?? this.recordingState,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        channelId: channelId ?? this.channelId,
        source: source ?? this.source,
        recordingType: recordingType ?? this.recordingType,
        pinProtected: pinProtected ?? this.pinProtected,
        failureReason: failureReason ?? this.failureReason,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        recDuration: recDuration ?? this.recDuration,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        wakeup: wakeup ?? this.wakeup,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        bookingTime: bookingTime ?? this.bookingTime);
  }

  LocalRecordingForHorizonGo copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? cpeId,
      Wrapped<String?>? localRecordingId,
      Wrapped<String>? originDeviceId,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<bool>? isAdult,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int>? prePaddingOffset,
      Wrapped<int>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<String>? channelId,
      Wrapped<enums.Source>? source,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<bool?>? pinProtected,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<int?>? recDuration,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<bool?>? wakeup,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<DateTime?>? bookingTime}) {
    return LocalRecordingForHorizonGo(
        eventId: (eventId != null ? eventId.value : this.eventId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        originDeviceId: (originDeviceId != null
            ? originDeviceId.value
            : this.originDeviceId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        channelId: (channelId != null ? channelId.value : this.channelId),
        source: (source != null ? source.value : this.source),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        pinProtected:
            (pinProtected != null ? pinProtected.value : this.pinProtected),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        recDuration:
            (recDuration != null ? recDuration.value : this.recDuration),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        wakeup: (wakeup != null ? wakeup.value : this.wakeup),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingsView {
  RecordingsView({
    this.offset,
    this.limit,
    this.total,
    this.isAdultContentAvailable,
    this.data,
  });

  factory RecordingsView.fromJson(Map<String, dynamic> json) =>
      _$RecordingsViewFromJson(json);

  @JsonKey(name: 'offset', includeIfNull: false)
  final int? offset;
  @JsonKey(name: 'limit', includeIfNull: false)
  final int? limit;
  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'isAdultContentAvailable', includeIfNull: false)
  final bool? isAdultContentAvailable;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <RecordingView>[])
  final List<RecordingView>? data;
  static const fromJsonFactory = _$RecordingsViewFromJson;
  static const toJsonFactory = _$RecordingsViewToJson;
  Map<String, dynamic> toJson() => _$RecordingsViewToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingsView &&
            (identical(other.offset, offset) ||
                const DeepCollectionEquality().equals(other.offset, offset)) &&
            (identical(other.limit, limit) ||
                const DeepCollectionEquality().equals(other.limit, limit)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(
                    other.isAdultContentAvailable, isAdultContentAvailable) ||
                const DeepCollectionEquality().equals(
                    other.isAdultContentAvailable, isAdultContentAvailable)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(offset) ^
      const DeepCollectionEquality().hash(limit) ^
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(isAdultContentAvailable) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $RecordingsViewExtension on RecordingsView {
  RecordingsView copyWith(
      {int? offset,
      int? limit,
      int? total,
      bool? isAdultContentAvailable,
      List<RecordingView>? data}) {
    return RecordingsView(
        offset: offset ?? this.offset,
        limit: limit ?? this.limit,
        total: total ?? this.total,
        isAdultContentAvailable:
            isAdultContentAvailable ?? this.isAdultContentAvailable,
        data: data ?? this.data);
  }

  RecordingsView copyWithWrapped(
      {Wrapped<int?>? offset,
      Wrapped<int?>? limit,
      Wrapped<int?>? total,
      Wrapped<bool?>? isAdultContentAvailable,
      Wrapped<List<RecordingView>?>? data}) {
    return RecordingsView(
        offset: (offset != null ? offset.value : this.offset),
        limit: (limit != null ? limit.value : this.limit),
        total: (total != null ? total.value : this.total),
        isAdultContentAvailable: (isAdultContentAvailable != null
            ? isAdultContentAvailable.value
            : this.isAdultContentAvailable),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerParams {
  CustomerParams({
    this.suspended,
    this.entitlements,
  });

  factory CustomerParams.fromJson(Map<String, dynamic> json) =>
      _$CustomerParamsFromJson(json);

  @JsonKey(name: 'suspended', includeIfNull: false)
  final bool? suspended;
  @JsonKey(name: 'entitlements', includeIfNull: false, defaultValue: <String>[])
  final List<String>? entitlements;
  static const fromJsonFactory = _$CustomerParamsFromJson;
  static const toJsonFactory = _$CustomerParamsToJson;
  Map<String, dynamic> toJson() => _$CustomerParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerParams &&
            (identical(other.suspended, suspended) ||
                const DeepCollectionEquality()
                    .equals(other.suspended, suspended)) &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(suspended) ^
      const DeepCollectionEquality().hash(entitlements) ^
      runtimeType.hashCode;
}

extension $CustomerParamsExtension on CustomerParams {
  CustomerParams copyWith({bool? suspended, List<String>? entitlements}) {
    return CustomerParams(
        suspended: suspended ?? this.suspended,
        entitlements: entitlements ?? this.entitlements);
  }

  CustomerParams copyWithWrapped(
      {Wrapped<bool?>? suspended, Wrapped<List<String>?>? entitlements}) {
    return CustomerParams(
        suspended: (suspended != null ? suspended.value : this.suspended),
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements));
  }
}

@JsonSerializable(explicitToJson: true)
class CustomerView {
  CustomerView({
    required this.id,
    required this.active,
    required this.suspended,
    required this.quota,
    required this.occupied,
    required this.entitlements,
  });

  factory CustomerView.fromJson(Map<String, dynamic> json) =>
      _$CustomerViewFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool active;
  @JsonKey(name: 'suspended', includeIfNull: false)
  final bool suspended;
  @JsonKey(name: 'quota', includeIfNull: false)
  final double quota;
  @JsonKey(name: 'occupied', includeIfNull: false)
  final double occupied;
  @JsonKey(name: 'entitlements', includeIfNull: false, defaultValue: <String>[])
  final List<String> entitlements;
  static const fromJsonFactory = _$CustomerViewFromJson;
  static const toJsonFactory = _$CustomerViewToJson;
  Map<String, dynamic> toJson() => _$CustomerViewToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CustomerView &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.suspended, suspended) ||
                const DeepCollectionEquality()
                    .equals(other.suspended, suspended)) &&
            (identical(other.quota, quota) ||
                const DeepCollectionEquality().equals(other.quota, quota)) &&
            (identical(other.occupied, occupied) ||
                const DeepCollectionEquality()
                    .equals(other.occupied, occupied)) &&
            (identical(other.entitlements, entitlements) ||
                const DeepCollectionEquality()
                    .equals(other.entitlements, entitlements)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(suspended) ^
      const DeepCollectionEquality().hash(quota) ^
      const DeepCollectionEquality().hash(occupied) ^
      const DeepCollectionEquality().hash(entitlements) ^
      runtimeType.hashCode;
}

extension $CustomerViewExtension on CustomerView {
  CustomerView copyWith(
      {String? id,
      bool? active,
      bool? suspended,
      double? quota,
      double? occupied,
      List<String>? entitlements}) {
    return CustomerView(
        id: id ?? this.id,
        active: active ?? this.active,
        suspended: suspended ?? this.suspended,
        quota: quota ?? this.quota,
        occupied: occupied ?? this.occupied,
        entitlements: entitlements ?? this.entitlements);
  }

  CustomerView copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<bool>? active,
      Wrapped<bool>? suspended,
      Wrapped<double>? quota,
      Wrapped<double>? occupied,
      Wrapped<List<String>>? entitlements}) {
    return CustomerView(
        id: (id != null ? id.value : this.id),
        active: (active != null ? active.value : this.active),
        suspended: (suspended != null ? suspended.value : this.suspended),
        quota: (quota != null ? quota.value : this.quota),
        occupied: (occupied != null ? occupied.value : this.occupied),
        entitlements:
            (entitlements != null ? entitlements.value : this.entitlements));
  }
}

@JsonSerializable(explicitToJson: true)
class Channel {
  Channel({
    this.channelId,
    this.channelName,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.disallowSkipForward,
    this.disallowFastForward,
    this.allowPastRecordings,
    this.allowFutureRecordings,
    this.retentionLimit,
    this.isBlackout,
    this.trickPlayControl,
  });

  factory Channel.fromJson(Map<String, dynamic> json) =>
      _$ChannelFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'disallowSkipForward', includeIfNull: false)
  final bool? disallowSkipForward;
  @JsonKey(name: 'disallowFastForward', includeIfNull: false)
  final bool? disallowFastForward;
  @JsonKey(name: 'allowPastRecordings', includeIfNull: false)
  final bool? allowPastRecordings;
  @JsonKey(
      name: 'allowFutureRecordings', includeIfNull: false, defaultValue: true)
  final bool? allowFutureRecordings;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'isBlackout', includeIfNull: false)
  final bool? isBlackout;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  static const fromJsonFactory = _$ChannelFromJson;
  static const toJsonFactory = _$ChannelToJson;
  Map<String, dynamic> toJson() => _$ChannelToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Channel &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.disallowSkipForward, disallowSkipForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowSkipForward, disallowSkipForward)) &&
            (identical(other.disallowFastForward, disallowFastForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowFastForward, disallowFastForward)) &&
            (identical(other.allowPastRecordings, allowPastRecordings) ||
                const DeepCollectionEquality()
                    .equals(other.allowPastRecordings, allowPastRecordings)) &&
            (identical(other.allowFutureRecordings, allowFutureRecordings) ||
                const DeepCollectionEquality().equals(
                    other.allowFutureRecordings, allowFutureRecordings)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.isBlackout, isBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isBlackout, isBlackout)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(disallowSkipForward) ^
      const DeepCollectionEquality().hash(disallowFastForward) ^
      const DeepCollectionEquality().hash(allowPastRecordings) ^
      const DeepCollectionEquality().hash(allowFutureRecordings) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(isBlackout) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      runtimeType.hashCode;
}

extension $ChannelExtension on Channel {
  Channel copyWith(
      {String? channelId,
      String? channelName,
      int? prePaddingOffset,
      int? postPaddingOffset,
      bool? disallowSkipForward,
      bool? disallowFastForward,
      bool? allowPastRecordings,
      bool? allowFutureRecordings,
      int? retentionLimit,
      bool? isBlackout,
      String? trickPlayControl}) {
    return Channel(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        disallowSkipForward: disallowSkipForward ?? this.disallowSkipForward,
        disallowFastForward: disallowFastForward ?? this.disallowFastForward,
        allowPastRecordings: allowPastRecordings ?? this.allowPastRecordings,
        allowFutureRecordings:
            allowFutureRecordings ?? this.allowFutureRecordings,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        isBlackout: isBlackout ?? this.isBlackout,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl);
  }

  Channel copyWithWrapped(
      {Wrapped<String?>? channelId,
      Wrapped<String?>? channelName,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<bool?>? disallowSkipForward,
      Wrapped<bool?>? disallowFastForward,
      Wrapped<bool?>? allowPastRecordings,
      Wrapped<bool?>? allowFutureRecordings,
      Wrapped<int?>? retentionLimit,
      Wrapped<bool?>? isBlackout,
      Wrapped<String?>? trickPlayControl}) {
    return Channel(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        disallowSkipForward: (disallowSkipForward != null
            ? disallowSkipForward.value
            : this.disallowSkipForward),
        disallowFastForward: (disallowFastForward != null
            ? disallowFastForward.value
            : this.disallowFastForward),
        allowPastRecordings: (allowPastRecordings != null
            ? allowPastRecordings.value
            : this.allowPastRecordings),
        allowFutureRecordings: (allowFutureRecordings != null
            ? allowFutureRecordings.value
            : this.allowFutureRecordings),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        isBlackout: (isBlackout != null ? isBlackout.value : this.isBlackout),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelCreateParams {
  ChannelCreateParams({
    this.channelId,
    this.channelName,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.disallowSkipForward,
    this.disallowFastForward,
    this.allowFutureRecordings,
    this.retentionLimit,
    this.isBlackout,
    this.trickPlayControl,
  });

  factory ChannelCreateParams.fromJson(Map<String, dynamic> json) =>
      _$ChannelCreateParamsFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'disallowSkipForward', includeIfNull: false)
  final bool? disallowSkipForward;
  @JsonKey(name: 'disallowFastForward', includeIfNull: false)
  final bool? disallowFastForward;
  @JsonKey(
      name: 'allowFutureRecordings', includeIfNull: false, defaultValue: true)
  final bool? allowFutureRecordings;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'isBlackout', includeIfNull: false)
  final bool? isBlackout;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  static const fromJsonFactory = _$ChannelCreateParamsFromJson;
  static const toJsonFactory = _$ChannelCreateParamsToJson;
  Map<String, dynamic> toJson() => _$ChannelCreateParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelCreateParams &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.disallowSkipForward, disallowSkipForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowSkipForward, disallowSkipForward)) &&
            (identical(other.disallowFastForward, disallowFastForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowFastForward, disallowFastForward)) &&
            (identical(other.allowFutureRecordings, allowFutureRecordings) ||
                const DeepCollectionEquality().equals(
                    other.allowFutureRecordings, allowFutureRecordings)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.isBlackout, isBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isBlackout, isBlackout)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(disallowSkipForward) ^
      const DeepCollectionEquality().hash(disallowFastForward) ^
      const DeepCollectionEquality().hash(allowFutureRecordings) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(isBlackout) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      runtimeType.hashCode;
}

extension $ChannelCreateParamsExtension on ChannelCreateParams {
  ChannelCreateParams copyWith(
      {String? channelId,
      String? channelName,
      int? prePaddingOffset,
      int? postPaddingOffset,
      bool? disallowSkipForward,
      bool? disallowFastForward,
      bool? allowFutureRecordings,
      int? retentionLimit,
      bool? isBlackout,
      String? trickPlayControl}) {
    return ChannelCreateParams(
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        disallowSkipForward: disallowSkipForward ?? this.disallowSkipForward,
        disallowFastForward: disallowFastForward ?? this.disallowFastForward,
        allowFutureRecordings:
            allowFutureRecordings ?? this.allowFutureRecordings,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        isBlackout: isBlackout ?? this.isBlackout,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl);
  }

  ChannelCreateParams copyWithWrapped(
      {Wrapped<String?>? channelId,
      Wrapped<String?>? channelName,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<bool?>? disallowSkipForward,
      Wrapped<bool?>? disallowFastForward,
      Wrapped<bool?>? allowFutureRecordings,
      Wrapped<int?>? retentionLimit,
      Wrapped<bool?>? isBlackout,
      Wrapped<String?>? trickPlayControl}) {
    return ChannelCreateParams(
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        disallowSkipForward: (disallowSkipForward != null
            ? disallowSkipForward.value
            : this.disallowSkipForward),
        disallowFastForward: (disallowFastForward != null
            ? disallowFastForward.value
            : this.disallowFastForward),
        allowFutureRecordings: (allowFutureRecordings != null
            ? allowFutureRecordings.value
            : this.allowFutureRecordings),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        isBlackout: (isBlackout != null ? isBlackout.value : this.isBlackout),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelResponse {
  ChannelResponse({
    this.productIds,
    this.channelId,
    this.channelName,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.disallowSkipForward,
    this.disallowFastForward,
    this.allowPastRecordings,
    this.allowFutureRecordings,
    this.retentionLimit,
    this.isBlackout,
    this.trickPlayControl,
  });

  factory ChannelResponse.fromJson(Map<String, dynamic> json) =>
      _$ChannelResponseFromJson(json);

  @JsonKey(name: 'productIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? productIds;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'disallowSkipForward', includeIfNull: false)
  final bool? disallowSkipForward;
  @JsonKey(name: 'disallowFastForward', includeIfNull: false)
  final bool? disallowFastForward;
  @JsonKey(name: 'allowPastRecordings', includeIfNull: false)
  final bool? allowPastRecordings;
  @JsonKey(
      name: 'allowFutureRecordings', includeIfNull: false, defaultValue: true)
  final bool? allowFutureRecordings;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'isBlackout', includeIfNull: false)
  final bool? isBlackout;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  static const fromJsonFactory = _$ChannelResponseFromJson;
  static const toJsonFactory = _$ChannelResponseToJson;
  Map<String, dynamic> toJson() => _$ChannelResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelResponse &&
            (identical(other.productIds, productIds) ||
                const DeepCollectionEquality()
                    .equals(other.productIds, productIds)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.disallowSkipForward, disallowSkipForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowSkipForward, disallowSkipForward)) &&
            (identical(other.disallowFastForward, disallowFastForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowFastForward, disallowFastForward)) &&
            (identical(other.allowPastRecordings, allowPastRecordings) ||
                const DeepCollectionEquality()
                    .equals(other.allowPastRecordings, allowPastRecordings)) &&
            (identical(other.allowFutureRecordings, allowFutureRecordings) ||
                const DeepCollectionEquality().equals(
                    other.allowFutureRecordings, allowFutureRecordings)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.isBlackout, isBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isBlackout, isBlackout)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(productIds) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(disallowSkipForward) ^
      const DeepCollectionEquality().hash(disallowFastForward) ^
      const DeepCollectionEquality().hash(allowPastRecordings) ^
      const DeepCollectionEquality().hash(allowFutureRecordings) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(isBlackout) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      runtimeType.hashCode;
}

extension $ChannelResponseExtension on ChannelResponse {
  ChannelResponse copyWith(
      {List<String>? productIds,
      String? channelId,
      String? channelName,
      int? prePaddingOffset,
      int? postPaddingOffset,
      bool? disallowSkipForward,
      bool? disallowFastForward,
      bool? allowPastRecordings,
      bool? allowFutureRecordings,
      int? retentionLimit,
      bool? isBlackout,
      String? trickPlayControl}) {
    return ChannelResponse(
        productIds: productIds ?? this.productIds,
        channelId: channelId ?? this.channelId,
        channelName: channelName ?? this.channelName,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        disallowSkipForward: disallowSkipForward ?? this.disallowSkipForward,
        disallowFastForward: disallowFastForward ?? this.disallowFastForward,
        allowPastRecordings: allowPastRecordings ?? this.allowPastRecordings,
        allowFutureRecordings:
            allowFutureRecordings ?? this.allowFutureRecordings,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        isBlackout: isBlackout ?? this.isBlackout,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl);
  }

  ChannelResponse copyWithWrapped(
      {Wrapped<List<String>?>? productIds,
      Wrapped<String?>? channelId,
      Wrapped<String?>? channelName,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<bool?>? disallowSkipForward,
      Wrapped<bool?>? disallowFastForward,
      Wrapped<bool?>? allowPastRecordings,
      Wrapped<bool?>? allowFutureRecordings,
      Wrapped<int?>? retentionLimit,
      Wrapped<bool?>? isBlackout,
      Wrapped<String?>? trickPlayControl}) {
    return ChannelResponse(
        productIds: (productIds != null ? productIds.value : this.productIds),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        disallowSkipForward: (disallowSkipForward != null
            ? disallowSkipForward.value
            : this.disallowSkipForward),
        disallowFastForward: (disallowFastForward != null
            ? disallowFastForward.value
            : this.disallowFastForward),
        allowPastRecordings: (allowPastRecordings != null
            ? allowPastRecordings.value
            : this.allowPastRecordings),
        allowFutureRecordings: (allowFutureRecordings != null
            ? allowFutureRecordings.value
            : this.allowFutureRecordings),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        isBlackout: (isBlackout != null ? isBlackout.value : this.isBlackout),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl));
  }
}

@JsonSerializable(explicitToJson: true)
class ChannelUpdateParams {
  ChannelUpdateParams({
    this.channelName,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.disallowSkipForward,
    this.disallowFastForward,
    this.allowFutureRecordings,
    this.retentionLimit,
    this.isBlackout,
  });

  factory ChannelUpdateParams.fromJson(Map<String, dynamic> json) =>
      _$ChannelUpdateParamsFromJson(json);

  @JsonKey(name: 'channelName', includeIfNull: false, defaultValue: '')
  final String? channelName;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'disallowSkipForward', includeIfNull: false)
  final bool? disallowSkipForward;
  @JsonKey(name: 'disallowFastForward', includeIfNull: false)
  final bool? disallowFastForward;
  @JsonKey(name: 'allowFutureRecordings', includeIfNull: false)
  final bool? allowFutureRecordings;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'isBlackout', includeIfNull: false)
  final bool? isBlackout;
  static const fromJsonFactory = _$ChannelUpdateParamsFromJson;
  static const toJsonFactory = _$ChannelUpdateParamsToJson;
  Map<String, dynamic> toJson() => _$ChannelUpdateParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ChannelUpdateParams &&
            (identical(other.channelName, channelName) ||
                const DeepCollectionEquality()
                    .equals(other.channelName, channelName)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.disallowSkipForward, disallowSkipForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowSkipForward, disallowSkipForward)) &&
            (identical(other.disallowFastForward, disallowFastForward) ||
                const DeepCollectionEquality()
                    .equals(other.disallowFastForward, disallowFastForward)) &&
            (identical(other.allowFutureRecordings, allowFutureRecordings) ||
                const DeepCollectionEquality().equals(
                    other.allowFutureRecordings, allowFutureRecordings)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.isBlackout, isBlackout) ||
                const DeepCollectionEquality()
                    .equals(other.isBlackout, isBlackout)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelName) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(disallowSkipForward) ^
      const DeepCollectionEquality().hash(disallowFastForward) ^
      const DeepCollectionEquality().hash(allowFutureRecordings) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(isBlackout) ^
      runtimeType.hashCode;
}

extension $ChannelUpdateParamsExtension on ChannelUpdateParams {
  ChannelUpdateParams copyWith(
      {String? channelName,
      int? prePaddingOffset,
      int? postPaddingOffset,
      bool? disallowSkipForward,
      bool? disallowFastForward,
      bool? allowFutureRecordings,
      int? retentionLimit,
      bool? isBlackout}) {
    return ChannelUpdateParams(
        channelName: channelName ?? this.channelName,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        disallowSkipForward: disallowSkipForward ?? this.disallowSkipForward,
        disallowFastForward: disallowFastForward ?? this.disallowFastForward,
        allowFutureRecordings:
            allowFutureRecordings ?? this.allowFutureRecordings,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        isBlackout: isBlackout ?? this.isBlackout);
  }

  ChannelUpdateParams copyWithWrapped(
      {Wrapped<String?>? channelName,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<bool?>? disallowSkipForward,
      Wrapped<bool?>? disallowFastForward,
      Wrapped<bool?>? allowFutureRecordings,
      Wrapped<int?>? retentionLimit,
      Wrapped<bool?>? isBlackout}) {
    return ChannelUpdateParams(
        channelName:
            (channelName != null ? channelName.value : this.channelName),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        disallowSkipForward: (disallowSkipForward != null
            ? disallowSkipForward.value
            : this.disallowSkipForward),
        disallowFastForward: (disallowFastForward != null
            ? disallowFastForward.value
            : this.disallowFastForward),
        allowFutureRecordings: (allowFutureRecordings != null
            ? allowFutureRecordings.value
            : this.allowFutureRecordings),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        isBlackout: (isBlackout != null ? isBlackout.value : this.isBlackout));
  }
}

@JsonSerializable(explicitToJson: true)
class SingleBookingParams {
  SingleBookingParams({
    required this.eventId,
    this.pinProtected,
    this.retentionLimit,
    this.autoDeletionProtected,
  });

  factory SingleBookingParams.fromJson(Map<String, dynamic> json) =>
      _$SingleBookingParamsFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'pinProtected', includeIfNull: false)
  final bool? pinProtected;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  static const fromJsonFactory = _$SingleBookingParamsFromJson;
  static const toJsonFactory = _$SingleBookingParamsToJson;
  Map<String, dynamic> toJson() => _$SingleBookingParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SingleBookingParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.pinProtected, pinProtected) ||
                const DeepCollectionEquality()
                    .equals(other.pinProtected, pinProtected)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(pinProtected) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      runtimeType.hashCode;
}

extension $SingleBookingParamsExtension on SingleBookingParams {
  SingleBookingParams copyWith(
      {String? eventId,
      bool? pinProtected,
      int? retentionLimit,
      bool? autoDeletionProtected}) {
    return SingleBookingParams(
        eventId: eventId ?? this.eventId,
        pinProtected: pinProtected ?? this.pinProtected,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected);
  }

  SingleBookingParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<bool?>? pinProtected,
      Wrapped<int?>? retentionLimit,
      Wrapped<bool?>? autoDeletionProtected}) {
    return SingleBookingParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        pinProtected:
            (pinProtected != null ? pinProtected.value : this.pinProtected),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowBookingParams {
  ShowBookingParams({
    required this.eventId,
    this.pinProtected,
    this.retentionLimit,
    this.replayRecordingsFrom,
    this.autoDeletionProtected,
    this.expansionType,
    this.maxEpisodes,
  });

  factory ShowBookingParams.fromJson(Map<String, dynamic> json) =>
      _$ShowBookingParamsFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'pinProtected', includeIfNull: false)
  final bool? pinProtected;
  @JsonKey(name: 'retentionLimit', includeIfNull: false)
  final int? retentionLimit;
  @JsonKey(name: 'replayRecordingsFrom', includeIfNull: false)
  final DateTime? replayRecordingsFrom;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  static const fromJsonFactory = _$ShowBookingParamsFromJson;
  static const toJsonFactory = _$ShowBookingParamsToJson;
  Map<String, dynamic> toJson() => _$ShowBookingParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowBookingParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.pinProtected, pinProtected) ||
                const DeepCollectionEquality()
                    .equals(other.pinProtected, pinProtected)) &&
            (identical(other.retentionLimit, retentionLimit) ||
                const DeepCollectionEquality()
                    .equals(other.retentionLimit, retentionLimit)) &&
            (identical(other.replayRecordingsFrom, replayRecordingsFrom) ||
                const DeepCollectionEquality().equals(
                    other.replayRecordingsFrom, replayRecordingsFrom)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(pinProtected) ^
      const DeepCollectionEquality().hash(retentionLimit) ^
      const DeepCollectionEquality().hash(replayRecordingsFrom) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      runtimeType.hashCode;
}

extension $ShowBookingParamsExtension on ShowBookingParams {
  ShowBookingParams copyWith(
      {String? eventId,
      bool? pinProtected,
      int? retentionLimit,
      DateTime? replayRecordingsFrom,
      bool? autoDeletionProtected,
      enums.ExpansionType? expansionType,
      int? maxEpisodes}) {
    return ShowBookingParams(
        eventId: eventId ?? this.eventId,
        pinProtected: pinProtected ?? this.pinProtected,
        retentionLimit: retentionLimit ?? this.retentionLimit,
        replayRecordingsFrom: replayRecordingsFrom ?? this.replayRecordingsFrom,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        expansionType: expansionType ?? this.expansionType,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes);
  }

  ShowBookingParams copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<bool?>? pinProtected,
      Wrapped<int?>? retentionLimit,
      Wrapped<DateTime?>? replayRecordingsFrom,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? maxEpisodes}) {
    return ShowBookingParams(
        eventId: (eventId != null ? eventId.value : this.eventId),
        pinProtected:
            (pinProtected != null ? pinProtected.value : this.pinProtected),
        retentionLimit: (retentionLimit != null
            ? retentionLimit.value
            : this.retentionLimit),
        replayRecordingsFrom: (replayRecordingsFrom != null
            ? replayRecordingsFrom.value
            : this.replayRecordingsFrom),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteGrouppedRecordingsParams {
  DeleteGrouppedRecordingsParams({
    required this.channelId,
    this.recordingsKind,
  });

  factory DeleteGrouppedRecordingsParams.fromJson(Map<String, dynamic> json) =>
      _$DeleteGrouppedRecordingsParamsFromJson(json);

  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(
    name: 'recordingsKind',
    includeIfNull: false,
    toJson: recordingsKindToJson,
    fromJson: recordingsKindFromJson,
  )
  final enums.RecordingsKind? recordingsKind;
  static const fromJsonFactory = _$DeleteGrouppedRecordingsParamsFromJson;
  static const toJsonFactory = _$DeleteGrouppedRecordingsParamsToJson;
  Map<String, dynamic> toJson() => _$DeleteGrouppedRecordingsParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteGrouppedRecordingsParams &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.recordingsKind, recordingsKind) ||
                const DeepCollectionEquality()
                    .equals(other.recordingsKind, recordingsKind)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(recordingsKind) ^
      runtimeType.hashCode;
}

extension $DeleteGrouppedRecordingsParamsExtension
    on DeleteGrouppedRecordingsParams {
  DeleteGrouppedRecordingsParams copyWith(
      {String? channelId, enums.RecordingsKind? recordingsKind}) {
    return DeleteGrouppedRecordingsParams(
        channelId: channelId ?? this.channelId,
        recordingsKind: recordingsKind ?? this.recordingsKind);
  }

  DeleteGrouppedRecordingsParams copyWithWrapped(
      {Wrapped<String>? channelId,
      Wrapped<enums.RecordingsKind?>? recordingsKind}) {
    return DeleteGrouppedRecordingsParams(
        channelId: (channelId != null ? channelId.value : this.channelId),
        recordingsKind: (recordingsKind != null
            ? recordingsKind.value
            : this.recordingsKind));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteRecordingsParams {
  DeleteRecordingsParams({
    this.recordingsKind,
    this.shows,
    this.events,
  });

  factory DeleteRecordingsParams.fromJson(Map<String, dynamic> json) =>
      _$DeleteRecordingsParamsFromJson(json);

  @JsonKey(
    name: 'recordingsKind',
    includeIfNull: false,
    toJson: recordingsKindToJson,
    fromJson: recordingsKindFromJson,
  )
  final enums.RecordingsKind? recordingsKind;
  @JsonKey(
      name: 'shows', includeIfNull: false, defaultValue: <DeleteShowParams>[])
  final List<DeleteShowParams>? shows;
  @JsonKey(
      name: 'events', includeIfNull: false, defaultValue: <DeleteEventParams>[])
  final List<DeleteEventParams>? events;
  static const fromJsonFactory = _$DeleteRecordingsParamsFromJson;
  static const toJsonFactory = _$DeleteRecordingsParamsToJson;
  Map<String, dynamic> toJson() => _$DeleteRecordingsParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteRecordingsParams &&
            (identical(other.recordingsKind, recordingsKind) ||
                const DeepCollectionEquality()
                    .equals(other.recordingsKind, recordingsKind)) &&
            (identical(other.shows, shows) ||
                const DeepCollectionEquality().equals(other.shows, shows)) &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordingsKind) ^
      const DeepCollectionEquality().hash(shows) ^
      const DeepCollectionEquality().hash(events) ^
      runtimeType.hashCode;
}

extension $DeleteRecordingsParamsExtension on DeleteRecordingsParams {
  DeleteRecordingsParams copyWith(
      {enums.RecordingsKind? recordingsKind,
      List<DeleteShowParams>? shows,
      List<DeleteEventParams>? events}) {
    return DeleteRecordingsParams(
        recordingsKind: recordingsKind ?? this.recordingsKind,
        shows: shows ?? this.shows,
        events: events ?? this.events);
  }

  DeleteRecordingsParams copyWithWrapped(
      {Wrapped<enums.RecordingsKind?>? recordingsKind,
      Wrapped<List<DeleteShowParams>?>? shows,
      Wrapped<List<DeleteEventParams>?>? events}) {
    return DeleteRecordingsParams(
        recordingsKind: (recordingsKind != null
            ? recordingsKind.value
            : this.recordingsKind),
        shows: (shows != null ? shows.value : this.shows),
        events: (events != null ? events.value : this.events));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteShowRecordingsParams {
  DeleteShowRecordingsParams({
    required this.cpeId,
    required this.channelId,
    required this.showId,
  });

  factory DeleteShowRecordingsParams.fromJson(Map<String, dynamic> json) =>
      _$DeleteShowRecordingsParamsFromJson(json);

  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String cpeId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  static const fromJsonFactory = _$DeleteShowRecordingsParamsFromJson;
  static const toJsonFactory = _$DeleteShowRecordingsParamsToJson;
  Map<String, dynamic> toJson() => _$DeleteShowRecordingsParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteShowRecordingsParams &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(showId) ^
      runtimeType.hashCode;
}

extension $DeleteShowRecordingsParamsExtension on DeleteShowRecordingsParams {
  DeleteShowRecordingsParams copyWith(
      {String? cpeId, String? channelId, String? showId}) {
    return DeleteShowRecordingsParams(
        cpeId: cpeId ?? this.cpeId,
        channelId: channelId ?? this.channelId,
        showId: showId ?? this.showId);
  }

  DeleteShowRecordingsParams copyWithWrapped(
      {Wrapped<String>? cpeId,
      Wrapped<String>? channelId,
      Wrapped<String>? showId}) {
    return DeleteShowRecordingsParams(
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        showId: (showId != null ? showId.value : this.showId));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteShowParams {
  DeleteShowParams({
    this.showId,
    this.channelId,
  });

  factory DeleteShowParams.fromJson(Map<String, dynamic> json) =>
      _$DeleteShowParamsFromJson(json);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  static const fromJsonFactory = _$DeleteShowParamsFromJson;
  static const toJsonFactory = _$DeleteShowParamsToJson;
  Map<String, dynamic> toJson() => _$DeleteShowParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteShowParams &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      runtimeType.hashCode;
}

extension $DeleteShowParamsExtension on DeleteShowParams {
  DeleteShowParams copyWith({String? showId, String? channelId}) {
    return DeleteShowParams(
        showId: showId ?? this.showId, channelId: channelId ?? this.channelId);
  }

  DeleteShowParams copyWithWrapped(
      {Wrapped<String?>? showId, Wrapped<String?>? channelId}) {
    return DeleteShowParams(
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteEventParams {
  DeleteEventParams({
    this.eventId,
  });

  factory DeleteEventParams.fromJson(Map<String, dynamic> json) =>
      _$DeleteEventParamsFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  static const fromJsonFactory = _$DeleteEventParamsFromJson;
  static const toJsonFactory = _$DeleteEventParamsToJson;
  Map<String, dynamic> toJson() => _$DeleteEventParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DeleteEventParams &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality().equals(other.eventId, eventId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^ runtimeType.hashCode;
}

extension $DeleteEventParamsExtension on DeleteEventParams {
  DeleteEventParams copyWith({String? eventId}) {
    return DeleteEventParams(eventId: eventId ?? this.eventId);
  }

  DeleteEventParams copyWithWrapped({Wrapped<String?>? eventId}) {
    return DeleteEventParams(
        eventId: (eventId != null ? eventId.value : this.eventId));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingCompleteNotification {
  RecordingCompleteNotification({
    required this.showingID,
    this.successfulRecordings,
    this.partialRecordings,
    this.failedRecordings,
    this.initiator,
    this.seasonID,
  });

  factory RecordingCompleteNotification.fromJson(Map<String, dynamic> json) =>
      _$RecordingCompleteNotificationFromJson(json);

  @JsonKey(name: 'ShowingID', includeIfNull: false, defaultValue: '')
  final String showingID;
  @JsonKey(name: 'SuccessfulRecordings', includeIfNull: false)
  final RecordingCompleteNotification$SuccessfulRecordings?
      successfulRecordings;
  @JsonKey(name: 'PartialRecordings', includeIfNull: false)
  final RecordingCompleteNotification$PartialRecordings? partialRecordings;
  @JsonKey(name: 'FailedRecordings', includeIfNull: false)
  final RecordingCompleteNotification$FailedRecordings? failedRecordings;
  @JsonKey(name: 'Initiator', includeIfNull: false, defaultValue: '')
  final String? initiator;
  @JsonKey(name: 'SeasonID', includeIfNull: false, defaultValue: '')
  final String? seasonID;
  static const fromJsonFactory = _$RecordingCompleteNotificationFromJson;
  static const toJsonFactory = _$RecordingCompleteNotificationToJson;
  Map<String, dynamic> toJson() => _$RecordingCompleteNotificationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingCompleteNotification &&
            (identical(other.showingID, showingID) ||
                const DeepCollectionEquality()
                    .equals(other.showingID, showingID)) &&
            (identical(other.successfulRecordings, successfulRecordings) ||
                const DeepCollectionEquality().equals(
                    other.successfulRecordings, successfulRecordings)) &&
            (identical(other.partialRecordings, partialRecordings) ||
                const DeepCollectionEquality()
                    .equals(other.partialRecordings, partialRecordings)) &&
            (identical(other.failedRecordings, failedRecordings) ||
                const DeepCollectionEquality()
                    .equals(other.failedRecordings, failedRecordings)) &&
            (identical(other.initiator, initiator) ||
                const DeepCollectionEquality()
                    .equals(other.initiator, initiator)) &&
            (identical(other.seasonID, seasonID) ||
                const DeepCollectionEquality()
                    .equals(other.seasonID, seasonID)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showingID) ^
      const DeepCollectionEquality().hash(successfulRecordings) ^
      const DeepCollectionEquality().hash(partialRecordings) ^
      const DeepCollectionEquality().hash(failedRecordings) ^
      const DeepCollectionEquality().hash(initiator) ^
      const DeepCollectionEquality().hash(seasonID) ^
      runtimeType.hashCode;
}

extension $RecordingCompleteNotificationExtension
    on RecordingCompleteNotification {
  RecordingCompleteNotification copyWith(
      {String? showingID,
      RecordingCompleteNotification$SuccessfulRecordings? successfulRecordings,
      RecordingCompleteNotification$PartialRecordings? partialRecordings,
      RecordingCompleteNotification$FailedRecordings? failedRecordings,
      String? initiator,
      String? seasonID}) {
    return RecordingCompleteNotification(
        showingID: showingID ?? this.showingID,
        successfulRecordings: successfulRecordings ?? this.successfulRecordings,
        partialRecordings: partialRecordings ?? this.partialRecordings,
        failedRecordings: failedRecordings ?? this.failedRecordings,
        initiator: initiator ?? this.initiator,
        seasonID: seasonID ?? this.seasonID);
  }

  RecordingCompleteNotification copyWithWrapped(
      {Wrapped<String>? showingID,
      Wrapped<RecordingCompleteNotification$SuccessfulRecordings?>?
          successfulRecordings,
      Wrapped<RecordingCompleteNotification$PartialRecordings?>?
          partialRecordings,
      Wrapped<RecordingCompleteNotification$FailedRecordings?>?
          failedRecordings,
      Wrapped<String?>? initiator,
      Wrapped<String?>? seasonID}) {
    return RecordingCompleteNotification(
        showingID: (showingID != null ? showingID.value : this.showingID),
        successfulRecordings: (successfulRecordings != null
            ? successfulRecordings.value
            : this.successfulRecordings),
        partialRecordings: (partialRecordings != null
            ? partialRecordings.value
            : this.partialRecordings),
        failedRecordings: (failedRecordings != null
            ? failedRecordings.value
            : this.failedRecordings),
        initiator: (initiator != null ? initiator.value : this.initiator),
        seasonID: (seasonID != null ? seasonID.value : this.seasonID));
  }
}

typedef Recordings = List<Recordings$Item>;

@JsonSerializable(explicitToJson: true)
class Recordings$Item {
  Recordings$Item({
    required this.type,
    this.size,
    this.duration,
    this.failReason,
    this.podName,
    this.home,
  });

  factory Recordings$Item.fromJson(Map<String, dynamic> json) =>
      _$Recordings$ItemFromJson(json);

  @JsonKey(
    name: 'Type',
    includeIfNull: false,
    toJson: recordings$ItemTypeToJson,
    fromJson: recordings$ItemTypeFromJson,
  )
  final enums.Recordings$ItemType type;
  @JsonKey(name: 'Size', includeIfNull: false)
  final num? size;
  @JsonKey(name: 'Duration', includeIfNull: false, defaultValue: '')
  final String? duration;
  @JsonKey(name: 'FailReason', includeIfNull: false)
  final int? failReason;
  @JsonKey(name: 'PodName', includeIfNull: false, defaultValue: '')
  final String? podName;
  @JsonKey(name: 'Home', includeIfNull: false, defaultValue: <Object>[])
  final List<Object>? home;
  static const fromJsonFactory = _$Recordings$ItemFromJson;
  static const toJsonFactory = _$Recordings$ItemToJson;
  Map<String, dynamic> toJson() => _$Recordings$ItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Recordings$Item &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.duration, duration) ||
                const DeepCollectionEquality()
                    .equals(other.duration, duration)) &&
            (identical(other.failReason, failReason) ||
                const DeepCollectionEquality()
                    .equals(other.failReason, failReason)) &&
            (identical(other.podName, podName) ||
                const DeepCollectionEquality()
                    .equals(other.podName, podName)) &&
            (identical(other.home, home) ||
                const DeepCollectionEquality().equals(other.home, home)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(duration) ^
      const DeepCollectionEquality().hash(failReason) ^
      const DeepCollectionEquality().hash(podName) ^
      const DeepCollectionEquality().hash(home) ^
      runtimeType.hashCode;
}

extension $Recordings$ItemExtension on Recordings$Item {
  Recordings$Item copyWith(
      {enums.Recordings$ItemType? type,
      num? size,
      String? duration,
      int? failReason,
      String? podName,
      List<Object>? home}) {
    return Recordings$Item(
        type: type ?? this.type,
        size: size ?? this.size,
        duration: duration ?? this.duration,
        failReason: failReason ?? this.failReason,
        podName: podName ?? this.podName,
        home: home ?? this.home);
  }

  Recordings$Item copyWithWrapped(
      {Wrapped<enums.Recordings$ItemType>? type,
      Wrapped<num?>? size,
      Wrapped<String?>? duration,
      Wrapped<int?>? failReason,
      Wrapped<String?>? podName,
      Wrapped<List<Object>?>? home}) {
    return Recordings$Item(
        type: (type != null ? type.value : this.type),
        size: (size != null ? size.value : this.size),
        duration: (duration != null ? duration.value : this.duration),
        failReason: (failReason != null ? failReason.value : this.failReason),
        podName: (podName != null ? podName.value : this.podName),
        home: (home != null ? home.value : this.home));
  }
}

@JsonSerializable(explicitToJson: true)
class Home {
  Home({
    required this.id,
  });

  factory Home.fromJson(Map<String, dynamic> json) => _$HomeFromJson(json);

  @JsonKey(name: 'ID', includeIfNull: false, defaultValue: '')
  final String id;
  static const fromJsonFactory = _$HomeFromJson;
  static const toJsonFactory = _$HomeToJson;
  Map<String, dynamic> toJson() => _$HomeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Home &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $HomeExtension on Home {
  Home copyWith({String? id}) {
    return Home(id: id ?? this.id);
  }

  Home copyWithWrapped({Wrapped<String>? id}) {
    return Home(id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchParams {
  SearchParams({
    this.eventIds,
    this.groupIds,
    this.titleMergedIds,
    this.seriesMergedIds,
    this.titleIds,
    this.recordingStates,
    this.includeRestricted,
  });

  factory SearchParams.fromJson(Map<String, dynamic> json) =>
      _$SearchParamsFromJson(json);

  @JsonKey(name: 'eventIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? eventIds;
  @JsonKey(name: 'groupIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? groupIds;
  @JsonKey(
      name: 'titleMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleMergedIds;
  @JsonKey(
      name: 'seriesMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesMergedIds;
  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(
    name: 'recordingStates',
    includeIfNull: false,
    toJson: recordingStateListToJson,
    fromJson: recordingStateListFromJson,
  )
  final List<enums.RecordingState>? recordingStates;
  @JsonKey(name: 'includeRestricted', includeIfNull: false)
  final bool? includeRestricted;
  static const fromJsonFactory = _$SearchParamsFromJson;
  static const toJsonFactory = _$SearchParamsToJson;
  Map<String, dynamic> toJson() => _$SearchParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchParams &&
            (identical(other.eventIds, eventIds) ||
                const DeepCollectionEquality()
                    .equals(other.eventIds, eventIds)) &&
            (identical(other.groupIds, groupIds) ||
                const DeepCollectionEquality()
                    .equals(other.groupIds, groupIds)) &&
            (identical(other.titleMergedIds, titleMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleMergedIds, titleMergedIds)) &&
            (identical(other.seriesMergedIds, seriesMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesMergedIds, seriesMergedIds)) &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.recordingStates, recordingStates) ||
                const DeepCollectionEquality()
                    .equals(other.recordingStates, recordingStates)) &&
            (identical(other.includeRestricted, includeRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.includeRestricted, includeRestricted)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventIds) ^
      const DeepCollectionEquality().hash(groupIds) ^
      const DeepCollectionEquality().hash(titleMergedIds) ^
      const DeepCollectionEquality().hash(seriesMergedIds) ^
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(recordingStates) ^
      const DeepCollectionEquality().hash(includeRestricted) ^
      runtimeType.hashCode;
}

extension $SearchParamsExtension on SearchParams {
  SearchParams copyWith(
      {List<String>? eventIds,
      List<String>? groupIds,
      List<String>? titleMergedIds,
      List<String>? seriesMergedIds,
      List<String>? titleIds,
      List<enums.RecordingState>? recordingStates,
      bool? includeRestricted}) {
    return SearchParams(
        eventIds: eventIds ?? this.eventIds,
        groupIds: groupIds ?? this.groupIds,
        titleMergedIds: titleMergedIds ?? this.titleMergedIds,
        seriesMergedIds: seriesMergedIds ?? this.seriesMergedIds,
        titleIds: titleIds ?? this.titleIds,
        recordingStates: recordingStates ?? this.recordingStates,
        includeRestricted: includeRestricted ?? this.includeRestricted);
  }

  SearchParams copyWithWrapped(
      {Wrapped<List<String>?>? eventIds,
      Wrapped<List<String>?>? groupIds,
      Wrapped<List<String>?>? titleMergedIds,
      Wrapped<List<String>?>? seriesMergedIds,
      Wrapped<List<String>?>? titleIds,
      Wrapped<List<enums.RecordingState>?>? recordingStates,
      Wrapped<bool?>? includeRestricted}) {
    return SearchParams(
        eventIds: (eventIds != null ? eventIds.value : this.eventIds),
        groupIds: (groupIds != null ? groupIds.value : this.groupIds),
        titleMergedIds: (titleMergedIds != null
            ? titleMergedIds.value
            : this.titleMergedIds),
        seriesMergedIds: (seriesMergedIds != null
            ? seriesMergedIds.value
            : this.seriesMergedIds),
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        recordingStates: (recordingStates != null
            ? recordingStates.value
            : this.recordingStates),
        includeRestricted: (includeRestricted != null
            ? includeRestricted.value
            : this.includeRestricted));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingView {
  RecordingView({
    required this.id,
    this.localRecordingId,
    this.originDeviceId,
    this.recordingState,
    this.recStartTime,
    this.recEndTime,
    this.cpeId,
    this.isAdult,
    this.minimumAge,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.channelId,
    this.source,
    this.recordingType,
    this.startTime,
    this.endTime,
    this.itemType,
    this.seasonNumber,
    this.episodeNumber,
    this.showId,
    this.seasonId,
    this.title,
    this.showName,
    this.seasonName,
    this.noOfEpisodes,
    this.seasonIds,
    this.isMostRelevantEpisode,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.recDuration,
    this.mostRelevantEpisode,
    this.bookingTime,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.cancelTime,
    this.restrictCpeStreaming,
    this.displayStartTime,
    this.displayEndTime,
    this.failureReason,
    this.pinProtected,
    this.ottPaddingsBlackout,
    this.isPremiere,
    this.isSplitProgram,
    this.groupedStartTime,
    this.groupedEndTime,
    this.groupedEventIdFirstPart,
  });

  factory RecordingView.fromJson(Map<String, dynamic> json) =>
      _$RecordingViewFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'originDeviceId', includeIfNull: false, defaultValue: '')
  final String? originDeviceId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceToJson,
    fromJson: sourceFromJson,
  )
  final enums.Source? source;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(
    name: 'itemType',
    includeIfNull: false,
    toJson: itemTypeToJson,
    fromJson: itemTypeFromJson,
  )
  final enums.ItemType? itemType;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'noOfEpisodes', includeIfNull: false)
  final int? noOfEpisodes;
  @JsonKey(name: 'seasonIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seasonIds;
  @JsonKey(name: 'isMostRelevantEpisode', includeIfNull: false)
  final bool? isMostRelevantEpisode;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'recDuration', includeIfNull: false)
  final int? recDuration;
  @JsonKey(name: 'mostRelevantEpisode', includeIfNull: false)
  final MostRelevantEpisode? mostRelevantEpisode;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'cancelTime', includeIfNull: false)
  final DateTime? cancelTime;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'displayStartTime', includeIfNull: false)
  final DateTime? displayStartTime;
  @JsonKey(name: 'displayEndTime', includeIfNull: false)
  final DateTime? displayEndTime;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'pinProtected', includeIfNull: false)
  final bool? pinProtected;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool? ottPaddingsBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'groupedStartTime', includeIfNull: false)
  final DateTime? groupedStartTime;
  @JsonKey(name: 'groupedEndTime', includeIfNull: false)
  final DateTime? groupedEndTime;
  @JsonKey(
      name: 'groupedEventIdFirstPart', includeIfNull: false, defaultValue: '')
  final String? groupedEventIdFirstPart;
  static const fromJsonFactory = _$RecordingViewFromJson;
  static const toJsonFactory = _$RecordingViewToJson;
  Map<String, dynamic> toJson() => _$RecordingViewToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingView &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.originDeviceId, originDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceId, originDeviceId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.itemType, itemType) ||
                const DeepCollectionEquality()
                    .equals(other.itemType, itemType)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality().equals(other.seasonId, seasonId)) &&
            (identical(other.title, title) || const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.showName, showName) || const DeepCollectionEquality().equals(other.showName, showName)) &&
            (identical(other.seasonName, seasonName) || const DeepCollectionEquality().equals(other.seasonName, seasonName)) &&
            (identical(other.noOfEpisodes, noOfEpisodes) || const DeepCollectionEquality().equals(other.noOfEpisodes, noOfEpisodes)) &&
            (identical(other.seasonIds, seasonIds) || const DeepCollectionEquality().equals(other.seasonIds, seasonIds)) &&
            (identical(other.isMostRelevantEpisode, isMostRelevantEpisode) || const DeepCollectionEquality().equals(other.isMostRelevantEpisode, isMostRelevantEpisode)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.recDuration, recDuration) || const DeepCollectionEquality().equals(other.recDuration, recDuration)) &&
            (identical(other.mostRelevantEpisode, mostRelevantEpisode) || const DeepCollectionEquality().equals(other.mostRelevantEpisode, mostRelevantEpisode)) &&
            (identical(other.bookingTime, bookingTime) || const DeepCollectionEquality().equals(other.bookingTime, bookingTime)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.cancelTime, cancelTime) || const DeepCollectionEquality().equals(other.cancelTime, cancelTime)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.displayStartTime, displayStartTime) || const DeepCollectionEquality().equals(other.displayStartTime, displayStartTime)) &&
            (identical(other.displayEndTime, displayEndTime) || const DeepCollectionEquality().equals(other.displayEndTime, displayEndTime)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.pinProtected, pinProtected) || const DeepCollectionEquality().equals(other.pinProtected, pinProtected)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.groupedStartTime, groupedStartTime) || const DeepCollectionEquality().equals(other.groupedStartTime, groupedStartTime)) &&
            (identical(other.groupedEndTime, groupedEndTime) || const DeepCollectionEquality().equals(other.groupedEndTime, groupedEndTime)) &&
            (identical(other.groupedEventIdFirstPart, groupedEventIdFirstPart) || const DeepCollectionEquality().equals(other.groupedEventIdFirstPart, groupedEventIdFirstPart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(originDeviceId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(itemType) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(noOfEpisodes) ^
      const DeepCollectionEquality().hash(seasonIds) ^
      const DeepCollectionEquality().hash(isMostRelevantEpisode) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(recDuration) ^
      const DeepCollectionEquality().hash(mostRelevantEpisode) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(cancelTime) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(displayStartTime) ^
      const DeepCollectionEquality().hash(displayEndTime) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(pinProtected) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(groupedStartTime) ^
      const DeepCollectionEquality().hash(groupedEndTime) ^
      const DeepCollectionEquality().hash(groupedEventIdFirstPart) ^
      runtimeType.hashCode;
}

extension $RecordingViewExtension on RecordingView {
  RecordingView copyWith(
      {String? id,
      String? localRecordingId,
      String? originDeviceId,
      enums.RecordingState? recordingState,
      DateTime? recStartTime,
      DateTime? recEndTime,
      String? cpeId,
      bool? isAdult,
      String? minimumAge,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      String? channelId,
      enums.Source? source,
      enums.RecordingType? recordingType,
      DateTime? startTime,
      DateTime? endTime,
      enums.ItemType? itemType,
      int? seasonNumber,
      int? episodeNumber,
      String? showId,
      String? seasonId,
      String? title,
      String? showName,
      String? seasonName,
      int? noOfEpisodes,
      List<String>? seasonIds,
      bool? isMostRelevantEpisode,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      int? recDuration,
      MostRelevantEpisode? mostRelevantEpisode,
      DateTime? bookingTime,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      DateTime? cancelTime,
      bool? restrictCpeStreaming,
      DateTime? displayStartTime,
      DateTime? displayEndTime,
      enums.FailureReason? failureReason,
      bool? pinProtected,
      bool? ottPaddingsBlackout,
      bool? isPremiere,
      bool? isSplitProgram,
      DateTime? groupedStartTime,
      DateTime? groupedEndTime,
      String? groupedEventIdFirstPart}) {
    return RecordingView(
        id: id ?? this.id,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        originDeviceId: originDeviceId ?? this.originDeviceId,
        recordingState: recordingState ?? this.recordingState,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        cpeId: cpeId ?? this.cpeId,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        channelId: channelId ?? this.channelId,
        source: source ?? this.source,
        recordingType: recordingType ?? this.recordingType,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        itemType: itemType ?? this.itemType,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        showId: showId ?? this.showId,
        seasonId: seasonId ?? this.seasonId,
        title: title ?? this.title,
        showName: showName ?? this.showName,
        seasonName: seasonName ?? this.seasonName,
        noOfEpisodes: noOfEpisodes ?? this.noOfEpisodes,
        seasonIds: seasonIds ?? this.seasonIds,
        isMostRelevantEpisode:
            isMostRelevantEpisode ?? this.isMostRelevantEpisode,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        recDuration: recDuration ?? this.recDuration,
        mostRelevantEpisode: mostRelevantEpisode ?? this.mostRelevantEpisode,
        bookingTime: bookingTime ?? this.bookingTime,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        cancelTime: cancelTime ?? this.cancelTime,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        displayStartTime: displayStartTime ?? this.displayStartTime,
        displayEndTime: displayEndTime ?? this.displayEndTime,
        failureReason: failureReason ?? this.failureReason,
        pinProtected: pinProtected ?? this.pinProtected,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        groupedStartTime: groupedStartTime ?? this.groupedStartTime,
        groupedEndTime: groupedEndTime ?? this.groupedEndTime,
        groupedEventIdFirstPart:
            groupedEventIdFirstPart ?? this.groupedEventIdFirstPart);
  }

  RecordingView copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? originDeviceId,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<String?>? channelId,
      Wrapped<enums.Source?>? source,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<enums.ItemType?>? itemType,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? seasonId,
      Wrapped<String?>? title,
      Wrapped<String?>? showName,
      Wrapped<String?>? seasonName,
      Wrapped<int?>? noOfEpisodes,
      Wrapped<List<String>?>? seasonIds,
      Wrapped<bool?>? isMostRelevantEpisode,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<int?>? recDuration,
      Wrapped<MostRelevantEpisode?>? mostRelevantEpisode,
      Wrapped<DateTime?>? bookingTime,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<DateTime?>? cancelTime,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<DateTime?>? displayStartTime,
      Wrapped<DateTime?>? displayEndTime,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? pinProtected,
      Wrapped<bool?>? ottPaddingsBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<DateTime?>? groupedStartTime,
      Wrapped<DateTime?>? groupedEndTime,
      Wrapped<String?>? groupedEventIdFirstPart}) {
    return RecordingView(
        id: (id != null ? id.value : this.id),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        originDeviceId: (originDeviceId != null
            ? originDeviceId.value
            : this.originDeviceId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        channelId: (channelId != null ? channelId.value : this.channelId),
        source: (source != null ? source.value : this.source),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        itemType: (itemType != null ? itemType.value : this.itemType),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        showId: (showId != null ? showId.value : this.showId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        title: (title != null ? title.value : this.title),
        showName: (showName != null ? showName.value : this.showName),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        noOfEpisodes:
            (noOfEpisodes != null ? noOfEpisodes.value : this.noOfEpisodes),
        seasonIds: (seasonIds != null ? seasonIds.value : this.seasonIds),
        isMostRelevantEpisode: (isMostRelevantEpisode != null
            ? isMostRelevantEpisode.value
            : this.isMostRelevantEpisode),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        recDuration:
            (recDuration != null ? recDuration.value : this.recDuration),
        mostRelevantEpisode: (mostRelevantEpisode != null
            ? mostRelevantEpisode.value
            : this.mostRelevantEpisode),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        cancelTime: (cancelTime != null ? cancelTime.value : this.cancelTime),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        displayStartTime: (displayStartTime != null
            ? displayStartTime.value
            : this.displayStartTime),
        displayEndTime: (displayEndTime != null
            ? displayEndTime.value
            : this.displayEndTime),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        pinProtected:
            (pinProtected != null ? pinProtected.value : this.pinProtected),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        groupedStartTime: (groupedStartTime != null
            ? groupedStartTime.value
            : this.groupedStartTime),
        groupedEndTime: (groupedEndTime != null
            ? groupedEndTime.value
            : this.groupedEndTime),
        groupedEventIdFirstPart: (groupedEventIdFirstPart != null
            ? groupedEventIdFirstPart.value
            : this.groupedEventIdFirstPart));
  }
}

@JsonSerializable(explicitToJson: true)
class MostRelevantEpisode {
  MostRelevantEpisode({
    required this.id,
    this.localRecordingId,
    this.originDeviceId,
    required this.recordingState,
    this.recStartTime,
    this.recEndTime,
    this.cpeId,
    this.isAdult,
    this.minimumAge,
    this.containsAdult,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.channelId,
    this.recordingType,
    this.startTime,
    this.endTime,
    this.seasonNumber,
    this.episodeNumber,
    this.showId,
    this.seasonId,
    required this.title,
    this.showName,
    this.seasonName,
    this.isContinuous,
    this.channelBasedAuthorization,
    this.restricted,
    this.recDuration,
    this.bookingTime,
    this.retentionPeriod,
    this.autoDeletionProtected,
    this.diskSpace,
    this.deleteTime,
    this.cancelTime,
    this.restrictCpeStreaming,
    this.failureReason,
    this.pinProtected,
    required this.ottPaddingsBlackout,
    this.isPremiere,
    this.isSplitProgram,
    this.groupedStartTime,
    this.groupedEndTime,
    this.groupedEventIdFirstPart,
  });

  factory MostRelevantEpisode.fromJson(Map<String, dynamic> json) =>
      _$MostRelevantEpisodeFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'originDeviceId', includeIfNull: false, defaultValue: '')
  final String? originDeviceId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState recordingState;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String title;
  @JsonKey(name: 'showName', includeIfNull: false, defaultValue: '')
  final String? showName;
  @JsonKey(name: 'seasonName', includeIfNull: false, defaultValue: '')
  final String? seasonName;
  @JsonKey(name: 'isContinuous', includeIfNull: false)
  final bool? isContinuous;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'recDuration', includeIfNull: false)
  final int? recDuration;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'diskSpace', includeIfNull: false)
  final double? diskSpace;
  @JsonKey(name: 'deleteTime', includeIfNull: false)
  final DateTime? deleteTime;
  @JsonKey(name: 'cancelTime', includeIfNull: false)
  final DateTime? cancelTime;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(
    name: 'failureReason',
    includeIfNull: false,
    toJson: failureReasonToJson,
    fromJson: failureReasonFromJson,
  )
  final enums.FailureReason? failureReason;
  @JsonKey(name: 'pinProtected', includeIfNull: false)
  final bool? pinProtected;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool ottPaddingsBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isSplitProgram', includeIfNull: false)
  final bool? isSplitProgram;
  @JsonKey(name: 'groupedStartTime', includeIfNull: false)
  final DateTime? groupedStartTime;
  @JsonKey(name: 'groupedEndTime', includeIfNull: false)
  final DateTime? groupedEndTime;
  @JsonKey(
      name: 'groupedEventIdFirstPart', includeIfNull: false, defaultValue: '')
  final String? groupedEventIdFirstPart;
  static const fromJsonFactory = _$MostRelevantEpisodeFromJson;
  static const toJsonFactory = _$MostRelevantEpisodeToJson;
  Map<String, dynamic> toJson() => _$MostRelevantEpisodeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MostRelevantEpisode &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.originDeviceId, originDeviceId) ||
                const DeepCollectionEquality()
                    .equals(other.originDeviceId, originDeviceId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.showName, showName) ||
                const DeepCollectionEquality().equals(other.showName, showName)) &&
            (identical(other.seasonName, seasonName) || const DeepCollectionEquality().equals(other.seasonName, seasonName)) &&
            (identical(other.isContinuous, isContinuous) || const DeepCollectionEquality().equals(other.isContinuous, isContinuous)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) || const DeepCollectionEquality().equals(other.channelBasedAuthorization, channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) || const DeepCollectionEquality().equals(other.restricted, restricted)) &&
            (identical(other.recDuration, recDuration) || const DeepCollectionEquality().equals(other.recDuration, recDuration)) &&
            (identical(other.bookingTime, bookingTime) || const DeepCollectionEquality().equals(other.bookingTime, bookingTime)) &&
            (identical(other.retentionPeriod, retentionPeriod) || const DeepCollectionEquality().equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) || const DeepCollectionEquality().equals(other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.diskSpace, diskSpace) || const DeepCollectionEquality().equals(other.diskSpace, diskSpace)) &&
            (identical(other.deleteTime, deleteTime) || const DeepCollectionEquality().equals(other.deleteTime, deleteTime)) &&
            (identical(other.cancelTime, cancelTime) || const DeepCollectionEquality().equals(other.cancelTime, cancelTime)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) || const DeepCollectionEquality().equals(other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.failureReason, failureReason) || const DeepCollectionEquality().equals(other.failureReason, failureReason)) &&
            (identical(other.pinProtected, pinProtected) || const DeepCollectionEquality().equals(other.pinProtected, pinProtected)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isSplitProgram, isSplitProgram) || const DeepCollectionEquality().equals(other.isSplitProgram, isSplitProgram)) &&
            (identical(other.groupedStartTime, groupedStartTime) || const DeepCollectionEquality().equals(other.groupedStartTime, groupedStartTime)) &&
            (identical(other.groupedEndTime, groupedEndTime) || const DeepCollectionEquality().equals(other.groupedEndTime, groupedEndTime)) &&
            (identical(other.groupedEventIdFirstPart, groupedEventIdFirstPart) || const DeepCollectionEquality().equals(other.groupedEventIdFirstPart, groupedEventIdFirstPart)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(originDeviceId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(showName) ^
      const DeepCollectionEquality().hash(seasonName) ^
      const DeepCollectionEquality().hash(isContinuous) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(recDuration) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(diskSpace) ^
      const DeepCollectionEquality().hash(deleteTime) ^
      const DeepCollectionEquality().hash(cancelTime) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(failureReason) ^
      const DeepCollectionEquality().hash(pinProtected) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isSplitProgram) ^
      const DeepCollectionEquality().hash(groupedStartTime) ^
      const DeepCollectionEquality().hash(groupedEndTime) ^
      const DeepCollectionEquality().hash(groupedEventIdFirstPart) ^
      runtimeType.hashCode;
}

extension $MostRelevantEpisodeExtension on MostRelevantEpisode {
  MostRelevantEpisode copyWith(
      {String? id,
      String? localRecordingId,
      String? originDeviceId,
      enums.RecordingState? recordingState,
      DateTime? recStartTime,
      DateTime? recEndTime,
      String? cpeId,
      bool? isAdult,
      String? minimumAge,
      bool? containsAdult,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      String? channelId,
      enums.RecordingType? recordingType,
      DateTime? startTime,
      DateTime? endTime,
      int? seasonNumber,
      int? episodeNumber,
      String? showId,
      String? seasonId,
      String? title,
      String? showName,
      String? seasonName,
      bool? isContinuous,
      bool? channelBasedAuthorization,
      bool? restricted,
      int? recDuration,
      DateTime? bookingTime,
      int? retentionPeriod,
      bool? autoDeletionProtected,
      double? diskSpace,
      DateTime? deleteTime,
      DateTime? cancelTime,
      bool? restrictCpeStreaming,
      enums.FailureReason? failureReason,
      bool? pinProtected,
      bool? ottPaddingsBlackout,
      bool? isPremiere,
      bool? isSplitProgram,
      DateTime? groupedStartTime,
      DateTime? groupedEndTime,
      String? groupedEventIdFirstPart}) {
    return MostRelevantEpisode(
        id: id ?? this.id,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        originDeviceId: originDeviceId ?? this.originDeviceId,
        recordingState: recordingState ?? this.recordingState,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        cpeId: cpeId ?? this.cpeId,
        isAdult: isAdult ?? this.isAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        containsAdult: containsAdult ?? this.containsAdult,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        channelId: channelId ?? this.channelId,
        recordingType: recordingType ?? this.recordingType,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        showId: showId ?? this.showId,
        seasonId: seasonId ?? this.seasonId,
        title: title ?? this.title,
        showName: showName ?? this.showName,
        seasonName: seasonName ?? this.seasonName,
        isContinuous: isContinuous ?? this.isContinuous,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        recDuration: recDuration ?? this.recDuration,
        bookingTime: bookingTime ?? this.bookingTime,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        diskSpace: diskSpace ?? this.diskSpace,
        deleteTime: deleteTime ?? this.deleteTime,
        cancelTime: cancelTime ?? this.cancelTime,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        failureReason: failureReason ?? this.failureReason,
        pinProtected: pinProtected ?? this.pinProtected,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        isSplitProgram: isSplitProgram ?? this.isSplitProgram,
        groupedStartTime: groupedStartTime ?? this.groupedStartTime,
        groupedEndTime: groupedEndTime ?? this.groupedEndTime,
        groupedEventIdFirstPart:
            groupedEventIdFirstPart ?? this.groupedEventIdFirstPart);
  }

  MostRelevantEpisode copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? originDeviceId,
      Wrapped<enums.RecordingState>? recordingState,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? isAdult,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<String?>? channelId,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? seasonId,
      Wrapped<String>? title,
      Wrapped<String?>? showName,
      Wrapped<String?>? seasonName,
      Wrapped<bool?>? isContinuous,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<int?>? recDuration,
      Wrapped<DateTime?>? bookingTime,
      Wrapped<int?>? retentionPeriod,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<double?>? diskSpace,
      Wrapped<DateTime?>? deleteTime,
      Wrapped<DateTime?>? cancelTime,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<enums.FailureReason?>? failureReason,
      Wrapped<bool?>? pinProtected,
      Wrapped<bool>? ottPaddingsBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isSplitProgram,
      Wrapped<DateTime?>? groupedStartTime,
      Wrapped<DateTime?>? groupedEndTime,
      Wrapped<String?>? groupedEventIdFirstPart}) {
    return MostRelevantEpisode(
        id: (id != null ? id.value : this.id),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        originDeviceId: (originDeviceId != null
            ? originDeviceId.value
            : this.originDeviceId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        channelId: (channelId != null ? channelId.value : this.channelId),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        showId: (showId != null ? showId.value : this.showId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        title: (title != null ? title.value : this.title),
        showName: (showName != null ? showName.value : this.showName),
        seasonName: (seasonName != null ? seasonName.value : this.seasonName),
        isContinuous:
            (isContinuous != null ? isContinuous.value : this.isContinuous),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        recDuration:
            (recDuration != null ? recDuration.value : this.recDuration),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        diskSpace: (diskSpace != null ? diskSpace.value : this.diskSpace),
        deleteTime: (deleteTime != null ? deleteTime.value : this.deleteTime),
        cancelTime: (cancelTime != null ? cancelTime.value : this.cancelTime),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        failureReason:
            (failureReason != null ? failureReason.value : this.failureReason),
        pinProtected:
            (pinProtected != null ? pinProtected.value : this.pinProtected),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isSplitProgram: (isSplitProgram != null
            ? isSplitProgram.value
            : this.isSplitProgram),
        groupedStartTime: (groupedStartTime != null
            ? groupedStartTime.value
            : this.groupedStartTime),
        groupedEndTime: (groupedEndTime != null
            ? groupedEndTime.value
            : this.groupedEndTime),
        groupedEventIdFirstPart: (groupedEventIdFirstPart != null
            ? groupedEventIdFirstPart.value
            : this.groupedEventIdFirstPart));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingDetails {
  RecordingDetails({
    this.recordingState,
    this.startTime,
    this.endTime,
    this.bookingTime,
    this.cancelTime,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.channelId,
    this.id,
    this.trickPlayControl,
    this.assetizationStatus,
    this.podName,
    this.streamerName,
    this.adBlockStart,
    this.adBlockEnd,
  });

  factory RecordingDetails.fromJson(Map<String, dynamic> json) =>
      _$RecordingDetailsFromJson(json);

  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  @JsonKey(name: 'cancelTime', includeIfNull: false)
  final DateTime? cancelTime;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(
    name: 'assetizationStatus',
    includeIfNull: false,
    toJson: assetizationStatusToJson,
    fromJson: assetizationStatusFromJson,
  )
  final enums.AssetizationStatus? assetizationStatus;
  @JsonKey(name: 'podName', includeIfNull: false, defaultValue: '')
  final String? podName;
  @JsonKey(name: 'streamerName', includeIfNull: false, defaultValue: '')
  final String? streamerName;
  @JsonKey(name: 'adBlockStart', includeIfNull: false)
  final DateTime? adBlockStart;
  @JsonKey(name: 'adBlockEnd', includeIfNull: false)
  final DateTime? adBlockEnd;
  static const fromJsonFactory = _$RecordingDetailsFromJson;
  static const toJsonFactory = _$RecordingDetailsToJson;
  Map<String, dynamic> toJson() => _$RecordingDetailsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingDetails &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.bookingTime, bookingTime) ||
                const DeepCollectionEquality()
                    .equals(other.bookingTime, bookingTime)) &&
            (identical(other.cancelTime, cancelTime) ||
                const DeepCollectionEquality()
                    .equals(other.cancelTime, cancelTime)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.assetizationStatus, assetizationStatus) ||
                const DeepCollectionEquality()
                    .equals(other.assetizationStatus, assetizationStatus)) &&
            (identical(other.podName, podName) ||
                const DeepCollectionEquality()
                    .equals(other.podName, podName)) &&
            (identical(other.streamerName, streamerName) ||
                const DeepCollectionEquality()
                    .equals(other.streamerName, streamerName)) &&
            (identical(other.adBlockStart, adBlockStart) ||
                const DeepCollectionEquality()
                    .equals(other.adBlockStart, adBlockStart)) &&
            (identical(other.adBlockEnd, adBlockEnd) ||
                const DeepCollectionEquality()
                    .equals(other.adBlockEnd, adBlockEnd)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      const DeepCollectionEquality().hash(cancelTime) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(assetizationStatus) ^
      const DeepCollectionEquality().hash(podName) ^
      const DeepCollectionEquality().hash(streamerName) ^
      const DeepCollectionEquality().hash(adBlockStart) ^
      const DeepCollectionEquality().hash(adBlockEnd) ^
      runtimeType.hashCode;
}

extension $RecordingDetailsExtension on RecordingDetails {
  RecordingDetails copyWith(
      {enums.RecordingState? recordingState,
      DateTime? startTime,
      DateTime? endTime,
      DateTime? bookingTime,
      DateTime? cancelTime,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? channelId,
      String? id,
      String? trickPlayControl,
      enums.AssetizationStatus? assetizationStatus,
      String? podName,
      String? streamerName,
      DateTime? adBlockStart,
      DateTime? adBlockEnd}) {
    return RecordingDetails(
        recordingState: recordingState ?? this.recordingState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        bookingTime: bookingTime ?? this.bookingTime,
        cancelTime: cancelTime ?? this.cancelTime,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        channelId: channelId ?? this.channelId,
        id: id ?? this.id,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        assetizationStatus: assetizationStatus ?? this.assetizationStatus,
        podName: podName ?? this.podName,
        streamerName: streamerName ?? this.streamerName,
        adBlockStart: adBlockStart ?? this.adBlockStart,
        adBlockEnd: adBlockEnd ?? this.adBlockEnd);
  }

  RecordingDetails copyWithWrapped(
      {Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<DateTime?>? bookingTime,
      Wrapped<DateTime?>? cancelTime,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? channelId,
      Wrapped<String?>? id,
      Wrapped<String?>? trickPlayControl,
      Wrapped<enums.AssetizationStatus?>? assetizationStatus,
      Wrapped<String?>? podName,
      Wrapped<String?>? streamerName,
      Wrapped<DateTime?>? adBlockStart,
      Wrapped<DateTime?>? adBlockEnd}) {
    return RecordingDetails(
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime),
        cancelTime: (cancelTime != null ? cancelTime.value : this.cancelTime),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        channelId: (channelId != null ? channelId.value : this.channelId),
        id: (id != null ? id.value : this.id),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        assetizationStatus: (assetizationStatus != null
            ? assetizationStatus.value
            : this.assetizationStatus),
        podName: (podName != null ? podName.value : this.podName),
        streamerName:
            (streamerName != null ? streamerName.value : this.streamerName),
        adBlockStart:
            (adBlockStart != null ? adBlockStart.value : this.adBlockStart),
        adBlockEnd: (adBlockEnd != null ? adBlockEnd.value : this.adBlockEnd));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchRecording {
  SearchRecording({
    this.eventId,
    this.recordingState,
    this.minimumAge,
    this.isAdult,
    this.containsAdult,
    this.localRecordingId,
    this.cpeId,
    this.restrictCpeStreaming,
    this.resolution,
    this.prePaddingOffset,
    this.postPaddingOffset,
    this.trickPlayControl,
    this.episodeNumber,
    this.seasonNumber,
    this.showId,
    this.seasonId,
    this.recordingType,
    this.channelId,
    this.channelBasedAuthorization,
    this.restricted,
    this.recStartTime,
    this.recEndTime,
    this.recDuration,
    this.startTime,
    this.endTime,
    this.cancelTime,
    this.bookingTime,
    required this.ottPaddingsBlackout,
    this.isPremiere,
    this.isOttBlackout,
  });

  factory SearchRecording.fromJson(Map<String, dynamic> json) =>
      _$SearchRecordingFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String? eventId;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'localRecordingId', includeIfNull: false, defaultValue: '')
  final String? localRecordingId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'resolution', includeIfNull: false, defaultValue: '')
  final String? resolution;
  @JsonKey(name: 'prePaddingOffset', includeIfNull: false)
  final int? prePaddingOffset;
  @JsonKey(name: 'postPaddingOffset', includeIfNull: false)
  final int? postPaddingOffset;
  @JsonKey(name: 'trickPlayControl', includeIfNull: false, defaultValue: '')
  final String? trickPlayControl;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'seasonId', includeIfNull: false, defaultValue: '')
  final String? seasonId;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  @JsonKey(name: 'recDuration', includeIfNull: false)
  final int? recDuration;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'cancelTime', includeIfNull: false)
  final DateTime? cancelTime;
  @JsonKey(name: 'bookingTime', includeIfNull: false)
  final DateTime? bookingTime;
  @JsonKey(name: 'ottPaddingsBlackout', includeIfNull: false)
  final bool ottPaddingsBlackout;
  @JsonKey(name: 'isPremiere', includeIfNull: false)
  final bool? isPremiere;
  @JsonKey(name: 'isOttBlackout', includeIfNull: false)
  final bool? isOttBlackout;
  static const fromJsonFactory = _$SearchRecordingFromJson;
  static const toJsonFactory = _$SearchRecordingToJson;
  Map<String, dynamic> toJson() => _$SearchRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchRecording &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.localRecordingId, localRecordingId) ||
                const DeepCollectionEquality()
                    .equals(other.localRecordingId, localRecordingId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) ||
                const DeepCollectionEquality().equals(
                    other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.resolution, resolution) ||
                const DeepCollectionEquality()
                    .equals(other.resolution, resolution)) &&
            (identical(other.prePaddingOffset, prePaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.prePaddingOffset, prePaddingOffset)) &&
            (identical(other.postPaddingOffset, postPaddingOffset) ||
                const DeepCollectionEquality()
                    .equals(other.postPaddingOffset, postPaddingOffset)) &&
            (identical(other.trickPlayControl, trickPlayControl) ||
                const DeepCollectionEquality()
                    .equals(other.trickPlayControl, trickPlayControl)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.seasonId, seasonId) ||
                const DeepCollectionEquality()
                    .equals(other.seasonId, seasonId)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelBasedAuthorization, channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality().equals(other.recEndTime, recEndTime)) &&
            (identical(other.recDuration, recDuration) || const DeepCollectionEquality().equals(other.recDuration, recDuration)) &&
            (identical(other.startTime, startTime) || const DeepCollectionEquality().equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) || const DeepCollectionEquality().equals(other.endTime, endTime)) &&
            (identical(other.cancelTime, cancelTime) || const DeepCollectionEquality().equals(other.cancelTime, cancelTime)) &&
            (identical(other.bookingTime, bookingTime) || const DeepCollectionEquality().equals(other.bookingTime, bookingTime)) &&
            (identical(other.ottPaddingsBlackout, ottPaddingsBlackout) || const DeepCollectionEquality().equals(other.ottPaddingsBlackout, ottPaddingsBlackout)) &&
            (identical(other.isPremiere, isPremiere) || const DeepCollectionEquality().equals(other.isPremiere, isPremiere)) &&
            (identical(other.isOttBlackout, isOttBlackout) || const DeepCollectionEquality().equals(other.isOttBlackout, isOttBlackout)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(localRecordingId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(resolution) ^
      const DeepCollectionEquality().hash(prePaddingOffset) ^
      const DeepCollectionEquality().hash(postPaddingOffset) ^
      const DeepCollectionEquality().hash(trickPlayControl) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(seasonId) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      const DeepCollectionEquality().hash(recDuration) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(cancelTime) ^
      const DeepCollectionEquality().hash(bookingTime) ^
      const DeepCollectionEquality().hash(ottPaddingsBlackout) ^
      const DeepCollectionEquality().hash(isPremiere) ^
      const DeepCollectionEquality().hash(isOttBlackout) ^
      runtimeType.hashCode;
}

extension $SearchRecordingExtension on SearchRecording {
  SearchRecording copyWith(
      {String? eventId,
      enums.RecordingState? recordingState,
      String? minimumAge,
      bool? isAdult,
      bool? containsAdult,
      String? localRecordingId,
      String? cpeId,
      bool? restrictCpeStreaming,
      String? resolution,
      int? prePaddingOffset,
      int? postPaddingOffset,
      String? trickPlayControl,
      int? episodeNumber,
      int? seasonNumber,
      String? showId,
      String? seasonId,
      enums.RecordingType? recordingType,
      String? channelId,
      bool? channelBasedAuthorization,
      bool? restricted,
      DateTime? recStartTime,
      DateTime? recEndTime,
      int? recDuration,
      DateTime? startTime,
      DateTime? endTime,
      DateTime? cancelTime,
      DateTime? bookingTime,
      bool? ottPaddingsBlackout,
      bool? isPremiere,
      bool? isOttBlackout}) {
    return SearchRecording(
        eventId: eventId ?? this.eventId,
        recordingState: recordingState ?? this.recordingState,
        minimumAge: minimumAge ?? this.minimumAge,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        localRecordingId: localRecordingId ?? this.localRecordingId,
        cpeId: cpeId ?? this.cpeId,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        resolution: resolution ?? this.resolution,
        prePaddingOffset: prePaddingOffset ?? this.prePaddingOffset,
        postPaddingOffset: postPaddingOffset ?? this.postPaddingOffset,
        trickPlayControl: trickPlayControl ?? this.trickPlayControl,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        showId: showId ?? this.showId,
        seasonId: seasonId ?? this.seasonId,
        recordingType: recordingType ?? this.recordingType,
        channelId: channelId ?? this.channelId,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime,
        recDuration: recDuration ?? this.recDuration,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        cancelTime: cancelTime ?? this.cancelTime,
        bookingTime: bookingTime ?? this.bookingTime,
        ottPaddingsBlackout: ottPaddingsBlackout ?? this.ottPaddingsBlackout,
        isPremiere: isPremiere ?? this.isPremiere,
        isOttBlackout: isOttBlackout ?? this.isOttBlackout);
  }

  SearchRecording copyWithWrapped(
      {Wrapped<String?>? eventId,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<String?>? minimumAge,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? localRecordingId,
      Wrapped<String?>? cpeId,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<String?>? resolution,
      Wrapped<int?>? prePaddingOffset,
      Wrapped<int?>? postPaddingOffset,
      Wrapped<String?>? trickPlayControl,
      Wrapped<int?>? episodeNumber,
      Wrapped<int?>? seasonNumber,
      Wrapped<String?>? showId,
      Wrapped<String?>? seasonId,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<String?>? channelId,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime,
      Wrapped<int?>? recDuration,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<DateTime?>? cancelTime,
      Wrapped<DateTime?>? bookingTime,
      Wrapped<bool>? ottPaddingsBlackout,
      Wrapped<bool?>? isPremiere,
      Wrapped<bool?>? isOttBlackout}) {
    return SearchRecording(
        eventId: (eventId != null ? eventId.value : this.eventId),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        localRecordingId: (localRecordingId != null
            ? localRecordingId.value
            : this.localRecordingId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        resolution: (resolution != null ? resolution.value : this.resolution),
        prePaddingOffset: (prePaddingOffset != null
            ? prePaddingOffset.value
            : this.prePaddingOffset),
        postPaddingOffset: (postPaddingOffset != null
            ? postPaddingOffset.value
            : this.postPaddingOffset),
        trickPlayControl: (trickPlayControl != null
            ? trickPlayControl.value
            : this.trickPlayControl),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        showId: (showId != null ? showId.value : this.showId),
        seasonId: (seasonId != null ? seasonId.value : this.seasonId),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime),
        recDuration:
            (recDuration != null ? recDuration.value : this.recDuration),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        cancelTime: (cancelTime != null ? cancelTime.value : this.cancelTime),
        bookingTime:
            (bookingTime != null ? bookingTime.value : this.bookingTime),
        ottPaddingsBlackout: (ottPaddingsBlackout != null
            ? ottPaddingsBlackout.value
            : this.ottPaddingsBlackout),
        isPremiere: (isPremiere != null ? isPremiere.value : this.isPremiere),
        isOttBlackout:
            (isOttBlackout != null ? isOttBlackout.value : this.isOttBlackout));
  }
}

@JsonSerializable(explicitToJson: true)
class DuplicatedRecording {
  DuplicatedRecording({
    required this.eventId,
    required this.cpeId,
    required this.source,
    this.recordingState,
    this.startTime,
    this.endTime,
    this.isAdult,
    this.containsAdult,
    this.minimumAge,
    this.showId,
    this.channelId,
    this.channelBasedAuthorization,
    this.restricted,
    this.restrictCpeStreaming,
    this.recStartTime,
    this.recEndTime,
  });

  factory DuplicatedRecording.fromJson(Map<String, dynamic> json) =>
      _$DuplicatedRecordingFromJson(json);

  @JsonKey(name: 'eventId', includeIfNull: false, defaultValue: '')
  final String eventId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String cpeId;
  @JsonKey(
    name: 'source',
    includeIfNull: false,
    toJson: sourceToJson,
    fromJson: sourceFromJson,
  )
  final enums.Source source;
  @JsonKey(
    name: 'recordingState',
    includeIfNull: false,
    toJson: recordingStateToJson,
    fromJson: recordingStateFromJson,
  )
  final enums.RecordingState? recordingState;
  @JsonKey(name: 'startTime', includeIfNull: false)
  final DateTime? startTime;
  @JsonKey(name: 'endTime', includeIfNull: false)
  final DateTime? endTime;
  @JsonKey(name: 'isAdult', includeIfNull: false)
  final bool? isAdult;
  @JsonKey(name: 'containsAdult', includeIfNull: false)
  final bool? containsAdult;
  @JsonKey(name: 'minimumAge', includeIfNull: false, defaultValue: '')
  final String? minimumAge;
  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'channelBasedAuthorization', includeIfNull: false)
  final bool? channelBasedAuthorization;
  @JsonKey(name: 'restricted', includeIfNull: false)
  final bool? restricted;
  @JsonKey(name: 'restrictCpeStreaming', includeIfNull: false)
  final bool? restrictCpeStreaming;
  @JsonKey(name: 'recStartTime', includeIfNull: false)
  final DateTime? recStartTime;
  @JsonKey(name: 'recEndTime', includeIfNull: false)
  final DateTime? recEndTime;
  static const fromJsonFactory = _$DuplicatedRecordingFromJson;
  static const toJsonFactory = _$DuplicatedRecordingToJson;
  Map<String, dynamic> toJson() => _$DuplicatedRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DuplicatedRecording &&
            (identical(other.eventId, eventId) ||
                const DeepCollectionEquality()
                    .equals(other.eventId, eventId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.source, source) ||
                const DeepCollectionEquality().equals(other.source, source)) &&
            (identical(other.recordingState, recordingState) ||
                const DeepCollectionEquality()
                    .equals(other.recordingState, recordingState)) &&
            (identical(other.startTime, startTime) ||
                const DeepCollectionEquality()
                    .equals(other.startTime, startTime)) &&
            (identical(other.endTime, endTime) ||
                const DeepCollectionEquality()
                    .equals(other.endTime, endTime)) &&
            (identical(other.isAdult, isAdult) ||
                const DeepCollectionEquality()
                    .equals(other.isAdult, isAdult)) &&
            (identical(other.containsAdult, containsAdult) ||
                const DeepCollectionEquality()
                    .equals(other.containsAdult, containsAdult)) &&
            (identical(other.minimumAge, minimumAge) ||
                const DeepCollectionEquality()
                    .equals(other.minimumAge, minimumAge)) &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.channelBasedAuthorization,
                    channelBasedAuthorization) ||
                const DeepCollectionEquality().equals(
                    other.channelBasedAuthorization,
                    channelBasedAuthorization)) &&
            (identical(other.restricted, restricted) ||
                const DeepCollectionEquality()
                    .equals(other.restricted, restricted)) &&
            (identical(other.restrictCpeStreaming, restrictCpeStreaming) ||
                const DeepCollectionEquality().equals(
                    other.restrictCpeStreaming, restrictCpeStreaming)) &&
            (identical(other.recStartTime, recStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.recStartTime, recStartTime)) &&
            (identical(other.recEndTime, recEndTime) ||
                const DeepCollectionEquality()
                    .equals(other.recEndTime, recEndTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(eventId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(source) ^
      const DeepCollectionEquality().hash(recordingState) ^
      const DeepCollectionEquality().hash(startTime) ^
      const DeepCollectionEquality().hash(endTime) ^
      const DeepCollectionEquality().hash(isAdult) ^
      const DeepCollectionEquality().hash(containsAdult) ^
      const DeepCollectionEquality().hash(minimumAge) ^
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(channelBasedAuthorization) ^
      const DeepCollectionEquality().hash(restricted) ^
      const DeepCollectionEquality().hash(restrictCpeStreaming) ^
      const DeepCollectionEquality().hash(recStartTime) ^
      const DeepCollectionEquality().hash(recEndTime) ^
      runtimeType.hashCode;
}

extension $DuplicatedRecordingExtension on DuplicatedRecording {
  DuplicatedRecording copyWith(
      {String? eventId,
      String? cpeId,
      enums.Source? source,
      enums.RecordingState? recordingState,
      DateTime? startTime,
      DateTime? endTime,
      bool? isAdult,
      bool? containsAdult,
      String? minimumAge,
      String? showId,
      String? channelId,
      bool? channelBasedAuthorization,
      bool? restricted,
      bool? restrictCpeStreaming,
      DateTime? recStartTime,
      DateTime? recEndTime}) {
    return DuplicatedRecording(
        eventId: eventId ?? this.eventId,
        cpeId: cpeId ?? this.cpeId,
        source: source ?? this.source,
        recordingState: recordingState ?? this.recordingState,
        startTime: startTime ?? this.startTime,
        endTime: endTime ?? this.endTime,
        isAdult: isAdult ?? this.isAdult,
        containsAdult: containsAdult ?? this.containsAdult,
        minimumAge: minimumAge ?? this.minimumAge,
        showId: showId ?? this.showId,
        channelId: channelId ?? this.channelId,
        channelBasedAuthorization:
            channelBasedAuthorization ?? this.channelBasedAuthorization,
        restricted: restricted ?? this.restricted,
        restrictCpeStreaming: restrictCpeStreaming ?? this.restrictCpeStreaming,
        recStartTime: recStartTime ?? this.recStartTime,
        recEndTime: recEndTime ?? this.recEndTime);
  }

  DuplicatedRecording copyWithWrapped(
      {Wrapped<String>? eventId,
      Wrapped<String>? cpeId,
      Wrapped<enums.Source>? source,
      Wrapped<enums.RecordingState?>? recordingState,
      Wrapped<DateTime?>? startTime,
      Wrapped<DateTime?>? endTime,
      Wrapped<bool?>? isAdult,
      Wrapped<bool?>? containsAdult,
      Wrapped<String?>? minimumAge,
      Wrapped<String?>? showId,
      Wrapped<String?>? channelId,
      Wrapped<bool?>? channelBasedAuthorization,
      Wrapped<bool?>? restricted,
      Wrapped<bool?>? restrictCpeStreaming,
      Wrapped<DateTime?>? recStartTime,
      Wrapped<DateTime?>? recEndTime}) {
    return DuplicatedRecording(
        eventId: (eventId != null ? eventId.value : this.eventId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        source: (source != null ? source.value : this.source),
        recordingState: (recordingState != null
            ? recordingState.value
            : this.recordingState),
        startTime: (startTime != null ? startTime.value : this.startTime),
        endTime: (endTime != null ? endTime.value : this.endTime),
        isAdult: (isAdult != null ? isAdult.value : this.isAdult),
        containsAdult:
            (containsAdult != null ? containsAdult.value : this.containsAdult),
        minimumAge: (minimumAge != null ? minimumAge.value : this.minimumAge),
        showId: (showId != null ? showId.value : this.showId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        channelBasedAuthorization: (channelBasedAuthorization != null
            ? channelBasedAuthorization.value
            : this.channelBasedAuthorization),
        restricted: (restricted != null ? restricted.value : this.restricted),
        restrictCpeStreaming: (restrictCpeStreaming != null
            ? restrictCpeStreaming.value
            : this.restrictCpeStreaming),
        recStartTime:
            (recStartTime != null ? recStartTime.value : this.recStartTime),
        recEndTime: (recEndTime != null ? recEndTime.value : this.recEndTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowRecording {
  ShowRecording({
    this.showId,
    this.cpeId,
    this.channelId,
    this.seasonNumber,
    this.episodeNumber,
    this.expansionType,
    this.prePadding,
    this.postPadding,
    this.recordingType,
    this.maxEpisodes,
    this.autoDeletionProtected,
    this.retentionPeriod,
    this.lastUpdated,
    this.seedEventId,
    this.seedStartTime,
  });

  factory ShowRecording.fromJson(Map<String, dynamic> json) =>
      _$ShowRecordingFromJson(json);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'lastUpdated', includeIfNull: false)
  final DateTime? lastUpdated;
  @JsonKey(name: 'seedEventId', includeIfNull: false, defaultValue: '')
  final String? seedEventId;
  @JsonKey(name: 'seedStartTime', includeIfNull: false)
  final DateTime? seedStartTime;
  static const fromJsonFactory = _$ShowRecordingFromJson;
  static const toJsonFactory = _$ShowRecordingToJson;
  Map<String, dynamic> toJson() => _$ShowRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowRecording &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.lastUpdated, lastUpdated) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdated, lastUpdated)) &&
            (identical(other.seedEventId, seedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.seedEventId, seedEventId)) &&
            (identical(other.seedStartTime, seedStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.seedStartTime, seedStartTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(lastUpdated) ^
      const DeepCollectionEquality().hash(seedEventId) ^
      const DeepCollectionEquality().hash(seedStartTime) ^
      runtimeType.hashCode;
}

extension $ShowRecordingExtension on ShowRecording {
  ShowRecording copyWith(
      {String? showId,
      String? cpeId,
      String? channelId,
      int? seasonNumber,
      int? episodeNumber,
      enums.ExpansionType? expansionType,
      int? prePadding,
      int? postPadding,
      enums.RecordingType? recordingType,
      int? maxEpisodes,
      bool? autoDeletionProtected,
      int? retentionPeriod,
      DateTime? lastUpdated,
      String? seedEventId,
      DateTime? seedStartTime}) {
    return ShowRecording(
        showId: showId ?? this.showId,
        cpeId: cpeId ?? this.cpeId,
        channelId: channelId ?? this.channelId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        expansionType: expansionType ?? this.expansionType,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        recordingType: recordingType ?? this.recordingType,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        lastUpdated: lastUpdated ?? this.lastUpdated,
        seedEventId: seedEventId ?? this.seedEventId,
        seedStartTime: seedStartTime ?? this.seedStartTime);
  }

  ShowRecording copyWithWrapped(
      {Wrapped<String?>? showId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? channelId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<int?>? maxEpisodes,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<int?>? retentionPeriod,
      Wrapped<DateTime?>? lastUpdated,
      Wrapped<String?>? seedEventId,
      Wrapped<DateTime?>? seedStartTime}) {
    return ShowRecording(
        showId: (showId != null ? showId.value : this.showId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        lastUpdated:
            (lastUpdated != null ? lastUpdated.value : this.lastUpdated),
        seedEventId:
            (seedEventId != null ? seedEventId.value : this.seedEventId),
        seedStartTime:
            (seedStartTime != null ? seedStartTime.value : this.seedStartTime));
  }
}

@JsonSerializable(explicitToJson: true)
class ShowRecordings {
  ShowRecordings({
    this.total,
    this.data,
  });

  factory ShowRecordings.fromJson(Map<String, dynamic> json) =>
      _$ShowRecordingsFromJson(json);

  @JsonKey(name: 'total', includeIfNull: false)
  final int? total;
  @JsonKey(name: 'data', includeIfNull: false, defaultValue: <ShowRecording>[])
  final List<ShowRecording>? data;
  static const fromJsonFactory = _$ShowRecordingsFromJson;
  static const toJsonFactory = _$ShowRecordingsToJson;
  Map<String, dynamic> toJson() => _$ShowRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ShowRecordings &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $ShowRecordingsExtension on ShowRecordings {
  ShowRecordings copyWith({int? total, List<ShowRecording>? data}) {
    return ShowRecordings(total: total ?? this.total, data: data ?? this.data);
  }

  ShowRecordings copyWithWrapped(
      {Wrapped<int?>? total, Wrapped<List<ShowRecording>?>? data}) {
    return ShowRecordings(
        total: (total != null ? total.value : this.total),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class UploadedShowRecording {
  UploadedShowRecording({
    required this.showId,
    this.cpeId,
    this.channelId,
    this.seasonNumber,
    this.episodeNumber,
    this.expansionType,
    this.prePadding,
    this.postPadding,
    this.recordingType,
    this.maxEpisodes,
    this.autoDeletionProtected,
    this.retentionPeriod,
    this.seedEventId,
    this.seedStartTime,
    this.replayRecordingsFrom,
  });

  factory UploadedShowRecording.fromJson(Map<String, dynamic> json) =>
      _$UploadedShowRecordingFromJson(json);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String showId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'seedEventId', includeIfNull: false, defaultValue: '')
  final String? seedEventId;
  @JsonKey(name: 'seedStartTime', includeIfNull: false)
  final DateTime? seedStartTime;
  @JsonKey(name: 'replayRecordingsFrom', includeIfNull: false)
  final DateTime? replayRecordingsFrom;
  static const fromJsonFactory = _$UploadedShowRecordingFromJson;
  static const toJsonFactory = _$UploadedShowRecordingToJson;
  Map<String, dynamic> toJson() => _$UploadedShowRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UploadedShowRecording &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.seedEventId, seedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.seedEventId, seedEventId)) &&
            (identical(other.seedStartTime, seedStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.seedStartTime, seedStartTime)) &&
            (identical(other.replayRecordingsFrom, replayRecordingsFrom) ||
                const DeepCollectionEquality()
                    .equals(other.replayRecordingsFrom, replayRecordingsFrom)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(seedEventId) ^
      const DeepCollectionEquality().hash(seedStartTime) ^
      const DeepCollectionEquality().hash(replayRecordingsFrom) ^
      runtimeType.hashCode;
}

extension $UploadedShowRecordingExtension on UploadedShowRecording {
  UploadedShowRecording copyWith(
      {String? showId,
      String? cpeId,
      String? channelId,
      int? seasonNumber,
      int? episodeNumber,
      enums.ExpansionType? expansionType,
      int? prePadding,
      int? postPadding,
      enums.RecordingType? recordingType,
      int? maxEpisodes,
      bool? autoDeletionProtected,
      int? retentionPeriod,
      String? seedEventId,
      DateTime? seedStartTime,
      DateTime? replayRecordingsFrom}) {
    return UploadedShowRecording(
        showId: showId ?? this.showId,
        cpeId: cpeId ?? this.cpeId,
        channelId: channelId ?? this.channelId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        expansionType: expansionType ?? this.expansionType,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        recordingType: recordingType ?? this.recordingType,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        seedEventId: seedEventId ?? this.seedEventId,
        seedStartTime: seedStartTime ?? this.seedStartTime,
        replayRecordingsFrom:
            replayRecordingsFrom ?? this.replayRecordingsFrom);
  }

  UploadedShowRecording copyWithWrapped(
      {Wrapped<String>? showId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? channelId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<int?>? maxEpisodes,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<int?>? retentionPeriod,
      Wrapped<String?>? seedEventId,
      Wrapped<DateTime?>? seedStartTime,
      Wrapped<DateTime?>? replayRecordingsFrom}) {
    return UploadedShowRecording(
        showId: (showId != null ? showId.value : this.showId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        seedEventId:
            (seedEventId != null ? seedEventId.value : this.seedEventId),
        seedStartTime:
            (seedStartTime != null ? seedStartTime.value : this.seedStartTime),
        replayRecordingsFrom: (replayRecordingsFrom != null
            ? replayRecordingsFrom.value
            : this.replayRecordingsFrom));
  }
}

@JsonSerializable(explicitToJson: true)
class DuplicatedShowRecording {
  DuplicatedShowRecording({
    this.showId,
    this.cpeId,
    this.channelId,
    this.seasonNumber,
    this.episodeNumber,
    this.expansionType,
    this.prePadding,
    this.postPadding,
    this.recordingType,
    this.maxEpisodes,
    this.autoDeletionProtected,
    this.retentionPeriod,
    this.seedEventId,
    this.seedStartTime,
  });

  factory DuplicatedShowRecording.fromJson(Map<String, dynamic> json) =>
      _$DuplicatedShowRecordingFromJson(json);

  @JsonKey(name: 'showId', includeIfNull: false, defaultValue: '')
  final String? showId;
  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String? cpeId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String? channelId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'seedEventId', includeIfNull: false, defaultValue: '')
  final String? seedEventId;
  @JsonKey(name: 'seedStartTime', includeIfNull: false)
  final DateTime? seedStartTime;
  static const fromJsonFactory = _$DuplicatedShowRecordingFromJson;
  static const toJsonFactory = _$DuplicatedShowRecordingToJson;
  Map<String, dynamic> toJson() => _$DuplicatedShowRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is DuplicatedShowRecording &&
            (identical(other.showId, showId) ||
                const DeepCollectionEquality().equals(other.showId, showId)) &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.seedEventId, seedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.seedEventId, seedEventId)) &&
            (identical(other.seedStartTime, seedStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.seedStartTime, seedStartTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(showId) ^
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(seedEventId) ^
      const DeepCollectionEquality().hash(seedStartTime) ^
      runtimeType.hashCode;
}

extension $DuplicatedShowRecordingExtension on DuplicatedShowRecording {
  DuplicatedShowRecording copyWith(
      {String? showId,
      String? cpeId,
      String? channelId,
      int? seasonNumber,
      int? episodeNumber,
      enums.ExpansionType? expansionType,
      int? prePadding,
      int? postPadding,
      enums.RecordingType? recordingType,
      int? maxEpisodes,
      bool? autoDeletionProtected,
      int? retentionPeriod,
      String? seedEventId,
      DateTime? seedStartTime}) {
    return DuplicatedShowRecording(
        showId: showId ?? this.showId,
        cpeId: cpeId ?? this.cpeId,
        channelId: channelId ?? this.channelId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        expansionType: expansionType ?? this.expansionType,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        recordingType: recordingType ?? this.recordingType,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        seedEventId: seedEventId ?? this.seedEventId,
        seedStartTime: seedStartTime ?? this.seedStartTime);
  }

  DuplicatedShowRecording copyWithWrapped(
      {Wrapped<String?>? showId,
      Wrapped<String?>? cpeId,
      Wrapped<String?>? channelId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<int?>? maxEpisodes,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<int?>? retentionPeriod,
      Wrapped<String?>? seedEventId,
      Wrapped<DateTime?>? seedStartTime}) {
    return DuplicatedShowRecording(
        showId: (showId != null ? showId.value : this.showId),
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        seedEventId:
            (seedEventId != null ? seedEventId.value : this.seedEventId),
        seedStartTime:
            (seedStartTime != null ? seedStartTime.value : this.seedStartTime));
  }
}

@JsonSerializable(explicitToJson: true)
class UploadedSingleShowRecording {
  UploadedSingleShowRecording({
    required this.cpeId,
    required this.channelId,
    this.seasonNumber,
    this.episodeNumber,
    this.expansionType,
    this.prePadding,
    this.postPadding,
    this.recordingType,
    this.maxEpisodes,
    this.autoDeletionProtected,
    this.retentionPeriod,
    this.seedEventId,
    this.seedStartTime,
  });

  factory UploadedSingleShowRecording.fromJson(Map<String, dynamic> json) =>
      _$UploadedSingleShowRecordingFromJson(json);

  @JsonKey(name: 'cpeId', includeIfNull: false, defaultValue: '')
  final String cpeId;
  @JsonKey(name: 'channelId', includeIfNull: false, defaultValue: '')
  final String channelId;
  @JsonKey(name: 'seasonNumber', includeIfNull: false)
  final int? seasonNumber;
  @JsonKey(name: 'episodeNumber', includeIfNull: false)
  final int? episodeNumber;
  @JsonKey(
    name: 'expansionType',
    includeIfNull: false,
    toJson: expansionTypeToJson,
    fromJson: expansionTypeFromJson,
  )
  final enums.ExpansionType? expansionType;
  @JsonKey(name: 'prePadding', includeIfNull: false)
  final int? prePadding;
  @JsonKey(name: 'postPadding', includeIfNull: false)
  final int? postPadding;
  @JsonKey(
    name: 'recordingType',
    includeIfNull: false,
    toJson: recordingTypeToJson,
    fromJson: recordingTypeFromJson,
  )
  final enums.RecordingType? recordingType;
  @JsonKey(name: 'maxEpisodes', includeIfNull: false)
  final int? maxEpisodes;
  @JsonKey(name: 'autoDeletionProtected', includeIfNull: false)
  final bool? autoDeletionProtected;
  @JsonKey(name: 'retentionPeriod', includeIfNull: false)
  final int? retentionPeriod;
  @JsonKey(name: 'seedEventId', includeIfNull: false, defaultValue: '')
  final String? seedEventId;
  @JsonKey(name: 'seedStartTime', includeIfNull: false)
  final DateTime? seedStartTime;
  static const fromJsonFactory = _$UploadedSingleShowRecordingFromJson;
  static const toJsonFactory = _$UploadedSingleShowRecordingToJson;
  Map<String, dynamic> toJson() => _$UploadedSingleShowRecordingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UploadedSingleShowRecording &&
            (identical(other.cpeId, cpeId) ||
                const DeepCollectionEquality().equals(other.cpeId, cpeId)) &&
            (identical(other.channelId, channelId) ||
                const DeepCollectionEquality()
                    .equals(other.channelId, channelId)) &&
            (identical(other.seasonNumber, seasonNumber) ||
                const DeepCollectionEquality()
                    .equals(other.seasonNumber, seasonNumber)) &&
            (identical(other.episodeNumber, episodeNumber) ||
                const DeepCollectionEquality()
                    .equals(other.episodeNumber, episodeNumber)) &&
            (identical(other.expansionType, expansionType) ||
                const DeepCollectionEquality()
                    .equals(other.expansionType, expansionType)) &&
            (identical(other.prePadding, prePadding) ||
                const DeepCollectionEquality()
                    .equals(other.prePadding, prePadding)) &&
            (identical(other.postPadding, postPadding) ||
                const DeepCollectionEquality()
                    .equals(other.postPadding, postPadding)) &&
            (identical(other.recordingType, recordingType) ||
                const DeepCollectionEquality()
                    .equals(other.recordingType, recordingType)) &&
            (identical(other.maxEpisodes, maxEpisodes) ||
                const DeepCollectionEquality()
                    .equals(other.maxEpisodes, maxEpisodes)) &&
            (identical(other.autoDeletionProtected, autoDeletionProtected) ||
                const DeepCollectionEquality().equals(
                    other.autoDeletionProtected, autoDeletionProtected)) &&
            (identical(other.retentionPeriod, retentionPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.retentionPeriod, retentionPeriod)) &&
            (identical(other.seedEventId, seedEventId) ||
                const DeepCollectionEquality()
                    .equals(other.seedEventId, seedEventId)) &&
            (identical(other.seedStartTime, seedStartTime) ||
                const DeepCollectionEquality()
                    .equals(other.seedStartTime, seedStartTime)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(cpeId) ^
      const DeepCollectionEquality().hash(channelId) ^
      const DeepCollectionEquality().hash(seasonNumber) ^
      const DeepCollectionEquality().hash(episodeNumber) ^
      const DeepCollectionEquality().hash(expansionType) ^
      const DeepCollectionEquality().hash(prePadding) ^
      const DeepCollectionEquality().hash(postPadding) ^
      const DeepCollectionEquality().hash(recordingType) ^
      const DeepCollectionEquality().hash(maxEpisodes) ^
      const DeepCollectionEquality().hash(autoDeletionProtected) ^
      const DeepCollectionEquality().hash(retentionPeriod) ^
      const DeepCollectionEquality().hash(seedEventId) ^
      const DeepCollectionEquality().hash(seedStartTime) ^
      runtimeType.hashCode;
}

extension $UploadedSingleShowRecordingExtension on UploadedSingleShowRecording {
  UploadedSingleShowRecording copyWith(
      {String? cpeId,
      String? channelId,
      int? seasonNumber,
      int? episodeNumber,
      enums.ExpansionType? expansionType,
      int? prePadding,
      int? postPadding,
      enums.RecordingType? recordingType,
      int? maxEpisodes,
      bool? autoDeletionProtected,
      int? retentionPeriod,
      String? seedEventId,
      DateTime? seedStartTime}) {
    return UploadedSingleShowRecording(
        cpeId: cpeId ?? this.cpeId,
        channelId: channelId ?? this.channelId,
        seasonNumber: seasonNumber ?? this.seasonNumber,
        episodeNumber: episodeNumber ?? this.episodeNumber,
        expansionType: expansionType ?? this.expansionType,
        prePadding: prePadding ?? this.prePadding,
        postPadding: postPadding ?? this.postPadding,
        recordingType: recordingType ?? this.recordingType,
        maxEpisodes: maxEpisodes ?? this.maxEpisodes,
        autoDeletionProtected:
            autoDeletionProtected ?? this.autoDeletionProtected,
        retentionPeriod: retentionPeriod ?? this.retentionPeriod,
        seedEventId: seedEventId ?? this.seedEventId,
        seedStartTime: seedStartTime ?? this.seedStartTime);
  }

  UploadedSingleShowRecording copyWithWrapped(
      {Wrapped<String>? cpeId,
      Wrapped<String>? channelId,
      Wrapped<int?>? seasonNumber,
      Wrapped<int?>? episodeNumber,
      Wrapped<enums.ExpansionType?>? expansionType,
      Wrapped<int?>? prePadding,
      Wrapped<int?>? postPadding,
      Wrapped<enums.RecordingType?>? recordingType,
      Wrapped<int?>? maxEpisodes,
      Wrapped<bool?>? autoDeletionProtected,
      Wrapped<int?>? retentionPeriod,
      Wrapped<String?>? seedEventId,
      Wrapped<DateTime?>? seedStartTime}) {
    return UploadedSingleShowRecording(
        cpeId: (cpeId != null ? cpeId.value : this.cpeId),
        channelId: (channelId != null ? channelId.value : this.channelId),
        seasonNumber:
            (seasonNumber != null ? seasonNumber.value : this.seasonNumber),
        episodeNumber:
            (episodeNumber != null ? episodeNumber.value : this.episodeNumber),
        expansionType:
            (expansionType != null ? expansionType.value : this.expansionType),
        prePadding: (prePadding != null ? prePadding.value : this.prePadding),
        postPadding:
            (postPadding != null ? postPadding.value : this.postPadding),
        recordingType:
            (recordingType != null ? recordingType.value : this.recordingType),
        maxEpisodes:
            (maxEpisodes != null ? maxEpisodes.value : this.maxEpisodes),
        autoDeletionProtected: (autoDeletionProtected != null
            ? autoDeletionProtected.value
            : this.autoDeletionProtected),
        retentionPeriod: (retentionPeriod != null
            ? retentionPeriod.value
            : this.retentionPeriod),
        seedEventId:
            (seedEventId != null ? seedEventId.value : this.seedEventId),
        seedStartTime:
            (seedStartTime != null ? seedStartTime.value : this.seedStartTime));
  }
}

@JsonSerializable(explicitToJson: true)
class OpWithUploadedShowRecordings {
  OpWithUploadedShowRecordings({
    required this.op,
    required this.shows,
  });

  factory OpWithUploadedShowRecordings.fromJson(Map<String, dynamic> json) =>
      _$OpWithUploadedShowRecordingsFromJson(json);

  @JsonKey(
    name: 'op',
    includeIfNull: false,
    toJson: opToJson,
    fromJson: opFromJson,
  )
  final enums.Op op;
  @JsonKey(
      name: 'shows',
      includeIfNull: false,
      defaultValue: <UploadedShowRecording>[])
  final List<UploadedShowRecording> shows;
  static const fromJsonFactory = _$OpWithUploadedShowRecordingsFromJson;
  static const toJsonFactory = _$OpWithUploadedShowRecordingsToJson;
  Map<String, dynamic> toJson() => _$OpWithUploadedShowRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OpWithUploadedShowRecordings &&
            (identical(other.op, op) ||
                const DeepCollectionEquality().equals(other.op, op)) &&
            (identical(other.shows, shows) ||
                const DeepCollectionEquality().equals(other.shows, shows)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(op) ^
      const DeepCollectionEquality().hash(shows) ^
      runtimeType.hashCode;
}

extension $OpWithUploadedShowRecordingsExtension
    on OpWithUploadedShowRecordings {
  OpWithUploadedShowRecordings copyWith(
      {enums.Op? op, List<UploadedShowRecording>? shows}) {
    return OpWithUploadedShowRecordings(
        op: op ?? this.op, shows: shows ?? this.shows);
  }

  OpWithUploadedShowRecordings copyWithWrapped(
      {Wrapped<enums.Op>? op, Wrapped<List<UploadedShowRecording>>? shows}) {
    return OpWithUploadedShowRecordings(
        op: (op != null ? op.value : this.op),
        shows: (shows != null ? shows.value : this.shows));
  }
}

@JsonSerializable(explicitToJson: true)
class OpWithLocalRecordings {
  OpWithLocalRecordings({
    required this.op,
    required this.events,
  });

  factory OpWithLocalRecordings.fromJson(Map<String, dynamic> json) =>
      _$OpWithLocalRecordingsFromJson(json);

  @JsonKey(
    name: 'op',
    includeIfNull: false,
    toJson: opToJson,
    fromJson: opFromJson,
  )
  final enums.Op op;
  @JsonKey(
      name: 'events', includeIfNull: false, defaultValue: <LocalRecording>[])
  final List<LocalRecording> events;
  static const fromJsonFactory = _$OpWithLocalRecordingsFromJson;
  static const toJsonFactory = _$OpWithLocalRecordingsToJson;
  Map<String, dynamic> toJson() => _$OpWithLocalRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OpWithLocalRecordings &&
            (identical(other.op, op) ||
                const DeepCollectionEquality().equals(other.op, op)) &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(op) ^
      const DeepCollectionEquality().hash(events) ^
      runtimeType.hashCode;
}

extension $OpWithLocalRecordingsExtension on OpWithLocalRecordings {
  OpWithLocalRecordings copyWith({enums.Op? op, List<LocalRecording>? events}) {
    return OpWithLocalRecordings(
        op: op ?? this.op, events: events ?? this.events);
  }

  OpWithLocalRecordings copyWithWrapped(
      {Wrapped<enums.Op>? op, Wrapped<List<LocalRecording>>? events}) {
    return OpWithLocalRecordings(
        op: (op != null ? op.value : this.op),
        events: (events != null ? events.value : this.events));
  }
}

@JsonSerializable(explicitToJson: true)
class OpWithNetworkRecordings {
  OpWithNetworkRecordings({
    required this.op,
    required this.events,
  });

  factory OpWithNetworkRecordings.fromJson(Map<String, dynamic> json) =>
      _$OpWithNetworkRecordingsFromJson(json);

  @JsonKey(
    name: 'op',
    includeIfNull: false,
    toJson: opWithNetworkRecordingsOpToJson,
    fromJson: opWithNetworkRecordingsOpFromJson,
  )
  final enums.OpWithNetworkRecordingsOp op;
  @JsonKey(
      name: 'events', includeIfNull: false, defaultValue: <NetworkRecording>[])
  final List<NetworkRecording> events;
  static const fromJsonFactory = _$OpWithNetworkRecordingsFromJson;
  static const toJsonFactory = _$OpWithNetworkRecordingsToJson;
  Map<String, dynamic> toJson() => _$OpWithNetworkRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OpWithNetworkRecordings &&
            (identical(other.op, op) ||
                const DeepCollectionEquality().equals(other.op, op)) &&
            (identical(other.events, events) ||
                const DeepCollectionEquality().equals(other.events, events)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(op) ^
      const DeepCollectionEquality().hash(events) ^
      runtimeType.hashCode;
}

extension $OpWithNetworkRecordingsExtension on OpWithNetworkRecordings {
  OpWithNetworkRecordings copyWith(
      {enums.OpWithNetworkRecordingsOp? op, List<NetworkRecording>? events}) {
    return OpWithNetworkRecordings(
        op: op ?? this.op, events: events ?? this.events);
  }

  OpWithNetworkRecordings copyWithWrapped(
      {Wrapped<enums.OpWithNetworkRecordingsOp>? op,
      Wrapped<List<NetworkRecording>>? events}) {
    return OpWithNetworkRecordings(
        op: (op != null ? op.value : this.op),
        events: (events != null ? events.value : this.events));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingParams {
  RecordingParams({
    required this.adBlockStart,
    required this.adBlockEnd,
  });

  factory RecordingParams.fromJson(Map<String, dynamic> json) =>
      _$RecordingParamsFromJson(json);

  @JsonKey(name: 'adBlockStart', includeIfNull: false)
  final DateTime adBlockStart;
  @JsonKey(name: 'adBlockEnd', includeIfNull: false)
  final DateTime adBlockEnd;
  static const fromJsonFactory = _$RecordingParamsFromJson;
  static const toJsonFactory = _$RecordingParamsToJson;
  Map<String, dynamic> toJson() => _$RecordingParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingParams &&
            (identical(other.adBlockStart, adBlockStart) ||
                const DeepCollectionEquality()
                    .equals(other.adBlockStart, adBlockStart)) &&
            (identical(other.adBlockEnd, adBlockEnd) ||
                const DeepCollectionEquality()
                    .equals(other.adBlockEnd, adBlockEnd)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(adBlockStart) ^
      const DeepCollectionEquality().hash(adBlockEnd) ^
      runtimeType.hashCode;
}

extension $RecordingParamsExtension on RecordingParams {
  RecordingParams copyWith({DateTime? adBlockStart, DateTime? adBlockEnd}) {
    return RecordingParams(
        adBlockStart: adBlockStart ?? this.adBlockStart,
        adBlockEnd: adBlockEnd ?? this.adBlockEnd);
  }

  RecordingParams copyWithWrapped(
      {Wrapped<DateTime>? adBlockStart, Wrapped<DateTime>? adBlockEnd}) {
    return RecordingParams(
        adBlockStart:
            (adBlockStart != null ? adBlockStart.value : this.adBlockStart),
        adBlockEnd: (adBlockEnd != null ? adBlockEnd.value : this.adBlockEnd));
  }
}

@JsonSerializable(explicitToJson: true)
class PickerSearchParams {
  PickerSearchParams({
    this.titles,
    this.series,
    this.recordingStates,
    this.includeRestricted,
  });

  factory PickerSearchParams.fromJson(Map<String, dynamic> json) =>
      _$PickerSearchParamsFromJson(json);

  @JsonKey(name: 'titles', includeIfNull: false)
  final Titles? titles;
  @JsonKey(name: 'series', includeIfNull: false)
  final Series? series;
  @JsonKey(
    name: 'recordingStates',
    includeIfNull: false,
    toJson: recordingStateListToJson,
    fromJson: recordingStateListFromJson,
  )
  final List<enums.RecordingState>? recordingStates;
  @JsonKey(name: 'includeRestricted', includeIfNull: false)
  final bool? includeRestricted;
  static const fromJsonFactory = _$PickerSearchParamsFromJson;
  static const toJsonFactory = _$PickerSearchParamsToJson;
  Map<String, dynamic> toJson() => _$PickerSearchParamsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PickerSearchParams &&
            (identical(other.titles, titles) ||
                const DeepCollectionEquality().equals(other.titles, titles)) &&
            (identical(other.series, series) ||
                const DeepCollectionEquality().equals(other.series, series)) &&
            (identical(other.recordingStates, recordingStates) ||
                const DeepCollectionEquality()
                    .equals(other.recordingStates, recordingStates)) &&
            (identical(other.includeRestricted, includeRestricted) ||
                const DeepCollectionEquality()
                    .equals(other.includeRestricted, includeRestricted)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titles) ^
      const DeepCollectionEquality().hash(series) ^
      const DeepCollectionEquality().hash(recordingStates) ^
      const DeepCollectionEquality().hash(includeRestricted) ^
      runtimeType.hashCode;
}

extension $PickerSearchParamsExtension on PickerSearchParams {
  PickerSearchParams copyWith(
      {Titles? titles,
      Series? series,
      List<enums.RecordingState>? recordingStates,
      bool? includeRestricted}) {
    return PickerSearchParams(
        titles: titles ?? this.titles,
        series: series ?? this.series,
        recordingStates: recordingStates ?? this.recordingStates,
        includeRestricted: includeRestricted ?? this.includeRestricted);
  }

  PickerSearchParams copyWithWrapped(
      {Wrapped<Titles?>? titles,
      Wrapped<Series?>? series,
      Wrapped<List<enums.RecordingState>?>? recordingStates,
      Wrapped<bool?>? includeRestricted}) {
    return PickerSearchParams(
        titles: (titles != null ? titles.value : this.titles),
        series: (series != null ? series.value : this.series),
        recordingStates: (recordingStates != null
            ? recordingStates.value
            : this.recordingStates),
        includeRestricted: (includeRestricted != null
            ? includeRestricted.value
            : this.includeRestricted));
  }
}

@JsonSerializable(explicitToJson: true)
class Titles {
  Titles({
    this.titleIds,
    this.titleMergedIds,
  });

  factory Titles.fromJson(Map<String, dynamic> json) => _$TitlesFromJson(json);

  @JsonKey(name: 'titleIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleIds;
  @JsonKey(
      name: 'titleMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? titleMergedIds;
  static const fromJsonFactory = _$TitlesFromJson;
  static const toJsonFactory = _$TitlesToJson;
  Map<String, dynamic> toJson() => _$TitlesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Titles &&
            (identical(other.titleIds, titleIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleIds, titleIds)) &&
            (identical(other.titleMergedIds, titleMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.titleMergedIds, titleMergedIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(titleIds) ^
      const DeepCollectionEquality().hash(titleMergedIds) ^
      runtimeType.hashCode;
}

extension $TitlesExtension on Titles {
  Titles copyWith({List<String>? titleIds, List<String>? titleMergedIds}) {
    return Titles(
        titleIds: titleIds ?? this.titleIds,
        titleMergedIds: titleMergedIds ?? this.titleMergedIds);
  }

  Titles copyWithWrapped(
      {Wrapped<List<String>?>? titleIds,
      Wrapped<List<String>?>? titleMergedIds}) {
    return Titles(
        titleIds: (titleIds != null ? titleIds.value : this.titleIds),
        titleMergedIds: (titleMergedIds != null
            ? titleMergedIds.value
            : this.titleMergedIds));
  }
}

@JsonSerializable(explicitToJson: true)
class Series {
  Series({
    this.seriesIds,
    this.seriesMergedIds,
  });

  factory Series.fromJson(Map<String, dynamic> json) => _$SeriesFromJson(json);

  @JsonKey(name: 'seriesIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesIds;
  @JsonKey(
      name: 'seriesMergedIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? seriesMergedIds;
  static const fromJsonFactory = _$SeriesFromJson;
  static const toJsonFactory = _$SeriesToJson;
  Map<String, dynamic> toJson() => _$SeriesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Series &&
            (identical(other.seriesIds, seriesIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesIds, seriesIds)) &&
            (identical(other.seriesMergedIds, seriesMergedIds) ||
                const DeepCollectionEquality()
                    .equals(other.seriesMergedIds, seriesMergedIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(seriesIds) ^
      const DeepCollectionEquality().hash(seriesMergedIds) ^
      runtimeType.hashCode;
}

extension $SeriesExtension on Series {
  Series copyWith({List<String>? seriesIds, List<String>? seriesMergedIds}) {
    return Series(
        seriesIds: seriesIds ?? this.seriesIds,
        seriesMergedIds: seriesMergedIds ?? this.seriesMergedIds);
  }

  Series copyWithWrapped(
      {Wrapped<List<String>?>? seriesIds,
      Wrapped<List<String>?>? seriesMergedIds}) {
    return Series(
        seriesIds: (seriesIds != null ? seriesIds.value : this.seriesIds),
        seriesMergedIds: (seriesMergedIds != null
            ? seriesMergedIds.value
            : this.seriesMergedIds));
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse$Error {
  ErrorResponse$Error({
    required this.httpStatusCode,
    this.statusCode,
    required this.message,
    this.details,
  });

  factory ErrorResponse$Error.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponse$ErrorFromJson(json);

  @JsonKey(name: 'httpStatusCode', includeIfNull: false)
  final int httpStatusCode;
  @JsonKey(name: 'statusCode', includeIfNull: false)
  final int? statusCode;
  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  @JsonKey(name: 'details', includeIfNull: false, defaultValue: '')
  final String? details;
  static const fromJsonFactory = _$ErrorResponse$ErrorFromJson;
  static const toJsonFactory = _$ErrorResponse$ErrorToJson;
  Map<String, dynamic> toJson() => _$ErrorResponse$ErrorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse$Error &&
            (identical(other.httpStatusCode, httpStatusCode) ||
                const DeepCollectionEquality()
                    .equals(other.httpStatusCode, httpStatusCode)) &&
            (identical(other.statusCode, statusCode) ||
                const DeepCollectionEquality()
                    .equals(other.statusCode, statusCode)) &&
            (identical(other.message, message) ||
                const DeepCollectionEquality()
                    .equals(other.message, message)) &&
            (identical(other.details, details) ||
                const DeepCollectionEquality().equals(other.details, details)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(httpStatusCode) ^
      const DeepCollectionEquality().hash(statusCode) ^
      const DeepCollectionEquality().hash(message) ^
      const DeepCollectionEquality().hash(details) ^
      runtimeType.hashCode;
}

extension $ErrorResponse$ErrorExtension on ErrorResponse$Error {
  ErrorResponse$Error copyWith(
      {int? httpStatusCode,
      int? statusCode,
      String? message,
      String? details}) {
    return ErrorResponse$Error(
        httpStatusCode: httpStatusCode ?? this.httpStatusCode,
        statusCode: statusCode ?? this.statusCode,
        message: message ?? this.message,
        details: details ?? this.details);
  }

  ErrorResponse$Error copyWithWrapped(
      {Wrapped<int>? httpStatusCode,
      Wrapped<int?>? statusCode,
      Wrapped<String>? message,
      Wrapped<String?>? details}) {
    return ErrorResponse$Error(
        httpStatusCode: (httpStatusCode != null
            ? httpStatusCode.value
            : this.httpStatusCode),
        statusCode: (statusCode != null ? statusCode.value : this.statusCode),
        message: (message != null ? message.value : this.message),
        details: (details != null ? details.value : this.details));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingCompleteNotification$SuccessfulRecordings {
  RecordingCompleteNotification$SuccessfulRecordings({
    required this.recordings,
  });

  factory RecordingCompleteNotification$SuccessfulRecordings.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingCompleteNotification$SuccessfulRecordingsFromJson(json);

  @JsonKey(
      name: 'Recordings', includeIfNull: false, defaultValue: <Recordings>[])
  final List<Recordings> recordings;
  static const fromJsonFactory =
      _$RecordingCompleteNotification$SuccessfulRecordingsFromJson;
  static const toJsonFactory =
      _$RecordingCompleteNotification$SuccessfulRecordingsToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingCompleteNotification$SuccessfulRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingCompleteNotification$SuccessfulRecordings &&
            (identical(other.recordings, recordings) ||
                const DeepCollectionEquality()
                    .equals(other.recordings, recordings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordings) ^ runtimeType.hashCode;
}

extension $RecordingCompleteNotification$SuccessfulRecordingsExtension
    on RecordingCompleteNotification$SuccessfulRecordings {
  RecordingCompleteNotification$SuccessfulRecordings copyWith(
      {List<Recordings>? recordings}) {
    return RecordingCompleteNotification$SuccessfulRecordings(
        recordings: recordings ?? this.recordings);
  }

  RecordingCompleteNotification$SuccessfulRecordings copyWithWrapped(
      {Wrapped<List<Recordings>>? recordings}) {
    return RecordingCompleteNotification$SuccessfulRecordings(
        recordings: (recordings != null ? recordings.value : this.recordings));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingCompleteNotification$PartialRecordings {
  RecordingCompleteNotification$PartialRecordings({
    required this.recordings,
  });

  factory RecordingCompleteNotification$PartialRecordings.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingCompleteNotification$PartialRecordingsFromJson(json);

  @JsonKey(
      name: 'Recordings', includeIfNull: false, defaultValue: <Recordings>[])
  final List<Recordings> recordings;
  static const fromJsonFactory =
      _$RecordingCompleteNotification$PartialRecordingsFromJson;
  static const toJsonFactory =
      _$RecordingCompleteNotification$PartialRecordingsToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingCompleteNotification$PartialRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingCompleteNotification$PartialRecordings &&
            (identical(other.recordings, recordings) ||
                const DeepCollectionEquality()
                    .equals(other.recordings, recordings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordings) ^ runtimeType.hashCode;
}

extension $RecordingCompleteNotification$PartialRecordingsExtension
    on RecordingCompleteNotification$PartialRecordings {
  RecordingCompleteNotification$PartialRecordings copyWith(
      {List<Recordings>? recordings}) {
    return RecordingCompleteNotification$PartialRecordings(
        recordings: recordings ?? this.recordings);
  }

  RecordingCompleteNotification$PartialRecordings copyWithWrapped(
      {Wrapped<List<Recordings>>? recordings}) {
    return RecordingCompleteNotification$PartialRecordings(
        recordings: (recordings != null ? recordings.value : this.recordings));
  }
}

@JsonSerializable(explicitToJson: true)
class RecordingCompleteNotification$FailedRecordings {
  RecordingCompleteNotification$FailedRecordings({
    required this.recordings,
  });

  factory RecordingCompleteNotification$FailedRecordings.fromJson(
          Map<String, dynamic> json) =>
      _$RecordingCompleteNotification$FailedRecordingsFromJson(json);

  @JsonKey(
      name: 'Recordings', includeIfNull: false, defaultValue: <Recordings>[])
  final List<Recordings> recordings;
  static const fromJsonFactory =
      _$RecordingCompleteNotification$FailedRecordingsFromJson;
  static const toJsonFactory =
      _$RecordingCompleteNotification$FailedRecordingsToJson;
  Map<String, dynamic> toJson() =>
      _$RecordingCompleteNotification$FailedRecordingsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecordingCompleteNotification$FailedRecordings &&
            (identical(other.recordings, recordings) ||
                const DeepCollectionEquality()
                    .equals(other.recordings, recordings)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(recordings) ^ runtimeType.hashCode;
}

extension $RecordingCompleteNotification$FailedRecordingsExtension
    on RecordingCompleteNotification$FailedRecordings {
  RecordingCompleteNotification$FailedRecordings copyWith(
      {List<Recordings>? recordings}) {
    return RecordingCompleteNotification$FailedRecordings(
        recordings: recordings ?? this.recordings);
  }

  RecordingCompleteNotification$FailedRecordings copyWithWrapped(
      {Wrapped<List<Recordings>>? recordings}) {
    return RecordingCompleteNotification$FailedRecordings(
        recordings: (recordings != null ? recordings.value : this.recordings));
  }
}

String? customersCustomerIdRecordingsGetMostRelevantEpisodeForToJson(
    enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor?
        customersCustomerIdRecordingsGetMostRelevantEpisodeFor) {
  return enums.$CustomersCustomerIdRecordingsGetMostRelevantEpisodeForMap[
      customersCustomerIdRecordingsGetMostRelevantEpisodeFor];
}

enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor
    customersCustomerIdRecordingsGetMostRelevantEpisodeForFromJson(
  Object? customersCustomerIdRecordingsGetMostRelevantEpisodeFor, [
  enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetMostRelevantEpisodeFor is String) {
    return enums
        .$CustomersCustomerIdRecordingsGetMostRelevantEpisodeForMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customersCustomerIdRecordingsGetMostRelevantEpisodeFor
                    .toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomersCustomerIdRecordingsGetMostRelevantEpisodeForMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsGetMostRelevantEpisodeForListToJson(
    List<enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor>?
        customersCustomerIdRecordingsGetMostRelevantEpisodeFor) {
  if (customersCustomerIdRecordingsGetMostRelevantEpisodeFor == null) {
    return [];
  }

  return customersCustomerIdRecordingsGetMostRelevantEpisodeFor
      .map((e) =>
          enums.$CustomersCustomerIdRecordingsGetMostRelevantEpisodeForMap[e]!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor>
    customersCustomerIdRecordingsGetMostRelevantEpisodeForListFromJson(
  List? customersCustomerIdRecordingsGetMostRelevantEpisodeFor, [
  List<enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor>?
      defaultValue,
]) {
  if (customersCustomerIdRecordingsGetMostRelevantEpisodeFor == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsGetMostRelevantEpisodeFor
      .map((e) =>
          customersCustomerIdRecordingsGetMostRelevantEpisodeForFromJson(
              e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor>?
    customersCustomerIdRecordingsGetMostRelevantEpisodeForNullableListFromJson(
  List? customersCustomerIdRecordingsGetMostRelevantEpisodeFor, [
  List<enums.CustomersCustomerIdRecordingsGetMostRelevantEpisodeFor>?
      defaultValue,
]) {
  if (customersCustomerIdRecordingsGetMostRelevantEpisodeFor == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsGetMostRelevantEpisodeFor
      .map((e) =>
          customersCustomerIdRecordingsGetMostRelevantEpisodeForFromJson(
              e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsGetRecordingsKindToJson(
    enums.CustomersCustomerIdRecordingsGetRecordingsKind?
        customersCustomerIdRecordingsGetRecordingsKind) {
  return enums.$CustomersCustomerIdRecordingsGetRecordingsKindMap[
      customersCustomerIdRecordingsGetRecordingsKind];
}

enums.CustomersCustomerIdRecordingsGetRecordingsKind
    customersCustomerIdRecordingsGetRecordingsKindFromJson(
  Object? customersCustomerIdRecordingsGetRecordingsKind, [
  enums.CustomersCustomerIdRecordingsGetRecordingsKind? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetRecordingsKind is String) {
    return enums.$CustomersCustomerIdRecordingsGetRecordingsKindMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customersCustomerIdRecordingsGetRecordingsKind.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomersCustomerIdRecordingsGetRecordingsKind
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomersCustomerIdRecordingsGetRecordingsKindMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsGetRecordingsKind
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsGetRecordingsKindListToJson(
    List<enums.CustomersCustomerIdRecordingsGetRecordingsKind>?
        customersCustomerIdRecordingsGetRecordingsKind) {
  if (customersCustomerIdRecordingsGetRecordingsKind == null) {
    return [];
  }

  return customersCustomerIdRecordingsGetRecordingsKind
      .map((e) => enums.$CustomersCustomerIdRecordingsGetRecordingsKindMap[e]!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetRecordingsKind>
    customersCustomerIdRecordingsGetRecordingsKindListFromJson(
  List? customersCustomerIdRecordingsGetRecordingsKind, [
  List<enums.CustomersCustomerIdRecordingsGetRecordingsKind>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetRecordingsKind == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsGetRecordingsKind
      .map((e) =>
          customersCustomerIdRecordingsGetRecordingsKindFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetRecordingsKind>?
    customersCustomerIdRecordingsGetRecordingsKindNullableListFromJson(
  List? customersCustomerIdRecordingsGetRecordingsKind, [
  List<enums.CustomersCustomerIdRecordingsGetRecordingsKind>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetRecordingsKind == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsGetRecordingsKind
      .map((e) =>
          customersCustomerIdRecordingsGetRecordingsKindFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsGetSortToJson(
    enums.CustomersCustomerIdRecordingsGetSort?
        customersCustomerIdRecordingsGetSort) {
  return enums.$CustomersCustomerIdRecordingsGetSortMap[
      customersCustomerIdRecordingsGetSort];
}

enums.CustomersCustomerIdRecordingsGetSort
    customersCustomerIdRecordingsGetSortFromJson(
  Object? customersCustomerIdRecordingsGetSort, [
  enums.CustomersCustomerIdRecordingsGetSort? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSort is String) {
    return enums.$CustomersCustomerIdRecordingsGetSortMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customersCustomerIdRecordingsGetSort.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomersCustomerIdRecordingsGetSort
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomersCustomerIdRecordingsGetSortMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsGetSort.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsGetSortListToJson(
    List<enums.CustomersCustomerIdRecordingsGetSort>?
        customersCustomerIdRecordingsGetSort) {
  if (customersCustomerIdRecordingsGetSort == null) {
    return [];
  }

  return customersCustomerIdRecordingsGetSort
      .map((e) => enums.$CustomersCustomerIdRecordingsGetSortMap[e]!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSort>
    customersCustomerIdRecordingsGetSortListFromJson(
  List? customersCustomerIdRecordingsGetSort, [
  List<enums.CustomersCustomerIdRecordingsGetSort>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSort == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsGetSort
      .map((e) => customersCustomerIdRecordingsGetSortFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSort>?
    customersCustomerIdRecordingsGetSortNullableListFromJson(
  List? customersCustomerIdRecordingsGetSort, [
  List<enums.CustomersCustomerIdRecordingsGetSort>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSort == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsGetSort
      .map((e) => customersCustomerIdRecordingsGetSortFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsGetSortOrderToJson(
    enums.CustomersCustomerIdRecordingsGetSortOrder?
        customersCustomerIdRecordingsGetSortOrder) {
  return enums.$CustomersCustomerIdRecordingsGetSortOrderMap[
      customersCustomerIdRecordingsGetSortOrder];
}

enums.CustomersCustomerIdRecordingsGetSortOrder
    customersCustomerIdRecordingsGetSortOrderFromJson(
  Object? customersCustomerIdRecordingsGetSortOrder, [
  enums.CustomersCustomerIdRecordingsGetSortOrder? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSortOrder is String) {
    return enums.$CustomersCustomerIdRecordingsGetSortOrderMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customersCustomerIdRecordingsGetSortOrder.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomersCustomerIdRecordingsGetSortOrder
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomersCustomerIdRecordingsGetSortOrderMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsGetSortOrder.swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsGetSortOrderListToJson(
    List<enums.CustomersCustomerIdRecordingsGetSortOrder>?
        customersCustomerIdRecordingsGetSortOrder) {
  if (customersCustomerIdRecordingsGetSortOrder == null) {
    return [];
  }

  return customersCustomerIdRecordingsGetSortOrder
      .map((e) => enums.$CustomersCustomerIdRecordingsGetSortOrderMap[e]!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSortOrder>
    customersCustomerIdRecordingsGetSortOrderListFromJson(
  List? customersCustomerIdRecordingsGetSortOrder, [
  List<enums.CustomersCustomerIdRecordingsGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSortOrder == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsGetSortOrder
      .map((e) =>
          customersCustomerIdRecordingsGetSortOrderFromJson(e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsGetSortOrder>?
    customersCustomerIdRecordingsGetSortOrderNullableListFromJson(
  List? customersCustomerIdRecordingsGetSortOrder, [
  List<enums.CustomersCustomerIdRecordingsGetSortOrder>? defaultValue,
]) {
  if (customersCustomerIdRecordingsGetSortOrder == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsGetSortOrder
      .map((e) =>
          customersCustomerIdRecordingsGetSortOrderFromJson(e.toString()))
      .toList();
}

String? customersCustomerIdRecordingsShowGetRecordingTypeToJson(
    enums.CustomersCustomerIdRecordingsShowGetRecordingType?
        customersCustomerIdRecordingsShowGetRecordingType) {
  return enums.$CustomersCustomerIdRecordingsShowGetRecordingTypeMap[
      customersCustomerIdRecordingsShowGetRecordingType];
}

enums.CustomersCustomerIdRecordingsShowGetRecordingType
    customersCustomerIdRecordingsShowGetRecordingTypeFromJson(
  Object? customersCustomerIdRecordingsShowGetRecordingType, [
  enums.CustomersCustomerIdRecordingsShowGetRecordingType? defaultValue,
]) {
  if (customersCustomerIdRecordingsShowGetRecordingType is String) {
    return enums.$CustomersCustomerIdRecordingsShowGetRecordingTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                customersCustomerIdRecordingsShowGetRecordingType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CustomersCustomerIdRecordingsShowGetRecordingType
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CustomersCustomerIdRecordingsShowGetRecordingTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CustomersCustomerIdRecordingsShowGetRecordingType
          .swaggerGeneratedUnknown;
}

List<String> customersCustomerIdRecordingsShowGetRecordingTypeListToJson(
    List<enums.CustomersCustomerIdRecordingsShowGetRecordingType>?
        customersCustomerIdRecordingsShowGetRecordingType) {
  if (customersCustomerIdRecordingsShowGetRecordingType == null) {
    return [];
  }

  return customersCustomerIdRecordingsShowGetRecordingType
      .map((e) =>
          enums.$CustomersCustomerIdRecordingsShowGetRecordingTypeMap[e]!)
      .toList();
}

List<enums.CustomersCustomerIdRecordingsShowGetRecordingType>
    customersCustomerIdRecordingsShowGetRecordingTypeListFromJson(
  List? customersCustomerIdRecordingsShowGetRecordingType, [
  List<enums.CustomersCustomerIdRecordingsShowGetRecordingType>? defaultValue,
]) {
  if (customersCustomerIdRecordingsShowGetRecordingType == null) {
    return defaultValue ?? [];
  }

  return customersCustomerIdRecordingsShowGetRecordingType
      .map((e) => customersCustomerIdRecordingsShowGetRecordingTypeFromJson(
          e.toString()))
      .toList();
}

List<enums.CustomersCustomerIdRecordingsShowGetRecordingType>?
    customersCustomerIdRecordingsShowGetRecordingTypeNullableListFromJson(
  List? customersCustomerIdRecordingsShowGetRecordingType, [
  List<enums.CustomersCustomerIdRecordingsShowGetRecordingType>? defaultValue,
]) {
  if (customersCustomerIdRecordingsShowGetRecordingType == null) {
    return defaultValue;
  }

  return customersCustomerIdRecordingsShowGetRecordingType
      .map((e) => customersCustomerIdRecordingsShowGetRecordingTypeFromJson(
          e.toString()))
      .toList();
}

String? recordingStateToJson(enums.RecordingState? recordingState) {
  return enums.$RecordingStateMap[recordingState];
}

enums.RecordingState recordingStateFromJson(
  Object? recordingState, [
  enums.RecordingState? defaultValue,
]) {
  if (recordingState is String) {
    return enums.$RecordingStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == recordingState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.RecordingState.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RecordingStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RecordingState.swaggerGeneratedUnknown;
}

List<String> recordingStateListToJson(
    List<enums.RecordingState>? recordingState) {
  if (recordingState == null) {
    return [];
  }

  return recordingState.map((e) => enums.$RecordingStateMap[e]!).toList();
}

List<enums.RecordingState> recordingStateListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue ?? [];
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

List<enums.RecordingState>? recordingStateNullableListFromJson(
  List? recordingState, [
  List<enums.RecordingState>? defaultValue,
]) {
  if (recordingState == null) {
    return defaultValue;
  }

  return recordingState
      .map((e) => recordingStateFromJson(e.toString()))
      .toList();
}

String? recordingTypeToJson(enums.RecordingType? recordingType) {
  return enums.$RecordingTypeMap[recordingType];
}

enums.RecordingType recordingTypeFromJson(
  Object? recordingType, [
  enums.RecordingType? defaultValue,
]) {
  if (recordingType is String) {
    return enums.$RecordingTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == recordingType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.RecordingType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RecordingTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RecordingType.swaggerGeneratedUnknown;
}

List<String> recordingTypeListToJson(List<enums.RecordingType>? recordingType) {
  if (recordingType == null) {
    return [];
  }

  return recordingType.map((e) => enums.$RecordingTypeMap[e]!).toList();
}

List<enums.RecordingType> recordingTypeListFromJson(
  List? recordingType, [
  List<enums.RecordingType>? defaultValue,
]) {
  if (recordingType == null) {
    return defaultValue ?? [];
  }

  return recordingType.map((e) => recordingTypeFromJson(e.toString())).toList();
}

List<enums.RecordingType>? recordingTypeNullableListFromJson(
  List? recordingType, [
  List<enums.RecordingType>? defaultValue,
]) {
  if (recordingType == null) {
    return defaultValue;
  }

  return recordingType.map((e) => recordingTypeFromJson(e.toString())).toList();
}

String? expansionTypeToJson(enums.ExpansionType? expansionType) {
  return enums.$ExpansionTypeMap[expansionType];
}

enums.ExpansionType expansionTypeFromJson(
  Object? expansionType, [
  enums.ExpansionType? defaultValue,
]) {
  if (expansionType is String) {
    return enums.$ExpansionTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == expansionType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ExpansionType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ExpansionTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ExpansionType.swaggerGeneratedUnknown;
}

List<String> expansionTypeListToJson(List<enums.ExpansionType>? expansionType) {
  if (expansionType == null) {
    return [];
  }

  return expansionType.map((e) => enums.$ExpansionTypeMap[e]!).toList();
}

List<enums.ExpansionType> expansionTypeListFromJson(
  List? expansionType, [
  List<enums.ExpansionType>? defaultValue,
]) {
  if (expansionType == null) {
    return defaultValue ?? [];
  }

  return expansionType.map((e) => expansionTypeFromJson(e.toString())).toList();
}

List<enums.ExpansionType>? expansionTypeNullableListFromJson(
  List? expansionType, [
  List<enums.ExpansionType>? defaultValue,
]) {
  if (expansionType == null) {
    return defaultValue;
  }

  return expansionType.map((e) => expansionTypeFromJson(e.toString())).toList();
}

String? itemTypeToJson(enums.ItemType? itemType) {
  return enums.$ItemTypeMap[itemType];
}

enums.ItemType itemTypeFromJson(
  Object? itemType, [
  enums.ItemType? defaultValue,
]) {
  if (itemType is String) {
    return enums.$ItemTypeMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == itemType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.ItemType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ItemTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.ItemType.swaggerGeneratedUnknown;
}

List<String> itemTypeListToJson(List<enums.ItemType>? itemType) {
  if (itemType == null) {
    return [];
  }

  return itemType.map((e) => enums.$ItemTypeMap[e]!).toList();
}

List<enums.ItemType> itemTypeListFromJson(
  List? itemType, [
  List<enums.ItemType>? defaultValue,
]) {
  if (itemType == null) {
    return defaultValue ?? [];
  }

  return itemType.map((e) => itemTypeFromJson(e.toString())).toList();
}

List<enums.ItemType>? itemTypeNullableListFromJson(
  List? itemType, [
  List<enums.ItemType>? defaultValue,
]) {
  if (itemType == null) {
    return defaultValue;
  }

  return itemType.map((e) => itemTypeFromJson(e.toString())).toList();
}

String? assetizationStatusToJson(enums.AssetizationStatus? assetizationStatus) {
  return enums.$AssetizationStatusMap[assetizationStatus];
}

enums.AssetizationStatus assetizationStatusFromJson(
  Object? assetizationStatus, [
  enums.AssetizationStatus? defaultValue,
]) {
  if (assetizationStatus is String) {
    return enums.$AssetizationStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == assetizationStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.AssetizationStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$AssetizationStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.AssetizationStatus.swaggerGeneratedUnknown;
}

List<String> assetizationStatusListToJson(
    List<enums.AssetizationStatus>? assetizationStatus) {
  if (assetizationStatus == null) {
    return [];
  }

  return assetizationStatus
      .map((e) => enums.$AssetizationStatusMap[e]!)
      .toList();
}

List<enums.AssetizationStatus> assetizationStatusListFromJson(
  List? assetizationStatus, [
  List<enums.AssetizationStatus>? defaultValue,
]) {
  if (assetizationStatus == null) {
    return defaultValue ?? [];
  }

  return assetizationStatus
      .map((e) => assetizationStatusFromJson(e.toString()))
      .toList();
}

List<enums.AssetizationStatus>? assetizationStatusNullableListFromJson(
  List? assetizationStatus, [
  List<enums.AssetizationStatus>? defaultValue,
]) {
  if (assetizationStatus == null) {
    return defaultValue;
  }

  return assetizationStatus
      .map((e) => assetizationStatusFromJson(e.toString()))
      .toList();
}

String? failureReasonToJson(enums.FailureReason? failureReason) {
  return enums.$FailureReasonMap[failureReason];
}

enums.FailureReason failureReasonFromJson(
  Object? failureReason, [
  enums.FailureReason? defaultValue,
]) {
  if (failureReason is String) {
    return enums.$FailureReasonMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == failureReason.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.FailureReason.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$FailureReasonMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.FailureReason.swaggerGeneratedUnknown;
}

List<String> failureReasonListToJson(List<enums.FailureReason>? failureReason) {
  if (failureReason == null) {
    return [];
  }

  return failureReason.map((e) => enums.$FailureReasonMap[e]!).toList();
}

List<enums.FailureReason> failureReasonListFromJson(
  List? failureReason, [
  List<enums.FailureReason>? defaultValue,
]) {
  if (failureReason == null) {
    return defaultValue ?? [];
  }

  return failureReason.map((e) => failureReasonFromJson(e.toString())).toList();
}

List<enums.FailureReason>? failureReasonNullableListFromJson(
  List? failureReason, [
  List<enums.FailureReason>? defaultValue,
]) {
  if (failureReason == null) {
    return defaultValue;
  }

  return failureReason.map((e) => failureReasonFromJson(e.toString())).toList();
}

String? sourceToJson(enums.Source? source) {
  return enums.$SourceMap[source];
}

enums.Source sourceFromJson(
  Object? source, [
  enums.Source? defaultValue,
]) {
  if (source is String) {
    return enums.$SourceMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == source.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.Source.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SourceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.Source.swaggerGeneratedUnknown;
}

List<String> sourceListToJson(List<enums.Source>? source) {
  if (source == null) {
    return [];
  }

  return source.map((e) => enums.$SourceMap[e]!).toList();
}

List<enums.Source> sourceListFromJson(
  List? source, [
  List<enums.Source>? defaultValue,
]) {
  if (source == null) {
    return defaultValue ?? [];
  }

  return source.map((e) => sourceFromJson(e.toString())).toList();
}

List<enums.Source>? sourceNullableListFromJson(
  List? source, [
  List<enums.Source>? defaultValue,
]) {
  if (source == null) {
    return defaultValue;
  }

  return source.map((e) => sourceFromJson(e.toString())).toList();
}

String? recordingsKindToJson(enums.RecordingsKind? recordingsKind) {
  return enums.$RecordingsKindMap[recordingsKind];
}

enums.RecordingsKind recordingsKindFromJson(
  Object? recordingsKind, [
  enums.RecordingsKind? defaultValue,
]) {
  if (recordingsKind is String) {
    return enums.$RecordingsKindMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == recordingsKind.toLowerCase(),
            orElse: () => const MapEntry(
                enums.RecordingsKind.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$RecordingsKindMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.RecordingsKind.swaggerGeneratedUnknown;
}

List<String> recordingsKindListToJson(
    List<enums.RecordingsKind>? recordingsKind) {
  if (recordingsKind == null) {
    return [];
  }

  return recordingsKind.map((e) => enums.$RecordingsKindMap[e]!).toList();
}

List<enums.RecordingsKind> recordingsKindListFromJson(
  List? recordingsKind, [
  List<enums.RecordingsKind>? defaultValue,
]) {
  if (recordingsKind == null) {
    return defaultValue ?? [];
  }

  return recordingsKind
      .map((e) => recordingsKindFromJson(e.toString()))
      .toList();
}

List<enums.RecordingsKind>? recordingsKindNullableListFromJson(
  List? recordingsKind, [
  List<enums.RecordingsKind>? defaultValue,
]) {
  if (recordingsKind == null) {
    return defaultValue;
  }

  return recordingsKind
      .map((e) => recordingsKindFromJson(e.toString()))
      .toList();
}

String? recordings$ItemTypeToJson(
    enums.Recordings$ItemType? recordings$ItemType) {
  return enums.$Recordings$ItemTypeMap[recordings$ItemType];
}

enums.Recordings$ItemType recordings$ItemTypeFromJson(
  Object? recordings$ItemType, [
  enums.Recordings$ItemType? defaultValue,
]) {
  if (recordings$ItemType is String) {
    return enums.$Recordings$ItemTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                recordings$ItemType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.Recordings$ItemType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$Recordings$ItemTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.Recordings$ItemType.swaggerGeneratedUnknown;
}

List<String> recordings$ItemTypeListToJson(
    List<enums.Recordings$ItemType>? recordings$ItemType) {
  if (recordings$ItemType == null) {
    return [];
  }

  return recordings$ItemType
      .map((e) => enums.$Recordings$ItemTypeMap[e]!)
      .toList();
}

List<enums.Recordings$ItemType> recordings$ItemTypeListFromJson(
  List? recordings$ItemType, [
  List<enums.Recordings$ItemType>? defaultValue,
]) {
  if (recordings$ItemType == null) {
    return defaultValue ?? [];
  }

  return recordings$ItemType
      .map((e) => recordings$ItemTypeFromJson(e.toString()))
      .toList();
}

List<enums.Recordings$ItemType>? recordings$ItemTypeNullableListFromJson(
  List? recordings$ItemType, [
  List<enums.Recordings$ItemType>? defaultValue,
]) {
  if (recordings$ItemType == null) {
    return defaultValue;
  }

  return recordings$ItemType
      .map((e) => recordings$ItemTypeFromJson(e.toString()))
      .toList();
}

String? opWithNetworkRecordingsOpToJson(
    enums.OpWithNetworkRecordingsOp? opWithNetworkRecordingsOp) {
  return enums.$OpWithNetworkRecordingsOpMap[opWithNetworkRecordingsOp];
}

enums.OpWithNetworkRecordingsOp opWithNetworkRecordingsOpFromJson(
  Object? opWithNetworkRecordingsOp, [
  enums.OpWithNetworkRecordingsOp? defaultValue,
]) {
  if (opWithNetworkRecordingsOp is String) {
    return enums.$OpWithNetworkRecordingsOpMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                opWithNetworkRecordingsOp.toLowerCase(),
            orElse: () => const MapEntry(
                enums.OpWithNetworkRecordingsOp.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$OpWithNetworkRecordingsOpMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.OpWithNetworkRecordingsOp.swaggerGeneratedUnknown;
}

List<String> opWithNetworkRecordingsOpListToJson(
    List<enums.OpWithNetworkRecordingsOp>? opWithNetworkRecordingsOp) {
  if (opWithNetworkRecordingsOp == null) {
    return [];
  }

  return opWithNetworkRecordingsOp
      .map((e) => enums.$OpWithNetworkRecordingsOpMap[e]!)
      .toList();
}

List<enums.OpWithNetworkRecordingsOp> opWithNetworkRecordingsOpListFromJson(
  List? opWithNetworkRecordingsOp, [
  List<enums.OpWithNetworkRecordingsOp>? defaultValue,
]) {
  if (opWithNetworkRecordingsOp == null) {
    return defaultValue ?? [];
  }

  return opWithNetworkRecordingsOp
      .map((e) => opWithNetworkRecordingsOpFromJson(e.toString()))
      .toList();
}

List<enums.OpWithNetworkRecordingsOp>?
    opWithNetworkRecordingsOpNullableListFromJson(
  List? opWithNetworkRecordingsOp, [
  List<enums.OpWithNetworkRecordingsOp>? defaultValue,
]) {
  if (opWithNetworkRecordingsOp == null) {
    return defaultValue;
  }

  return opWithNetworkRecordingsOp
      .map((e) => opWithNetworkRecordingsOpFromJson(e.toString()))
      .toList();
}

String? opToJson(enums.Op? op) {
  return enums.$OpMap[op];
}

enums.Op opFromJson(
  Object? op, [
  enums.Op? defaultValue,
]) {
  if (op is String) {
    return enums.$OpMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == op.toLowerCase(),
            orElse: () => const MapEntry(enums.Op.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$OpMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ?? defaultValue ?? enums.Op.swaggerGeneratedUnknown;
}

List<String> opListToJson(List<enums.Op>? op) {
  if (op == null) {
    return [];
  }

  return op.map((e) => enums.$OpMap[e]!).toList();
}

List<enums.Op> opListFromJson(
  List? op, [
  List<enums.Op>? defaultValue,
]) {
  if (op == null) {
    return defaultValue ?? [];
  }

  return op.map((e) => opFromJson(e.toString())).toList();
}

List<enums.Op>? opNullableListFromJson(
  List? op, [
  List<enums.Op>? defaultValue,
]) {
  if (op == null) {
    return defaultValue;
  }

  return op.map((e) => opFromJson(e.toString())).toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
