// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'spec.enums.swagger.dart' as enums;
export 'spec.enums.swagger.dart';

part 'spec.swagger.chopper.dart';
part 'spec.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class Spec extends ChopperService {
  static Spec create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$Spec(client);
    }

    final newClient = ChopperClient(
        services: [_$Spec()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$Spec(newClient);
  }

  ///Registers a user.
  Future<chopper.Response<User>> accountRegisterPost({
    String? cacheControl,
    required UserRegister? body,
  }) {
    generatedMapping.putIfAbsent(User, () => User.fromJsonFactory);

    return _accountRegisterPost(cacheControl: cacheControl, body: body);
  }

  ///Registers a user.
  @Post(path: '/account/register')
  Future<chopper.Response<User>> _accountRegisterPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserRegister? body,
  });

  ///Activate the registered user
  ///@param key the activation key
  Future<chopper.Response> accountActivateGet({
    String? key,
    String? cacheControl,
  }) {
    return _accountActivateGet(key: key, cacheControl: cacheControl);
  }

  ///Activate the registered user
  ///@param key the activation key
  @Get(path: '/account/activate')
  Future<chopper.Response> _accountActivateGet({
    @Query('key') String? key,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Login or registers a user.
  ///@param subNewsletter
  Future<chopper.Response<User>> accountLoginPost({
    bool? subNewsletter,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(User, () => User.fromJsonFactory);

    return _accountLoginPost(
        subNewsletter: subNewsletter, cacheControl: cacheControl);
  }

  ///Login or registers a user.
  ///@param subNewsletter
  @Post(
    path: '/account/login',
    optionalBody: true,
  )
  Future<chopper.Response<User>> _accountLoginPost({
    @Query('subNewsletter') bool? subNewsletter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Checks login parameters.
  ///@param email
  Future<chopper.Response> accountCheckPost({
    String? email,
    String? cacheControl,
  }) {
    return _accountCheckPost(email: email, cacheControl: cacheControl);
  }

  ///Checks login parameters.
  ///@param email
  @Post(
    path: '/account/check',
    optionalBody: true,
  )
  Future<chopper.Response> _accountCheckPost({
    @Query('email') String? email,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Send an email to reset the password of the user
  Future<chopper.Response> accountResetPasswordInitPost({
    String? cacheControl,
    required String? body,
  }) {
    return _accountResetPasswordInitPost(
        cacheControl: cacheControl, body: body);
  }

  ///Send an email to reset the password of the user
  @Post(path: '/account/reset-password/init')
  Future<chopper.Response> _accountResetPasswordInitPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required String? body,
  });

  ///Finish to reset the password of the user
  Future<chopper.Response> accountResetPasswordFinishPost({
    String? cacheControl,
    required UserNewPassword? body,
  }) {
    return _accountResetPasswordFinishPost(
        cacheControl: cacheControl, body: body);
  }

  ///Finish to reset the password of the user
  @Post(path: '/account/reset-password/finish')
  Future<chopper.Response> _accountResetPasswordFinishPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserNewPassword? body,
  });

  ///Update the account profile information
  Future<chopper.Response<UserProfile>> accountProfilePut({
    String? cacheControl,
    required UserProfile? body,
  }) {
    generatedMapping.putIfAbsent(
        UserProfile, () => UserProfile.fromJsonFactory);

    return _accountProfilePut(cacheControl: cacheControl, body: body);
  }

  ///Update the account profile information
  @Put(path: '/account/profile')
  Future<chopper.Response<UserProfile>> _accountProfilePut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserProfile? body,
  });

  ///Get the profile information
  Future<chopper.Response<UserProfile>> accountProfileGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        UserProfile, () => UserProfile.fromJsonFactory);

    return _accountProfileGet(cacheControl: cacheControl);
  }

  ///Get the profile information
  @Get(path: '/account/profile')
  Future<chopper.Response<UserProfile>> _accountProfileGet(
      {@Header('Cache-Control') String? cacheControl});

  ///List all the Addresss
  Future<chopper.Response<Addresses>> accountAddressesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(Address, () => Address.fromJsonFactory);

    return _accountAddressesGet(cacheControl: cacheControl);
  }

  ///List all the Addresss
  @Get(path: '/account/addresses')
  Future<chopper.Response<Addresses>> _accountAddressesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates an Address
  Future<chopper.Response<Address>> accountAddressesPost({
    String? cacheControl,
    required Address? body,
  }) {
    generatedMapping.putIfAbsent(Address, () => Address.fromJsonFactory);

    return _accountAddressesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates an Address
  @Post(path: '/account/addresses')
  Future<chopper.Response<Address>> _accountAddressesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Address? body,
  });

  ///Info for a specific Address
  ///@param addressId The address id.
  Future<chopper.Response<Address>> accountAddressesAddressIdGet({
    required String? addressId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Address, () => Address.fromJsonFactory);

    return _accountAddressesAddressIdGet(
        addressId: addressId, cacheControl: cacheControl);
  }

  ///Info for a specific Address
  ///@param addressId The address id.
  @Get(path: '/account/addresses/{addressId}')
  Future<chopper.Response<Address>> _accountAddressesAddressIdGet({
    @Path('addressId') required String? addressId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Address
  ///@param addressId The address id.
  Future<chopper.Response<Address>> accountAddressesAddressIdPut({
    required String? addressId,
    String? cacheControl,
    required Address? body,
  }) {
    generatedMapping.putIfAbsent(Address, () => Address.fromJsonFactory);

    return _accountAddressesAddressIdPut(
        addressId: addressId, cacheControl: cacheControl, body: body);
  }

  ///Update a Address
  ///@param addressId The address id.
  @Put(path: '/account/addresses/{addressId}')
  Future<chopper.Response<Address>> _accountAddressesAddressIdPut({
    @Path('addressId') required String? addressId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Address? body,
  });

  ///Deletes an Address
  ///@param addressId The address id.
  Future<chopper.Response> accountAddressesAddressIdDelete({
    required String? addressId,
    String? cacheControl,
  }) {
    return _accountAddressesAddressIdDelete(
        addressId: addressId, cacheControl: cacheControl);
  }

  ///Deletes an Address
  ///@param addressId The address id.
  @Delete(path: '/account/addresses/{addressId}')
  Future<chopper.Response> _accountAddressesAddressIdDelete({
    @Path('addressId') required String? addressId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the user files
  Future<chopper.Response<UserFiles>> accountFilesGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(UserFile, () => UserFile.fromJsonFactory);

    return _accountFilesGet(cacheControl: cacheControl);
  }

  ///List all the user files
  @Get(path: '/account/files')
  Future<chopper.Response<UserFiles>> _accountFilesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Uploads File
  Future<chopper.Response> accountFilesPost({
    String? cacheControl,
    required String? id,
    required List<int> file,
  }) {
    return _accountFilesPost(cacheControl: cacheControl, id: id, file: file);
  }

  ///Uploads File
  @Post(path: '/account/files')
  @Multipart()
  Future<chopper.Response> _accountFilesPost({
    @Header('Cache-Control') String? cacheControl,
    @Part() required String? id,
    @PartFile() required List<int> file,
  });

  ///Gets a File
  ///@param fileId The File id
  Future<chopper.Response<String>> accountFilesFileIdGet({
    required String? fileId,
    String? cacheControl,
  }) {
    return _accountFilesFileIdGet(fileId: fileId, cacheControl: cacheControl);
  }

  ///Gets a File
  ///@param fileId The File id
  @Get(path: '/account/files/{fileId}')
  Future<chopper.Response<String>> _accountFilesFileIdGet({
    @Path('fileId') required String? fileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a File
  ///@param fileId The File id
  Future<chopper.Response> accountFilesFileIdPut({
    required String? fileId,
    String? cacheControl,
    List<int>? file,
  }) {
    return _accountFilesFileIdPut(
        fileId: fileId, cacheControl: cacheControl, file: file);
  }

  ///Update a File
  ///@param fileId The File id
  @Put(path: '/account/files/{fileId}')
  @Multipart()
  Future<chopper.Response> _accountFilesFileIdPut({
    @Path('fileId') required String? fileId,
    @Header('Cache-Control') String? cacheControl,
    @PartFile() List<int>? file,
  });

  ///Deletes a File
  ///@param fileId The File id
  Future<chopper.Response> accountFilesFileIdDelete({
    required String? fileId,
    String? cacheControl,
  }) {
    return _accountFilesFileIdDelete(
        fileId: fileId, cacheControl: cacheControl);
  }

  ///Deletes a File
  ///@param fileId The File id
  @Delete(path: '/account/files/{fileId}')
  Future<chopper.Response> _accountFilesFileIdDelete({
    @Path('fileId') required String? fileId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all service options
  ///@param serviceId Filter by service ID.
  ///@param activeOnly If true, only the active entries are returned.
  Future<chopper.Response<ServiceOptions>> serviceOptionsGet({
    String? serviceId,
    bool? activeOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _serviceOptionsGet(
        serviceId: serviceId,
        activeOnly: activeOnly,
        cacheControl: cacheControl);
  }

  ///List all service options
  ///@param serviceId Filter by service ID.
  ///@param activeOnly If true, only the active entries are returned.
  @Get(path: '/service-options')
  Future<chopper.Response<ServiceOptions>> _serviceOptionsGet({
    @Query('serviceId') String? serviceId,
    @Query('activeOnly') bool? activeOnly,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create a service option
  Future<chopper.Response<ServiceOption>> serviceOptionsPost({
    String? cacheControl,
    required ServiceOption? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _serviceOptionsPost(cacheControl: cacheControl, body: body);
  }

  ///Create a service option
  @Post(path: '/service-options')
  Future<chopper.Response<ServiceOption>> _serviceOptionsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceOption? body,
  });

  ///Info for a specific service option
  ///@param optionId Option ID.
  Future<chopper.Response<ServiceOption>> serviceOptionsOptionIdGet({
    required String? optionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _serviceOptionsOptionIdGet(
        optionId: optionId, cacheControl: cacheControl);
  }

  ///Info for a specific service option
  ///@param optionId Option ID.
  @Get(path: '/service-options/{optionId}')
  Future<chopper.Response<ServiceOption>> _serviceOptionsOptionIdGet({
    @Path('optionId') required String? optionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update service option
  ///@param optionId Option ID.
  Future<chopper.Response<ServiceOption>> serviceOptionsOptionIdPut({
    required String? optionId,
    String? cacheControl,
    required ServiceOption? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _serviceOptionsOptionIdPut(
        optionId: optionId, cacheControl: cacheControl, body: body);
  }

  ///Update service option
  ///@param optionId Option ID.
  @Put(path: '/service-options/{optionId}')
  Future<chopper.Response<ServiceOption>> _serviceOptionsOptionIdPut({
    @Path('optionId') required String? optionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceOption? body,
  });

  ///Delete Service Option
  ///@param optionId Option ID.
  Future<chopper.Response> serviceOptionsOptionIdDelete({
    required String? optionId,
    String? cacheControl,
  }) {
    return _serviceOptionsOptionIdDelete(
        optionId: optionId, cacheControl: cacheControl);
  }

  ///Delete Service Option
  ///@param optionId Option ID.
  @Delete(path: '/service-options/{optionId}')
  Future<chopper.Response> _serviceOptionsOptionIdDelete({
    @Path('optionId') required String? optionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Add an OptionFeature to a ServiceOption
  ///@param optionId Option ID.
  Future<chopper.Response<ServiceOption>>
      serviceOptionOptionIdAddOptionFeaturePost({
    required String? optionId,
    String? cacheControl,
    required OptionFeature? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _serviceOptionOptionIdAddOptionFeaturePost(
        optionId: optionId, cacheControl: cacheControl, body: body);
  }

  ///Add an OptionFeature to a ServiceOption
  ///@param optionId Option ID.
  @Post(path: '/service-option/{optionId}/addOptionFeature')
  Future<chopper.Response<ServiceOption>>
      _serviceOptionOptionIdAddOptionFeaturePost({
    @Path('optionId') required String? optionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OptionFeature? body,
  });

  ///Add an Image to a ServiceOption
  ///@param optionId Option ID.
  Future<chopper.Response<ServiceOption>> serviceOptionOptionIdAddImagePost({
    required String? optionId,
    String? cacheControl,
    required Image? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _serviceOptionOptionIdAddImagePost(
        optionId: optionId, cacheControl: cacheControl, body: body);
  }

  ///Add an Image to a ServiceOption
  ///@param optionId Option ID.
  @Post(path: '/service-option/{optionId}/addImage')
  Future<chopper.Response<ServiceOption>> _serviceOptionOptionIdAddImagePost({
    @Path('optionId') required String? optionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Image? body,
  });

  ///List all service categories
  ///@param q
  Future<chopper.Response<ServiceCategories>> serviceCategoriesGet({
    ServiceCategoryCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategoryCriteria, () => ServiceCategoryCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesGet(q: q, cacheControl: cacheControl);
  }

  ///List all service categories
  ///@param q
  @Get(path: '/service-categories')
  Future<chopper.Response<ServiceCategories>> _serviceCategoriesGet({
    @Query('q') ServiceCategoryCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create a service category
  Future<chopper.Response<ServiceCategory>> serviceCategoriesPost({
    String? cacheControl,
    required ServiceCategory? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesPost(cacheControl: cacheControl, body: body);
  }

  ///Create a service category
  @Post(path: '/service-categories')
  Future<chopper.Response<ServiceCategory>> _serviceCategoriesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceCategory? body,
  });

  ///Info for a specific service category
  ///@param categoryId Category ID.
  Future<chopper.Response<ServiceCategory>> serviceCategoriesCategoryIdGet({
    required String? categoryId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesCategoryIdGet(
        categoryId: categoryId, cacheControl: cacheControl);
  }

  ///Info for a specific service category
  ///@param categoryId Category ID.
  @Get(path: '/service-categories/{categoryId}')
  Future<chopper.Response<ServiceCategory>> _serviceCategoriesCategoryIdGet({
    @Path('categoryId') required String? categoryId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update service category
  ///@param categoryId Category ID.
  Future<chopper.Response<ServiceCategory>> serviceCategoriesCategoryIdPut({
    required String? categoryId,
    String? cacheControl,
    required ServiceCategory? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesCategoryIdPut(
        categoryId: categoryId, cacheControl: cacheControl, body: body);
  }

  ///Update service category
  ///@param categoryId Category ID.
  @Put(path: '/service-categories/{categoryId}')
  Future<chopper.Response<ServiceCategory>> _serviceCategoriesCategoryIdPut({
    @Path('categoryId') required String? categoryId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceCategory? body,
  });

  ///Delete Service Category
  ///@param categoryId Category ID.
  Future<chopper.Response> serviceCategoriesCategoryIdDelete({
    required String? categoryId,
    String? cacheControl,
  }) {
    return _serviceCategoriesCategoryIdDelete(
        categoryId: categoryId, cacheControl: cacheControl);
  }

  ///Delete Service Category
  ///@param categoryId Category ID.
  @Delete(path: '/service-categories/{categoryId}')
  Future<chopper.Response> _serviceCategoriesCategoryIdDelete({
    @Path('categoryId') required String? categoryId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the services of a category
  ///@param pageable
  ///@param categoryId Category ID.
  ///@param activeOnly If true, only the active entries are returned.
  ///@param recursive If true, retrive also from recursive childs
  ///@param q
  Future<chopper.Response<SimplrServicesPage>>
      serviceCategoriesCategoryIdSimplrServicesGet({
    Pageable? pageable,
    required String? categoryId,
    bool? activeOnly,
    bool? recursive,
    SimplrServiceCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServiceCriteria, () => SimplrServiceCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServicesPage, () => SimplrServicesPage.fromJsonFactory);

    return _serviceCategoriesCategoryIdSimplrServicesGet(
        pageable: pageable,
        categoryId: categoryId,
        activeOnly: activeOnly,
        recursive: recursive,
        q: q,
        cacheControl: cacheControl);
  }

  ///List all the services of a category
  ///@param pageable
  ///@param categoryId Category ID.
  ///@param activeOnly If true, only the active entries are returned.
  ///@param recursive If true, retrive also from recursive childs
  ///@param q
  @Get(path: '/service-categories/{categoryId}/simplr-services')
  Future<chopper.Response<SimplrServicesPage>>
      _serviceCategoriesCategoryIdSimplrServicesGet({
    @Query('pageable') Pageable? pageable,
    @Path('categoryId') required String? categoryId,
    @Query('activeOnly') bool? activeOnly,
    @Query('recursive') bool? recursive,
    @Query('q') SimplrServiceCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Find all top services of a category
  ///@param pageable
  ///@param categoryId Category ID.
  ///@param showAll
  Future<chopper.Response<SimplrServicesPage>>
      serviceCategoriesCategoryIdTopServicesGet({
    Pageable? pageable,
    required String? categoryId,
    bool? showAll,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServicesPage, () => SimplrServicesPage.fromJsonFactory);

    return _serviceCategoriesCategoryIdTopServicesGet(
        pageable: pageable,
        categoryId: categoryId,
        showAll: showAll,
        cacheControl: cacheControl);
  }

  ///Find all top services of a category
  ///@param pageable
  ///@param categoryId Category ID.
  ///@param showAll
  @Get(path: '/service-categories/{categoryId}/top-services')
  Future<chopper.Response<SimplrServicesPage>>
      _serviceCategoriesCategoryIdTopServicesGet({
    @Query('pageable') Pageable? pageable,
    @Path('categoryId') required String? categoryId,
    @Query('showAll') bool? showAll,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Sets top services to this category
  ///@param categoryId Category ID.
  Future<chopper.Response> serviceCategoriesCategoryIdTopServicesPut({
    required String? categoryId,
    String? cacheControl,
    required SimplrServiceIdList? body,
  }) {
    return _serviceCategoriesCategoryIdTopServicesPut(
        categoryId: categoryId, cacheControl: cacheControl, body: body);
  }

  ///Sets top services to this category
  ///@param categoryId Category ID.
  @Put(path: '/service-categories/{categoryId}/top-services')
  Future<chopper.Response> _serviceCategoriesCategoryIdTopServicesPut({
    @Path('categoryId') required String? categoryId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SimplrServiceIdList? body,
  });

  ///Search all the services of a category (Elastic)
  ///@param pageable
  ///@param categoryId Category ID.
  ///@param activeOnly If true, only the active entries are returned.
  ///@param recursive If true, retrive also from recursive childs
  ///@param filterQuery
  Future<chopper.Response<SimplrServiceSearch>>
      serviceCategoriesCategoryIdSimplrServicesSearchGet({
    Pageable? pageable,
    required String? categoryId,
    bool? activeOnly,
    bool? recursive,
    SimplrServiceSearchFilter? filterQuery,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(SimplrServiceSearchFilter,
        () => SimplrServiceSearchFilter.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServiceSearch, () => SimplrServiceSearch.fromJsonFactory);

    return _serviceCategoriesCategoryIdSimplrServicesSearchGet(
        pageable: pageable,
        categoryId: categoryId,
        activeOnly: activeOnly,
        recursive: recursive,
        filterQuery: filterQuery,
        cacheControl: cacheControl);
  }

  ///Search all the services of a category (Elastic)
  ///@param pageable
  ///@param categoryId Category ID.
  ///@param activeOnly If true, only the active entries are returned.
  ///@param recursive If true, retrive also from recursive childs
  ///@param filterQuery
  @Get(path: '/service-categories/{categoryId}/simplr-services/search')
  Future<chopper.Response<SimplrServiceSearch>>
      _serviceCategoriesCategoryIdSimplrServicesSearchGet({
    @Query('pageable') Pageable? pageable,
    @Path('categoryId') required String? categoryId,
    @Query('activeOnly') bool? activeOnly,
    @Query('recursive') bool? recursive,
    @Query('filterQuery') SimplrServiceSearchFilter? filterQuery,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Adds a service
  ///@param categoryId Category ID.
  ///@param serviceId Service ID.
  Future<chopper.Response<ServiceCategory>>
      serviceCategoriesCategoryIdSimplrServicesServiceIdPut({
    required String? categoryId,
    required String? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesCategoryIdSimplrServicesServiceIdPut(
        categoryId: categoryId,
        serviceId: serviceId,
        cacheControl: cacheControl);
  }

  ///Adds a service
  ///@param categoryId Category ID.
  ///@param serviceId Service ID.
  @Put(
    path: '/service-categories/{categoryId}/simplr-services/{serviceId}',
    optionalBody: true,
  )
  Future<chopper.Response<ServiceCategory>>
      _serviceCategoriesCategoryIdSimplrServicesServiceIdPut({
    @Path('categoryId') required String? categoryId,
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Remove a service from a category
  ///@param categoryId Category ID.
  ///@param serviceId Service ID.
  Future<chopper.Response<ServiceCategory>>
      serviceCategoriesCategoryIdSimplrServicesServiceIdDelete({
    required String? categoryId,
    required String? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesCategoryIdSimplrServicesServiceIdDelete(
        categoryId: categoryId,
        serviceId: serviceId,
        cacheControl: cacheControl);
  }

  ///Remove a service from a category
  ///@param categoryId Category ID.
  ///@param serviceId Service ID.
  @Delete(path: '/service-categories/{categoryId}/simplr-services/{serviceId}')
  Future<chopper.Response<ServiceCategory>>
      _serviceCategoriesCategoryIdSimplrServicesServiceIdDelete({
    @Path('categoryId') required String? categoryId,
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create a service category
  Future<chopper.Response<ServiceCategories>>
      serviceCategoriesSaveCategoriesOrderPost({
    String? cacheControl,
    required ServiceCategories? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceCategory, () => ServiceCategory.fromJsonFactory);

    return _serviceCategoriesSaveCategoriesOrderPost(
        cacheControl: cacheControl, body: body);
  }

  ///Create a service category
  @Post(path: '/service-categories/saveCategoriesOrder')
  Future<chopper.Response<ServiceCategories>>
      _serviceCategoriesSaveCategoriesOrderPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceCategories? body,
  });

  ///List all service categories
  ///@param pageable
  ///@param q
  ///@param simplrServiceExpandFields Allows to return expanded attributes
  ///@param prioritisedField Allows to prioritised the results with same value
  Future<chopper.Response<SimplrServicesPage>> simplrServicesGet({
    Pageable? pageable,
    SimplrServiceCriteria? q,
    List<enums.SimplrServiceExpand>? simplrServiceExpandFields,
    SimplrServicePrioritisedField? prioritisedField,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServiceCriteria, () => SimplrServiceCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(SimplrServicePrioritisedField,
        () => SimplrServicePrioritisedField.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServicesPage, () => SimplrServicesPage.fromJsonFactory);

    return _simplrServicesGet(
        pageable: pageable,
        q: q,
        simplrServiceExpandFields:
            simplrServiceExpandListToJson(simplrServiceExpandFields),
        prioritisedField: prioritisedField,
        cacheControl: cacheControl);
  }

  ///List all service categories
  ///@param pageable
  ///@param q
  ///@param simplrServiceExpandFields Allows to return expanded attributes
  ///@param prioritisedField Allows to prioritised the results with same value
  @Get(path: '/simplr-services')
  Future<chopper.Response<SimplrServicesPage>> _simplrServicesGet({
    @Query('pageable') Pageable? pageable,
    @Query('q') SimplrServiceCriteria? q,
    @Query('simplrServiceExpandFields')
        List<String?>? simplrServiceExpandFields,
    @Query('prioritisedField') SimplrServicePrioritisedField? prioritisedField,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a service
  Future<chopper.Response<SimplrService>> simplrServicesPost({
    String? cacheControl,
    required SimplrService? body,
  }) {
    generatedMapping.putIfAbsent(
        SimplrService, () => SimplrService.fromJsonFactory);

    return _simplrServicesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a service
  @Post(path: '/simplr-services')
  Future<chopper.Response<SimplrService>> _simplrServicesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SimplrService? body,
  });

  ///Info for a specific service
  ///@param serviceId Service ID.
  Future<chopper.Response<SimplrService>> simplrServicesServiceIdGet({
    required String? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimplrService, () => SimplrService.fromJsonFactory);

    return _simplrServicesServiceIdGet(
        serviceId: serviceId, cacheControl: cacheControl);
  }

  ///Info for a specific service
  ///@param serviceId Service ID.
  @Get(path: '/simplr-services/{serviceId}')
  Future<chopper.Response<SimplrService>> _simplrServicesServiceIdGet({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update Simplr service
  ///@param serviceId Service ID.
  Future<chopper.Response<SimplrService>> simplrServicesServiceIdPut({
    required String? serviceId,
    String? cacheControl,
    required SimplrService? body,
  }) {
    generatedMapping.putIfAbsent(
        SimplrService, () => SimplrService.fromJsonFactory);

    return _simplrServicesServiceIdPut(
        serviceId: serviceId, cacheControl: cacheControl, body: body);
  }

  ///Update Simplr service
  ///@param serviceId Service ID.
  @Put(path: '/simplr-services/{serviceId}')
  Future<chopper.Response<SimplrService>> _simplrServicesServiceIdPut({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SimplrService? body,
  });

  ///Deletes a Service
  ///@param serviceId Service ID.
  Future<chopper.Response> simplrServicesServiceIdDelete({
    required String? serviceId,
    String? cacheControl,
  }) {
    return _simplrServicesServiceIdDelete(
        serviceId: serviceId, cacheControl: cacheControl);
  }

  ///Deletes a Service
  ///@param serviceId Service ID.
  @Delete(path: '/simplr-services/{serviceId}')
  Future<chopper.Response> _simplrServicesServiceIdDelete({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the ServiceTypes
  ///@param pageable
  ///@param q
  Future<chopper.Response<ServiceTypes>> serviceTypesGet({
    Pageable? pageable,
    ServiceTypeCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        ServiceTypeCriteria, () => ServiceTypeCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(
        ServiceTypes, () => ServiceTypes.fromJsonFactory);

    return _serviceTypesGet(
        pageable: pageable, q: q, cacheControl: cacheControl);
  }

  ///List all the ServiceTypes
  ///@param pageable
  ///@param q
  @Get(path: '/service-types')
  Future<chopper.Response<ServiceTypes>> _serviceTypesGet({
    @Query('pageable') Pageable? pageable,
    @Query('q') ServiceTypeCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Service type
  Future<chopper.Response<ServiceType>> serviceTypesPost({
    String? cacheControl,
    required ServiceType? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceType, () => ServiceType.fromJsonFactory);

    return _serviceTypesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Service type
  @Post(path: '/service-types')
  Future<chopper.Response<ServiceType>> _serviceTypesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceType? body,
  });

  ///Info for a specific ServiceType
  ///@param serviceTypeId ServiceType ID.
  Future<chopper.Response<ServiceType>> serviceTypesServiceTypeIdGet({
    required String? serviceTypeId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceType, () => ServiceType.fromJsonFactory);

    return _serviceTypesServiceTypeIdGet(
        serviceTypeId: serviceTypeId, cacheControl: cacheControl);
  }

  ///Info for a specific ServiceType
  ///@param serviceTypeId ServiceType ID.
  @Get(path: '/service-types/{serviceTypeId}')
  Future<chopper.Response<ServiceType>> _serviceTypesServiceTypeIdGet({
    @Path('serviceTypeId') required String? serviceTypeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a ServiceType
  ///@param serviceTypeId ServiceType ID.
  Future<chopper.Response<ServiceType>> serviceTypesServiceTypeIdPut({
    required String? serviceTypeId,
    String? cacheControl,
    required ServiceType? body,
  }) {
    generatedMapping.putIfAbsent(
        ServiceType, () => ServiceType.fromJsonFactory);

    return _serviceTypesServiceTypeIdPut(
        serviceTypeId: serviceTypeId, cacheControl: cacheControl, body: body);
  }

  ///Update a ServiceType
  ///@param serviceTypeId ServiceType ID.
  @Put(path: '/service-types/{serviceTypeId}')
  Future<chopper.Response<ServiceType>> _serviceTypesServiceTypeIdPut({
    @Path('serviceTypeId') required String? serviceTypeId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ServiceType? body,
  });

  ///Deletes a ServiceType
  ///@param serviceTypeId ServiceType ID.
  Future<chopper.Response> serviceTypesServiceTypeIdDelete({
    required String? serviceTypeId,
    String? cacheControl,
  }) {
    return _serviceTypesServiceTypeIdDelete(
        serviceTypeId: serviceTypeId, cacheControl: cacheControl);
  }

  ///Deletes a ServiceType
  ///@param serviceTypeId ServiceType ID.
  @Delete(path: '/service-types/{serviceTypeId}')
  Future<chopper.Response> _serviceTypesServiceTypeIdDelete({
    @Path('serviceTypeId') required String? serviceTypeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for Services
  ///@param pageable
  ///@param q the search query.
  ///@param filterQuery
  Future<chopper.Response<SimplrServiceSearch>> simplrServicesSearchGet({
    Pageable? pageable,
    String? q,
    SimplrServiceSearchFilter? filterQuery,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(SimplrServiceSearchFilter,
        () => SimplrServiceSearchFilter.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrServiceSearch, () => SimplrServiceSearch.fromJsonFactory);

    return _simplrServicesSearchGet(
        pageable: pageable,
        q: q,
        filterQuery: filterQuery,
        cacheControl: cacheControl);
  }

  ///Search for Services
  ///@param pageable
  ///@param q the search query.
  ///@param filterQuery
  @Get(path: '/simplr-services/search')
  Future<chopper.Response<SimplrServiceSearch>> _simplrServicesSearchGet({
    @Query('pageable') Pageable? pageable,
    @Query('q') String? q,
    @Query('filterQuery') SimplrServiceSearchFilter? filterQuery,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Add an Image to a Service
  ///@param serviceId Service ID.
  Future<chopper.Response<SimplrService>> simplrServicesServiceIdAddImagePost({
    required String? serviceId,
    String? cacheControl,
    required Image? body,
  }) {
    generatedMapping.putIfAbsent(
        SimplrService, () => SimplrService.fromJsonFactory);

    return _simplrServicesServiceIdAddImagePost(
        serviceId: serviceId, cacheControl: cacheControl, body: body);
  }

  ///Add an Image to a Service
  ///@param serviceId Service ID.
  @Post(path: '/simplr-services/{serviceId}/addImage')
  Future<chopper.Response<SimplrService>> _simplrServicesServiceIdAddImagePost({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Image? body,
  });

  ///Update Base Prices within Simplr Service
  ///@param serviceId Service ID.
  Future<chopper.Response<ServiceOptions>>
      simplrServicesUpdateBasePricesServiceIdPut({
    required String? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ServiceOption, () => ServiceOption.fromJsonFactory);

    return _simplrServicesUpdateBasePricesServiceIdPut(
        serviceId: serviceId, cacheControl: cacheControl);
  }

  ///Update Base Prices within Simplr Service
  ///@param serviceId Service ID.
  @Put(
    path: '/simplr-services/update-base-prices/{serviceId}',
    optionalBody: true,
  )
  Future<chopper.Response<ServiceOptions>>
      _simplrServicesUpdateBasePricesServiceIdPut({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the jobs
  ///@param embed Allows to return lists of job sub resources that are not returned by default.
  ///@param pageable
  ///@param q
  Future<chopper.Response<Jobs>> jobsGet({
    List<enums.JobsEmbed>? embed,
    Pageable? pageable,
    JobCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        JobCriteria, () => JobCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(Jobs, () => Jobs.fromJsonFactory);

    return _jobsGet(
        embed: jobsEmbedListToJson(embed),
        pageable: pageable,
        q: q,
        cacheControl: cacheControl);
  }

  ///List all the jobs
  ///@param embed Allows to return lists of job sub resources that are not returned by default.
  ///@param pageable
  ///@param q
  @Get(path: '/jobs')
  Future<chopper.Response<Jobs>> _jobsGet({
    @Query('embed') List<String?>? embed,
    @Query('pageable') Pageable? pageable,
    @Query('q') JobCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Job
  Future<chopper.Response<Job>> jobsPost({
    String? cacheControl,
    required Job? body,
  }) {
    generatedMapping.putIfAbsent(Job, () => Job.fromJsonFactory);

    return _jobsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Job
  @Post(path: '/jobs')
  Future<chopper.Response<Job>> _jobsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Job? body,
  });

  ///List all the SimplrServiceRequest
  ///@param serviceId Service ID.
  Future<chopper.Response<SimplrServiceRequests>>
      simplrServicesServiceIdRequestsGet({
    required String? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimplrServiceRequest, () => SimplrServiceRequest.fromJsonFactory);

    return _simplrServicesServiceIdRequestsGet(
        serviceId: serviceId, cacheControl: cacheControl);
  }

  ///List all the SimplrServiceRequest
  ///@param serviceId Service ID.
  @Get(path: '/simplr-services/{serviceId}/requests')
  Future<chopper.Response<SimplrServiceRequests>>
      _simplrServicesServiceIdRequestsGet({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a service request
  ///@param serviceId Service ID.
  Future<chopper.Response<SimplrServiceRequest>>
      simplrServicesServiceIdRequestsPost({
    required String? serviceId,
    String? cacheControl,
    required SimplrServiceRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        SimplrServiceRequest, () => SimplrServiceRequest.fromJsonFactory);

    return _simplrServicesServiceIdRequestsPost(
        serviceId: serviceId, cacheControl: cacheControl, body: body);
  }

  ///Creates a service request
  ///@param serviceId Service ID.
  @Post(path: '/simplr-services/{serviceId}/requests')
  Future<chopper.Response<SimplrServiceRequest>>
      _simplrServicesServiceIdRequestsPost({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SimplrServiceRequest? body,
  });

  ///Info for a specific SimplrServiceRequest
  ///@param serviceId Service ID.
  ///@param serviceRequestId Service Request ID.
  Future<chopper.Response<SimplrServiceRequest>>
      simplrServicesServiceIdRequestsServiceRequestIdGet({
    required String? serviceId,
    required String? serviceRequestId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SimplrServiceRequest, () => SimplrServiceRequest.fromJsonFactory);

    return _simplrServicesServiceIdRequestsServiceRequestIdGet(
        serviceId: serviceId,
        serviceRequestId: serviceRequestId,
        cacheControl: cacheControl);
  }

  ///Info for a specific SimplrServiceRequest
  ///@param serviceId Service ID.
  ///@param serviceRequestId Service Request ID.
  @Get(path: '/simplr-services/{serviceId}/requests/{serviceRequestId}')
  Future<chopper.Response<SimplrServiceRequest>>
      _simplrServicesServiceIdRequestsServiceRequestIdGet({
    @Path('serviceId') required String? serviceId,
    @Path('serviceRequestId') required String? serviceRequestId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a SimplrServiceRequest
  ///@param serviceId Service ID.
  ///@param serviceRequestId Service Request ID.
  Future<chopper.Response<SimplrServiceRequest>>
      simplrServicesServiceIdRequestsServiceRequestIdPut({
    required String? serviceId,
    required String? serviceRequestId,
    String? cacheControl,
    required SimplrServiceRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        SimplrServiceRequest, () => SimplrServiceRequest.fromJsonFactory);

    return _simplrServicesServiceIdRequestsServiceRequestIdPut(
        serviceId: serviceId,
        serviceRequestId: serviceRequestId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update a SimplrServiceRequest
  ///@param serviceId Service ID.
  ///@param serviceRequestId Service Request ID.
  @Put(path: '/simplr-services/{serviceId}/requests/{serviceRequestId}')
  Future<chopper.Response<SimplrServiceRequest>>
      _simplrServicesServiceIdRequestsServiceRequestIdPut({
    @Path('serviceId') required String? serviceId,
    @Path('serviceRequestId') required String? serviceRequestId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SimplrServiceRequest? body,
  });

  ///Deletes a SimplrServiceRequest
  ///@param serviceId Service ID.
  ///@param serviceRequestId Service Request ID.
  Future<chopper.Response>
      simplrServicesServiceIdRequestsServiceRequestIdDelete({
    required String? serviceId,
    required String? serviceRequestId,
    String? cacheControl,
  }) {
    return _simplrServicesServiceIdRequestsServiceRequestIdDelete(
        serviceId: serviceId,
        serviceRequestId: serviceRequestId,
        cacheControl: cacheControl);
  }

  ///Deletes a SimplrServiceRequest
  ///@param serviceId Service ID.
  ///@param serviceRequestId Service Request ID.
  @Delete(path: '/simplr-services/{serviceId}/requests/{serviceRequestId}')
  Future<chopper.Response>
      _simplrServicesServiceIdRequestsServiceRequestIdDelete({
    @Path('serviceId') required String? serviceId,
    @Path('serviceRequestId') required String? serviceRequestId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set this service option as the default one for this service
  ///@param serviceId Service ID.
  ///@param optionId The service option id to get the bounding area.
  Future<chopper.Response> simplrServicesServiceIdOptionsOptionIdDefaultPut({
    required String? serviceId,
    required num? optionId,
    String? cacheControl,
  }) {
    return _simplrServicesServiceIdOptionsOptionIdDefaultPut(
        serviceId: serviceId, optionId: optionId, cacheControl: cacheControl);
  }

  ///Set this service option as the default one for this service
  ///@param serviceId Service ID.
  ///@param optionId The service option id to get the bounding area.
  @Put(
    path: '/simplr-services/{serviceId}/options/{optionId}/default',
    optionalBody: true,
  )
  Future<chopper.Response> _simplrServicesServiceIdOptionsOptionIdDefaultPut({
    @Path('serviceId') required String? serviceId,
    @Path('optionId') required num? optionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Removes a ServiceOption from being the Service's default option
  ///@param serviceId Service ID.
  ///@param optionId The service option id to get the bounding area.
  Future<chopper.Response> simplrServicesServiceIdOptionsOptionIdDefaultDelete({
    required String? serviceId,
    required num? optionId,
    String? cacheControl,
  }) {
    return _simplrServicesServiceIdOptionsOptionIdDefaultDelete(
        serviceId: serviceId, optionId: optionId, cacheControl: cacheControl);
  }

  ///Removes a ServiceOption from being the Service's default option
  ///@param serviceId Service ID.
  ///@param optionId The service option id to get the bounding area.
  @Delete(path: '/simplr-services/{serviceId}/options/{optionId}/default')
  Future<chopper.Response>
      _simplrServicesServiceIdOptionsOptionIdDefaultDelete({
    @Path('serviceId') required String? serviceId,
    @Path('optionId') required num? optionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get a Job
  ///@param jobId Job ID.
  ///@param embed Allows to return lists of job sub resources that are not returned by default.
  Future<chopper.Response<Job>> jobsJobIdGet({
    required String? jobId,
    List<enums.JobsEmbed>? embed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Job, () => Job.fromJsonFactory);

    return _jobsJobIdGet(
        jobId: jobId,
        embed: jobsEmbedListToJson(embed),
        cacheControl: cacheControl);
  }

  ///Get a Job
  ///@param jobId Job ID.
  ///@param embed Allows to return lists of job sub resources that are not returned by default.
  @Get(path: '/jobs/{jobId}')
  Future<chopper.Response<Job>> _jobsJobIdGet({
    @Path('jobId') required String? jobId,
    @Query('embed') List<String?>? embed,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Job
  ///@param jobId Job ID.
  Future<chopper.Response<Job>> jobsJobIdPut({
    required String? jobId,
    String? cacheControl,
    required Job? body,
  }) {
    generatedMapping.putIfAbsent(Job, () => Job.fromJsonFactory);

    return _jobsJobIdPut(jobId: jobId, cacheControl: cacheControl, body: body);
  }

  ///Update a Job
  ///@param jobId Job ID.
  @Put(path: '/jobs/{jobId}')
  Future<chopper.Response<Job>> _jobsJobIdPut({
    @Path('jobId') required String? jobId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Job? body,
  });

  ///Deletes a Job
  ///@param jobId Job ID.
  Future<chopper.Response> jobsJobIdDelete({
    required String? jobId,
    String? cacheControl,
  }) {
    return _jobsJobIdDelete(jobId: jobId, cacheControl: cacheControl);
  }

  ///Deletes a Job
  ///@param jobId Job ID.
  @Delete(path: '/jobs/{jobId}')
  Future<chopper.Response> _jobsJobIdDelete({
    @Path('jobId') required String? jobId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the tasks
  ///@param pageable
  Future<chopper.Response<Tasks>> tasksGet({
    Pageable? pageable,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(Tasks, () => Tasks.fromJsonFactory);

    return _tasksGet(pageable: pageable, cacheControl: cacheControl);
  }

  ///List all the tasks
  ///@param pageable
  @Get(path: '/tasks')
  Future<chopper.Response<Tasks>> _tasksGet({
    @Query('pageable') Pageable? pageable,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Task
  Future<chopper.Response<Task>> tasksPost({
    String? cacheControl,
    required Task? body,
  }) {
    generatedMapping.putIfAbsent(Task, () => Task.fromJsonFactory);

    return _tasksPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Task
  @Post(path: '/tasks')
  Future<chopper.Response<Task>> _tasksPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Task? body,
  });

  ///Gets a Task
  ///@param taskId Task ID.
  Future<chopper.Response<Task>> tasksTaskIdGet({
    required String? taskId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Task, () => Task.fromJsonFactory);

    return _tasksTaskIdGet(taskId: taskId, cacheControl: cacheControl);
  }

  ///Gets a Task
  ///@param taskId Task ID.
  @Get(path: '/tasks/{taskId}')
  Future<chopper.Response<Task>> _tasksTaskIdGet({
    @Path('taskId') required String? taskId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Task
  ///@param taskId Task ID.
  Future<chopper.Response<Task>> tasksTaskIdPut({
    required String? taskId,
    String? cacheControl,
    required Task? body,
  }) {
    generatedMapping.putIfAbsent(Task, () => Task.fromJsonFactory);

    return _tasksTaskIdPut(
        taskId: taskId, cacheControl: cacheControl, body: body);
  }

  ///Update a Task
  ///@param taskId Task ID.
  @Put(path: '/tasks/{taskId}')
  Future<chopper.Response<Task>> _tasksTaskIdPut({
    @Path('taskId') required String? taskId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Task? body,
  });

  ///Deletes a Task
  ///@param taskId Task ID.
  Future<chopper.Response> tasksTaskIdDelete({
    required String? taskId,
    String? cacheControl,
  }) {
    return _tasksTaskIdDelete(taskId: taskId, cacheControl: cacheControl);
  }

  ///Deletes a Task
  ///@param taskId Task ID.
  @Delete(path: '/tasks/{taskId}')
  Future<chopper.Response> _tasksTaskIdDelete({
    @Path('taskId') required String? taskId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the partners
  ///@param pageable
  ///@param q
  Future<chopper.Response<Partners>> partnersGet({
    Pageable? pageable,
    PartnerCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        PartnerCriteria, () => PartnerCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(Partners, () => Partners.fromJsonFactory);

    return _partnersGet(pageable: pageable, q: q, cacheControl: cacheControl);
  }

  ///List all the partners
  ///@param pageable
  ///@param q
  @Get(path: '/partners')
  Future<chopper.Response<Partners>> _partnersGet({
    @Query('pageable') Pageable? pageable,
    @Query('q') PartnerCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Partner
  Future<chopper.Response<Partner>> partnersPost({
    String? cacheControl,
    required Partner? body,
  }) {
    generatedMapping.putIfAbsent(Partner, () => Partner.fromJsonFactory);

    return _partnersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Partner
  @Post(path: '/partners')
  Future<chopper.Response<Partner>> _partnersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Partner? body,
  });

  ///Info for a specific Partner
  ///@param partnerId Partner ID.
  Future<chopper.Response<Partner>> partnersPartnerIdGet({
    required String? partnerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Partner, () => Partner.fromJsonFactory);

    return _partnersPartnerIdGet(
        partnerId: partnerId, cacheControl: cacheControl);
  }

  ///Info for a specific Partner
  ///@param partnerId Partner ID.
  @Get(path: '/partners/{partnerId}')
  Future<chopper.Response<Partner>> _partnersPartnerIdGet({
    @Path('partnerId') required String? partnerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Partner
  ///@param partnerId Partner ID.
  Future<chopper.Response<Partner>> partnersPartnerIdPut({
    required String? partnerId,
    String? cacheControl,
    required Partner? body,
  }) {
    generatedMapping.putIfAbsent(Partner, () => Partner.fromJsonFactory);

    return _partnersPartnerIdPut(
        partnerId: partnerId, cacheControl: cacheControl, body: body);
  }

  ///Update a Partner
  ///@param partnerId Partner ID.
  @Put(path: '/partners/{partnerId}')
  Future<chopper.Response<Partner>> _partnersPartnerIdPut({
    @Path('partnerId') required String? partnerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Partner? body,
  });

  ///Deletes a Partner
  ///@param partnerId Partner ID.
  Future<chopper.Response> partnersPartnerIdDelete({
    required String? partnerId,
    String? cacheControl,
  }) {
    return _partnersPartnerIdDelete(
        partnerId: partnerId, cacheControl: cacheControl);
  }

  ///Deletes a Partner
  ///@param partnerId Partner ID.
  @Delete(path: '/partners/{partnerId}')
  Future<chopper.Response> _partnersPartnerIdDelete({
    @Path('partnerId') required String? partnerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create a payment intent
  Future<chopper.Response<PaymentIntent>> paymentsIntentsPost({
    String? cacheControl,
    required PaymentIntent? body,
  }) {
    generatedMapping.putIfAbsent(
        PaymentIntent, () => PaymentIntent.fromJsonFactory);

    return _paymentsIntentsPost(cacheControl: cacheControl, body: body);
  }

  ///Create a payment intent
  @Post(path: '/payments/intents')
  Future<chopper.Response<PaymentIntent>> _paymentsIntentsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PaymentIntent? body,
  });

  ///Create a setup intent
  Future<chopper.Response<SetupIntent>> paymentsSetupIntentsPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        SetupIntent, () => SetupIntent.fromJsonFactory);

    return _paymentsSetupIntentsPost(cacheControl: cacheControl);
  }

  ///Create a setup intent
  @Post(
    path: '/payments/setup-intents',
    optionalBody: true,
  )
  Future<chopper.Response<SetupIntent>> _paymentsSetupIntentsPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Adds a payment method for the user
  Future<chopper.Response<PaymentMethod>> paymentsMethodsPost({
    String? cacheControl,
    required PaymentMethod? body,
  }) {
    generatedMapping.putIfAbsent(
        PaymentMethod, () => PaymentMethod.fromJsonFactory);

    return _paymentsMethodsPost(cacheControl: cacheControl, body: body);
  }

  ///Adds a payment method for the user
  @Post(path: '/payments/methods')
  Future<chopper.Response<PaymentMethod>> _paymentsMethodsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PaymentMethod? body,
  });

  ///List all the payment methods
  Future<chopper.Response<List<PaymentMethod>>> paymentsMethodsGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        PaymentMethod, () => PaymentMethod.fromJsonFactory);

    return _paymentsMethodsGet(cacheControl: cacheControl);
  }

  ///List all the payment methods
  @Get(path: '/payments/methods')
  Future<chopper.Response<List<PaymentMethod>>> _paymentsMethodsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Get the default payment methods for the user
  Future<chopper.Response<PaymentMethod>> paymentsMethodsDefaultGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        PaymentMethod, () => PaymentMethod.fromJsonFactory);

    return _paymentsMethodsDefaultGet(cacheControl: cacheControl);
  }

  ///Get the default payment methods for the user
  @Get(path: '/payments/methods/default')
  Future<chopper.Response<PaymentMethod>> _paymentsMethodsDefaultGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Set the default payment methods for the user
  Future<chopper.Response<PaymentMethod>> paymentsMethodsDefaultPut({
    String? cacheControl,
    required PaymentMethod? body,
  }) {
    generatedMapping.putIfAbsent(
        PaymentMethod, () => PaymentMethod.fromJsonFactory);

    return _paymentsMethodsDefaultPut(cacheControl: cacheControl, body: body);
  }

  ///Set the default payment methods for the user
  @Put(path: '/payments/methods/default')
  Future<chopper.Response<PaymentMethod>> _paymentsMethodsDefaultPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PaymentMethod? body,
  });

  ///remove the default payment methods for the user
  Future<chopper.Response> paymentsMethodsDefaultDelete(
      {String? cacheControl}) {
    return _paymentsMethodsDefaultDelete(cacheControl: cacheControl);
  }

  ///remove the default payment methods for the user
  @Delete(path: '/payments/methods/default')
  Future<chopper.Response> _paymentsMethodsDefaultDelete(
      {@Header('Cache-Control') String? cacheControl});

  ///List all the partner apps
  ///@param partnerId Partner ID.
  Future<chopper.Response<PartnerApps>> partnersPartnerIdAppsGet({
    required String? partnerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PartnerApp, () => PartnerApp.fromJsonFactory);

    return _partnersPartnerIdAppsGet(
        partnerId: partnerId, cacheControl: cacheControl);
  }

  ///List all the partner apps
  ///@param partnerId Partner ID.
  @Get(path: '/partners/{partnerId}/apps')
  Future<chopper.Response<PartnerApps>> _partnersPartnerIdAppsGet({
    @Path('partnerId') required String? partnerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Partner app
  ///@param partnerId Partner ID.
  Future<chopper.Response<PartnerApp>> partnersPartnerIdAppsPost({
    required String? partnerId,
    String? cacheControl,
    required PartnerApp? body,
  }) {
    generatedMapping.putIfAbsent(PartnerApp, () => PartnerApp.fromJsonFactory);

    return _partnersPartnerIdAppsPost(
        partnerId: partnerId, cacheControl: cacheControl, body: body);
  }

  ///Creates a Partner app
  ///@param partnerId Partner ID.
  @Post(path: '/partners/{partnerId}/apps')
  Future<chopper.Response<PartnerApp>> _partnersPartnerIdAppsPost({
    @Path('partnerId') required String? partnerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PartnerApp? body,
  });

  ///Info for a specific Partner App
  ///@param partnerId Partner ID.
  ///@param partnerAppId Partner App ID.
  Future<chopper.Response<PartnerApp>> partnersPartnerIdAppsPartnerAppIdGet({
    required String? partnerId,
    required String? partnerAppId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(PartnerApp, () => PartnerApp.fromJsonFactory);

    return _partnersPartnerIdAppsPartnerAppIdGet(
        partnerId: partnerId,
        partnerAppId: partnerAppId,
        cacheControl: cacheControl);
  }

  ///Info for a specific Partner App
  ///@param partnerId Partner ID.
  ///@param partnerAppId Partner App ID.
  @Get(path: '/partners/{partnerId}/apps/{partnerAppId}')
  Future<chopper.Response<PartnerApp>> _partnersPartnerIdAppsPartnerAppIdGet({
    @Path('partnerId') required String? partnerId,
    @Path('partnerAppId') required String? partnerAppId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Partner app
  ///@param partnerId Partner ID.
  ///@param partnerAppId Partner App ID.
  Future<chopper.Response<PartnerApp>> partnersPartnerIdAppsPartnerAppIdPut({
    required String? partnerId,
    required String? partnerAppId,
    String? cacheControl,
    required PartnerApp? body,
  }) {
    generatedMapping.putIfAbsent(PartnerApp, () => PartnerApp.fromJsonFactory);

    return _partnersPartnerIdAppsPartnerAppIdPut(
        partnerId: partnerId,
        partnerAppId: partnerAppId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update a Partner app
  ///@param partnerId Partner ID.
  ///@param partnerAppId Partner App ID.
  @Put(path: '/partners/{partnerId}/apps/{partnerAppId}')
  Future<chopper.Response<PartnerApp>> _partnersPartnerIdAppsPartnerAppIdPut({
    @Path('partnerId') required String? partnerId,
    @Path('partnerAppId') required String? partnerAppId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PartnerApp? body,
  });

  ///Deletes a Partner app
  ///@param partnerId Partner ID.
  ///@param partnerAppId Partner App ID.
  Future<chopper.Response> partnersPartnerIdAppsPartnerAppIdDelete({
    required String? partnerId,
    required String? partnerAppId,
    String? cacheControl,
  }) {
    return _partnersPartnerIdAppsPartnerAppIdDelete(
        partnerId: partnerId,
        partnerAppId: partnerAppId,
        cacheControl: cacheControl);
  }

  ///Deletes a Partner app
  ///@param partnerId Partner ID.
  ///@param partnerAppId Partner App ID.
  @Delete(path: '/partners/{partnerId}/apps/{partnerAppId}')
  Future<chopper.Response> _partnersPartnerIdAppsPartnerAppIdDelete({
    @Path('partnerId') required String? partnerId,
    @Path('partnerAppId') required String? partnerAppId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the partner app types
  Future<chopper.Response<PartnerAppTypes>> partnerAppTypesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        PartnerAppType, () => PartnerAppType.fromJsonFactory);

    return _partnerAppTypesGet(cacheControl: cacheControl);
  }

  ///List all the partner app types
  @Get(path: '/partner-app-types')
  Future<chopper.Response<PartnerAppTypes>> _partnerAppTypesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a Partner app type
  Future<chopper.Response<PartnerAppType>> partnerAppTypesPost({
    String? cacheControl,
    required PartnerAppType? body,
  }) {
    generatedMapping.putIfAbsent(
        PartnerAppType, () => PartnerAppType.fromJsonFactory);

    return _partnerAppTypesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Partner app type
  @Post(path: '/partner-app-types')
  Future<chopper.Response<PartnerAppType>> _partnerAppTypesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PartnerAppType? body,
  });

  ///Info for a specific Partner App type
  ///@param partnerAppTypeId Partner App Type ID.
  Future<chopper.Response<PartnerAppType>> partnerAppTypesPartnerAppTypeIdGet({
    required String? partnerAppTypeId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PartnerAppType, () => PartnerAppType.fromJsonFactory);

    return _partnerAppTypesPartnerAppTypeIdGet(
        partnerAppTypeId: partnerAppTypeId, cacheControl: cacheControl);
  }

  ///Info for a specific Partner App type
  ///@param partnerAppTypeId Partner App Type ID.
  @Get(path: '/partner-app-types/{partnerAppTypeId}')
  Future<chopper.Response<PartnerAppType>> _partnerAppTypesPartnerAppTypeIdGet({
    @Path('partnerAppTypeId') required String? partnerAppTypeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Partner app type
  ///@param partnerAppTypeId Partner App Type ID.
  Future<chopper.Response<PartnerAppType>> partnerAppTypesPartnerAppTypeIdPut({
    required String? partnerAppTypeId,
    String? cacheControl,
    required PartnerAppType? body,
  }) {
    generatedMapping.putIfAbsent(
        PartnerAppType, () => PartnerAppType.fromJsonFactory);

    return _partnerAppTypesPartnerAppTypeIdPut(
        partnerAppTypeId: partnerAppTypeId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update a Partner app type
  ///@param partnerAppTypeId Partner App Type ID.
  @Put(path: '/partner-app-types/{partnerAppTypeId}')
  Future<chopper.Response<PartnerAppType>> _partnerAppTypesPartnerAppTypeIdPut({
    @Path('partnerAppTypeId') required String? partnerAppTypeId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PartnerAppType? body,
  });

  ///Deletes a Partner app type
  ///@param partnerAppTypeId Partner App Type ID.
  Future<chopper.Response> partnerAppTypesPartnerAppTypeIdDelete({
    required String? partnerAppTypeId,
    String? cacheControl,
  }) {
    return _partnerAppTypesPartnerAppTypeIdDelete(
        partnerAppTypeId: partnerAppTypeId, cacheControl: cacheControl);
  }

  ///Deletes a Partner app type
  ///@param partnerAppTypeId Partner App Type ID.
  @Delete(path: '/partner-app-types/{partnerAppTypeId}')
  Future<chopper.Response> _partnerAppTypesPartnerAppTypeIdDelete({
    @Path('partnerAppTypeId') required String? partnerAppTypeId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the Orders
  ///@param embed Allows to return orders sub resources that are not returned by default.
  ///@param pageable
  ///@param q
  Future<chopper.Response<Orders>> ordersGet({
    List<enums.OrdersEmbed>? embed,
    Pageable? pageable,
    OrderCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        OrderCriteria, () => OrderCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(Orders, () => Orders.fromJsonFactory);

    return _ordersGet(
        embed: ordersEmbedListToJson(embed),
        pageable: pageable,
        q: q,
        cacheControl: cacheControl);
  }

  ///List all the Orders
  ///@param embed Allows to return orders sub resources that are not returned by default.
  ///@param pageable
  ///@param q
  @Get(path: '/orders')
  Future<chopper.Response<Orders>> _ordersGet({
    @Query('embed') List<String?>? embed,
    @Query('pageable') Pageable? pageable,
    @Query('q') OrderCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates an Order
  Future<chopper.Response<Order>> ordersPost({
    String? cacheControl,
    required Order? body,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates an Order
  @Post(path: '/orders')
  Future<chopper.Response<Order>> _ordersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Order? body,
  });

  ///Order detail
  ///@param orderId Order ID.
  ///@param embed Allows to return orders sub resources that are not returned by default.
  Future<chopper.Response<Order>> ordersOrderIdGet({
    required String? orderId,
    List<enums.OrdersEmbed>? embed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersOrderIdGet(
        orderId: orderId,
        embed: ordersEmbedListToJson(embed),
        cacheControl: cacheControl);
  }

  ///Order detail
  ///@param orderId Order ID.
  ///@param embed Allows to return orders sub resources that are not returned by default.
  @Get(path: '/orders/{orderId}')
  Future<chopper.Response<Order>> _ordersOrderIdGet({
    @Path('orderId') required String? orderId,
    @Query('embed') List<String?>? embed,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates an Order
  ///@param orderId Order ID.
  Future<chopper.Response<Order>> ordersOrderIdPut({
    required String? orderId,
    String? cacheControl,
    required Order? body,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersOrderIdPut(
        orderId: orderId, cacheControl: cacheControl, body: body);
  }

  ///Updates an Order
  ///@param orderId Order ID.
  @Put(path: '/orders/{orderId}')
  Future<chopper.Response<Order>> _ordersOrderIdPut({
    @Path('orderId') required String? orderId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Order? body,
  });

  ///Deletes an Order
  ///@param orderId Order ID.
  Future<chopper.Response> ordersOrderIdDelete({
    required String? orderId,
    String? cacheControl,
  }) {
    return _ordersOrderIdDelete(orderId: orderId, cacheControl: cacheControl);
  }

  ///Deletes an Order
  ///@param orderId Order ID.
  @Delete(path: '/orders/{orderId}')
  Future<chopper.Response> _ordersOrderIdDelete({
    @Path('orderId') required String? orderId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Order readonly detail
  ///@param orderId Order ID.
  ///@param embed Allows to return orders sub resources that are not returned by default.
  Future<chopper.Response<Order>> ordersOrderIdDetailGet({
    required String? orderId,
    List<enums.OrdersEmbed>? embed,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersOrderIdDetailGet(
        orderId: orderId,
        embed: ordersEmbedListToJson(embed),
        cacheControl: cacheControl);
  }

  ///Order readonly detail
  ///@param orderId Order ID.
  ///@param embed Allows to return orders sub resources that are not returned by default.
  @Get(path: '/orders/{orderId}/detail')
  Future<chopper.Response<Order>> _ordersOrderIdDetailGet({
    @Path('orderId') required String? orderId,
    @Query('embed') List<String?>? embed,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Confirms an Order
  ///@param orderId Order ID.
  ///@param confirmPayment Boolean to confirm the payment intent from the backend
  Future<chopper.Response<Order>> ordersOrderIdConfirmPut({
    required String? orderId,
    bool? confirmPayment,
    String? cacheControl,
    required OrderConfirmation? body,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersOrderIdConfirmPut(
        orderId: orderId,
        confirmPayment: confirmPayment,
        cacheControl: cacheControl,
        body: body);
  }

  ///Confirms an Order
  ///@param orderId Order ID.
  ///@param confirmPayment Boolean to confirm the payment intent from the backend
  @Put(path: '/orders/{orderId}/confirm')
  Future<chopper.Response<Order>> _ordersOrderIdConfirmPut({
    @Path('orderId') required String? orderId,
    @Query('confirmPayment') bool? confirmPayment,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OrderConfirmation? body,
  });

  ///Applies a promotion code to this order
  ///@param orderId Order ID.
  Future<chopper.Response<Order>> ordersOrderIdPromotionPut({
    required String? orderId,
    String? cacheControl,
    required PromotionCode? body,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersOrderIdPromotionPut(
        orderId: orderId, cacheControl: cacheControl, body: body);
  }

  ///Applies a promotion code to this order
  ///@param orderId Order ID.
  @Put(path: '/orders/{orderId}/promotion')
  Future<chopper.Response<Order>> _ordersOrderIdPromotionPut({
    @Path('orderId') required String? orderId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PromotionCode? body,
  });

  ///Removes a promotion discount from this order
  ///@param orderId Order ID.
  Future<chopper.Response<Order>> ordersOrderIdPromotionDelete({
    required String? orderId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Order, () => Order.fromJsonFactory);

    return _ordersOrderIdPromotionDelete(
        orderId: orderId, cacheControl: cacheControl);
  }

  ///Removes a promotion discount from this order
  ///@param orderId Order ID.
  @Delete(path: '/orders/{orderId}/promotion')
  Future<chopper.Response<Order>> _ordersOrderIdPromotionDelete({
    @Path('orderId') required String? orderId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Contact
  Future<chopper.Response<Contact>> contactsPost({
    String? cacheControl,
    required Contact? body,
  }) {
    generatedMapping.putIfAbsent(Contact, () => Contact.fromJsonFactory);

    return _contactsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Contact
  @Post(path: '/contacts')
  Future<chopper.Response<Contact>> _contactsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Contact? body,
  });

  ///Deletes a Contact
  ///@param contactId Contact ID.
  Future<chopper.Response> contactsContactIdDelete({
    required String? contactId,
    String? cacheControl,
  }) {
    return _contactsContactIdDelete(
        contactId: contactId, cacheControl: cacheControl);
  }

  ///Deletes a Contact
  ///@param contactId Contact ID.
  @Delete(path: '/contacts/{contactId}')
  Future<chopper.Response> _contactsContactIdDelete({
    @Path('contactId') required String? contactId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Suggestion
  Future<chopper.Response<Suggestion>> suggestionsPost({
    String? cacheControl,
    required Suggestion? body,
  }) {
    generatedMapping.putIfAbsent(Suggestion, () => Suggestion.fromJsonFactory);

    return _suggestionsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Suggestion
  @Post(path: '/suggestions')
  Future<chopper.Response<Suggestion>> _suggestionsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Suggestion? body,
  });

  ///List all the suggestions
  ///@param pageable
  Future<chopper.Response<Suggestions>> suggestionsGet({
    Pageable? pageable,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        Suggestions, () => Suggestions.fromJsonFactory);

    return _suggestionsGet(pageable: pageable, cacheControl: cacheControl);
  }

  ///List all the suggestions
  ///@param pageable
  @Get(path: '/suggestions')
  Future<chopper.Response<Suggestions>> _suggestionsGet({
    @Query('pageable') Pageable? pageable,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the subscriptions
  ///@param q
  ///@param pageable
  Future<chopper.Response<Subscriptions>> subscriptionsGet({
    SubscriptionCriteria? q,
    Pageable? pageable,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SubscriptionCriteria, () => SubscriptionCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        Subscriptions, () => Subscriptions.fromJsonFactory);

    return _subscriptionsGet(
        q: q, pageable: pageable, cacheControl: cacheControl);
  }

  ///List all the subscriptions
  ///@param q
  ///@param pageable
  @Get(path: '/subscriptions')
  Future<chopper.Response<Subscriptions>> _subscriptionsGet({
    @Query('q') SubscriptionCriteria? q,
    @Query('pageable') Pageable? pageable,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Subscription
  Future<chopper.Response<Subscription>> subscriptionsPost({
    String? cacheControl,
    required SubscriptionCreateBody? body,
  }) {
    generatedMapping.putIfAbsent(
        Subscription, () => Subscription.fromJsonFactory);

    return _subscriptionsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Subscription
  @Post(path: '/subscriptions')
  Future<chopper.Response<Subscription>> _subscriptionsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SubscriptionCreateBody? body,
  });

  ///Info for a specific subscription
  ///@param subscriptionId Subscription ID.
  Future<chopper.Response<Subscription>> subscriptionsSubscriptionIdGet({
    required String? subscriptionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        Subscription, () => Subscription.fromJsonFactory);

    return _subscriptionsSubscriptionIdGet(
        subscriptionId: subscriptionId, cacheControl: cacheControl);
  }

  ///Info for a specific subscription
  ///@param subscriptionId Subscription ID.
  @Get(path: '/subscriptions/{subscriptionId}')
  Future<chopper.Response<Subscription>> _subscriptionsSubscriptionIdGet({
    @Path('subscriptionId') required String? subscriptionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates a Subscription
  ///@param subscriptionId Subscription ID.
  Future<chopper.Response<Subscription>> subscriptionsSubscriptionIdPut({
    required String? subscriptionId,
    String? cacheControl,
    required SubscriptionRequestBody? body,
  }) {
    generatedMapping.putIfAbsent(
        Subscription, () => Subscription.fromJsonFactory);

    return _subscriptionsSubscriptionIdPut(
        subscriptionId: subscriptionId, cacheControl: cacheControl, body: body);
  }

  ///Updates a Subscription
  ///@param subscriptionId Subscription ID.
  @Put(path: '/subscriptions/{subscriptionId}')
  Future<chopper.Response<Subscription>> _subscriptionsSubscriptionIdPut({
    @Path('subscriptionId') required String? subscriptionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SubscriptionRequestBody? body,
  });

  ///Subscription instructions to user
  ///@param subscriptionId Subscription ID.
  Future<chopper.Response<SimplrServiceInstructions>>
      subscriptionsSubscriptionIdInstructionsGet({
    required String? subscriptionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SimplrServiceInstructions,
        () => SimplrServiceInstructions.fromJsonFactory);

    return _subscriptionsSubscriptionIdInstructionsGet(
        subscriptionId: subscriptionId, cacheControl: cacheControl);
  }

  ///Subscription instructions to user
  ///@param subscriptionId Subscription ID.
  @Get(path: '/subscriptions/{subscriptionId}/instructions')
  Future<chopper.Response<SimplrServiceInstructions>>
      _subscriptionsSubscriptionIdInstructionsGet({
    @Path('subscriptionId') required String? subscriptionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Updates a Subscription status
  ///@param subscriptionId Subscription ID.
  Future<chopper.Response<Subscription>> subscriptionsSubscriptionIdStatusPut({
    required String? subscriptionId,
    String? cacheControl,
    required enums.SubscriptionStatus? body,
  }) {
    generatedMapping.putIfAbsent(
        Subscription, () => Subscription.fromJsonFactory);

    return _subscriptionsSubscriptionIdStatusPut(
        subscriptionId: subscriptionId,
        cacheControl: cacheControl,
        body: enums.$SubscriptionStatusMap[body]?.toString());
  }

  ///Updates a Subscription status
  ///@param subscriptionId Subscription ID.
  @Put(path: '/subscriptions/{subscriptionId}/status')
  Future<chopper.Response<Subscription>> _subscriptionsSubscriptionIdStatusPut({
    @Path('subscriptionId') required String? subscriptionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required dynamic body,
  });

  ///Updates a Subscription
  ///@param subscriptionId Subscription ID.
  Future<chopper.Response<Subscription>> subscriptionsSubscriptionIdCancelPut({
    required String? subscriptionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        Subscription, () => Subscription.fromJsonFactory);

    return _subscriptionsSubscriptionIdCancelPut(
        subscriptionId: subscriptionId, cacheControl: cacheControl);
  }

  ///Updates a Subscription
  ///@param subscriptionId Subscription ID.
  @Put(
    path: '/subscriptions/{subscriptionId}/cancel',
    optionalBody: true,
  )
  Future<chopper.Response<Subscription>> _subscriptionsSubscriptionIdCancelPut({
    @Path('subscriptionId') required String? subscriptionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Sets item quantity
  ///@param subscriptionId Subscription ID.
  ///@param quantity item quantity
  Future<chopper.Response<Subscription>>
      subscriptionsSubscriptionIdQuantityQuantityPut({
    required String? subscriptionId,
    required int? quantity,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        Subscription, () => Subscription.fromJsonFactory);

    return _subscriptionsSubscriptionIdQuantityQuantityPut(
        subscriptionId: subscriptionId,
        quantity: quantity,
        cacheControl: cacheControl);
  }

  ///Sets item quantity
  ///@param subscriptionId Subscription ID.
  ///@param quantity item quantity
  @Put(
    path: '/subscriptions/{subscriptionId}/quantity/{quantity}',
    optionalBody: true,
  )
  Future<chopper.Response<Subscription>>
      _subscriptionsSubscriptionIdQuantityQuantityPut({
    @Path('subscriptionId') required String? subscriptionId,
    @Path('quantity') required int? quantity,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the issues
  ///@param pageable
  Future<chopper.Response<Issues>> issuesGet({
    Pageable? pageable,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(Issue, () => Issue.fromJsonFactory);

    return _issuesGet(pageable: pageable, cacheControl: cacheControl);
  }

  ///List all the issues
  ///@param pageable
  @Get(path: '/issues')
  Future<chopper.Response<Issues>> _issuesGet({
    @Query('pageable') Pageable? pageable,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Issue
  Future<chopper.Response<Issue>> issuesPost({
    String? cacheControl,
    required Issue? body,
  }) {
    generatedMapping.putIfAbsent(Issue, () => Issue.fromJsonFactory);

    return _issuesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Issue
  @Post(path: '/issues')
  Future<chopper.Response<Issue>> _issuesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Issue? body,
  });

  ///Get an Issue
  ///@param issueId Issue ID.
  Future<chopper.Response<Issue>> issuesIssueIdGet({
    required String? issueId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Issue, () => Issue.fromJsonFactory);

    return _issuesIssueIdGet(issueId: issueId, cacheControl: cacheControl);
  }

  ///Get an Issue
  ///@param issueId Issue ID.
  @Get(path: '/issues/{issueId}')
  Future<chopper.Response<Issue>> _issuesIssueIdGet({
    @Path('issueId') required String? issueId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Issue
  ///@param issueId Issue ID.
  Future<chopper.Response<Issue>> issuesIssueIdPut({
    required String? issueId,
    String? cacheControl,
    required Issue? body,
  }) {
    generatedMapping.putIfAbsent(Issue, () => Issue.fromJsonFactory);

    return _issuesIssueIdPut(
        issueId: issueId, cacheControl: cacheControl, body: body);
  }

  ///Update a Issue
  ///@param issueId Issue ID.
  @Put(path: '/issues/{issueId}')
  Future<chopper.Response<Issue>> _issuesIssueIdPut({
    @Path('issueId') required String? issueId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Issue? body,
  });

  ///Deletes a Issue
  ///@param issueId Issue ID.
  Future<chopper.Response> issuesIssueIdDelete({
    required String? issueId,
    String? cacheControl,
  }) {
    return _issuesIssueIdDelete(issueId: issueId, cacheControl: cacheControl);
  }

  ///Deletes a Issue
  ///@param issueId Issue ID.
  @Delete(path: '/issues/{issueId}')
  Future<chopper.Response> _issuesIssueIdDelete({
    @Path('issueId') required String? issueId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the validation requests
  Future<chopper.Response<ValidationRequests>> validationRequestGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ValidationRequest, () => ValidationRequest.fromJsonFactory);

    return _validationRequestGet(cacheControl: cacheControl);
  }

  ///List all the validation requests
  @Get(path: '/validation-request')
  Future<chopper.Response<ValidationRequests>> _validationRequestGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a Validation request
  Future<chopper.Response<ValidationRequest>> validationRequestPost({
    String? cacheControl,
    required ValidationRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ValidationRequest, () => ValidationRequest.fromJsonFactory);

    return _validationRequestPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Validation request
  @Post(path: '/validation-request')
  Future<chopper.Response<ValidationRequest>> _validationRequestPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ValidationRequest? body,
  });

  ///Info for a specific ValidationRequest
  ///@param validationRequestId The validation request id.
  Future<chopper.Response<ValidationRequest>>
      validationRequestValidationRequestIdGet({
    required String? validationRequestId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ValidationRequest, () => ValidationRequest.fromJsonFactory);

    return _validationRequestValidationRequestIdGet(
        validationRequestId: validationRequestId, cacheControl: cacheControl);
  }

  ///Info for a specific ValidationRequest
  ///@param validationRequestId The validation request id.
  @Get(path: '/validation-request/{validationRequestId}')
  Future<chopper.Response<ValidationRequest>>
      _validationRequestValidationRequestIdGet({
    @Path('validationRequestId') required String? validationRequestId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Validation request
  ///@param validationRequestId The validation request id.
  Future<chopper.Response<ValidationRequest>>
      validationRequestValidationRequestIdPut({
    required String? validationRequestId,
    String? cacheControl,
    required ValidationRequest? body,
  }) {
    generatedMapping.putIfAbsent(
        ValidationRequest, () => ValidationRequest.fromJsonFactory);

    return _validationRequestValidationRequestIdPut(
        validationRequestId: validationRequestId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update a Validation request
  ///@param validationRequestId The validation request id.
  @Put(path: '/validation-request/{validationRequestId}')
  Future<chopper.Response<ValidationRequest>>
      _validationRequestValidationRequestIdPut({
    @Path('validationRequestId') required String? validationRequestId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required ValidationRequest? body,
  });

  ///Deletes a ValidationRequest
  ///@param validationRequestId The validation request id.
  Future<chopper.Response> validationRequestValidationRequestIdDelete({
    required String? validationRequestId,
    String? cacheControl,
  }) {
    return _validationRequestValidationRequestIdDelete(
        validationRequestId: validationRequestId, cacheControl: cacheControl);
  }

  ///Deletes a ValidationRequest
  ///@param validationRequestId The validation request id.
  @Delete(path: '/validation-request/{validationRequestId}')
  Future<chopper.Response> _validationRequestValidationRequestIdDelete({
    @Path('validationRequestId') required String? validationRequestId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Recommend similar services
  Future<chopper.Response<SimplrServices>> recommenderServicesPost({
    String? cacheControl,
    required RecommenderData? body,
  }) {
    generatedMapping.putIfAbsent(
        SimplrService, () => SimplrService.fromJsonFactory);

    return _recommenderServicesPost(cacheControl: cacheControl, body: body);
  }

  ///Recommend similar services
  @Post(path: '/recommender/services/')
  Future<chopper.Response<SimplrServices>> _recommenderServicesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RecommenderData? body,
  });

  ///Pull content
  Future<chopper.Response<String>> contentPromotionPullPost({
    String? cacheControl,
    required ContentPromotionPackageInfo? body,
  }) {
    return _contentPromotionPullPost(cacheControl: cacheControl, body: body);
  }

  ///Pull content
  @Post(path: '/content-promotion/pull')
  Future<chopper.Response<String>> _contentPromotionPullPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ContentPromotionPackageInfo? body,
  });

  ///List all the ContentPromotion pushed packages
  Future<chopper.Response<ContentPromotionPackageInfos>> contentPromotionGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(ContentPromotionPackageInfo,
        () => ContentPromotionPackageInfo.fromJsonFactory);

    return _contentPromotionGet(cacheControl: cacheControl);
  }

  ///List all the ContentPromotion pushed packages
  @Get(path: '/content-promotion/')
  Future<chopper.Response<ContentPromotionPackageInfos>> _contentPromotionGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Push a service package
  ///@param serviceId Service ID.
  Future<chopper.Response<ContentPromotionPackageInfo>>
      contentPromotionPushServiceServiceIdPost({
    required String? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ContentPromotionPackageInfo,
        () => ContentPromotionPackageInfo.fromJsonFactory);

    return _contentPromotionPushServiceServiceIdPost(
        serviceId: serviceId, cacheControl: cacheControl);
  }

  ///Push a service package
  ///@param serviceId Service ID.
  @Post(
    path: '/content-promotion/push/service/{serviceId}',
    optionalBody: true,
  )
  Future<chopper.Response<ContentPromotionPackageInfo>>
      _contentPromotionPushServiceServiceIdPost({
    @Path('serviceId') required String? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Push a job package
  ///@param jobId Job ID.
  Future<chopper.Response<ContentPromotionPackageInfo>>
      contentPromotionPushJobJobIdPost({
    required String? jobId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(ContentPromotionPackageInfo,
        () => ContentPromotionPackageInfo.fromJsonFactory);

    return _contentPromotionPushJobJobIdPost(
        jobId: jobId, cacheControl: cacheControl);
  }

  ///Push a job package
  ///@param jobId Job ID.
  @Post(
    path: '/content-promotion/push/job/{jobId}',
    optionalBody: true,
  )
  Future<chopper.Response<ContentPromotionPackageInfo>>
      _contentPromotionPushJobJobIdPost({
    @Path('jobId') required String? jobId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Installs a content promotion package
  Future<chopper.Response> contentPromotionInstallPost({
    String? cacheControl,
    required ContentPromotionPackageInfo? body,
  }) {
    return _contentPromotionInstallPost(cacheControl: cacheControl, body: body);
  }

  ///Installs a content promotion package
  @Post(path: '/content-promotion/install/')
  Future<chopper.Response> _contentPromotionInstallPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required ContentPromotionPackageInfo? body,
  });

  ///List all UserPartnerData
  Future<chopper.Response<UsersPartnersData>> userPartnerDataGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        UserPartnerData, () => UserPartnerData.fromJsonFactory);

    return _userPartnerDataGet(cacheControl: cacheControl);
  }

  ///List all UserPartnerData
  @Get(path: '/user-partner-data')
  Future<chopper.Response<UsersPartnersData>> _userPartnerDataGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a UserPartnerData
  Future<chopper.Response<UserPartnerData>> userPartnerDataPost({
    String? cacheControl,
    required UserPartnerData? body,
  }) {
    generatedMapping.putIfAbsent(
        UserPartnerData, () => UserPartnerData.fromJsonFactory);

    return _userPartnerDataPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a UserPartnerData
  @Post(path: '/user-partner-data')
  Future<chopper.Response<UserPartnerData>> _userPartnerDataPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserPartnerData? body,
  });

  ///An array of UserPartnerData
  ///@param partnerId Partner ID.
  ///@param userId user ID.
  Future<chopper.Response<UsersPartnersData>>
      userPartnerDataPartnerIdUserIdGet({
    required String? partnerId,
    required String? userId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UserPartnerData, () => UserPartnerData.fromJsonFactory);

    return _userPartnerDataPartnerIdUserIdGet(
        partnerId: partnerId, userId: userId, cacheControl: cacheControl);
  }

  ///An array of UserPartnerData
  ///@param partnerId Partner ID.
  ///@param userId user ID.
  @Get(path: '/user-partner-data/{partnerId}/{userId}')
  Future<chopper.Response<UsersPartnersData>>
      _userPartnerDataPartnerIdUserIdGet({
    @Path('partnerId') required String? partnerId,
    @Path('userId') required String? userId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update UserPartnerData
  ///@param userPartnerDataId The userPartnerData request id.
  Future<chopper.Response<UserPartnerData>>
      userPartnerDataUserPartnerDataIdPut({
    required String? userPartnerDataId,
    String? cacheControl,
    required UserPartnerData? body,
  }) {
    generatedMapping.putIfAbsent(
        UserPartnerData, () => UserPartnerData.fromJsonFactory);

    return _userPartnerDataUserPartnerDataIdPut(
        userPartnerDataId: userPartnerDataId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update UserPartnerData
  ///@param userPartnerDataId The userPartnerData request id.
  @Put(path: '/user-partner-data/{userPartnerDataId}')
  Future<chopper.Response<UserPartnerData>>
      _userPartnerDataUserPartnerDataIdPut({
    @Path('userPartnerDataId') required String? userPartnerDataId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserPartnerData? body,
  });

  ///Delete UserPartnerData
  ///@param userPartnerDataId The userPartnerData request id.
  Future<chopper.Response> userPartnerDataUserPartnerDataIdDelete({
    required String? userPartnerDataId,
    String? cacheControl,
  }) {
    return _userPartnerDataUserPartnerDataIdDelete(
        userPartnerDataId: userPartnerDataId, cacheControl: cacheControl);
  }

  ///Delete UserPartnerData
  ///@param userPartnerDataId The userPartnerData request id.
  @Delete(path: '/user-partner-data/{userPartnerDataId}')
  Future<chopper.Response> _userPartnerDataUserPartnerDataIdDelete({
    @Path('userPartnerDataId') required String? userPartnerDataId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the property managers
  ///@param activeOnly If true, only the active entries are returned.
  Future<chopper.Response<PropertyManagers>> propertyManagersGet({
    bool? activeOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PropertyManager, () => PropertyManager.fromJsonFactory);

    return _propertyManagersGet(
        activeOnly: activeOnly, cacheControl: cacheControl);
  }

  ///List all the property managers
  ///@param activeOnly If true, only the active entries are returned.
  @Get(path: '/property-managers')
  Future<chopper.Response<PropertyManagers>> _propertyManagersGet({
    @Query('activeOnly') bool? activeOnly,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Property Manager
  Future<chopper.Response<PropertyManager>> propertyManagersPost({
    String? cacheControl,
    required PropertyManager? body,
  }) {
    generatedMapping.putIfAbsent(
        PropertyManager, () => PropertyManager.fromJsonFactory);

    return _propertyManagersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Property Manager
  @Post(path: '/property-managers')
  Future<chopper.Response<PropertyManager>> _propertyManagersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PropertyManager? body,
  });

  ///Info for a specific Property Manager
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response<PropertyManager>>
      propertyManagersPropertyManagerIdGet({
    required String? propertyManagerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PropertyManager, () => PropertyManager.fromJsonFactory);

    return _propertyManagersPropertyManagerIdGet(
        propertyManagerId: propertyManagerId, cacheControl: cacheControl);
  }

  ///Info for a specific Property Manager
  ///@param propertyManagerId The property manager id.
  @Get(path: '/property-managers/{propertyManagerId}')
  Future<chopper.Response<PropertyManager>>
      _propertyManagersPropertyManagerIdGet({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Property Manager
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response<PropertyManager>>
      propertyManagersPropertyManagerIdPut({
    required String? propertyManagerId,
    String? cacheControl,
    required PropertyManager? body,
  }) {
    generatedMapping.putIfAbsent(
        PropertyManager, () => PropertyManager.fromJsonFactory);

    return _propertyManagersPropertyManagerIdPut(
        propertyManagerId: propertyManagerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update a Property Manager
  ///@param propertyManagerId The property manager id.
  @Put(path: '/property-managers/{propertyManagerId}')
  Future<chopper.Response<PropertyManager>>
      _propertyManagersPropertyManagerIdPut({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PropertyManager? body,
  });

  ///Deletes a Property Manager
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response> propertyManagersPropertyManagerIdDelete({
    required String? propertyManagerId,
    String? cacheControl,
  }) {
    return _propertyManagersPropertyManagerIdDelete(
        propertyManagerId: propertyManagerId, cacheControl: cacheControl);
  }

  ///Deletes a Property Manager
  ///@param propertyManagerId The property manager id.
  @Delete(path: '/property-managers/{propertyManagerId}')
  Future<chopper.Response> _propertyManagersPropertyManagerIdDelete({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the properties for a property manager
  ///@param propertyManagerId The property manager id.
  ///@param activeOnly If true, only the active entries are returned.
  Future<chopper.Response<Properties>>
      propertyManagersPropertyManagerIdPropertiesGet({
    required String? propertyManagerId,
    bool? activeOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Property, () => Property.fromJsonFactory);

    return _propertyManagersPropertyManagerIdPropertiesGet(
        propertyManagerId: propertyManagerId,
        activeOnly: activeOnly,
        cacheControl: cacheControl);
  }

  ///List all the properties for a property manager
  ///@param propertyManagerId The property manager id.
  ///@param activeOnly If true, only the active entries are returned.
  @Get(path: '/property-managers/{propertyManagerId}/properties')
  Future<chopper.Response<Properties>>
      _propertyManagersPropertyManagerIdPropertiesGet({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Query('activeOnly') bool? activeOnly,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Invite a user
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response<InvitedUser>>
      propertyManagersPropertyManagerIdInvitePost({
    required String? propertyManagerId,
    String? cacheControl,
    required InvitedUser? body,
  }) {
    generatedMapping.putIfAbsent(
        InvitedUser, () => InvitedUser.fromJsonFactory);

    return _propertyManagersPropertyManagerIdInvitePost(
        propertyManagerId: propertyManagerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Invite a user
  ///@param propertyManagerId The property manager id.
  @Post(path: '/property-managers/{propertyManagerId}/invite')
  Future<chopper.Response<InvitedUser>>
      _propertyManagersPropertyManagerIdInvitePost({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required InvitedUser? body,
  });

  ///Users associated to a property manager
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response<InvitedUsers>>
      propertyManagersPropertyManagerIdAssociatedUsersGet({
    required String? propertyManagerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        InvitedUser, () => InvitedUser.fromJsonFactory);

    return _propertyManagersPropertyManagerIdAssociatedUsersGet(
        propertyManagerId: propertyManagerId, cacheControl: cacheControl);
  }

  ///Users associated to a property manager
  ///@param propertyManagerId The property manager id.
  @Get(path: '/property-managers/{propertyManagerId}/associated-users')
  Future<chopper.Response<InvitedUsers>>
      _propertyManagersPropertyManagerIdAssociatedUsersGet({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///CheckIn a user
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response<CheckIn>>
      propertyManagersPropertyManagerIdCheckInPost({
    required String? propertyManagerId,
    String? cacheControl,
    required CheckIn? body,
  }) {
    generatedMapping.putIfAbsent(CheckIn, () => CheckIn.fromJsonFactory);

    return _propertyManagersPropertyManagerIdCheckInPost(
        propertyManagerId: propertyManagerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///CheckIn a user
  ///@param propertyManagerId The property manager id.
  @Post(path: '/property-managers/{propertyManagerId}/check-in')
  Future<chopper.Response<CheckIn>>
      _propertyManagersPropertyManagerIdCheckInPost({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CheckIn? body,
  });

  ///List of Check ins done by Property Manager
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response<CheckIns>>
      propertyManagersPropertyManagerIdCheckInsGet({
    required String? propertyManagerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(CheckIn, () => CheckIn.fromJsonFactory);

    return _propertyManagersPropertyManagerIdCheckInsGet(
        propertyManagerId: propertyManagerId, cacheControl: cacheControl);
  }

  ///List of Check ins done by Property Manager
  ///@param propertyManagerId The property manager id.
  @Get(path: '/property-managers/{propertyManagerId}/check-ins')
  Future<chopper.Response<CheckIns>>
      _propertyManagersPropertyManagerIdCheckInsGet({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Confirm a check-in
  ///@param propertyManagerId The property manager id.
  ///@param checkInId The check-in id.
  Future<chopper.Response<CheckIn>>
      propertyManagersPropertyManagerIdCheckInsCheckInIdConfirmPut({
    required String? propertyManagerId,
    required String? checkInId,
    String? cacheControl,
    required CheckIn? body,
  }) {
    generatedMapping.putIfAbsent(CheckIn, () => CheckIn.fromJsonFactory);

    return _propertyManagersPropertyManagerIdCheckInsCheckInIdConfirmPut(
        propertyManagerId: propertyManagerId,
        checkInId: checkInId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Confirm a check-in
  ///@param propertyManagerId The property manager id.
  ///@param checkInId The check-in id.
  @Put(
      path:
          '/property-managers/{propertyManagerId}/check-ins/{checkInId}/confirm')
  Future<chopper.Response<CheckIn>>
      _propertyManagersPropertyManagerIdCheckInsCheckInIdConfirmPut({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Path('checkInId') required String? checkInId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required CheckIn? body,
  });

  ///Link a Property Manager to the user that represents him/her
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response> propertyManagersPropertyManagerIdLinkToUserPut({
    required String? propertyManagerId,
    String? cacheControl,
    required InvitedUser? body,
  }) {
    return _propertyManagersPropertyManagerIdLinkToUserPut(
        propertyManagerId: propertyManagerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Link a Property Manager to the user that represents him/her
  ///@param propertyManagerId The property manager id.
  @Put(path: '/property-managers/{propertyManagerId}/link-to-user')
  Future<chopper.Response> _propertyManagersPropertyManagerIdLinkToUserPut({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required InvitedUser? body,
  });

  ///Associate a user to a property manager
  ///@param propertyManagerId The property manager id.
  Future<chopper.Response> propertyManagersPropertyManagerIdAssociateUserPut({
    required String? propertyManagerId,
    String? cacheControl,
    required InvitedUser? body,
  }) {
    return _propertyManagersPropertyManagerIdAssociateUserPut(
        propertyManagerId: propertyManagerId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Associate a user to a property manager
  ///@param propertyManagerId The property manager id.
  @Put(path: '/property-managers/{propertyManagerId}/associate-user')
  Future<chopper.Response> _propertyManagersPropertyManagerIdAssociateUserPut({
    @Path('propertyManagerId') required String? propertyManagerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required InvitedUser? body,
  });

  ///List all the properties
  ///@param activeOnly If true, only the active entries are returned.
  Future<chopper.Response<Properties>> propertiesGet({
    bool? activeOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Property, () => Property.fromJsonFactory);

    return _propertiesGet(activeOnly: activeOnly, cacheControl: cacheControl);
  }

  ///List all the properties
  ///@param activeOnly If true, only the active entries are returned.
  @Get(path: '/properties')
  Future<chopper.Response<Properties>> _propertiesGet({
    @Query('activeOnly') bool? activeOnly,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Property
  Future<chopper.Response<Property>> propertiesPost({
    String? cacheControl,
    required Property? body,
  }) {
    generatedMapping.putIfAbsent(Property, () => Property.fromJsonFactory);

    return _propertiesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Property
  @Post(path: '/properties')
  Future<chopper.Response<Property>> _propertiesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Property? body,
  });

  ///Info for a specific Property
  ///@param propertyId The property id.
  Future<chopper.Response<Property>> propertiesPropertyIdGet({
    required String? propertyId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Property, () => Property.fromJsonFactory);

    return _propertiesPropertyIdGet(
        propertyId: propertyId, cacheControl: cacheControl);
  }

  ///Info for a specific Property
  ///@param propertyId The property id.
  @Get(path: '/properties/{propertyId}')
  Future<chopper.Response<Property>> _propertiesPropertyIdGet({
    @Path('propertyId') required String? propertyId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Property
  ///@param propertyId The property id.
  Future<chopper.Response<Property>> propertiesPropertyIdPut({
    required String? propertyId,
    String? cacheControl,
    required Property? body,
  }) {
    generatedMapping.putIfAbsent(Property, () => Property.fromJsonFactory);

    return _propertiesPropertyIdPut(
        propertyId: propertyId, cacheControl: cacheControl, body: body);
  }

  ///Update a Property
  ///@param propertyId The property id.
  @Put(path: '/properties/{propertyId}')
  Future<chopper.Response<Property>> _propertiesPropertyIdPut({
    @Path('propertyId') required String? propertyId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Property? body,
  });

  ///Deletes a Property
  ///@param propertyId The property id.
  Future<chopper.Response> propertiesPropertyIdDelete({
    required String? propertyId,
    String? cacheControl,
  }) {
    return _propertiesPropertyIdDelete(
        propertyId: propertyId, cacheControl: cacheControl);
  }

  ///Deletes a Property
  ///@param propertyId The property id.
  @Delete(path: '/properties/{propertyId}')
  Future<chopper.Response> _propertiesPropertyIdDelete({
    @Path('propertyId') required String? propertyId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Set the tenant of a property. Tenant needs to exist as a Simplr user
  ///@param propertyId The property id.
  Future<chopper.Response> propertiesPropertyIdSetTenantPut({
    required String? propertyId,
    String? cacheControl,
    required InvitedUser? body,
  }) {
    return _propertiesPropertyIdSetTenantPut(
        propertyId: propertyId, cacheControl: cacheControl, body: body);
  }

  ///Set the tenant of a property. Tenant needs to exist as a Simplr user
  ///@param propertyId The property id.
  @Put(path: '/properties/{propertyId}/set-tenant')
  Future<chopper.Response> _propertiesPropertyIdSetTenantPut({
    @Path('propertyId') required String? propertyId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required InvitedUser? body,
  });

  ///Gets the property manager associated with the user of property manger role
  ///@param userId user ID.
  Future<chopper.Response<PropertyManager>> usersUserIdPropertyManagerGet({
    required String? userId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PropertyManager, () => PropertyManager.fromJsonFactory);

    return _usersUserIdPropertyManagerGet(
        userId: userId, cacheControl: cacheControl);
  }

  ///Gets the property manager associated with the user of property manger role
  ///@param userId user ID.
  @Get(path: '/users/{userId}/property-manager')
  Future<chopper.Response<PropertyManager>> _usersUserIdPropertyManagerGet({
    @Path('userId') required String? userId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Gets the property manager associated with the user
  Future<chopper.Response<PropertyManager>> usersAssociatedPropertyManagerGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        PropertyManager, () => PropertyManager.fromJsonFactory);

    return _usersAssociatedPropertyManagerGet(cacheControl: cacheControl);
  }

  ///Gets the property manager associated with the user
  @Get(path: '/users/associated-property-manager')
  Future<chopper.Response<PropertyManager>> _usersAssociatedPropertyManagerGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Updates a User language
  Future<chopper.Response<User>> usersLangPut({String? cacheControl}) {
    generatedMapping.putIfAbsent(User, () => User.fromJsonFactory);

    return _usersLangPut(cacheControl: cacheControl);
  }

  ///Updates a User language
  @Put(
    path: '/users/lang',
    optionalBody: true,
  )
  Future<chopper.Response<User>> _usersLangPut(
      {@Header('Cache-Control') String? cacheControl});

  ///List all the Locations
  ///@param pageable
  Future<chopper.Response<Locations>> locationsGet({
    Pageable? pageable,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(Locations, () => Locations.fromJsonFactory);

    return _locationsGet(pageable: pageable, cacheControl: cacheControl);
  }

  ///List all the Locations
  ///@param pageable
  @Get(path: '/locations')
  Future<chopper.Response<Locations>> _locationsGet({
    @Query('pageable') Pageable? pageable,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates a Location
  Future<chopper.Response<Location>> locationsPost({
    String? cacheControl,
    required Location? body,
  }) {
    generatedMapping.putIfAbsent(Location, () => Location.fromJsonFactory);

    return _locationsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Location
  @Post(path: '/locations')
  Future<chopper.Response<Location>> _locationsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Location? body,
  });

  ///Info for a specific Location
  ///@param locationId The location id.
  Future<chopper.Response<Location>> locationsLocationIdGet({
    required String? locationId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Location, () => Location.fromJsonFactory);

    return _locationsLocationIdGet(
        locationId: locationId, cacheControl: cacheControl);
  }

  ///Info for a specific Location
  ///@param locationId The location id.
  @Get(path: '/locations/{locationId}')
  Future<chopper.Response<Location>> _locationsLocationIdGet({
    @Path('locationId') required String? locationId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Location
  ///@param locationId The location id.
  Future<chopper.Response<Location>> locationsLocationIdPut({
    required String? locationId,
    String? cacheControl,
    required Location? body,
  }) {
    generatedMapping.putIfAbsent(Location, () => Location.fromJsonFactory);

    return _locationsLocationIdPut(
        locationId: locationId, cacheControl: cacheControl, body: body);
  }

  ///Update a Location
  ///@param locationId The location id.
  @Put(path: '/locations/{locationId}')
  Future<chopper.Response<Location>> _locationsLocationIdPut({
    @Path('locationId') required String? locationId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Location? body,
  });

  ///Deletes a Location
  ///@param locationId The location id.
  Future<chopper.Response> locationsLocationIdDelete({
    required String? locationId,
    String? cacheControl,
  }) {
    return _locationsLocationIdDelete(
        locationId: locationId, cacheControl: cacheControl);
  }

  ///Deletes a Location
  ///@param locationId The location id.
  @Delete(path: '/locations/{locationId}')
  Future<chopper.Response> _locationsLocationIdDelete({
    @Path('locationId') required String? locationId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the Regions
  Future<chopper.Response<Regions>> regionsGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Region, () => Region.fromJsonFactory);

    return _regionsGet(cacheControl: cacheControl);
  }

  ///List all the Regions
  @Get(path: '/regions')
  Future<chopper.Response<Regions>> _regionsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a Region
  Future<chopper.Response<Region>> regionsPost({
    String? cacheControl,
    required Region? body,
  }) {
    generatedMapping.putIfAbsent(Region, () => Region.fromJsonFactory);

    return _regionsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Region
  @Post(path: '/regions')
  Future<chopper.Response<Region>> _regionsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Region? body,
  });

  ///Info for a specific Region
  ///@param regionId The region id.
  Future<chopper.Response<Region>> regionsRegionIdGet({
    required String? regionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Region, () => Region.fromJsonFactory);

    return _regionsRegionIdGet(regionId: regionId, cacheControl: cacheControl);
  }

  ///Info for a specific Region
  ///@param regionId The region id.
  @Get(path: '/regions/{regionId}')
  Future<chopper.Response<Region>> _regionsRegionIdGet({
    @Path('regionId') required String? regionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Region
  ///@param regionId The region id.
  Future<chopper.Response<Region>> regionsRegionIdPut({
    required String? regionId,
    String? cacheControl,
    required Region? body,
  }) {
    generatedMapping.putIfAbsent(Region, () => Region.fromJsonFactory);

    return _regionsRegionIdPut(
        regionId: regionId, cacheControl: cacheControl, body: body);
  }

  ///Update a Region
  ///@param regionId The region id.
  @Put(path: '/regions/{regionId}')
  Future<chopper.Response<Region>> _regionsRegionIdPut({
    @Path('regionId') required String? regionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Region? body,
  });

  ///Deletes a Region
  ///@param regionId The region id.
  Future<chopper.Response> regionsRegionIdDelete({
    required String? regionId,
    String? cacheControl,
  }) {
    return _regionsRegionIdDelete(
        regionId: regionId, cacheControl: cacheControl);
  }

  ///Deletes a Region
  ///@param regionId The region id.
  @Delete(path: '/regions/{regionId}')
  Future<chopper.Response> _regionsRegionIdDelete({
    @Path('regionId') required String? regionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the countries
  Future<chopper.Response<Countries>> countriesGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Country, () => Country.fromJsonFactory);

    return _countriesGet(cacheControl: cacheControl);
  }

  ///List all the countries
  @Get(path: '/countries')
  Future<chopper.Response<Countries>> _countriesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a Country
  Future<chopper.Response<Country>> countriesPost({
    String? cacheControl,
    required Country? body,
  }) {
    generatedMapping.putIfAbsent(Country, () => Country.fromJsonFactory);

    return _countriesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Country
  @Post(path: '/countries')
  Future<chopper.Response<Country>> _countriesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Country? body,
  });

  ///Info for a specific Country
  ///@param countryId The country id.
  Future<chopper.Response<Country>> countriesCountryIdGet({
    required String? countryId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Country, () => Country.fromJsonFactory);

    return _countriesCountryIdGet(
        countryId: countryId, cacheControl: cacheControl);
  }

  ///Info for a specific Country
  ///@param countryId The country id.
  @Get(path: '/countries/{countryId}')
  Future<chopper.Response<Country>> _countriesCountryIdGet({
    @Path('countryId') required String? countryId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Country
  ///@param countryId The country id.
  Future<chopper.Response<Country>> countriesCountryIdPut({
    required String? countryId,
    String? cacheControl,
    required Country? body,
  }) {
    generatedMapping.putIfAbsent(Country, () => Country.fromJsonFactory);

    return _countriesCountryIdPut(
        countryId: countryId, cacheControl: cacheControl, body: body);
  }

  ///Update a Country
  ///@param countryId The country id.
  @Put(path: '/countries/{countryId}')
  Future<chopper.Response<Country>> _countriesCountryIdPut({
    @Path('countryId') required String? countryId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Country? body,
  });

  ///Deletes a Country
  ///@param countryId The country id.
  Future<chopper.Response> countriesCountryIdDelete({
    required String? countryId,
    String? cacheControl,
  }) {
    return _countriesCountryIdDelete(
        countryId: countryId, cacheControl: cacheControl);
  }

  ///Deletes a Country
  ///@param countryId The country id.
  @Delete(path: '/countries/{countryId}')
  Future<chopper.Response> _countriesCountryIdDelete({
    @Path('countryId') required String? countryId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the user legal audits
  ///@param userId user ID.
  Future<chopper.Response<UserLegalAudits>> userLegalAuditGet({
    String? userId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UserLegalAudit, () => UserLegalAudit.fromJsonFactory);

    return _userLegalAuditGet(userId: userId, cacheControl: cacheControl);
  }

  ///List all the user legal audits
  ///@param userId user ID.
  @Get(path: '/user-legal-audit')
  Future<chopper.Response<UserLegalAudits>> _userLegalAuditGet({
    @Query('userId') String? userId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates an record of a user accepting a legal document
  Future<chopper.Response<UserLegalAudit>> userLegalAuditPost({
    String? cacheControl,
    required UserLegalAudit? body,
  }) {
    generatedMapping.putIfAbsent(
        UserLegalAudit, () => UserLegalAudit.fromJsonFactory);

    return _userLegalAuditPost(cacheControl: cacheControl, body: body);
  }

  ///Creates an record of a user accepting a legal document
  @Post(path: '/user-legal-audit')
  Future<chopper.Response<UserLegalAudit>> _userLegalAuditPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserLegalAudit? body,
  });

  ///Info for a specific user legal audit
  ///@param userLegalAuditId The user legal audit id.
  Future<chopper.Response<UserLegalAudit>> userLegalAuditUserLegalAuditIdGet({
    required String? userLegalAuditId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UserLegalAudit, () => UserLegalAudit.fromJsonFactory);

    return _userLegalAuditUserLegalAuditIdGet(
        userLegalAuditId: userLegalAuditId, cacheControl: cacheControl);
  }

  ///Info for a specific user legal audit
  ///@param userLegalAuditId The user legal audit id.
  @Get(path: '/user-legal-audit/{userLegalAuditId}')
  Future<chopper.Response<UserLegalAudit>> _userLegalAuditUserLegalAuditIdGet({
    @Path('userLegalAuditId') required String? userLegalAuditId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the legal documents
  Future<chopper.Response<LegalDocuments>> legalDocumentGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        LegalDocument, () => LegalDocument.fromJsonFactory);

    return _legalDocumentGet(cacheControl: cacheControl);
  }

  ///List all the legal documents
  @Get(path: '/legal-document')
  Future<chopper.Response<LegalDocuments>> _legalDocumentGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a legal document
  Future<chopper.Response<LegalDocument>> legalDocumentPost({
    String? cacheControl,
    required LegalDocument? body,
  }) {
    generatedMapping.putIfAbsent(
        LegalDocument, () => LegalDocument.fromJsonFactory);

    return _legalDocumentPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a legal document
  @Post(path: '/legal-document')
  Future<chopper.Response<LegalDocument>> _legalDocumentPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required LegalDocument? body,
  });

  ///Info for a specific Legal document
  ///@param legalDocumentId The legal document id.
  Future<chopper.Response<LegalDocument>> legalDocumentLegalDocumentIdGet({
    required String? legalDocumentId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LegalDocument, () => LegalDocument.fromJsonFactory);

    return _legalDocumentLegalDocumentIdGet(
        legalDocumentId: legalDocumentId, cacheControl: cacheControl);
  }

  ///Info for a specific Legal document
  ///@param legalDocumentId The legal document id.
  @Get(path: '/legal-document/{legalDocumentId}')
  Future<chopper.Response<LegalDocument>> _legalDocumentLegalDocumentIdGet({
    @Path('legalDocumentId') required String? legalDocumentId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Legal document if and only if no user have already accepted it
  ///@param legalDocumentId The legal document id.
  Future<chopper.Response<LegalDocument>> legalDocumentLegalDocumentIdPut({
    required String? legalDocumentId,
    String? cacheControl,
    required LegalDocument? body,
  }) {
    generatedMapping.putIfAbsent(
        LegalDocument, () => LegalDocument.fromJsonFactory);

    return _legalDocumentLegalDocumentIdPut(
        legalDocumentId: legalDocumentId,
        cacheControl: cacheControl,
        body: body);
  }

  ///Update a Legal document if and only if no user have already accepted it
  ///@param legalDocumentId The legal document id.
  @Put(path: '/legal-document/{legalDocumentId}')
  Future<chopper.Response<LegalDocument>> _legalDocumentLegalDocumentIdPut({
    @Path('legalDocumentId') required String? legalDocumentId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required LegalDocument? body,
  });

  ///Deletes a legal document record if and only if no users have accepted it already
  ///@param legalDocumentId The legal document id.
  Future<chopper.Response> legalDocumentLegalDocumentIdDelete({
    required String? legalDocumentId,
    String? cacheControl,
  }) {
    return _legalDocumentLegalDocumentIdDelete(
        legalDocumentId: legalDocumentId, cacheControl: cacheControl);
  }

  ///Deletes a legal document record if and only if no users have accepted it already
  ///@param legalDocumentId The legal document id.
  @Delete(path: '/legal-document/{legalDocumentId}')
  Future<chopper.Response> _legalDocumentLegalDocumentIdDelete({
    @Path('legalDocumentId') required String? legalDocumentId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Info for a specific Legal document
  ///@param docType
  Future<chopper.Response<LegalDocument>> legalDocumentActiveGet({
    enums.LegalDocumentType? docType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LegalDocument, () => LegalDocument.fromJsonFactory);

    return _legalDocumentActiveGet(
        docType: enums.$LegalDocumentTypeMap[docType]?.toString(),
        cacheControl: cacheControl);
  }

  ///Info for a specific Legal document
  ///@param docType
  @Get(path: '/legal-document/active')
  Future<chopper.Response<LegalDocument>> _legalDocumentActiveGet({
    @Query('docType') String? docType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the newsletter acceptances
  ///@param email an email.
  Future<chopper.Response<NewsletterAcceptances>> newsletterAcceptanceGet({
    String? email,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NewsletterAcceptance, () => NewsletterAcceptance.fromJsonFactory);

    return _newsletterAcceptanceGet(email: email, cacheControl: cacheControl);
  }

  ///List all the newsletter acceptances
  ///@param email an email.
  @Get(path: '/newsletter-acceptance')
  Future<chopper.Response<NewsletterAcceptances>> _newsletterAcceptanceGet({
    @Query('email') String? email,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates an record of a user accepting the newsletter
  Future<chopper.Response<NewsletterAcceptance>> newsletterAcceptancePost({
    String? cacheControl,
    required NewsletterAcceptance? body,
  }) {
    generatedMapping.putIfAbsent(
        NewsletterAcceptance, () => NewsletterAcceptance.fromJsonFactory);

    return _newsletterAcceptancePost(cacheControl: cacheControl, body: body);
  }

  ///Creates an record of a user accepting the newsletter
  @Post(path: '/newsletter-acceptance')
  Future<chopper.Response<NewsletterAcceptance>> _newsletterAcceptancePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required NewsletterAcceptance? body,
  });

  ///Info for a specific user legal audit
  ///@param newsletterAcceptanceId The newsletter acceptance id.
  Future<chopper.Response<NewsletterAcceptance>>
      newsletterAcceptanceNewsletterAcceptanceIdGet({
    required String? newsletterAcceptanceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        NewsletterAcceptance, () => NewsletterAcceptance.fromJsonFactory);

    return _newsletterAcceptanceNewsletterAcceptanceIdGet(
        newsletterAcceptanceId: newsletterAcceptanceId,
        cacheControl: cacheControl);
  }

  ///Info for a specific user legal audit
  ///@param newsletterAcceptanceId The newsletter acceptance id.
  @Get(path: '/newsletter-acceptance/{newsletterAcceptanceId}')
  Future<chopper.Response<NewsletterAcceptance>>
      _newsletterAcceptanceNewsletterAcceptanceIdGet({
    @Path('newsletterAcceptanceId') required String? newsletterAcceptanceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for globally and return related services
  ///@param pageable
  ///@param q the search query.
  Future<chopper.Response<SimplrServices>> searchGlobalGet({
    Pageable? pageable,
    String? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        SimplrService, () => SimplrService.fromJsonFactory);

    return _searchGlobalGet(
        pageable: pageable, q: q, cacheControl: cacheControl);
  }

  ///Search for globally and return related services
  ///@param pageable
  ///@param q the search query.
  @Get(path: '/search/global/')
  Future<chopper.Response<SimplrServices>> _searchGlobalGet({
    @Query('pageable') Pageable? pageable,
    @Query('q') String? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Populate services index with data from db
  Future<chopper.Response> searchPopulateServicesPost({String? cacheControl}) {
    return _searchPopulateServicesPost(cacheControl: cacheControl);
  }

  ///Populate services index with data from db
  @Post(
    path: '/search/populate-services/',
    optionalBody: true,
  )
  Future<chopper.Response> _searchPopulateServicesPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Populate all indices with data from db
  Future<chopper.Response> searchPopulateAllPost({String? cacheControl}) {
    return _searchPopulateAllPost(cacheControl: cacheControl);
  }

  ///Populate all indices with data from db
  @Post(
    path: '/search/populate-all/',
    optionalBody: true,
  )
  Future<chopper.Response> _searchPopulateAllPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Recreate indices if they are not yet created. Optional to populate with db data. If delete is specified, we force the creation of a new index and delete the old one.
  ///@param deleteIndices if we should delete the indices or not.
  ///@param populateIndices if we should populate the indices from the data in the db.
  Future<chopper.Response> searchRecreateIndicesPost({
    bool? deleteIndices,
    bool? populateIndices,
    String? cacheControl,
  }) {
    return _searchRecreateIndicesPost(
        deleteIndices: deleteIndices,
        populateIndices: populateIndices,
        cacheControl: cacheControl);
  }

  ///Recreate indices if they are not yet created. Optional to populate with db data. If delete is specified, we force the creation of a new index and delete the old one.
  ///@param deleteIndices if we should delete the indices or not.
  ///@param populateIndices if we should populate the indices from the data in the db.
  @Post(
    path: '/search/recreate-indices/',
    optionalBody: true,
  )
  Future<chopper.Response> _searchRecreateIndicesPost({
    @Query('deleteIndices') bool? deleteIndices,
    @Query('populateIndices') bool? populateIndices,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Reindexes a certain index and populates it with data
  Future<chopper.Response> searchReIndexPost({
    String? cacheControl,
    required enums.ElasticsearchIndices? body,
  }) {
    return _searchReIndexPost(
        cacheControl: cacheControl,
        body: enums.$ElasticsearchIndicesMap[body]?.toString());
  }

  ///Reindexes a certain index and populates it with data
  @Post(path: '/search/re-index/')
  Future<chopper.Response> _searchReIndexPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required dynamic body,
  });

  ///Verifies that each alias has one index
  Future<chopper.Response<AliasesIndices>> searchVerifyIndexAliasConsistencyGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AliasIndices, () => AliasIndices.fromJsonFactory);

    return _searchVerifyIndexAliasConsistencyGet(cacheControl: cacheControl);
  }

  ///Verifies that each alias has one index
  @Get(path: '/search/verify-index-alias-consistency/')
  Future<chopper.Response<AliasesIndices>>
      _searchVerifyIndexAliasConsistencyGet(
          {@Header('Cache-Control') String? cacheControl});

  ///Verifies that all index data are synchronized
  Future<chopper.Response> searchVerifyIndicesDataAreSynchronizedGet(
      {String? cacheControl}) {
    return _searchVerifyIndicesDataAreSynchronizedGet(
        cacheControl: cacheControl);
  }

  ///Verifies that all index data are synchronized
  @Get(path: '/search/verify-indices-data-are-synchronized/')
  Future<chopper.Response> _searchVerifyIndicesDataAreSynchronizedGet(
      {@Header('Cache-Control') String? cacheControl});

  ///List all the Associates
  ///@param q
  Future<chopper.Response<Associates>> associatesGet({
    AssociateCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AssociateCriteria, () => AssociateCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(Associate, () => Associate.fromJsonFactory);

    return _associatesGet(q: q, cacheControl: cacheControl);
  }

  ///List all the Associates
  ///@param q
  @Get(path: '/associates')
  Future<chopper.Response<Associates>> _associatesGet({
    @Query('q') AssociateCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates an Associate
  Future<chopper.Response<Associate>> associatesPost({
    String? cacheControl,
    required Associate? body,
  }) {
    generatedMapping.putIfAbsent(Associate, () => Associate.fromJsonFactory);

    return _associatesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates an Associate
  @Post(path: '/associates')
  Future<chopper.Response<Associate>> _associatesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Associate? body,
  });

  ///Info for a specific Associate
  ///@param associateId The associate id.
  ///@param activeOnly If true, only the active entries are returned.
  Future<chopper.Response<Associate>> associatesAssociateIdGet({
    required String? associateId,
    bool? activeOnly,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Associate, () => Associate.fromJsonFactory);

    return _associatesAssociateIdGet(
        associateId: associateId,
        activeOnly: activeOnly,
        cacheControl: cacheControl);
  }

  ///Info for a specific Associate
  ///@param associateId The associate id.
  ///@param activeOnly If true, only the active entries are returned.
  @Get(path: '/associates/{associateId}')
  Future<chopper.Response<Associate>> _associatesAssociateIdGet({
    @Path('associateId') required String? associateId,
    @Query('activeOnly') bool? activeOnly,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update an Associate
  ///@param associateId The associate id.
  Future<chopper.Response<Associate>> associatesAssociateIdPut({
    required String? associateId,
    String? cacheControl,
    required Associate? body,
  }) {
    generatedMapping.putIfAbsent(Associate, () => Associate.fromJsonFactory);

    return _associatesAssociateIdPut(
        associateId: associateId, cacheControl: cacheControl, body: body);
  }

  ///Update an Associate
  ///@param associateId The associate id.
  @Put(path: '/associates/{associateId}')
  Future<chopper.Response<Associate>> _associatesAssociateIdPut({
    @Path('associateId') required String? associateId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Associate? body,
  });

  ///Deletes an Associate
  ///@param associateId The associate id.
  Future<chopper.Response> associatesAssociateIdDelete({
    required String? associateId,
    String? cacheControl,
  }) {
    return _associatesAssociateIdDelete(
        associateId: associateId, cacheControl: cacheControl);
  }

  ///Deletes an Associate
  ///@param associateId The associate id.
  @Delete(path: '/associates/{associateId}')
  Future<chopper.Response> _associatesAssociateIdDelete({
    @Path('associateId') required String? associateId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Pre registers a user for associate.
  ///@param email
  ///@param associateId The associate id.
  ///@param subNewsletter
  Future<chopper.Response> associatesPreregisterAssociateIdGet({
    String? email,
    required String? associateId,
    bool? subNewsletter,
    String? cacheControl,
  }) {
    return _associatesPreregisterAssociateIdGet(
        email: email,
        associateId: associateId,
        subNewsletter: subNewsletter,
        cacheControl: cacheControl);
  }

  ///Pre registers a user for associate.
  ///@param email
  ///@param associateId The associate id.
  ///@param subNewsletter
  @Get(path: '/associates/preregister/{associateId}')
  Future<chopper.Response> _associatesPreregisterAssociateIdGet({
    @Query('email') String? email,
    @Path('associateId') required String? associateId,
    @Query('subNewsletter') bool? subNewsletter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all PromotionCode from the Associate
  ///@param associateId The associate id.
  Future<chopper.Response<PromotionCodes>>
      associatesAssociateIdPromotionCodesGet({
    required String? associateId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PromotionCode, () => PromotionCode.fromJsonFactory);

    return _associatesAssociateIdPromotionCodesGet(
        associateId: associateId, cacheControl: cacheControl);
  }

  ///List all PromotionCode from the Associate
  ///@param associateId The associate id.
  @Get(path: '/associates/{associateId}/promotion-codes')
  Future<chopper.Response<PromotionCodes>>
      _associatesAssociateIdPromotionCodesGet({
    @Path('associateId') required String? associateId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Adds a Promotion Code to an Associate
  ///@param associateId The associate id.
  Future<chopper.Response> associatesAssociateIdPromotionCodesPost({
    required String? associateId,
    String? cacheControl,
    required PromotionCode? body,
  }) {
    return _associatesAssociateIdPromotionCodesPost(
        associateId: associateId, cacheControl: cacheControl, body: body);
  }

  ///Adds a Promotion Code to an Associate
  ///@param associateId The associate id.
  @Post(path: '/associates/{associateId}/promotion-codes')
  Future<chopper.Response> _associatesAssociateIdPromotionCodesPost({
    @Path('associateId') required String? associateId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PromotionCode? body,
  });

  ///Deletes a Promotion Code from an Associate
  ///@param associateId The associate id.
  ///@param promotionCode The promotion code.
  Future<chopper.Response>
      associatesAssociateIdPromotionCodesPromotionCodeDelete({
    required String? associateId,
    required String? promotionCode,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PromotionCode, () => PromotionCode.fromJsonFactory);

    return _associatesAssociateIdPromotionCodesPromotionCodeDelete(
        associateId: associateId,
        promotionCode: promotionCode,
        cacheControl: cacheControl);
  }

  ///Deletes a Promotion Code from an Associate
  ///@param associateId The associate id.
  ///@param promotionCode The promotion code.
  @Delete(path: '/associates/{associateId}/promotion-codes/{promotionCode}')
  Future<chopper.Response>
      _associatesAssociateIdPromotionCodesPromotionCodeDelete({
    @Path('associateId') required String? associateId,
    @Path('promotionCode') required String? promotionCode,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all users linked to this Associate
  ///@param associateId The associate id.
  Future<chopper.Response<Users>> associatesAssociateIdUsersGet({
    required String? associateId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(User, () => User.fromJsonFactory);

    return _associatesAssociateIdUsersGet(
        associateId: associateId, cacheControl: cacheControl);
  }

  ///List all users linked to this Associate
  ///@param associateId The associate id.
  @Get(path: '/associates/{associateId}/users')
  Future<chopper.Response<Users>> _associatesAssociateIdUsersGet({
    @Path('associateId') required String? associateId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Adds a User to an Associate
  ///@param associateId The associate id.
  Future<chopper.Response> associatesAssociateIdUsersPost({
    required String? associateId,
    String? cacheControl,
    required User? body,
  }) {
    return _associatesAssociateIdUsersPost(
        associateId: associateId, cacheControl: cacheControl, body: body);
  }

  ///Adds a User to an Associate
  ///@param associateId The associate id.
  @Post(path: '/associates/{associateId}/users')
  Future<chopper.Response> _associatesAssociateIdUsersPost({
    @Path('associateId') required String? associateId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required User? body,
  });

  ///Deletes a User from an Associate
  ///@param associateId The associate id.
  ///@param userId user ID.
  Future<chopper.Response> associatesAssociateIdUsersUserIdDelete({
    required String? associateId,
    required String? userId,
    String? cacheControl,
  }) {
    return _associatesAssociateIdUsersUserIdDelete(
        associateId: associateId, userId: userId, cacheControl: cacheControl);
  }

  ///Deletes a User from an Associate
  ///@param associateId The associate id.
  ///@param userId user ID.
  @Delete(path: '/associates/{associateId}/users/{userId}')
  Future<chopper.Response> _associatesAssociateIdUsersUserIdDelete({
    @Path('associateId') required String? associateId,
    @Path('userId') required String? userId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the Promotions
  ///@param pageable
  ///@param q
  Future<chopper.Response<Promotions>> promotionsGet({
    Pageable? pageable,
    PromotionCriteria? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Pageable, () => Pageable.fromJsonFactory);
    generatedMapping.putIfAbsent(
        PromotionCriteria, () => PromotionCriteria.fromJsonFactory);
    generatedMapping.putIfAbsent(Promotions, () => Promotions.fromJsonFactory);

    return _promotionsGet(pageable: pageable, q: q, cacheControl: cacheControl);
  }

  ///List all the Promotions
  ///@param pageable
  ///@param q
  @Get(path: '/promotions')
  Future<chopper.Response<Promotions>> _promotionsGet({
    @Query('pageable') Pageable? pageable,
    @Query('q') PromotionCriteria? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Creates an Promotion
  Future<chopper.Response<Promotion>> promotionsPost({
    String? cacheControl,
    required Promotion? body,
  }) {
    generatedMapping.putIfAbsent(Promotion, () => Promotion.fromJsonFactory);

    return _promotionsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates an Promotion
  @Post(path: '/promotions')
  Future<chopper.Response<Promotion>> _promotionsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Promotion? body,
  });

  ///Info for a specific Promotion
  ///@param promotionId The promotion id.
  Future<chopper.Response<Promotion>> promotionsPromotionIdGet({
    required String? promotionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Promotion, () => Promotion.fromJsonFactory);

    return _promotionsPromotionIdGet(
        promotionId: promotionId, cacheControl: cacheControl);
  }

  ///Info for a specific Promotion
  ///@param promotionId The promotion id.
  @Get(path: '/promotions/{promotionId}')
  Future<chopper.Response<Promotion>> _promotionsPromotionIdGet({
    @Path('promotionId') required String? promotionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update an Promotion
  ///@param promotionId The promotion id.
  Future<chopper.Response<Promotion>> promotionsPromotionIdPut({
    required String? promotionId,
    String? cacheControl,
    required Promotion? body,
  }) {
    generatedMapping.putIfAbsent(Promotion, () => Promotion.fromJsonFactory);

    return _promotionsPromotionIdPut(
        promotionId: promotionId, cacheControl: cacheControl, body: body);
  }

  ///Update an Promotion
  ///@param promotionId The promotion id.
  @Put(path: '/promotions/{promotionId}')
  Future<chopper.Response<Promotion>> _promotionsPromotionIdPut({
    @Path('promotionId') required String? promotionId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Promotion? body,
  });

  ///Deletes an Promotion
  ///@param promotionId The promotion id.
  Future<chopper.Response> promotionsPromotionIdDelete({
    required String? promotionId,
    String? cacheControl,
  }) {
    return _promotionsPromotionIdDelete(
        promotionId: promotionId, cacheControl: cacheControl);
  }

  ///Deletes an Promotion
  ///@param promotionId The promotion id.
  @Delete(path: '/promotions/{promotionId}')
  Future<chopper.Response> _promotionsPromotionIdDelete({
    @Path('promotionId') required String? promotionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get the current global promotion, if there's one active
  Future<chopper.Response<Promotion>> promotionsGlobalGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(Promotion, () => Promotion.fromJsonFactory);

    return _promotionsGlobalGet(cacheControl: cacheControl);
  }

  ///Get the current global promotion, if there's one active
  @Get(path: '/promotions/global')
  Future<chopper.Response<Promotion>> _promotionsGlobalGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Search for Coordinates
  ///@param q the search query.
  Future<chopper.Response<Coordinates>> geoCoordinatesGet({
    String? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Coordinate, () => Coordinate.fromJsonFactory);

    return _geoCoordinatesGet(q: q, cacheControl: cacheControl);
  }

  ///Search for Coordinates
  ///@param q the search query.
  @Get(path: '/geo/coordinates')
  Future<chopper.Response<Coordinates>> _geoCoordinatesGet({
    @Query('q') String? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for Bounding Area
  ///@param q the search query.
  Future<chopper.Response<BoundingAreas>> geoAreaGet({
    String? q,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BoundingArea, () => BoundingArea.fromJsonFactory);

    return _geoAreaGet(q: q, cacheControl: cacheControl);
  }

  ///Search for Bounding Area
  ///@param q the search query.
  @Get(path: '/geo/area')
  Future<chopper.Response<BoundingAreas>> _geoAreaGet({
    @Query('q') String? q,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for Bounding Area
  Future<chopper.Response<MapNumber>>
      simplrServicesGetBasePricePercentageOfDoneGet({String? cacheControl}) {
    return _simplrServicesGetBasePricePercentageOfDoneGet(
        cacheControl: cacheControl);
  }

  ///Search for Bounding Area
  @Get(path: '/simplr-services/getBasePricePercentageOfDone')
  Future<chopper.Response<MapNumber>>
      _simplrServicesGetBasePricePercentageOfDoneGet(
          {@Header('Cache-Control') String? cacheControl});

  ///Log an event if there are an user
  Future<chopper.Response<EventRegister>> eventRegisterPost({
    String? cacheControl,
    required EventRegister? body,
  }) {
    generatedMapping.putIfAbsent(
        EventRegister, () => EventRegister.fromJsonFactory);

    return _eventRegisterPost(cacheControl: cacheControl, body: body);
  }

  ///Log an event if there are an user
  @Post(path: '/event-register')
  Future<chopper.Response<EventRegister>> _eventRegisterPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required EventRegister? body,
  });

  ///Search for Bounding Area
  Future<chopper.Response<PredefinedBoundingAreas>> geoAreaPredefinedGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        PredefinedBoundingArea, () => PredefinedBoundingArea.fromJsonFactory);

    return _geoAreaPredefinedGet(cacheControl: cacheControl);
  }

  ///Search for Bounding Area
  @Get(path: '/geo/area/predefined')
  Future<chopper.Response<PredefinedBoundingAreas>> _geoAreaPredefinedGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Search for Predefined Bounding Area
  ///@param predefinedId The predefined bounding area id.
  Future<chopper.Response<BoundingAreas>> geoAreaPredefinedPredefinedIdGet({
    required num? predefinedId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BoundingArea, () => BoundingArea.fromJsonFactory);

    return _geoAreaPredefinedPredefinedIdGet(
        predefinedId: predefinedId, cacheControl: cacheControl);
  }

  ///Search for Predefined Bounding Area
  ///@param predefinedId The predefined bounding area id.
  @Get(path: '/geo/area/predefined/{predefinedId}')
  Future<chopper.Response<BoundingAreas>> _geoAreaPredefinedPredefinedIdGet({
    @Path('predefinedId') required num? predefinedId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for Bounding Area
  ///@param optionId The service option id to get the bounding area.
  Future<chopper.Response<BoundingAreas>>
      serviceOptionsOptionIdDeliveryAreasGet({
    required num? optionId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BoundingArea, () => BoundingArea.fromJsonFactory);

    return _serviceOptionsOptionIdDeliveryAreasGet(
        optionId: optionId, cacheControl: cacheControl);
  }

  ///Search for Bounding Area
  ///@param optionId The service option id to get the bounding area.
  @Get(path: '/service-options/{optionId}/delivery-areas')
  Future<chopper.Response<BoundingAreas>>
      _serviceOptionsOptionIdDeliveryAreasGet({
    @Path('optionId') required num? optionId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for Bounding Area
  ///@param serviceId The service option id to get the bounding area.
  Future<chopper.Response<BoundingAreas>>
      simplrServicesServiceIdDeliveryAreasGet({
    required num? serviceId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        BoundingArea, () => BoundingArea.fromJsonFactory);

    return _simplrServicesServiceIdDeliveryAreasGet(
        serviceId: serviceId, cacheControl: cacheControl);
  }

  ///Search for Bounding Area
  ///@param serviceId The service option id to get the bounding area.
  @Get(path: '/simplr-services/{serviceId}/delivery-areas')
  Future<chopper.Response<BoundingAreas>>
      _simplrServicesServiceIdDeliveryAreasGet({
    @Path('serviceId') required num? serviceId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the HeroBanners
  Future<chopper.Response<HeroBanners>> heroBannersGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(HeroBanner, () => HeroBanner.fromJsonFactory);

    return _heroBannersGet(cacheControl: cacheControl);
  }

  ///List all the HeroBanners
  @Get(path: '/hero-banners')
  Future<chopper.Response<HeroBanners>> _heroBannersGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a HeroBanner
  Future<chopper.Response<HeroBanner>> heroBannersPost({
    String? cacheControl,
    required HeroBanner? body,
  }) {
    generatedMapping.putIfAbsent(HeroBanner, () => HeroBanner.fromJsonFactory);

    return _heroBannersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a HeroBanner
  @Post(path: '/hero-banners')
  Future<chopper.Response<HeroBanner>> _heroBannersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required HeroBanner? body,
  });

  ///List all the active HeroBanners
  Future<chopper.Response<HeroBanners>> heroBannersActiveGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(HeroBanner, () => HeroBanner.fromJsonFactory);

    return _heroBannersActiveGet(cacheControl: cacheControl);
  }

  ///List all the active HeroBanners
  @Get(path: '/hero-banners-active')
  Future<chopper.Response<HeroBanners>> _heroBannersActiveGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Info for a specific HeroBanner
  ///@param heroBannerId The HeroBanner id
  Future<chopper.Response<HeroBanner>> heroBannersHeroBannerIdGet({
    required num? heroBannerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(HeroBanner, () => HeroBanner.fromJsonFactory);

    return _heroBannersHeroBannerIdGet(
        heroBannerId: heroBannerId, cacheControl: cacheControl);
  }

  ///Info for a specific HeroBanner
  ///@param heroBannerId The HeroBanner id
  @Get(path: '/hero-banners/{heroBannerId}')
  Future<chopper.Response<HeroBanner>> _heroBannersHeroBannerIdGet({
    @Path('heroBannerId') required num? heroBannerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a HeroBanner
  ///@param heroBannerId The HeroBanner id
  Future<chopper.Response<HeroBanner>> heroBannersHeroBannerIdPut({
    required num? heroBannerId,
    String? cacheControl,
    required HeroBanner? body,
  }) {
    generatedMapping.putIfAbsent(HeroBanner, () => HeroBanner.fromJsonFactory);

    return _heroBannersHeroBannerIdPut(
        heroBannerId: heroBannerId, cacheControl: cacheControl, body: body);
  }

  ///Update a HeroBanner
  ///@param heroBannerId The HeroBanner id
  @Put(path: '/hero-banners/{heroBannerId}')
  Future<chopper.Response<HeroBanner>> _heroBannersHeroBannerIdPut({
    @Path('heroBannerId') required num? heroBannerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required HeroBanner? body,
  });

  ///Deletes a HeroBanner
  ///@param heroBannerId The HeroBanner id
  Future<chopper.Response> heroBannersHeroBannerIdDelete({
    required num? heroBannerId,
    String? cacheControl,
  }) {
    return _heroBannersHeroBannerIdDelete(
        heroBannerId: heroBannerId, cacheControl: cacheControl);
  }

  ///Deletes a HeroBanner
  ///@param heroBannerId The HeroBanner id
  @Delete(path: '/hero-banners/{heroBannerId}')
  Future<chopper.Response> _heroBannersHeroBannerIdDelete({
    @Path('heroBannerId') required num? heroBannerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Checks whether a feature-flag is enabled
  ///@param featureFlag Feature flag name
  Future<chopper.Response<bool>> featureFlagsCheckFeatureFlagGet({
    required String? featureFlag,
    String? cacheControl,
  }) {
    return _featureFlagsCheckFeatureFlagGet(
        featureFlag: featureFlag, cacheControl: cacheControl);
  }

  ///Checks whether a feature-flag is enabled
  ///@param featureFlag Feature flag name
  @Get(path: '/feature-flags/check/{featureFlag}')
  Future<chopper.Response<bool>> _featureFlagsCheckFeatureFlagGet({
    @Path('featureFlag') required String? featureFlag,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Checks all feature-flags are enabled
  Future<chopper.Response<MapBoolean>> featureFlagsCheckGet(
      {String? cacheControl}) {
    return _featureFlagsCheckGet(cacheControl: cacheControl);
  }

  ///Checks all feature-flags are enabled
  @Get(path: '/feature-flags/check')
  Future<chopper.Response<MapBoolean>> _featureFlagsCheckGet(
      {@Header('Cache-Control') String? cacheControl});

  ///List all the InfoBanners
  Future<chopper.Response<InfoBanners>> infoBannersGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(InfoBanner, () => InfoBanner.fromJsonFactory);

    return _infoBannersGet(cacheControl: cacheControl);
  }

  ///List all the InfoBanners
  @Get(path: '/info-banners')
  Future<chopper.Response<InfoBanners>> _infoBannersGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a InfoBanner
  Future<chopper.Response<InfoBanner>> infoBannersPost({
    String? cacheControl,
    required InfoBanner? body,
  }) {
    generatedMapping.putIfAbsent(InfoBanner, () => InfoBanner.fromJsonFactory);

    return _infoBannersPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a InfoBanner
  @Post(path: '/info-banners')
  Future<chopper.Response<InfoBanner>> _infoBannersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required InfoBanner? body,
  });

  ///Get the active InfoBanner
  Future<chopper.Response<InfoBanner>> infoBannersActiveGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(InfoBanner, () => InfoBanner.fromJsonFactory);

    return _infoBannersActiveGet(cacheControl: cacheControl);
  }

  ///Get the active InfoBanner
  @Get(path: '/info-banners-active')
  Future<chopper.Response<InfoBanner>> _infoBannersActiveGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Info for a specific InfoBanner
  ///@param infoBannerId The InfoBanner id
  Future<chopper.Response<InfoBanner>> infoBannersInfoBannerIdGet({
    required num? infoBannerId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(InfoBanner, () => InfoBanner.fromJsonFactory);

    return _infoBannersInfoBannerIdGet(
        infoBannerId: infoBannerId, cacheControl: cacheControl);
  }

  ///Info for a specific InfoBanner
  ///@param infoBannerId The InfoBanner id
  @Get(path: '/info-banners/{infoBannerId}')
  Future<chopper.Response<InfoBanner>> _infoBannersInfoBannerIdGet({
    @Path('infoBannerId') required num? infoBannerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a InfoBanner
  ///@param infoBannerId The InfoBanner id
  Future<chopper.Response<InfoBanner>> infoBannersInfoBannerIdPut({
    required num? infoBannerId,
    String? cacheControl,
    required InfoBanner? body,
  }) {
    generatedMapping.putIfAbsent(InfoBanner, () => InfoBanner.fromJsonFactory);

    return _infoBannersInfoBannerIdPut(
        infoBannerId: infoBannerId, cacheControl: cacheControl, body: body);
  }

  ///Update a InfoBanner
  ///@param infoBannerId The InfoBanner id
  @Put(path: '/info-banners/{infoBannerId}')
  Future<chopper.Response<InfoBanner>> _infoBannersInfoBannerIdPut({
    @Path('infoBannerId') required num? infoBannerId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required InfoBanner? body,
  });

  ///Deletes a InfoBanner
  ///@param infoBannerId The InfoBanner id
  Future<chopper.Response> infoBannersInfoBannerIdDelete({
    required num? infoBannerId,
    String? cacheControl,
  }) {
    return _infoBannersInfoBannerIdDelete(
        infoBannerId: infoBannerId, cacheControl: cacheControl);
  }

  ///Deletes a InfoBanner
  ///@param infoBannerId The InfoBanner id
  @Delete(path: '/info-banners/{infoBannerId}')
  Future<chopper.Response> _infoBannersInfoBannerIdDelete({
    @Path('infoBannerId') required num? infoBannerId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all tax rates
  Future<chopper.Response<TaxRates>> taxRatesGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(TaxRate, () => TaxRate.fromJsonFactory);

    return _taxRatesGet(cacheControl: cacheControl);
  }

  ///List all tax rates
  @Get(path: '/tax-rates')
  Future<chopper.Response<TaxRates>> _taxRatesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a tax rate
  Future<chopper.Response<TaxRate>> taxRatesPost({
    String? cacheControl,
    required TaxRate? body,
  }) {
    generatedMapping.putIfAbsent(TaxRate, () => TaxRate.fromJsonFactory);

    return _taxRatesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a tax rate
  @Post(path: '/tax-rates')
  Future<chopper.Response<TaxRate>> _taxRatesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TaxRate? body,
  });

  ///Search for Tax Rate
  ///@param taxRateId The TaxRate id
  Future<chopper.Response<TaxRate>> taxRatesTaxRateIdGet({
    required num? taxRateId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TaxRate, () => TaxRate.fromJsonFactory);

    return _taxRatesTaxRateIdGet(
        taxRateId: taxRateId, cacheControl: cacheControl);
  }

  ///Search for Tax Rate
  ///@param taxRateId The TaxRate id
  @Get(path: '/tax-rates/{taxRateId}')
  Future<chopper.Response<TaxRate>> _taxRatesTaxRateIdGet({
    @Path('taxRateId') required num? taxRateId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update Tax Rate
  ///@param taxRateId The TaxRate id
  Future<chopper.Response<TaxRate>> taxRatesTaxRateIdPut({
    required num? taxRateId,
    String? cacheControl,
    required TaxRate? body,
  }) {
    generatedMapping.putIfAbsent(TaxRate, () => TaxRate.fromJsonFactory);

    return _taxRatesTaxRateIdPut(
        taxRateId: taxRateId, cacheControl: cacheControl, body: body);
  }

  ///Update Tax Rate
  ///@param taxRateId The TaxRate id
  @Put(path: '/tax-rates/{taxRateId}')
  Future<chopper.Response<TaxRate>> _taxRatesTaxRateIdPut({
    @Path('taxRateId') required num? taxRateId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required TaxRate? body,
  });

  ///Delete Tax Rate
  ///@param taxRateId The TaxRate id
  Future<chopper.Response> taxRatesTaxRateIdDelete({
    required num? taxRateId,
    String? cacheControl,
  }) {
    return _taxRatesTaxRateIdDelete(
        taxRateId: taxRateId, cacheControl: cacheControl);
  }

  ///Delete Tax Rate
  ///@param taxRateId The TaxRate id
  @Delete(path: '/tax-rates/{taxRateId}')
  Future<chopper.Response> _taxRatesTaxRateIdDelete({
    @Path('taxRateId') required num? taxRateId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Search for Tax Rate
  ///@param taxRateType The TaxRate type
  Future<chopper.Response<TaxRates>> taxRatesTaxTypeTaxRateTypeGet({
    required String? taxRateType,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(TaxRate, () => TaxRate.fromJsonFactory);

    return _taxRatesTaxTypeTaxRateTypeGet(
        taxRateType: taxRateType, cacheControl: cacheControl);
  }

  ///Search for Tax Rate
  ///@param taxRateType The TaxRate type
  @Get(path: '/tax-rates/taxType/{taxRateType}')
  Future<chopper.Response<TaxRates>> _taxRatesTaxTypeTaxRateTypeGet({
    @Path('taxRateType') required String? taxRateType,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List all the markets
  Future<chopper.Response<Markets>> marketsGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Market, () => Market.fromJsonFactory);

    return _marketsGet(cacheControl: cacheControl);
  }

  ///List all the markets
  @Get(path: '/markets')
  Future<chopper.Response<Markets>> _marketsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a Market
  Future<chopper.Response<Market>> marketsPost({
    String? cacheControl,
    required Market? body,
  }) {
    generatedMapping.putIfAbsent(Market, () => Market.fromJsonFactory);

    return _marketsPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Market
  @Post(path: '/markets')
  Future<chopper.Response<Market>> _marketsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Market? body,
  });

  ///Info for a specific Market
  ///@param marketId The Market id
  Future<chopper.Response<Market>> marketsMarketIdGet({
    required num? marketId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Market, () => Market.fromJsonFactory);

    return _marketsMarketIdGet(marketId: marketId, cacheControl: cacheControl);
  }

  ///Info for a specific Market
  ///@param marketId The Market id
  @Get(path: '/markets/{marketId}')
  Future<chopper.Response<Market>> _marketsMarketIdGet({
    @Path('marketId') required num? marketId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Market
  ///@param marketId The Market id
  Future<chopper.Response<Market>> marketsMarketIdPut({
    required num? marketId,
    String? cacheControl,
    required Market? body,
  }) {
    generatedMapping.putIfAbsent(Market, () => Market.fromJsonFactory);

    return _marketsMarketIdPut(
        marketId: marketId, cacheControl: cacheControl, body: body);
  }

  ///Update a Market
  ///@param marketId The Market id
  @Put(path: '/markets/{marketId}')
  Future<chopper.Response<Market>> _marketsMarketIdPut({
    @Path('marketId') required num? marketId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Market? body,
  });

  ///List all the businesses
  Future<chopper.Response<Businesses>> businessesGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Business, () => Business.fromJsonFactory);

    return _businessesGet(cacheControl: cacheControl);
  }

  ///List all the businesses
  @Get(path: '/businesses')
  Future<chopper.Response<Businesses>> _businessesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Creates a Business
  Future<chopper.Response<Business>> businessesPost({
    String? cacheControl,
    required Business? body,
  }) {
    generatedMapping.putIfAbsent(Business, () => Business.fromJsonFactory);

    return _businessesPost(cacheControl: cacheControl, body: body);
  }

  ///Creates a Business
  @Post(path: '/businesses')
  Future<chopper.Response<Business>> _businessesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required Business? body,
  });

  ///Info for a specific Business
  ///@param businessId The Business id
  Future<chopper.Response<Business>> businessesBusinessIdGet({
    required String? businessId,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Business, () => Business.fromJsonFactory);

    return _businessesBusinessIdGet(
        businessId: businessId, cacheControl: cacheControl);
  }

  ///Info for a specific Business
  ///@param businessId The Business id
  @Get(path: '/businesses/{businessId}')
  Future<chopper.Response<Business>> _businessesBusinessIdGet({
    @Path('businessId') required String? businessId,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update a Business
  ///@param businessId The Business id
  Future<chopper.Response<Business>> businessesBusinessIdPut({
    required String? businessId,
    String? cacheControl,
    required Business? body,
  }) {
    generatedMapping.putIfAbsent(Business, () => Business.fromJsonFactory);

    return _businessesBusinessIdPut(
        businessId: businessId, cacheControl: cacheControl, body: body);
  }

  ///Update a Business
  ///@param businessId The Business id
  @Put(path: '/businesses/{businessId}')
  Future<chopper.Response<Business>> _businessesBusinessIdPut({
    @Path('businessId') required String? businessId,
    @Header('Cache-Control') String? cacheControl,
    @Body() required Business? body,
  });
}

@JsonSerializable(explicitToJson: true)
class ServiceOption {
  ServiceOption({
    this.id,
    this.serviceId,
    required this.name,
    this.nameForPartner,
    this.description,
    this.shortDescription,
    this.deliveryArea,
    this.deliveryFrequencyInterval,
    this.deliveryTime,
    this.imageUrl,
    this.active,
    this.additional,
    this.requiredDeliveryInformation,
    this.orderNb,
    this.alias,
    this.prices,
    this.features,
    this.images,
    this.deliveryAreas,
    this.businessIds,
    this.defaultOption,
  });

  factory ServiceOption.fromJson(Map<String, dynamic> json) =>
      _$ServiceOptionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'serviceId', includeIfNull: false)
  final num? serviceId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'nameForPartner', includeIfNull: false, defaultValue: '')
  final String? nameForPartner;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'deliveryArea', includeIfNull: false, defaultValue: '')
  final String? deliveryArea;
  @JsonKey(
      name: 'deliveryFrequencyInterval', includeIfNull: false, defaultValue: '')
  final String? deliveryFrequencyInterval;
  @JsonKey(name: 'deliveryTime', includeIfNull: false, defaultValue: '')
  final String? deliveryTime;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  @JsonKey(name: 'additional', includeIfNull: false, defaultValue: false)
  final bool? additional;
  @JsonKey(
      name: 'requiredDeliveryInformation',
      includeIfNull: false,
      defaultValue: true)
  final bool? requiredDeliveryInformation;
  @JsonKey(name: 'orderNb', includeIfNull: false)
  final int? orderNb;
  @JsonKey(name: 'alias', includeIfNull: false, defaultValue: '')
  final String? alias;
  @JsonKey(name: 'prices', includeIfNull: false)
  final List<PriceOption>? prices;
  @JsonKey(name: 'features', includeIfNull: false)
  final List<OptionFeature>? features;
  @JsonKey(name: 'images', includeIfNull: false)
  final List<Image>? images;
  @JsonKey(name: 'deliveryAreas', includeIfNull: false)
  final List<BoundingArea>? deliveryAreas;
  @JsonKey(name: 'businessIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? businessIds;
  @JsonKey(name: 'defaultOption', includeIfNull: false, defaultValue: false)
  final bool? defaultOption;
  static const fromJsonFactory = _$ServiceOptionFromJson;
  static const toJsonFactory = _$ServiceOptionToJson;
  Map<String, dynamic> toJson() => _$ServiceOptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceOption &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.nameForPartner, nameForPartner) ||
                const DeepCollectionEquality()
                    .equals(other.nameForPartner, nameForPartner)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.deliveryArea, deliveryArea) ||
                const DeepCollectionEquality()
                    .equals(other.deliveryArea, deliveryArea)) &&
            (identical(other.deliveryFrequencyInterval, deliveryFrequencyInterval) ||
                const DeepCollectionEquality().equals(
                    other.deliveryFrequencyInterval,
                    deliveryFrequencyInterval)) &&
            (identical(other.deliveryTime, deliveryTime) ||
                const DeepCollectionEquality()
                    .equals(other.deliveryTime, deliveryTime)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.additional, additional) ||
                const DeepCollectionEquality()
                    .equals(other.additional, additional)) &&
            (identical(other.requiredDeliveryInformation, requiredDeliveryInformation) ||
                const DeepCollectionEquality().equals(
                    other.requiredDeliveryInformation,
                    requiredDeliveryInformation)) &&
            (identical(other.orderNb, orderNb) ||
                const DeepCollectionEquality()
                    .equals(other.orderNb, orderNb)) &&
            (identical(other.alias, alias) ||
                const DeepCollectionEquality().equals(other.alias, alias)) &&
            (identical(other.prices, prices) ||
                const DeepCollectionEquality().equals(other.prices, prices)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.deliveryAreas, deliveryAreas) ||
                const DeepCollectionEquality()
                    .equals(other.deliveryAreas, deliveryAreas)) &&
            (identical(other.businessIds, businessIds) ||
                const DeepCollectionEquality().equals(other.businessIds, businessIds)) &&
            (identical(other.defaultOption, defaultOption) || const DeepCollectionEquality().equals(other.defaultOption, defaultOption)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(nameForPartner) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(deliveryArea) ^
      const DeepCollectionEquality().hash(deliveryFrequencyInterval) ^
      const DeepCollectionEquality().hash(deliveryTime) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(additional) ^
      const DeepCollectionEquality().hash(requiredDeliveryInformation) ^
      const DeepCollectionEquality().hash(orderNb) ^
      const DeepCollectionEquality().hash(alias) ^
      const DeepCollectionEquality().hash(prices) ^
      const DeepCollectionEquality().hash(features) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(deliveryAreas) ^
      const DeepCollectionEquality().hash(businessIds) ^
      const DeepCollectionEquality().hash(defaultOption) ^
      runtimeType.hashCode;
}

extension $ServiceOptionExtension on ServiceOption {
  ServiceOption copyWith(
      {num? id,
      num? serviceId,
      String? name,
      String? nameForPartner,
      String? description,
      String? shortDescription,
      String? deliveryArea,
      String? deliveryFrequencyInterval,
      String? deliveryTime,
      String? imageUrl,
      bool? active,
      bool? additional,
      bool? requiredDeliveryInformation,
      int? orderNb,
      String? alias,
      List<PriceOption>? prices,
      List<OptionFeature>? features,
      List<Image>? images,
      List<BoundingArea>? deliveryAreas,
      List<String>? businessIds,
      bool? defaultOption}) {
    return ServiceOption(
        id: id ?? this.id,
        serviceId: serviceId ?? this.serviceId,
        name: name ?? this.name,
        nameForPartner: nameForPartner ?? this.nameForPartner,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        deliveryArea: deliveryArea ?? this.deliveryArea,
        deliveryFrequencyInterval:
            deliveryFrequencyInterval ?? this.deliveryFrequencyInterval,
        deliveryTime: deliveryTime ?? this.deliveryTime,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        additional: additional ?? this.additional,
        requiredDeliveryInformation:
            requiredDeliveryInformation ?? this.requiredDeliveryInformation,
        orderNb: orderNb ?? this.orderNb,
        alias: alias ?? this.alias,
        prices: prices ?? this.prices,
        features: features ?? this.features,
        images: images ?? this.images,
        deliveryAreas: deliveryAreas ?? this.deliveryAreas,
        businessIds: businessIds ?? this.businessIds,
        defaultOption: defaultOption ?? this.defaultOption);
  }

  ServiceOption copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<num?>? serviceId,
      Wrapped<String>? name,
      Wrapped<String?>? nameForPartner,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? deliveryArea,
      Wrapped<String?>? deliveryFrequencyInterval,
      Wrapped<String?>? deliveryTime,
      Wrapped<String?>? imageUrl,
      Wrapped<bool?>? active,
      Wrapped<bool?>? additional,
      Wrapped<bool?>? requiredDeliveryInformation,
      Wrapped<int?>? orderNb,
      Wrapped<String?>? alias,
      Wrapped<List<PriceOption>?>? prices,
      Wrapped<List<OptionFeature>?>? features,
      Wrapped<List<Image>?>? images,
      Wrapped<List<BoundingArea>?>? deliveryAreas,
      Wrapped<List<String>?>? businessIds,
      Wrapped<bool?>? defaultOption}) {
    return ServiceOption(
        id: (id != null ? id.value : this.id),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        name: (name != null ? name.value : this.name),
        nameForPartner: (nameForPartner != null
            ? nameForPartner.value
            : this.nameForPartner),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        deliveryArea:
            (deliveryArea != null ? deliveryArea.value : this.deliveryArea),
        deliveryFrequencyInterval: (deliveryFrequencyInterval != null
            ? deliveryFrequencyInterval.value
            : this.deliveryFrequencyInterval),
        deliveryTime:
            (deliveryTime != null ? deliveryTime.value : this.deliveryTime),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        additional: (additional != null ? additional.value : this.additional),
        requiredDeliveryInformation: (requiredDeliveryInformation != null
            ? requiredDeliveryInformation.value
            : this.requiredDeliveryInformation),
        orderNb: (orderNb != null ? orderNb.value : this.orderNb),
        alias: (alias != null ? alias.value : this.alias),
        prices: (prices != null ? prices.value : this.prices),
        features: (features != null ? features.value : this.features),
        images: (images != null ? images.value : this.images),
        deliveryAreas:
            (deliveryAreas != null ? deliveryAreas.value : this.deliveryAreas),
        businessIds:
            (businessIds != null ? businessIds.value : this.businessIds),
        defaultOption:
            (defaultOption != null ? defaultOption.value : this.defaultOption));
  }
}

typedef ServiceOptions = List<ServiceOption>;

@JsonSerializable(explicitToJson: true)
class ServiceOptionsPage {
  ServiceOptionsPage({
    this.serviceOptions,
  });

  factory ServiceOptionsPage.fromJson(Map<String, dynamic> json) =>
      _$ServiceOptionsPageFromJson(json);

  @JsonKey(name: 'serviceOptions', includeIfNull: false)
  final List<ServiceOption>? serviceOptions;
  static const fromJsonFactory = _$ServiceOptionsPageFromJson;
  static const toJsonFactory = _$ServiceOptionsPageToJson;
  Map<String, dynamic> toJson() => _$ServiceOptionsPageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceOptionsPage &&
            (identical(other.serviceOptions, serviceOptions) ||
                const DeepCollectionEquality()
                    .equals(other.serviceOptions, serviceOptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(serviceOptions) ^
      runtimeType.hashCode;
}

extension $ServiceOptionsPageExtension on ServiceOptionsPage {
  ServiceOptionsPage copyWith({List<ServiceOption>? serviceOptions}) {
    return ServiceOptionsPage(
        serviceOptions: serviceOptions ?? this.serviceOptions);
  }

  ServiceOptionsPage copyWithWrapped(
      {Wrapped<List<ServiceOption>?>? serviceOptions}) {
    return ServiceOptionsPage(
        serviceOptions: (serviceOptions != null
            ? serviceOptions.value
            : this.serviceOptions));
  }
}

@JsonSerializable(explicitToJson: true)
class PriceOption {
  PriceOption({
    this.id,
    this.simplrServiceOptionId,
    this.period,
    this.intervalCount,
    this.intervalUsageType,
    this.basePrice,
    required this.amount,
    required this.active,
    this.deleted,
    this.minimumMembershipPeriod,
    this.originalAmount,
    this.minimumMembershipPeriodDiscount,
    this.basePriceDiscount,
    this.discounts,
    this.keepProduct,
    this.redirectUrl,
    this.depositAmount,
    this.alias,
    this.priceWithTax,
    this.priceWithTaxDiscounted,
    this.shipmentWithTax,
    this.finalPriceWithTax,
    this.finalPriceWithTaxDiscounted,
    this.serviceDeliveryType,
    this.businessIds,
  });

  factory PriceOption.fromJson(Map<String, dynamic> json) =>
      _$PriceOptionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'simplrServiceOptionId', includeIfNull: false)
  final num? simplrServiceOptionId;
  @JsonKey(
    name: 'period',
    includeIfNull: false,
    toJson: pricePeriodToJson,
    fromJson: pricePeriodFromJson,
  )
  final enums.PricePeriod? period;
  @JsonKey(name: 'intervalCount', includeIfNull: false)
  final int? intervalCount;
  @JsonKey(
    name: 'intervalUsageType',
    includeIfNull: false,
    toJson: usageTypeToJson,
    fromJson: usageTypeFromJson,
  )
  final enums.UsageType? intervalUsageType;
  @JsonKey(name: 'basePrice', includeIfNull: false)
  final double? basePrice;
  @JsonKey(name: 'amount', includeIfNull: false)
  final double amount;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: false)
  final bool active;
  @JsonKey(name: 'deleted', includeIfNull: false, defaultValue: false)
  final bool? deleted;
  @JsonKey(name: 'minimumMembershipPeriod', includeIfNull: false)
  final int? minimumMembershipPeriod;
  @JsonKey(name: 'originalAmount', includeIfNull: false)
  final double? originalAmount;
  @JsonKey(name: 'minimumMembershipPeriodDiscount', includeIfNull: false)
  final double? minimumMembershipPeriodDiscount;
  @JsonKey(name: 'basePriceDiscount', includeIfNull: false)
  final double? basePriceDiscount;
  @JsonKey(name: 'discounts', includeIfNull: false)
  final List<Discount>? discounts;
  @JsonKey(name: 'keepProduct', includeIfNull: false, defaultValue: false)
  final bool? keepProduct;
  @JsonKey(name: 'redirectUrl', includeIfNull: false, defaultValue: '')
  final String? redirectUrl;
  @JsonKey(name: 'depositAmount', includeIfNull: false)
  final double? depositAmount;
  @JsonKey(name: 'alias', includeIfNull: false, defaultValue: '')
  final String? alias;
  @JsonKey(name: 'priceWithTax', includeIfNull: false)
  final double? priceWithTax;
  @JsonKey(name: 'priceWithTaxDiscounted', includeIfNull: false)
  final double? priceWithTaxDiscounted;
  @JsonKey(name: 'shipmentWithTax', includeIfNull: false)
  final double? shipmentWithTax;
  @JsonKey(name: 'finalPriceWithTax', includeIfNull: false)
  final double? finalPriceWithTax;
  @JsonKey(name: 'finalPriceWithTaxDiscounted', includeIfNull: false)
  final double? finalPriceWithTaxDiscounted;
  @JsonKey(
    name: 'serviceDeliveryType',
    includeIfNull: false,
    toJson: deliveryTypeEnumToJson,
    fromJson: deliveryTypeEnumFromJson,
  )
  final enums.DeliveryTypeEnum? serviceDeliveryType;
  @JsonKey(name: 'businessIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? businessIds;
  static const fromJsonFactory = _$PriceOptionFromJson;
  static const toJsonFactory = _$PriceOptionToJson;
  Map<String, dynamic> toJson() => _$PriceOptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PriceOption &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.simplrServiceOptionId, simplrServiceOptionId) ||
                const DeepCollectionEquality().equals(
                    other.simplrServiceOptionId, simplrServiceOptionId)) &&
            (identical(other.period, period) ||
                const DeepCollectionEquality().equals(other.period, period)) &&
            (identical(other.intervalCount, intervalCount) ||
                const DeepCollectionEquality()
                    .equals(other.intervalCount, intervalCount)) &&
            (identical(other.intervalUsageType, intervalUsageType) ||
                const DeepCollectionEquality()
                    .equals(other.intervalUsageType, intervalUsageType)) &&
            (identical(other.basePrice, basePrice) ||
                const DeepCollectionEquality()
                    .equals(other.basePrice, basePrice)) &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.deleted, deleted) ||
                const DeepCollectionEquality()
                    .equals(other.deleted, deleted)) &&
            (identical(other.minimumMembershipPeriod, minimumMembershipPeriod) ||
                const DeepCollectionEquality().equals(
                    other.minimumMembershipPeriod, minimumMembershipPeriod)) &&
            (identical(other.originalAmount, originalAmount) ||
                const DeepCollectionEquality()
                    .equals(other.originalAmount, originalAmount)) &&
            (identical(other.minimumMembershipPeriodDiscount, minimumMembershipPeriodDiscount) ||
                const DeepCollectionEquality().equals(
                    other.minimumMembershipPeriodDiscount,
                    minimumMembershipPeriodDiscount)) &&
            (identical(other.basePriceDiscount, basePriceDiscount) ||
                const DeepCollectionEquality()
                    .equals(other.basePriceDiscount, basePriceDiscount)) &&
            (identical(other.discounts, discounts) ||
                const DeepCollectionEquality()
                    .equals(other.discounts, discounts)) &&
            (identical(other.keepProduct, keepProduct) ||
                const DeepCollectionEquality()
                    .equals(other.keepProduct, keepProduct)) &&
            (identical(other.redirectUrl, redirectUrl) ||
                const DeepCollectionEquality()
                    .equals(other.redirectUrl, redirectUrl)) &&
            (identical(other.depositAmount, depositAmount) ||
                const DeepCollectionEquality()
                    .equals(other.depositAmount, depositAmount)) &&
            (identical(other.alias, alias) ||
                const DeepCollectionEquality().equals(other.alias, alias)) &&
            (identical(other.priceWithTax, priceWithTax) ||
                const DeepCollectionEquality()
                    .equals(other.priceWithTax, priceWithTax)) &&
            (identical(other.priceWithTaxDiscounted, priceWithTaxDiscounted) || const DeepCollectionEquality().equals(other.priceWithTaxDiscounted, priceWithTaxDiscounted)) &&
            (identical(other.shipmentWithTax, shipmentWithTax) || const DeepCollectionEquality().equals(other.shipmentWithTax, shipmentWithTax)) &&
            (identical(other.finalPriceWithTax, finalPriceWithTax) || const DeepCollectionEquality().equals(other.finalPriceWithTax, finalPriceWithTax)) &&
            (identical(other.finalPriceWithTaxDiscounted, finalPriceWithTaxDiscounted) || const DeepCollectionEquality().equals(other.finalPriceWithTaxDiscounted, finalPriceWithTaxDiscounted)) &&
            (identical(other.serviceDeliveryType, serviceDeliveryType) || const DeepCollectionEquality().equals(other.serviceDeliveryType, serviceDeliveryType)) &&
            (identical(other.businessIds, businessIds) || const DeepCollectionEquality().equals(other.businessIds, businessIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(simplrServiceOptionId) ^
      const DeepCollectionEquality().hash(period) ^
      const DeepCollectionEquality().hash(intervalCount) ^
      const DeepCollectionEquality().hash(intervalUsageType) ^
      const DeepCollectionEquality().hash(basePrice) ^
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(deleted) ^
      const DeepCollectionEquality().hash(minimumMembershipPeriod) ^
      const DeepCollectionEquality().hash(originalAmount) ^
      const DeepCollectionEquality().hash(minimumMembershipPeriodDiscount) ^
      const DeepCollectionEquality().hash(basePriceDiscount) ^
      const DeepCollectionEquality().hash(discounts) ^
      const DeepCollectionEquality().hash(keepProduct) ^
      const DeepCollectionEquality().hash(redirectUrl) ^
      const DeepCollectionEquality().hash(depositAmount) ^
      const DeepCollectionEquality().hash(alias) ^
      const DeepCollectionEquality().hash(priceWithTax) ^
      const DeepCollectionEquality().hash(priceWithTaxDiscounted) ^
      const DeepCollectionEquality().hash(shipmentWithTax) ^
      const DeepCollectionEquality().hash(finalPriceWithTax) ^
      const DeepCollectionEquality().hash(finalPriceWithTaxDiscounted) ^
      const DeepCollectionEquality().hash(serviceDeliveryType) ^
      const DeepCollectionEquality().hash(businessIds) ^
      runtimeType.hashCode;
}

extension $PriceOptionExtension on PriceOption {
  PriceOption copyWith(
      {num? id,
      num? simplrServiceOptionId,
      enums.PricePeriod? period,
      int? intervalCount,
      enums.UsageType? intervalUsageType,
      double? basePrice,
      double? amount,
      bool? active,
      bool? deleted,
      int? minimumMembershipPeriod,
      double? originalAmount,
      double? minimumMembershipPeriodDiscount,
      double? basePriceDiscount,
      List<Discount>? discounts,
      bool? keepProduct,
      String? redirectUrl,
      double? depositAmount,
      String? alias,
      double? priceWithTax,
      double? priceWithTaxDiscounted,
      double? shipmentWithTax,
      double? finalPriceWithTax,
      double? finalPriceWithTaxDiscounted,
      enums.DeliveryTypeEnum? serviceDeliveryType,
      List<String>? businessIds}) {
    return PriceOption(
        id: id ?? this.id,
        simplrServiceOptionId:
            simplrServiceOptionId ?? this.simplrServiceOptionId,
        period: period ?? this.period,
        intervalCount: intervalCount ?? this.intervalCount,
        intervalUsageType: intervalUsageType ?? this.intervalUsageType,
        basePrice: basePrice ?? this.basePrice,
        amount: amount ?? this.amount,
        active: active ?? this.active,
        deleted: deleted ?? this.deleted,
        minimumMembershipPeriod:
            minimumMembershipPeriod ?? this.minimumMembershipPeriod,
        originalAmount: originalAmount ?? this.originalAmount,
        minimumMembershipPeriodDiscount: minimumMembershipPeriodDiscount ??
            this.minimumMembershipPeriodDiscount,
        basePriceDiscount: basePriceDiscount ?? this.basePriceDiscount,
        discounts: discounts ?? this.discounts,
        keepProduct: keepProduct ?? this.keepProduct,
        redirectUrl: redirectUrl ?? this.redirectUrl,
        depositAmount: depositAmount ?? this.depositAmount,
        alias: alias ?? this.alias,
        priceWithTax: priceWithTax ?? this.priceWithTax,
        priceWithTaxDiscounted:
            priceWithTaxDiscounted ?? this.priceWithTaxDiscounted,
        shipmentWithTax: shipmentWithTax ?? this.shipmentWithTax,
        finalPriceWithTax: finalPriceWithTax ?? this.finalPriceWithTax,
        finalPriceWithTaxDiscounted:
            finalPriceWithTaxDiscounted ?? this.finalPriceWithTaxDiscounted,
        serviceDeliveryType: serviceDeliveryType ?? this.serviceDeliveryType,
        businessIds: businessIds ?? this.businessIds);
  }

  PriceOption copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<num?>? simplrServiceOptionId,
      Wrapped<enums.PricePeriod?>? period,
      Wrapped<int?>? intervalCount,
      Wrapped<enums.UsageType?>? intervalUsageType,
      Wrapped<double?>? basePrice,
      Wrapped<double>? amount,
      Wrapped<bool>? active,
      Wrapped<bool?>? deleted,
      Wrapped<int?>? minimumMembershipPeriod,
      Wrapped<double?>? originalAmount,
      Wrapped<double?>? minimumMembershipPeriodDiscount,
      Wrapped<double?>? basePriceDiscount,
      Wrapped<List<Discount>?>? discounts,
      Wrapped<bool?>? keepProduct,
      Wrapped<String?>? redirectUrl,
      Wrapped<double?>? depositAmount,
      Wrapped<String?>? alias,
      Wrapped<double?>? priceWithTax,
      Wrapped<double?>? priceWithTaxDiscounted,
      Wrapped<double?>? shipmentWithTax,
      Wrapped<double?>? finalPriceWithTax,
      Wrapped<double?>? finalPriceWithTaxDiscounted,
      Wrapped<enums.DeliveryTypeEnum?>? serviceDeliveryType,
      Wrapped<List<String>?>? businessIds}) {
    return PriceOption(
        id: (id != null ? id.value : this.id),
        simplrServiceOptionId: (simplrServiceOptionId != null
            ? simplrServiceOptionId.value
            : this.simplrServiceOptionId),
        period: (period != null ? period.value : this.period),
        intervalCount:
            (intervalCount != null ? intervalCount.value : this.intervalCount),
        intervalUsageType: (intervalUsageType != null
            ? intervalUsageType.value
            : this.intervalUsageType),
        basePrice: (basePrice != null ? basePrice.value : this.basePrice),
        amount: (amount != null ? amount.value : this.amount),
        active: (active != null ? active.value : this.active),
        deleted: (deleted != null ? deleted.value : this.deleted),
        minimumMembershipPeriod: (minimumMembershipPeriod != null
            ? minimumMembershipPeriod.value
            : this.minimumMembershipPeriod),
        originalAmount: (originalAmount != null
            ? originalAmount.value
            : this.originalAmount),
        minimumMembershipPeriodDiscount:
            (minimumMembershipPeriodDiscount != null
                ? minimumMembershipPeriodDiscount.value
                : this.minimumMembershipPeriodDiscount),
        basePriceDiscount: (basePriceDiscount != null
            ? basePriceDiscount.value
            : this.basePriceDiscount),
        discounts: (discounts != null ? discounts.value : this.discounts),
        keepProduct:
            (keepProduct != null ? keepProduct.value : this.keepProduct),
        redirectUrl:
            (redirectUrl != null ? redirectUrl.value : this.redirectUrl),
        depositAmount:
            (depositAmount != null ? depositAmount.value : this.depositAmount),
        alias: (alias != null ? alias.value : this.alias),
        priceWithTax:
            (priceWithTax != null ? priceWithTax.value : this.priceWithTax),
        priceWithTaxDiscounted: (priceWithTaxDiscounted != null
            ? priceWithTaxDiscounted.value
            : this.priceWithTaxDiscounted),
        shipmentWithTax: (shipmentWithTax != null
            ? shipmentWithTax.value
            : this.shipmentWithTax),
        finalPriceWithTax: (finalPriceWithTax != null
            ? finalPriceWithTax.value
            : this.finalPriceWithTax),
        finalPriceWithTaxDiscounted: (finalPriceWithTaxDiscounted != null
            ? finalPriceWithTaxDiscounted.value
            : this.finalPriceWithTaxDiscounted),
        serviceDeliveryType: (serviceDeliveryType != null
            ? serviceDeliveryType.value
            : this.serviceDeliveryType),
        businessIds:
            (businessIds != null ? businessIds.value : this.businessIds));
  }
}

typedef PriceOptions = List<PriceOption>;

@JsonSerializable(explicitToJson: true)
class OptionFeature {
  OptionFeature({
    this.id,
    this.description,
    this.shortDescription,
    this.orderNb,
  });

  factory OptionFeature.fromJson(Map<String, dynamic> json) =>
      _$OptionFeatureFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'orderNb', includeIfNull: false)
  final int? orderNb;
  static const fromJsonFactory = _$OptionFeatureFromJson;
  static const toJsonFactory = _$OptionFeatureToJson;
  Map<String, dynamic> toJson() => _$OptionFeatureToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OptionFeature &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.orderNb, orderNb) ||
                const DeepCollectionEquality().equals(other.orderNb, orderNb)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(orderNb) ^
      runtimeType.hashCode;
}

extension $OptionFeatureExtension on OptionFeature {
  OptionFeature copyWith(
      {num? id, String? description, String? shortDescription, int? orderNb}) {
    return OptionFeature(
        id: id ?? this.id,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        orderNb: orderNb ?? this.orderNb);
  }

  OptionFeature copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription,
      Wrapped<int?>? orderNb}) {
    return OptionFeature(
        id: (id != null ? id.value : this.id),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        orderNb: (orderNb != null ? orderNb.value : this.orderNb));
  }
}

typedef OptionFeatures = List<OptionFeature>;

@JsonSerializable(explicitToJson: true)
class ServiceCategory {
  ServiceCategory({
    this.id,
    this.name,
    this.description,
    this.titleCarousel,
    this.parentId,
    this.children,
    this.enabled,
    this.imageUrl,
    this.imageUrlDesktop,
    this.imageUrlMobile,
    this.bgColor,
    this.orderNb,
  });

  factory ServiceCategory.fromJson(Map<String, dynamic> json) =>
      _$ServiceCategoryFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'titleCarousel', includeIfNull: false, defaultValue: '')
  final String? titleCarousel;
  @JsonKey(name: 'parentId', includeIfNull: false)
  final num? parentId;
  @JsonKey(name: 'children', includeIfNull: false)
  final List<ServiceCategory>? children;
  @JsonKey(name: 'enabled', includeIfNull: false)
  final bool? enabled;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  @JsonKey(name: 'imageUrlDesktop', includeIfNull: false, defaultValue: '')
  final String? imageUrlDesktop;
  @JsonKey(name: 'imageUrlMobile', includeIfNull: false, defaultValue: '')
  final String? imageUrlMobile;
  @JsonKey(name: 'bgColor', includeIfNull: false, defaultValue: '')
  final String? bgColor;
  @JsonKey(name: 'orderNb', includeIfNull: false)
  final int? orderNb;
  static const fromJsonFactory = _$ServiceCategoryFromJson;
  static const toJsonFactory = _$ServiceCategoryToJson;
  Map<String, dynamic> toJson() => _$ServiceCategoryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceCategory &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.titleCarousel, titleCarousel) ||
                const DeepCollectionEquality()
                    .equals(other.titleCarousel, titleCarousel)) &&
            (identical(other.parentId, parentId) ||
                const DeepCollectionEquality()
                    .equals(other.parentId, parentId)) &&
            (identical(other.children, children) ||
                const DeepCollectionEquality()
                    .equals(other.children, children)) &&
            (identical(other.enabled, enabled) ||
                const DeepCollectionEquality()
                    .equals(other.enabled, enabled)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.imageUrlDesktop, imageUrlDesktop) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrlDesktop, imageUrlDesktop)) &&
            (identical(other.imageUrlMobile, imageUrlMobile) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrlMobile, imageUrlMobile)) &&
            (identical(other.bgColor, bgColor) ||
                const DeepCollectionEquality()
                    .equals(other.bgColor, bgColor)) &&
            (identical(other.orderNb, orderNb) ||
                const DeepCollectionEquality().equals(other.orderNb, orderNb)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(titleCarousel) ^
      const DeepCollectionEquality().hash(parentId) ^
      const DeepCollectionEquality().hash(children) ^
      const DeepCollectionEquality().hash(enabled) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(imageUrlDesktop) ^
      const DeepCollectionEquality().hash(imageUrlMobile) ^
      const DeepCollectionEquality().hash(bgColor) ^
      const DeepCollectionEquality().hash(orderNb) ^
      runtimeType.hashCode;
}

extension $ServiceCategoryExtension on ServiceCategory {
  ServiceCategory copyWith(
      {num? id,
      String? name,
      String? description,
      String? titleCarousel,
      num? parentId,
      List<ServiceCategory>? children,
      bool? enabled,
      String? imageUrl,
      String? imageUrlDesktop,
      String? imageUrlMobile,
      String? bgColor,
      int? orderNb}) {
    return ServiceCategory(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        titleCarousel: titleCarousel ?? this.titleCarousel,
        parentId: parentId ?? this.parentId,
        children: children ?? this.children,
        enabled: enabled ?? this.enabled,
        imageUrl: imageUrl ?? this.imageUrl,
        imageUrlDesktop: imageUrlDesktop ?? this.imageUrlDesktop,
        imageUrlMobile: imageUrlMobile ?? this.imageUrlMobile,
        bgColor: bgColor ?? this.bgColor,
        orderNb: orderNb ?? this.orderNb);
  }

  ServiceCategory copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? titleCarousel,
      Wrapped<num?>? parentId,
      Wrapped<List<ServiceCategory>?>? children,
      Wrapped<bool?>? enabled,
      Wrapped<String?>? imageUrl,
      Wrapped<String?>? imageUrlDesktop,
      Wrapped<String?>? imageUrlMobile,
      Wrapped<String?>? bgColor,
      Wrapped<int?>? orderNb}) {
    return ServiceCategory(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        titleCarousel:
            (titleCarousel != null ? titleCarousel.value : this.titleCarousel),
        parentId: (parentId != null ? parentId.value : this.parentId),
        children: (children != null ? children.value : this.children),
        enabled: (enabled != null ? enabled.value : this.enabled),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        imageUrlDesktop: (imageUrlDesktop != null
            ? imageUrlDesktop.value
            : this.imageUrlDesktop),
        imageUrlMobile: (imageUrlMobile != null
            ? imageUrlMobile.value
            : this.imageUrlMobile),
        bgColor: (bgColor != null ? bgColor.value : this.bgColor),
        orderNb: (orderNb != null ? orderNb.value : this.orderNb));
  }
}

typedef ServiceCategories = List<ServiceCategory>;

@JsonSerializable(explicitToJson: true)
class ServiceCategoryCriteria {
  ServiceCategoryCriteria({
    this.parentId,
    this.onlyServicesActive,
    this.enabled,
  });

  factory ServiceCategoryCriteria.fromJson(Map<String, dynamic> json) =>
      _$ServiceCategoryCriteriaFromJson(json);

  @JsonKey(name: 'parentId', includeIfNull: false)
  final LongFilter? parentId;
  @JsonKey(
      name: 'onlyServicesActive', includeIfNull: false, defaultValue: false)
  final bool? onlyServicesActive;
  @JsonKey(name: 'enabled', includeIfNull: false)
  final BooleanFilter? enabled;
  static const fromJsonFactory = _$ServiceCategoryCriteriaFromJson;
  static const toJsonFactory = _$ServiceCategoryCriteriaToJson;
  Map<String, dynamic> toJson() => _$ServiceCategoryCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceCategoryCriteria &&
            (identical(other.parentId, parentId) ||
                const DeepCollectionEquality()
                    .equals(other.parentId, parentId)) &&
            (identical(other.onlyServicesActive, onlyServicesActive) ||
                const DeepCollectionEquality()
                    .equals(other.onlyServicesActive, onlyServicesActive)) &&
            (identical(other.enabled, enabled) ||
                const DeepCollectionEquality().equals(other.enabled, enabled)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(parentId) ^
      const DeepCollectionEquality().hash(onlyServicesActive) ^
      const DeepCollectionEquality().hash(enabled) ^
      runtimeType.hashCode;
}

extension $ServiceCategoryCriteriaExtension on ServiceCategoryCriteria {
  ServiceCategoryCriteria copyWith(
      {LongFilter? parentId,
      bool? onlyServicesActive,
      BooleanFilter? enabled}) {
    return ServiceCategoryCriteria(
        parentId: parentId ?? this.parentId,
        onlyServicesActive: onlyServicesActive ?? this.onlyServicesActive,
        enabled: enabled ?? this.enabled);
  }

  ServiceCategoryCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? parentId,
      Wrapped<bool?>? onlyServicesActive,
      Wrapped<BooleanFilter?>? enabled}) {
    return ServiceCategoryCriteria(
        parentId: (parentId != null ? parentId.value : this.parentId),
        onlyServicesActive: (onlyServicesActive != null
            ? onlyServicesActive.value
            : this.onlyServicesActive),
        enabled: (enabled != null ? enabled.value : this.enabled));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceType {
  ServiceType({
    this.id,
    this.serviceTypeGroup,
    this.status,
    this.name,
    this.code,
    this.imageUrl,
  });

  factory ServiceType.fromJson(Map<String, dynamic> json) =>
      _$ServiceTypeFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(
    name: 'serviceTypeGroup',
    includeIfNull: false,
    toJson: serviceTypeGroupToJson,
    fromJson: serviceTypeGroupFromJson,
  )
  final enums.ServiceTypeGroup? serviceTypeGroup;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: serviceTypeStatusToJson,
    fromJson: serviceTypeStatusFromJson,
  )
  final enums.ServiceTypeStatus? status;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String? code;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  static const fromJsonFactory = _$ServiceTypeFromJson;
  static const toJsonFactory = _$ServiceTypeToJson;
  Map<String, dynamic> toJson() => _$ServiceTypeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceType &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.serviceTypeGroup, serviceTypeGroup) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypeGroup, serviceTypeGroup)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(serviceTypeGroup) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      runtimeType.hashCode;
}

extension $ServiceTypeExtension on ServiceType {
  ServiceType copyWith(
      {num? id,
      enums.ServiceTypeGroup? serviceTypeGroup,
      enums.ServiceTypeStatus? status,
      String? name,
      String? code,
      String? imageUrl}) {
    return ServiceType(
        id: id ?? this.id,
        serviceTypeGroup: serviceTypeGroup ?? this.serviceTypeGroup,
        status: status ?? this.status,
        name: name ?? this.name,
        code: code ?? this.code,
        imageUrl: imageUrl ?? this.imageUrl);
  }

  ServiceType copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<enums.ServiceTypeGroup?>? serviceTypeGroup,
      Wrapped<enums.ServiceTypeStatus?>? status,
      Wrapped<String?>? name,
      Wrapped<String?>? code,
      Wrapped<String?>? imageUrl}) {
    return ServiceType(
        id: (id != null ? id.value : this.id),
        serviceTypeGroup: (serviceTypeGroup != null
            ? serviceTypeGroup.value
            : this.serviceTypeGroup),
        status: (status != null ? status.value : this.status),
        name: (name != null ? name.value : this.name),
        code: (code != null ? code.value : this.code),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceTypes {
  ServiceTypes({
    this.serviceTypes,
  });

  factory ServiceTypes.fromJson(Map<String, dynamic> json) =>
      _$ServiceTypesFromJson(json);

  @JsonKey(
      name: 'serviceTypes', includeIfNull: false, defaultValue: <ServiceType>[])
  final List<ServiceType>? serviceTypes;
  static const fromJsonFactory = _$ServiceTypesFromJson;
  static const toJsonFactory = _$ServiceTypesToJson;
  Map<String, dynamic> toJson() => _$ServiceTypesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceTypes &&
            (identical(other.serviceTypes, serviceTypes) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypes, serviceTypes)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(serviceTypes) ^ runtimeType.hashCode;
}

extension $ServiceTypesExtension on ServiceTypes {
  ServiceTypes copyWith({List<ServiceType>? serviceTypes}) {
    return ServiceTypes(serviceTypes: serviceTypes ?? this.serviceTypes);
  }

  ServiceTypes copyWithWrapped({Wrapped<List<ServiceType>?>? serviceTypes}) {
    return ServiceTypes(
        serviceTypes:
            (serviceTypes != null ? serviceTypes.value : this.serviceTypes));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrService {
  SimplrService({
    this.id,
    this.name,
    this.description,
    this.shortDescription,
    this.profileOwner,
    this.accessInstructions,
    this.variationLabel,
    this.imageUrl,
    this.active,
    this.revenueShare,
    this.partnerId,
    this.rating,
    this.partner,
    this.serviceCategories,
    this.fromPrice,
    this.defaultServiceOption,
    this.requiresInstructions,
    this.requiresCredentials,
    this.images,
    this.searchInfo,
    this.redirect,
    this.deliveryAreas,
    this.shipmentAmount,
    this.taxType,
    this.deliveryType,
    this.proratedDelivery,
    this.type,
    this.marketId,
    this.businessIds,
  });

  factory SimplrService.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'profileOwner', includeIfNull: false, defaultValue: '')
  final String? profileOwner;
  @JsonKey(name: 'accessInstructions', includeIfNull: false, defaultValue: '')
  final String? accessInstructions;
  @JsonKey(name: 'variationLabel', includeIfNull: false, defaultValue: '')
  final String? variationLabel;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  @JsonKey(name: 'revenueShare', includeIfNull: false)
  final double? revenueShare;
  @JsonKey(name: 'partnerId', includeIfNull: false)
  final num? partnerId;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  @JsonKey(name: 'partner', includeIfNull: false)
  final Partner? partner;
  @JsonKey(name: 'serviceCategories', includeIfNull: false)
  final List<ServiceCategory>? serviceCategories;
  @JsonKey(name: 'fromPrice', includeIfNull: false)
  final PriceOption? fromPrice;
  @JsonKey(name: 'defaultServiceOption', includeIfNull: false)
  final ServiceOption? defaultServiceOption;
  @JsonKey(name: 'requiresInstructions', includeIfNull: false)
  final bool? requiresInstructions;
  @JsonKey(name: 'requiresCredentials', includeIfNull: false)
  final bool? requiresCredentials;
  @JsonKey(name: 'images', includeIfNull: false)
  final List<Image>? images;
  @JsonKey(name: 'searchInfo', includeIfNull: false)
  final SearchInfo? searchInfo;
  @JsonKey(name: 'redirect', includeIfNull: false, defaultValue: false)
  final bool? redirect;
  @JsonKey(name: 'deliveryAreas', includeIfNull: false)
  final List<BoundingArea>? deliveryAreas;
  @JsonKey(name: 'shipmentAmount', includeIfNull: false)
  final double? shipmentAmount;
  @JsonKey(
    name: 'taxType',
    includeIfNull: false,
    toJson: taxTypeEnumToJson,
    fromJson: taxTypeEnumFromJson,
  )
  final enums.TaxTypeEnum? taxType;
  @JsonKey(
    name: 'deliveryType',
    includeIfNull: false,
    toJson: deliveryTypeEnumToJson,
    fromJson: deliveryTypeEnumFromJson,
  )
  final enums.DeliveryTypeEnum? deliveryType;
  @JsonKey(name: 'proratedDelivery', includeIfNull: false)
  final bool? proratedDelivery;
  @JsonKey(name: 'type', includeIfNull: false)
  final ServiceType? type;
  @JsonKey(name: 'marketId', includeIfNull: false)
  final num? marketId;
  @JsonKey(name: 'businessIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? businessIds;
  static const fromJsonFactory = _$SimplrServiceFromJson;
  static const toJsonFactory = _$SimplrServiceToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrService &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.profileOwner, profileOwner) ||
                const DeepCollectionEquality()
                    .equals(other.profileOwner, profileOwner)) &&
            (identical(other.accessInstructions, accessInstructions) ||
                const DeepCollectionEquality()
                    .equals(other.accessInstructions, accessInstructions)) &&
            (identical(other.variationLabel, variationLabel) ||
                const DeepCollectionEquality()
                    .equals(other.variationLabel, variationLabel)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.revenueShare, revenueShare) ||
                const DeepCollectionEquality()
                    .equals(other.revenueShare, revenueShare)) &&
            (identical(other.partnerId, partnerId) ||
                const DeepCollectionEquality()
                    .equals(other.partnerId, partnerId)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.partner, partner) ||
                const DeepCollectionEquality()
                    .equals(other.partner, partner)) &&
            (identical(other.serviceCategories, serviceCategories) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategories, serviceCategories)) &&
            (identical(other.fromPrice, fromPrice) ||
                const DeepCollectionEquality()
                    .equals(other.fromPrice, fromPrice)) &&
            (identical(other.defaultServiceOption, defaultServiceOption) ||
                const DeepCollectionEquality().equals(
                    other.defaultServiceOption, defaultServiceOption)) &&
            (identical(other.requiresInstructions, requiresInstructions) ||
                const DeepCollectionEquality().equals(
                    other.requiresInstructions, requiresInstructions)) &&
            (identical(other.requiresCredentials, requiresCredentials) ||
                const DeepCollectionEquality()
                    .equals(other.requiresCredentials, requiresCredentials)) &&
            (identical(other.images, images) ||
                const DeepCollectionEquality().equals(other.images, images)) &&
            (identical(other.searchInfo, searchInfo) ||
                const DeepCollectionEquality()
                    .equals(other.searchInfo, searchInfo)) &&
            (identical(other.redirect, redirect) ||
                const DeepCollectionEquality()
                    .equals(other.redirect, redirect)) &&
            (identical(other.deliveryAreas, deliveryAreas) ||
                const DeepCollectionEquality()
                    .equals(other.deliveryAreas, deliveryAreas)) &&
            (identical(other.shipmentAmount, shipmentAmount) ||
                const DeepCollectionEquality()
                    .equals(other.shipmentAmount, shipmentAmount)) &&
            (identical(other.taxType, taxType) ||
                const DeepCollectionEquality().equals(other.taxType, taxType)) &&
            (identical(other.deliveryType, deliveryType) || const DeepCollectionEquality().equals(other.deliveryType, deliveryType)) &&
            (identical(other.proratedDelivery, proratedDelivery) || const DeepCollectionEquality().equals(other.proratedDelivery, proratedDelivery)) &&
            (identical(other.type, type) || const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.marketId, marketId) || const DeepCollectionEquality().equals(other.marketId, marketId)) &&
            (identical(other.businessIds, businessIds) || const DeepCollectionEquality().equals(other.businessIds, businessIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(profileOwner) ^
      const DeepCollectionEquality().hash(accessInstructions) ^
      const DeepCollectionEquality().hash(variationLabel) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(revenueShare) ^
      const DeepCollectionEquality().hash(partnerId) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(partner) ^
      const DeepCollectionEquality().hash(serviceCategories) ^
      const DeepCollectionEquality().hash(fromPrice) ^
      const DeepCollectionEquality().hash(defaultServiceOption) ^
      const DeepCollectionEquality().hash(requiresInstructions) ^
      const DeepCollectionEquality().hash(requiresCredentials) ^
      const DeepCollectionEquality().hash(images) ^
      const DeepCollectionEquality().hash(searchInfo) ^
      const DeepCollectionEquality().hash(redirect) ^
      const DeepCollectionEquality().hash(deliveryAreas) ^
      const DeepCollectionEquality().hash(shipmentAmount) ^
      const DeepCollectionEquality().hash(taxType) ^
      const DeepCollectionEquality().hash(deliveryType) ^
      const DeepCollectionEquality().hash(proratedDelivery) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(marketId) ^
      const DeepCollectionEquality().hash(businessIds) ^
      runtimeType.hashCode;
}

extension $SimplrServiceExtension on SimplrService {
  SimplrService copyWith(
      {num? id,
      String? name,
      String? description,
      String? shortDescription,
      String? profileOwner,
      String? accessInstructions,
      String? variationLabel,
      String? imageUrl,
      bool? active,
      double? revenueShare,
      num? partnerId,
      double? rating,
      Partner? partner,
      List<ServiceCategory>? serviceCategories,
      PriceOption? fromPrice,
      ServiceOption? defaultServiceOption,
      bool? requiresInstructions,
      bool? requiresCredentials,
      List<Image>? images,
      SearchInfo? searchInfo,
      bool? redirect,
      List<BoundingArea>? deliveryAreas,
      double? shipmentAmount,
      enums.TaxTypeEnum? taxType,
      enums.DeliveryTypeEnum? deliveryType,
      bool? proratedDelivery,
      ServiceType? type,
      num? marketId,
      List<String>? businessIds}) {
    return SimplrService(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        profileOwner: profileOwner ?? this.profileOwner,
        accessInstructions: accessInstructions ?? this.accessInstructions,
        variationLabel: variationLabel ?? this.variationLabel,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        revenueShare: revenueShare ?? this.revenueShare,
        partnerId: partnerId ?? this.partnerId,
        rating: rating ?? this.rating,
        partner: partner ?? this.partner,
        serviceCategories: serviceCategories ?? this.serviceCategories,
        fromPrice: fromPrice ?? this.fromPrice,
        defaultServiceOption: defaultServiceOption ?? this.defaultServiceOption,
        requiresInstructions: requiresInstructions ?? this.requiresInstructions,
        requiresCredentials: requiresCredentials ?? this.requiresCredentials,
        images: images ?? this.images,
        searchInfo: searchInfo ?? this.searchInfo,
        redirect: redirect ?? this.redirect,
        deliveryAreas: deliveryAreas ?? this.deliveryAreas,
        shipmentAmount: shipmentAmount ?? this.shipmentAmount,
        taxType: taxType ?? this.taxType,
        deliveryType: deliveryType ?? this.deliveryType,
        proratedDelivery: proratedDelivery ?? this.proratedDelivery,
        type: type ?? this.type,
        marketId: marketId ?? this.marketId,
        businessIds: businessIds ?? this.businessIds);
  }

  SimplrService copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? profileOwner,
      Wrapped<String?>? accessInstructions,
      Wrapped<String?>? variationLabel,
      Wrapped<String?>? imageUrl,
      Wrapped<bool?>? active,
      Wrapped<double?>? revenueShare,
      Wrapped<num?>? partnerId,
      Wrapped<double?>? rating,
      Wrapped<Partner?>? partner,
      Wrapped<List<ServiceCategory>?>? serviceCategories,
      Wrapped<PriceOption?>? fromPrice,
      Wrapped<ServiceOption?>? defaultServiceOption,
      Wrapped<bool?>? requiresInstructions,
      Wrapped<bool?>? requiresCredentials,
      Wrapped<List<Image>?>? images,
      Wrapped<SearchInfo?>? searchInfo,
      Wrapped<bool?>? redirect,
      Wrapped<List<BoundingArea>?>? deliveryAreas,
      Wrapped<double?>? shipmentAmount,
      Wrapped<enums.TaxTypeEnum?>? taxType,
      Wrapped<enums.DeliveryTypeEnum?>? deliveryType,
      Wrapped<bool?>? proratedDelivery,
      Wrapped<ServiceType?>? type,
      Wrapped<num?>? marketId,
      Wrapped<List<String>?>? businessIds}) {
    return SimplrService(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        profileOwner:
            (profileOwner != null ? profileOwner.value : this.profileOwner),
        accessInstructions: (accessInstructions != null
            ? accessInstructions.value
            : this.accessInstructions),
        variationLabel: (variationLabel != null
            ? variationLabel.value
            : this.variationLabel),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        revenueShare:
            (revenueShare != null ? revenueShare.value : this.revenueShare),
        partnerId: (partnerId != null ? partnerId.value : this.partnerId),
        rating: (rating != null ? rating.value : this.rating),
        partner: (partner != null ? partner.value : this.partner),
        serviceCategories: (serviceCategories != null
            ? serviceCategories.value
            : this.serviceCategories),
        fromPrice: (fromPrice != null ? fromPrice.value : this.fromPrice),
        defaultServiceOption: (defaultServiceOption != null
            ? defaultServiceOption.value
            : this.defaultServiceOption),
        requiresInstructions: (requiresInstructions != null
            ? requiresInstructions.value
            : this.requiresInstructions),
        requiresCredentials: (requiresCredentials != null
            ? requiresCredentials.value
            : this.requiresCredentials),
        images: (images != null ? images.value : this.images),
        searchInfo: (searchInfo != null ? searchInfo.value : this.searchInfo),
        redirect: (redirect != null ? redirect.value : this.redirect),
        deliveryAreas:
            (deliveryAreas != null ? deliveryAreas.value : this.deliveryAreas),
        shipmentAmount: (shipmentAmount != null
            ? shipmentAmount.value
            : this.shipmentAmount),
        taxType: (taxType != null ? taxType.value : this.taxType),
        deliveryType:
            (deliveryType != null ? deliveryType.value : this.deliveryType),
        proratedDelivery: (proratedDelivery != null
            ? proratedDelivery.value
            : this.proratedDelivery),
        type: (type != null ? type.value : this.type),
        marketId: (marketId != null ? marketId.value : this.marketId),
        businessIds:
            (businessIds != null ? businessIds.value : this.businessIds));
  }
}

typedef SimplrServices = List<SimplrService>;

@JsonSerializable(explicitToJson: true)
class SimplrServicesPage {
  SimplrServicesPage({
    this.services,
  });

  factory SimplrServicesPage.fromJson(Map<String, dynamic> json) =>
      _$SimplrServicesPageFromJson(json);

  @JsonKey(name: 'services', includeIfNull: false)
  final List<SimplrService>? services;
  static const fromJsonFactory = _$SimplrServicesPageFromJson;
  static const toJsonFactory = _$SimplrServicesPageToJson;
  Map<String, dynamic> toJson() => _$SimplrServicesPageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServicesPage &&
            (identical(other.services, services) ||
                const DeepCollectionEquality()
                    .equals(other.services, services)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(services) ^ runtimeType.hashCode;
}

extension $SimplrServicesPageExtension on SimplrServicesPage {
  SimplrServicesPage copyWith({List<SimplrService>? services}) {
    return SimplrServicesPage(services: services ?? this.services);
  }

  SimplrServicesPage copyWithWrapped(
      {Wrapped<List<SimplrService>?>? services}) {
    return SimplrServicesPage(
        services: (services != null ? services.value : this.services));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceTypeGroupFilter {
  ServiceTypeGroupFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory ServiceTypeGroupFilter.fromJson(Map<String, dynamic> json) =>
      _$ServiceTypeGroupFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$ServiceTypeGroupFilterFromJson;
  static const toJsonFactory = _$ServiceTypeGroupFilterToJson;
  Map<String, dynamic> toJson() => _$ServiceTypeGroupFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceTypeGroupFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $ServiceTypeGroupFilterExtension on ServiceTypeGroupFilter {
  ServiceTypeGroupFilter copyWith(
      {String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return ServiceTypeGroupFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  ServiceTypeGroupFilter copyWithWrapped(
      {Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return ServiceTypeGroupFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceTypeStatusFilter {
  ServiceTypeStatusFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory ServiceTypeStatusFilter.fromJson(Map<String, dynamic> json) =>
      _$ServiceTypeStatusFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$ServiceTypeStatusFilterFromJson;
  static const toJsonFactory = _$ServiceTypeStatusFilterToJson;
  Map<String, dynamic> toJson() => _$ServiceTypeStatusFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceTypeStatusFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $ServiceTypeStatusFilterExtension on ServiceTypeStatusFilter {
  ServiceTypeStatusFilter copyWith(
      {String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return ServiceTypeStatusFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  ServiceTypeStatusFilter copyWithWrapped(
      {Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return ServiceTypeStatusFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServiceCriteria {
  SimplrServiceCriteria({
    this.id,
    this.imageUrl,
    this.profileOwner,
    this.active,
    this.revenueShare,
    this.requiresInstructions,
    this.requiresCredentials,
    this.partnerId,
    this.partnerName,
    this.partnerEmail,
    this.serviceCategoryId,
    this.name,
    this.description,
    this.shortDescription,
    this.rating,
    this.globalSearch,
    this.taxType,
    this.serviceTypeId,
    this.serviceTypeGroup,
    this.serviceTypeStatus,
    this.serviceTypeCode,
  });

  factory SimplrServiceCriteria.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final StringFilter? imageUrl;
  @JsonKey(name: 'profileOwner', includeIfNull: false)
  final StringFilter? profileOwner;
  @JsonKey(name: 'active', includeIfNull: false)
  final BooleanFilter? active;
  @JsonKey(name: 'revenueShare', includeIfNull: false)
  final BigDecimalFilter? revenueShare;
  @JsonKey(name: 'requiresInstructions', includeIfNull: false)
  final BooleanFilter? requiresInstructions;
  @JsonKey(name: 'requiresCredentials', includeIfNull: false)
  final BooleanFilter? requiresCredentials;
  @JsonKey(name: 'partnerId', includeIfNull: false)
  final LongFilter? partnerId;
  @JsonKey(name: 'partnerName', includeIfNull: false)
  final StringFilter? partnerName;
  @JsonKey(name: 'partnerEmail', includeIfNull: false)
  final StringFilter? partnerEmail;
  @JsonKey(name: 'serviceCategoryId', includeIfNull: false)
  final LongFilter? serviceCategoryId;
  @JsonKey(name: 'name', includeIfNull: false)
  final StringFilter? name;
  @JsonKey(name: 'description', includeIfNull: false)
  final StringFilter? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false)
  final StringFilter? shortDescription;
  @JsonKey(name: 'rating', includeIfNull: false)
  final LongFilter? rating;
  @JsonKey(name: 'globalSearch', includeIfNull: false)
  final StringFilter? globalSearch;
  @JsonKey(name: 'taxType', includeIfNull: false)
  final TaxTypeFilter? taxType;
  @JsonKey(name: 'serviceTypeId', includeIfNull: false)
  final LongFilter? serviceTypeId;
  @JsonKey(name: 'serviceTypeGroup', includeIfNull: false)
  final ServiceTypeGroupFilter? serviceTypeGroup;
  @JsonKey(name: 'serviceTypeStatus', includeIfNull: false)
  final ServiceTypeGroupFilter? serviceTypeStatus;
  @JsonKey(name: 'serviceTypeCode', includeIfNull: false)
  final StringFilter? serviceTypeCode;
  static const fromJsonFactory = _$SimplrServiceCriteriaFromJson;
  static const toJsonFactory = _$SimplrServiceCriteriaToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.profileOwner, profileOwner) ||
                const DeepCollectionEquality()
                    .equals(other.profileOwner, profileOwner)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.revenueShare, revenueShare) ||
                const DeepCollectionEquality()
                    .equals(other.revenueShare, revenueShare)) &&
            (identical(other.requiresInstructions, requiresInstructions) ||
                const DeepCollectionEquality().equals(
                    other.requiresInstructions, requiresInstructions)) &&
            (identical(other.requiresCredentials, requiresCredentials) ||
                const DeepCollectionEquality()
                    .equals(other.requiresCredentials, requiresCredentials)) &&
            (identical(other.partnerId, partnerId) ||
                const DeepCollectionEquality()
                    .equals(other.partnerId, partnerId)) &&
            (identical(other.partnerName, partnerName) ||
                const DeepCollectionEquality()
                    .equals(other.partnerName, partnerName)) &&
            (identical(other.partnerEmail, partnerEmail) ||
                const DeepCollectionEquality()
                    .equals(other.partnerEmail, partnerEmail)) &&
            (identical(other.serviceCategoryId, serviceCategoryId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategoryId, serviceCategoryId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.globalSearch, globalSearch) ||
                const DeepCollectionEquality()
                    .equals(other.globalSearch, globalSearch)) &&
            (identical(other.taxType, taxType) ||
                const DeepCollectionEquality()
                    .equals(other.taxType, taxType)) &&
            (identical(other.serviceTypeId, serviceTypeId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypeId, serviceTypeId)) &&
            (identical(other.serviceTypeGroup, serviceTypeGroup) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypeGroup, serviceTypeGroup)) &&
            (identical(other.serviceTypeStatus, serviceTypeStatus) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypeStatus, serviceTypeStatus)) &&
            (identical(other.serviceTypeCode, serviceTypeCode) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypeCode, serviceTypeCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(profileOwner) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(revenueShare) ^
      const DeepCollectionEquality().hash(requiresInstructions) ^
      const DeepCollectionEquality().hash(requiresCredentials) ^
      const DeepCollectionEquality().hash(partnerId) ^
      const DeepCollectionEquality().hash(partnerName) ^
      const DeepCollectionEquality().hash(partnerEmail) ^
      const DeepCollectionEquality().hash(serviceCategoryId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(globalSearch) ^
      const DeepCollectionEquality().hash(taxType) ^
      const DeepCollectionEquality().hash(serviceTypeId) ^
      const DeepCollectionEquality().hash(serviceTypeGroup) ^
      const DeepCollectionEquality().hash(serviceTypeStatus) ^
      const DeepCollectionEquality().hash(serviceTypeCode) ^
      runtimeType.hashCode;
}

extension $SimplrServiceCriteriaExtension on SimplrServiceCriteria {
  SimplrServiceCriteria copyWith(
      {LongFilter? id,
      StringFilter? imageUrl,
      StringFilter? profileOwner,
      BooleanFilter? active,
      BigDecimalFilter? revenueShare,
      BooleanFilter? requiresInstructions,
      BooleanFilter? requiresCredentials,
      LongFilter? partnerId,
      StringFilter? partnerName,
      StringFilter? partnerEmail,
      LongFilter? serviceCategoryId,
      StringFilter? name,
      StringFilter? description,
      StringFilter? shortDescription,
      LongFilter? rating,
      StringFilter? globalSearch,
      TaxTypeFilter? taxType,
      LongFilter? serviceTypeId,
      ServiceTypeGroupFilter? serviceTypeGroup,
      ServiceTypeGroupFilter? serviceTypeStatus,
      StringFilter? serviceTypeCode}) {
    return SimplrServiceCriteria(
        id: id ?? this.id,
        imageUrl: imageUrl ?? this.imageUrl,
        profileOwner: profileOwner ?? this.profileOwner,
        active: active ?? this.active,
        revenueShare: revenueShare ?? this.revenueShare,
        requiresInstructions: requiresInstructions ?? this.requiresInstructions,
        requiresCredentials: requiresCredentials ?? this.requiresCredentials,
        partnerId: partnerId ?? this.partnerId,
        partnerName: partnerName ?? this.partnerName,
        partnerEmail: partnerEmail ?? this.partnerEmail,
        serviceCategoryId: serviceCategoryId ?? this.serviceCategoryId,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        rating: rating ?? this.rating,
        globalSearch: globalSearch ?? this.globalSearch,
        taxType: taxType ?? this.taxType,
        serviceTypeId: serviceTypeId ?? this.serviceTypeId,
        serviceTypeGroup: serviceTypeGroup ?? this.serviceTypeGroup,
        serviceTypeStatus: serviceTypeStatus ?? this.serviceTypeStatus,
        serviceTypeCode: serviceTypeCode ?? this.serviceTypeCode);
  }

  SimplrServiceCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<StringFilter?>? imageUrl,
      Wrapped<StringFilter?>? profileOwner,
      Wrapped<BooleanFilter?>? active,
      Wrapped<BigDecimalFilter?>? revenueShare,
      Wrapped<BooleanFilter?>? requiresInstructions,
      Wrapped<BooleanFilter?>? requiresCredentials,
      Wrapped<LongFilter?>? partnerId,
      Wrapped<StringFilter?>? partnerName,
      Wrapped<StringFilter?>? partnerEmail,
      Wrapped<LongFilter?>? serviceCategoryId,
      Wrapped<StringFilter?>? name,
      Wrapped<StringFilter?>? description,
      Wrapped<StringFilter?>? shortDescription,
      Wrapped<LongFilter?>? rating,
      Wrapped<StringFilter?>? globalSearch,
      Wrapped<TaxTypeFilter?>? taxType,
      Wrapped<LongFilter?>? serviceTypeId,
      Wrapped<ServiceTypeGroupFilter?>? serviceTypeGroup,
      Wrapped<ServiceTypeGroupFilter?>? serviceTypeStatus,
      Wrapped<StringFilter?>? serviceTypeCode}) {
    return SimplrServiceCriteria(
        id: (id != null ? id.value : this.id),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        profileOwner:
            (profileOwner != null ? profileOwner.value : this.profileOwner),
        active: (active != null ? active.value : this.active),
        revenueShare:
            (revenueShare != null ? revenueShare.value : this.revenueShare),
        requiresInstructions: (requiresInstructions != null
            ? requiresInstructions.value
            : this.requiresInstructions),
        requiresCredentials: (requiresCredentials != null
            ? requiresCredentials.value
            : this.requiresCredentials),
        partnerId: (partnerId != null ? partnerId.value : this.partnerId),
        partnerName:
            (partnerName != null ? partnerName.value : this.partnerName),
        partnerEmail:
            (partnerEmail != null ? partnerEmail.value : this.partnerEmail),
        serviceCategoryId: (serviceCategoryId != null
            ? serviceCategoryId.value
            : this.serviceCategoryId),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        rating: (rating != null ? rating.value : this.rating),
        globalSearch:
            (globalSearch != null ? globalSearch.value : this.globalSearch),
        taxType: (taxType != null ? taxType.value : this.taxType),
        serviceTypeId:
            (serviceTypeId != null ? serviceTypeId.value : this.serviceTypeId),
        serviceTypeGroup: (serviceTypeGroup != null
            ? serviceTypeGroup.value
            : this.serviceTypeGroup),
        serviceTypeStatus: (serviceTypeStatus != null
            ? serviceTypeStatus.value
            : this.serviceTypeStatus),
        serviceTypeCode: (serviceTypeCode != null
            ? serviceTypeCode.value
            : this.serviceTypeCode));
  }
}

@JsonSerializable(explicitToJson: true)
class ServiceTypeCriteria {
  ServiceTypeCriteria({
    this.id,
    this.status,
    this.serviceTypeGroup,
    this.code,
  });

  factory ServiceTypeCriteria.fromJson(Map<String, dynamic> json) =>
      _$ServiceTypeCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'status', includeIfNull: false)
  final ServiceTypeStatusFilter? status;
  @JsonKey(name: 'serviceTypeGroup', includeIfNull: false)
  final ServiceTypeGroupFilter? serviceTypeGroup;
  @JsonKey(name: 'code', includeIfNull: false)
  final StringFilter? code;
  static const fromJsonFactory = _$ServiceTypeCriteriaFromJson;
  static const toJsonFactory = _$ServiceTypeCriteriaToJson;
  Map<String, dynamic> toJson() => _$ServiceTypeCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ServiceTypeCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.serviceTypeGroup, serviceTypeGroup) ||
                const DeepCollectionEquality()
                    .equals(other.serviceTypeGroup, serviceTypeGroup)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(serviceTypeGroup) ^
      const DeepCollectionEquality().hash(code) ^
      runtimeType.hashCode;
}

extension $ServiceTypeCriteriaExtension on ServiceTypeCriteria {
  ServiceTypeCriteria copyWith(
      {LongFilter? id,
      ServiceTypeStatusFilter? status,
      ServiceTypeGroupFilter? serviceTypeGroup,
      StringFilter? code}) {
    return ServiceTypeCriteria(
        id: id ?? this.id,
        status: status ?? this.status,
        serviceTypeGroup: serviceTypeGroup ?? this.serviceTypeGroup,
        code: code ?? this.code);
  }

  ServiceTypeCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<ServiceTypeStatusFilter?>? status,
      Wrapped<ServiceTypeGroupFilter?>? serviceTypeGroup,
      Wrapped<StringFilter?>? code}) {
    return ServiceTypeCriteria(
        id: (id != null ? id.value : this.id),
        status: (status != null ? status.value : this.status),
        serviceTypeGroup: (serviceTypeGroup != null
            ? serviceTypeGroup.value
            : this.serviceTypeGroup),
        code: (code != null ? code.value : this.code));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServiceInstructions {
  SimplrServiceInstructions({
    this.instructions,
    this.requiresInstructions,
    this.requiresCredentials,
    this.credentials,
  });

  factory SimplrServiceInstructions.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceInstructionsFromJson(json);

  @JsonKey(name: 'instructions', includeIfNull: false, defaultValue: '')
  final String? instructions;
  @JsonKey(name: 'requiresInstructions', includeIfNull: false)
  final bool? requiresInstructions;
  @JsonKey(name: 'requiresCredentials', includeIfNull: false)
  final bool? requiresCredentials;
  @JsonKey(
      name: 'credentials',
      includeIfNull: false,
      defaultValue: <UserPartnerData>[])
  final List<UserPartnerData>? credentials;
  static const fromJsonFactory = _$SimplrServiceInstructionsFromJson;
  static const toJsonFactory = _$SimplrServiceInstructionsToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceInstructionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceInstructions &&
            (identical(other.instructions, instructions) ||
                const DeepCollectionEquality()
                    .equals(other.instructions, instructions)) &&
            (identical(other.requiresInstructions, requiresInstructions) ||
                const DeepCollectionEquality().equals(
                    other.requiresInstructions, requiresInstructions)) &&
            (identical(other.requiresCredentials, requiresCredentials) ||
                const DeepCollectionEquality()
                    .equals(other.requiresCredentials, requiresCredentials)) &&
            (identical(other.credentials, credentials) ||
                const DeepCollectionEquality()
                    .equals(other.credentials, credentials)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(instructions) ^
      const DeepCollectionEquality().hash(requiresInstructions) ^
      const DeepCollectionEquality().hash(requiresCredentials) ^
      const DeepCollectionEquality().hash(credentials) ^
      runtimeType.hashCode;
}

extension $SimplrServiceInstructionsExtension on SimplrServiceInstructions {
  SimplrServiceInstructions copyWith(
      {String? instructions,
      bool? requiresInstructions,
      bool? requiresCredentials,
      List<UserPartnerData>? credentials}) {
    return SimplrServiceInstructions(
        instructions: instructions ?? this.instructions,
        requiresInstructions: requiresInstructions ?? this.requiresInstructions,
        requiresCredentials: requiresCredentials ?? this.requiresCredentials,
        credentials: credentials ?? this.credentials);
  }

  SimplrServiceInstructions copyWithWrapped(
      {Wrapped<String?>? instructions,
      Wrapped<bool?>? requiresInstructions,
      Wrapped<bool?>? requiresCredentials,
      Wrapped<List<UserPartnerData>?>? credentials}) {
    return SimplrServiceInstructions(
        instructions:
            (instructions != null ? instructions.value : this.instructions),
        requiresInstructions: (requiresInstructions != null
            ? requiresInstructions.value
            : this.requiresInstructions),
        requiresCredentials: (requiresCredentials != null
            ? requiresCredentials.value
            : this.requiresCredentials),
        credentials:
            (credentials != null ? credentials.value : this.credentials));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServiceSearch {
  SimplrServiceSearch({
    this.services,
    this.categories,
    this.minimumMembershipPeriods,
  });

  factory SimplrServiceSearch.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceSearchFromJson(json);

  @JsonKey(name: 'services', includeIfNull: false)
  final SimplrServicesPage? services;
  @JsonKey(name: 'categories', includeIfNull: false)
  final List<ServiceCategory>? categories;
  @JsonKey(
      name: 'minimumMembershipPeriods',
      includeIfNull: false,
      defaultValue: <num>[])
  final List<num>? minimumMembershipPeriods;
  static const fromJsonFactory = _$SimplrServiceSearchFromJson;
  static const toJsonFactory = _$SimplrServiceSearchToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceSearchToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceSearch &&
            (identical(other.services, services) ||
                const DeepCollectionEquality()
                    .equals(other.services, services)) &&
            (identical(other.categories, categories) ||
                const DeepCollectionEquality()
                    .equals(other.categories, categories)) &&
            (identical(
                    other.minimumMembershipPeriods, minimumMembershipPeriods) ||
                const DeepCollectionEquality().equals(
                    other.minimumMembershipPeriods, minimumMembershipPeriods)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(services) ^
      const DeepCollectionEquality().hash(categories) ^
      const DeepCollectionEquality().hash(minimumMembershipPeriods) ^
      runtimeType.hashCode;
}

extension $SimplrServiceSearchExtension on SimplrServiceSearch {
  SimplrServiceSearch copyWith(
      {SimplrServicesPage? services,
      List<ServiceCategory>? categories,
      List<num>? minimumMembershipPeriods}) {
    return SimplrServiceSearch(
        services: services ?? this.services,
        categories: categories ?? this.categories,
        minimumMembershipPeriods:
            minimumMembershipPeriods ?? this.minimumMembershipPeriods);
  }

  SimplrServiceSearch copyWithWrapped(
      {Wrapped<SimplrServicesPage?>? services,
      Wrapped<List<ServiceCategory>?>? categories,
      Wrapped<List<num>?>? minimumMembershipPeriods}) {
    return SimplrServiceSearch(
        services: (services != null ? services.value : this.services),
        categories: (categories != null ? categories.value : this.categories),
        minimumMembershipPeriods: (minimumMembershipPeriods != null
            ? minimumMembershipPeriods.value
            : this.minimumMembershipPeriods));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServiceSearchFilter {
  SimplrServiceSearchFilter({
    this.partnerId,
    this.categoryId,
    this.minimumMembershipPeriod,
    this.fixedFieldsForAggregations,
  });

  factory SimplrServiceSearchFilter.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceSearchFilterFromJson(json);

  @JsonKey(name: 'partnerId', includeIfNull: false, defaultValue: <num>[])
  final List<num>? partnerId;
  @JsonKey(name: 'categoryId', includeIfNull: false, defaultValue: <num>[])
  final List<num>? categoryId;
  @JsonKey(name: 'minimumMembershipPeriod', includeIfNull: false)
  final num? minimumMembershipPeriod;
  @JsonKey(
    name: 'fixedFieldsForAggregations',
    includeIfNull: false,
    toJson: aggregationFieldEnumListToJson,
    fromJson: aggregationFieldEnumListFromJson,
  )
  final List<enums.AggregationFieldEnum>? fixedFieldsForAggregations;
  static const fromJsonFactory = _$SimplrServiceSearchFilterFromJson;
  static const toJsonFactory = _$SimplrServiceSearchFilterToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceSearchFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceSearchFilter &&
            (identical(other.partnerId, partnerId) ||
                const DeepCollectionEquality()
                    .equals(other.partnerId, partnerId)) &&
            (identical(other.categoryId, categoryId) ||
                const DeepCollectionEquality()
                    .equals(other.categoryId, categoryId)) &&
            (identical(
                    other.minimumMembershipPeriod, minimumMembershipPeriod) ||
                const DeepCollectionEquality().equals(
                    other.minimumMembershipPeriod, minimumMembershipPeriod)) &&
            (identical(other.fixedFieldsForAggregations,
                    fixedFieldsForAggregations) ||
                const DeepCollectionEquality().equals(
                    other.fixedFieldsForAggregations,
                    fixedFieldsForAggregations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(partnerId) ^
      const DeepCollectionEquality().hash(categoryId) ^
      const DeepCollectionEquality().hash(minimumMembershipPeriod) ^
      const DeepCollectionEquality().hash(fixedFieldsForAggregations) ^
      runtimeType.hashCode;
}

extension $SimplrServiceSearchFilterExtension on SimplrServiceSearchFilter {
  SimplrServiceSearchFilter copyWith(
      {List<num>? partnerId,
      List<num>? categoryId,
      num? minimumMembershipPeriod,
      List<enums.AggregationFieldEnum>? fixedFieldsForAggregations}) {
    return SimplrServiceSearchFilter(
        partnerId: partnerId ?? this.partnerId,
        categoryId: categoryId ?? this.categoryId,
        minimumMembershipPeriod:
            minimumMembershipPeriod ?? this.minimumMembershipPeriod,
        fixedFieldsForAggregations:
            fixedFieldsForAggregations ?? this.fixedFieldsForAggregations);
  }

  SimplrServiceSearchFilter copyWithWrapped(
      {Wrapped<List<num>?>? partnerId,
      Wrapped<List<num>?>? categoryId,
      Wrapped<num?>? minimumMembershipPeriod,
      Wrapped<List<enums.AggregationFieldEnum>?>? fixedFieldsForAggregations}) {
    return SimplrServiceSearchFilter(
        partnerId: (partnerId != null ? partnerId.value : this.partnerId),
        categoryId: (categoryId != null ? categoryId.value : this.categoryId),
        minimumMembershipPeriod: (minimumMembershipPeriod != null
            ? minimumMembershipPeriod.value
            : this.minimumMembershipPeriod),
        fixedFieldsForAggregations: (fixedFieldsForAggregations != null
            ? fixedFieldsForAggregations.value
            : this.fixedFieldsForAggregations));
  }
}

typedef SimplrServiceIdList = List<Object>;

@JsonSerializable(explicitToJson: true)
class SimplrServiceRequest {
  SimplrServiceRequest({
    this.id,
    required this.serviceId,
    this.files,
    required this.address,
    this.bankAccount,
    this.cups,
    this.powerContracted,
    this.priceOptionIds,
  });

  factory SimplrServiceRequest.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'serviceId', includeIfNull: false)
  final num serviceId;
  @JsonKey(name: 'files', includeIfNull: false)
  final List<UserFile>? files;
  @JsonKey(name: 'address', includeIfNull: false)
  final Address address;
  @JsonKey(name: 'bankAccount', includeIfNull: false)
  final BankAccount? bankAccount;
  @JsonKey(name: 'cups', includeIfNull: false, defaultValue: '')
  final String? cups;
  @JsonKey(name: 'powerContracted', includeIfNull: false, defaultValue: '')
  final String? powerContracted;
  @JsonKey(name: 'priceOptionIds', includeIfNull: false, defaultValue: <num>[])
  final List<num>? priceOptionIds;
  static const fromJsonFactory = _$SimplrServiceRequestFromJson;
  static const toJsonFactory = _$SimplrServiceRequestToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.files, files) ||
                const DeepCollectionEquality().equals(other.files, files)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.bankAccount, bankAccount) ||
                const DeepCollectionEquality()
                    .equals(other.bankAccount, bankAccount)) &&
            (identical(other.cups, cups) ||
                const DeepCollectionEquality().equals(other.cups, cups)) &&
            (identical(other.powerContracted, powerContracted) ||
                const DeepCollectionEquality()
                    .equals(other.powerContracted, powerContracted)) &&
            (identical(other.priceOptionIds, priceOptionIds) ||
                const DeepCollectionEquality()
                    .equals(other.priceOptionIds, priceOptionIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(files) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(bankAccount) ^
      const DeepCollectionEquality().hash(cups) ^
      const DeepCollectionEquality().hash(powerContracted) ^
      const DeepCollectionEquality().hash(priceOptionIds) ^
      runtimeType.hashCode;
}

extension $SimplrServiceRequestExtension on SimplrServiceRequest {
  SimplrServiceRequest copyWith(
      {num? id,
      num? serviceId,
      List<UserFile>? files,
      Address? address,
      BankAccount? bankAccount,
      String? cups,
      String? powerContracted,
      List<num>? priceOptionIds}) {
    return SimplrServiceRequest(
        id: id ?? this.id,
        serviceId: serviceId ?? this.serviceId,
        files: files ?? this.files,
        address: address ?? this.address,
        bankAccount: bankAccount ?? this.bankAccount,
        cups: cups ?? this.cups,
        powerContracted: powerContracted ?? this.powerContracted,
        priceOptionIds: priceOptionIds ?? this.priceOptionIds);
  }

  SimplrServiceRequest copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<num>? serviceId,
      Wrapped<List<UserFile>?>? files,
      Wrapped<Address>? address,
      Wrapped<BankAccount?>? bankAccount,
      Wrapped<String?>? cups,
      Wrapped<String?>? powerContracted,
      Wrapped<List<num>?>? priceOptionIds}) {
    return SimplrServiceRequest(
        id: (id != null ? id.value : this.id),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        files: (files != null ? files.value : this.files),
        address: (address != null ? address.value : this.address),
        bankAccount:
            (bankAccount != null ? bankAccount.value : this.bankAccount),
        cups: (cups != null ? cups.value : this.cups),
        powerContracted: (powerContracted != null
            ? powerContracted.value
            : this.powerContracted),
        priceOptionIds: (priceOptionIds != null
            ? priceOptionIds.value
            : this.priceOptionIds));
  }
}

typedef SimplrServiceRequests = List<SimplrServiceRequest>;

@JsonSerializable(explicitToJson: true)
class BankAccount {
  BankAccount({
    this.iban,
    this.fullName,
  });

  factory BankAccount.fromJson(Map<String, dynamic> json) =>
      _$BankAccountFromJson(json);

  @JsonKey(name: 'iban', includeIfNull: false, defaultValue: '')
  final String? iban;
  @JsonKey(name: 'fullName', includeIfNull: false, defaultValue: '')
  final String? fullName;
  static const fromJsonFactory = _$BankAccountFromJson;
  static const toJsonFactory = _$BankAccountToJson;
  Map<String, dynamic> toJson() => _$BankAccountToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BankAccount &&
            (identical(other.iban, iban) ||
                const DeepCollectionEquality().equals(other.iban, iban)) &&
            (identical(other.fullName, fullName) ||
                const DeepCollectionEquality()
                    .equals(other.fullName, fullName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(iban) ^
      const DeepCollectionEquality().hash(fullName) ^
      runtimeType.hashCode;
}

extension $BankAccountExtension on BankAccount {
  BankAccount copyWith({String? iban, String? fullName}) {
    return BankAccount(
        iban: iban ?? this.iban, fullName: fullName ?? this.fullName);
  }

  BankAccount copyWithWrapped(
      {Wrapped<String?>? iban, Wrapped<String?>? fullName}) {
    return BankAccount(
        iban: (iban != null ? iban.value : this.iban),
        fullName: (fullName != null ? fullName.value : this.fullName));
  }
}

@JsonSerializable(explicitToJson: true)
class Job {
  Job({
    this.id,
    this.name,
    this.description,
    this.imageUrl,
    this.tags,
    this.active,
    this.rating,
    this.tasks,
    this.fromPrice,
    this.subscriptions,
    this.selectedServices,
    this.marketId,
    this.businessIds,
  });

  factory Job.fromJson(Map<String, dynamic> json) => _$JobFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  @JsonKey(name: 'tags', includeIfNull: false, defaultValue: '')
  final String? tags;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  @JsonKey(name: 'tasks', includeIfNull: false, defaultValue: <Task>[])
  final List<Task>? tasks;
  @JsonKey(name: 'fromPrice', includeIfNull: false)
  final PriceOption? fromPrice;
  @JsonKey(
      name: 'subscriptions',
      includeIfNull: false,
      defaultValue: <Subscription>[])
  final List<Subscription>? subscriptions;
  @JsonKey(name: 'selectedServices', includeIfNull: false)
  final List<SimplrService>? selectedServices;
  @JsonKey(name: 'marketId', includeIfNull: false)
  final num? marketId;
  @JsonKey(name: 'businessIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? businessIds;
  static const fromJsonFactory = _$JobFromJson;
  static const toJsonFactory = _$JobToJson;
  Map<String, dynamic> toJson() => _$JobToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Job &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.tags, tags) ||
                const DeepCollectionEquality().equals(other.tags, tags)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.tasks, tasks) ||
                const DeepCollectionEquality().equals(other.tasks, tasks)) &&
            (identical(other.fromPrice, fromPrice) ||
                const DeepCollectionEquality()
                    .equals(other.fromPrice, fromPrice)) &&
            (identical(other.subscriptions, subscriptions) ||
                const DeepCollectionEquality()
                    .equals(other.subscriptions, subscriptions)) &&
            (identical(other.selectedServices, selectedServices) ||
                const DeepCollectionEquality()
                    .equals(other.selectedServices, selectedServices)) &&
            (identical(other.marketId, marketId) ||
                const DeepCollectionEquality()
                    .equals(other.marketId, marketId)) &&
            (identical(other.businessIds, businessIds) ||
                const DeepCollectionEquality()
                    .equals(other.businessIds, businessIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(tags) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(tasks) ^
      const DeepCollectionEquality().hash(fromPrice) ^
      const DeepCollectionEquality().hash(subscriptions) ^
      const DeepCollectionEquality().hash(selectedServices) ^
      const DeepCollectionEquality().hash(marketId) ^
      const DeepCollectionEquality().hash(businessIds) ^
      runtimeType.hashCode;
}

extension $JobExtension on Job {
  Job copyWith(
      {num? id,
      String? name,
      String? description,
      String? imageUrl,
      String? tags,
      bool? active,
      double? rating,
      List<Task>? tasks,
      PriceOption? fromPrice,
      List<Subscription>? subscriptions,
      List<SimplrService>? selectedServices,
      num? marketId,
      List<String>? businessIds}) {
    return Job(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        imageUrl: imageUrl ?? this.imageUrl,
        tags: tags ?? this.tags,
        active: active ?? this.active,
        rating: rating ?? this.rating,
        tasks: tasks ?? this.tasks,
        fromPrice: fromPrice ?? this.fromPrice,
        subscriptions: subscriptions ?? this.subscriptions,
        selectedServices: selectedServices ?? this.selectedServices,
        marketId: marketId ?? this.marketId,
        businessIds: businessIds ?? this.businessIds);
  }

  Job copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? imageUrl,
      Wrapped<String?>? tags,
      Wrapped<bool?>? active,
      Wrapped<double?>? rating,
      Wrapped<List<Task>?>? tasks,
      Wrapped<PriceOption?>? fromPrice,
      Wrapped<List<Subscription>?>? subscriptions,
      Wrapped<List<SimplrService>?>? selectedServices,
      Wrapped<num?>? marketId,
      Wrapped<List<String>?>? businessIds}) {
    return Job(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        tags: (tags != null ? tags.value : this.tags),
        active: (active != null ? active.value : this.active),
        rating: (rating != null ? rating.value : this.rating),
        tasks: (tasks != null ? tasks.value : this.tasks),
        fromPrice: (fromPrice != null ? fromPrice.value : this.fromPrice),
        subscriptions:
            (subscriptions != null ? subscriptions.value : this.subscriptions),
        selectedServices: (selectedServices != null
            ? selectedServices.value
            : this.selectedServices),
        marketId: (marketId != null ? marketId.value : this.marketId),
        businessIds:
            (businessIds != null ? businessIds.value : this.businessIds));
  }
}

@JsonSerializable(explicitToJson: true)
class Jobs {
  Jobs({
    this.jobs,
  });

  factory Jobs.fromJson(Map<String, dynamic> json) => _$JobsFromJson(json);

  @JsonKey(name: 'jobs', includeIfNull: false, defaultValue: <Job>[])
  final List<Job>? jobs;
  static const fromJsonFactory = _$JobsFromJson;
  static const toJsonFactory = _$JobsToJson;
  Map<String, dynamic> toJson() => _$JobsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Jobs &&
            (identical(other.jobs, jobs) ||
                const DeepCollectionEquality().equals(other.jobs, jobs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(jobs) ^ runtimeType.hashCode;
}

extension $JobsExtension on Jobs {
  Jobs copyWith({List<Job>? jobs}) {
    return Jobs(jobs: jobs ?? this.jobs);
  }

  Jobs copyWithWrapped({Wrapped<List<Job>?>? jobs}) {
    return Jobs(jobs: (jobs != null ? jobs.value : this.jobs));
  }
}

@JsonSerializable(explicitToJson: true)
class JobCriteria {
  JobCriteria({
    this.id,
    this.tags,
    this.imageUrl,
    this.active,
    this.name,
    this.description,
    this.rating,
    this.globalSearch,
  });

  factory JobCriteria.fromJson(Map<String, dynamic> json) =>
      _$JobCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'tags', includeIfNull: false)
  final StringFilter? tags;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final StringFilter? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false)
  final BooleanFilter? active;
  @JsonKey(name: 'name', includeIfNull: false)
  final StringFilter? name;
  @JsonKey(name: 'description', includeIfNull: false)
  final StringFilter? description;
  @JsonKey(name: 'rating', includeIfNull: false)
  final BigDecimalFilter? rating;
  @JsonKey(name: 'globalSearch', includeIfNull: false)
  final StringFilter? globalSearch;
  static const fromJsonFactory = _$JobCriteriaFromJson;
  static const toJsonFactory = _$JobCriteriaToJson;
  Map<String, dynamic> toJson() => _$JobCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is JobCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.tags, tags) ||
                const DeepCollectionEquality().equals(other.tags, tags)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.globalSearch, globalSearch) ||
                const DeepCollectionEquality()
                    .equals(other.globalSearch, globalSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(tags) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(globalSearch) ^
      runtimeType.hashCode;
}

extension $JobCriteriaExtension on JobCriteria {
  JobCriteria copyWith(
      {LongFilter? id,
      StringFilter? tags,
      StringFilter? imageUrl,
      BooleanFilter? active,
      StringFilter? name,
      StringFilter? description,
      BigDecimalFilter? rating,
      StringFilter? globalSearch}) {
    return JobCriteria(
        id: id ?? this.id,
        tags: tags ?? this.tags,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        name: name ?? this.name,
        description: description ?? this.description,
        rating: rating ?? this.rating,
        globalSearch: globalSearch ?? this.globalSearch);
  }

  JobCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<StringFilter?>? tags,
      Wrapped<StringFilter?>? imageUrl,
      Wrapped<BooleanFilter?>? active,
      Wrapped<StringFilter?>? name,
      Wrapped<StringFilter?>? description,
      Wrapped<BigDecimalFilter?>? rating,
      Wrapped<StringFilter?>? globalSearch}) {
    return JobCriteria(
        id: (id != null ? id.value : this.id),
        tags: (tags != null ? tags.value : this.tags),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        rating: (rating != null ? rating.value : this.rating),
        globalSearch:
            (globalSearch != null ? globalSearch.value : this.globalSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class Task {
  Task({
    this.id,
    this.name,
    this.imageUrl,
    this.active,
    this.simplrServices,
    this.marketId,
    this.businessIds,
  });

  factory Task.fromJson(Map<String, dynamic> json) => _$TaskFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  @JsonKey(
      name: 'simplrServices',
      includeIfNull: false,
      defaultValue: <SimplrService>[])
  final List<SimplrService>? simplrServices;
  @JsonKey(name: 'marketId', includeIfNull: false)
  final num? marketId;
  @JsonKey(name: 'businessIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? businessIds;
  static const fromJsonFactory = _$TaskFromJson;
  static const toJsonFactory = _$TaskToJson;
  Map<String, dynamic> toJson() => _$TaskToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Task &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.simplrServices, simplrServices) ||
                const DeepCollectionEquality()
                    .equals(other.simplrServices, simplrServices)) &&
            (identical(other.marketId, marketId) ||
                const DeepCollectionEquality()
                    .equals(other.marketId, marketId)) &&
            (identical(other.businessIds, businessIds) ||
                const DeepCollectionEquality()
                    .equals(other.businessIds, businessIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(simplrServices) ^
      const DeepCollectionEquality().hash(marketId) ^
      const DeepCollectionEquality().hash(businessIds) ^
      runtimeType.hashCode;
}

extension $TaskExtension on Task {
  Task copyWith(
      {num? id,
      String? name,
      String? imageUrl,
      bool? active,
      List<SimplrService>? simplrServices,
      num? marketId,
      List<String>? businessIds}) {
    return Task(
        id: id ?? this.id,
        name: name ?? this.name,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        simplrServices: simplrServices ?? this.simplrServices,
        marketId: marketId ?? this.marketId,
        businessIds: businessIds ?? this.businessIds);
  }

  Task copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? imageUrl,
      Wrapped<bool?>? active,
      Wrapped<List<SimplrService>?>? simplrServices,
      Wrapped<num?>? marketId,
      Wrapped<List<String>?>? businessIds}) {
    return Task(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        simplrServices: (simplrServices != null
            ? simplrServices.value
            : this.simplrServices),
        marketId: (marketId != null ? marketId.value : this.marketId),
        businessIds:
            (businessIds != null ? businessIds.value : this.businessIds));
  }
}

@JsonSerializable(explicitToJson: true)
class Tasks {
  Tasks({
    this.tasks,
  });

  factory Tasks.fromJson(Map<String, dynamic> json) => _$TasksFromJson(json);

  @JsonKey(name: 'tasks', includeIfNull: false, defaultValue: <Task>[])
  final List<Task>? tasks;
  static const fromJsonFactory = _$TasksFromJson;
  static const toJsonFactory = _$TasksToJson;
  Map<String, dynamic> toJson() => _$TasksToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Tasks &&
            (identical(other.tasks, tasks) ||
                const DeepCollectionEquality().equals(other.tasks, tasks)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tasks) ^ runtimeType.hashCode;
}

extension $TasksExtension on Tasks {
  Tasks copyWith({List<Task>? tasks}) {
    return Tasks(tasks: tasks ?? this.tasks);
  }

  Tasks copyWithWrapped({Wrapped<List<Task>?>? tasks}) {
    return Tasks(tasks: (tasks != null ? tasks.value : this.tasks));
  }
}

@JsonSerializable(explicitToJson: true)
class Partner {
  Partner({
    this.id,
    required this.name,
    this.description,
    this.shortDescription,
    this.taxId,
    this.imageUrl,
    this.active,
    this.fromPrice,
    this.partnerEmail,
    this.rating,
  });

  factory Partner.fromJson(Map<String, dynamic> json) =>
      _$PartnerFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'taxId', includeIfNull: false, defaultValue: '')
  final String? taxId;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  @JsonKey(name: 'fromPrice', includeIfNull: false)
  final PriceOption? fromPrice;
  @JsonKey(name: 'partnerEmail', includeIfNull: false, defaultValue: '')
  final String? partnerEmail;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  static const fromJsonFactory = _$PartnerFromJson;
  static const toJsonFactory = _$PartnerToJson;
  Map<String, dynamic> toJson() => _$PartnerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Partner &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.taxId, taxId) ||
                const DeepCollectionEquality().equals(other.taxId, taxId)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.fromPrice, fromPrice) ||
                const DeepCollectionEquality()
                    .equals(other.fromPrice, fromPrice)) &&
            (identical(other.partnerEmail, partnerEmail) ||
                const DeepCollectionEquality()
                    .equals(other.partnerEmail, partnerEmail)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(taxId) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(fromPrice) ^
      const DeepCollectionEquality().hash(partnerEmail) ^
      const DeepCollectionEquality().hash(rating) ^
      runtimeType.hashCode;
}

extension $PartnerExtension on Partner {
  Partner copyWith(
      {num? id,
      String? name,
      String? description,
      String? shortDescription,
      String? taxId,
      String? imageUrl,
      bool? active,
      PriceOption? fromPrice,
      String? partnerEmail,
      double? rating}) {
    return Partner(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        taxId: taxId ?? this.taxId,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        fromPrice: fromPrice ?? this.fromPrice,
        partnerEmail: partnerEmail ?? this.partnerEmail,
        rating: rating ?? this.rating);
  }

  Partner copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription,
      Wrapped<String?>? taxId,
      Wrapped<String?>? imageUrl,
      Wrapped<bool?>? active,
      Wrapped<PriceOption?>? fromPrice,
      Wrapped<String?>? partnerEmail,
      Wrapped<double?>? rating}) {
    return Partner(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        taxId: (taxId != null ? taxId.value : this.taxId),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        fromPrice: (fromPrice != null ? fromPrice.value : this.fromPrice),
        partnerEmail:
            (partnerEmail != null ? partnerEmail.value : this.partnerEmail),
        rating: (rating != null ? rating.value : this.rating));
  }
}

@JsonSerializable(explicitToJson: true)
class Partners {
  Partners({
    this.partners,
  });

  factory Partners.fromJson(Map<String, dynamic> json) =>
      _$PartnersFromJson(json);

  @JsonKey(name: 'partners', includeIfNull: false, defaultValue: <Partner>[])
  final List<Partner>? partners;
  static const fromJsonFactory = _$PartnersFromJson;
  static const toJsonFactory = _$PartnersToJson;
  Map<String, dynamic> toJson() => _$PartnersToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Partners &&
            (identical(other.partners, partners) ||
                const DeepCollectionEquality()
                    .equals(other.partners, partners)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(partners) ^ runtimeType.hashCode;
}

extension $PartnersExtension on Partners {
  Partners copyWith({List<Partner>? partners}) {
    return Partners(partners: partners ?? this.partners);
  }

  Partners copyWithWrapped({Wrapped<List<Partner>?>? partners}) {
    return Partners(
        partners: (partners != null ? partners.value : this.partners));
  }
}

@JsonSerializable(explicitToJson: true)
class PartnerCriteria {
  PartnerCriteria({
    this.id,
    this.name,
    this.description,
    this.shortDescription,
    this.taxId,
    this.imageUrl,
    this.partnerEmail,
    this.rating,
    this.active,
    this.userLogin,
    this.userId,
    this.userEmail,
    this.globalSearch,
  });

  factory PartnerCriteria.fromJson(Map<String, dynamic> json) =>
      _$PartnerCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'name', includeIfNull: false)
  final StringFilter? name;
  @JsonKey(name: 'description', includeIfNull: false)
  final StringFilter? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false)
  final StringFilter? shortDescription;
  @JsonKey(name: 'taxId', includeIfNull: false)
  final StringFilter? taxId;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final StringFilter? imageUrl;
  @JsonKey(name: 'partnerEmail', includeIfNull: false)
  final StringFilter? partnerEmail;
  @JsonKey(name: 'rating', includeIfNull: false)
  final BigDecimalFilter? rating;
  @JsonKey(name: 'active', includeIfNull: false)
  final BooleanFilter? active;
  @JsonKey(name: 'userLogin', includeIfNull: false)
  final StringFilter? userLogin;
  @JsonKey(name: 'userId', includeIfNull: false)
  final StringFilter? userId;
  @JsonKey(name: 'userEmail', includeIfNull: false)
  final StringFilter? userEmail;
  @JsonKey(name: 'globalSearch', includeIfNull: false)
  final StringFilter? globalSearch;
  static const fromJsonFactory = _$PartnerCriteriaFromJson;
  static const toJsonFactory = _$PartnerCriteriaToJson;
  Map<String, dynamic> toJson() => _$PartnerCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PartnerCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.taxId, taxId) ||
                const DeepCollectionEquality().equals(other.taxId, taxId)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.partnerEmail, partnerEmail) ||
                const DeepCollectionEquality()
                    .equals(other.partnerEmail, partnerEmail)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.userLogin, userLogin) ||
                const DeepCollectionEquality()
                    .equals(other.userLogin, userLogin)) &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)) &&
            (identical(other.userEmail, userEmail) ||
                const DeepCollectionEquality()
                    .equals(other.userEmail, userEmail)) &&
            (identical(other.globalSearch, globalSearch) ||
                const DeepCollectionEquality()
                    .equals(other.globalSearch, globalSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(taxId) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(partnerEmail) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(userLogin) ^
      const DeepCollectionEquality().hash(userId) ^
      const DeepCollectionEquality().hash(userEmail) ^
      const DeepCollectionEquality().hash(globalSearch) ^
      runtimeType.hashCode;
}

extension $PartnerCriteriaExtension on PartnerCriteria {
  PartnerCriteria copyWith(
      {LongFilter? id,
      StringFilter? name,
      StringFilter? description,
      StringFilter? shortDescription,
      StringFilter? taxId,
      StringFilter? imageUrl,
      StringFilter? partnerEmail,
      BigDecimalFilter? rating,
      BooleanFilter? active,
      StringFilter? userLogin,
      StringFilter? userId,
      StringFilter? userEmail,
      StringFilter? globalSearch}) {
    return PartnerCriteria(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        taxId: taxId ?? this.taxId,
        imageUrl: imageUrl ?? this.imageUrl,
        partnerEmail: partnerEmail ?? this.partnerEmail,
        rating: rating ?? this.rating,
        active: active ?? this.active,
        userLogin: userLogin ?? this.userLogin,
        userId: userId ?? this.userId,
        userEmail: userEmail ?? this.userEmail,
        globalSearch: globalSearch ?? this.globalSearch);
  }

  PartnerCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<StringFilter?>? name,
      Wrapped<StringFilter?>? description,
      Wrapped<StringFilter?>? shortDescription,
      Wrapped<StringFilter?>? taxId,
      Wrapped<StringFilter?>? imageUrl,
      Wrapped<StringFilter?>? partnerEmail,
      Wrapped<BigDecimalFilter?>? rating,
      Wrapped<BooleanFilter?>? active,
      Wrapped<StringFilter?>? userLogin,
      Wrapped<StringFilter?>? userId,
      Wrapped<StringFilter?>? userEmail,
      Wrapped<StringFilter?>? globalSearch}) {
    return PartnerCriteria(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        taxId: (taxId != null ? taxId.value : this.taxId),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        partnerEmail:
            (partnerEmail != null ? partnerEmail.value : this.partnerEmail),
        rating: (rating != null ? rating.value : this.rating),
        active: (active != null ? active.value : this.active),
        userLogin: (userLogin != null ? userLogin.value : this.userLogin),
        userId: (userId != null ? userId.value : this.userId),
        userEmail: (userEmail != null ? userEmail.value : this.userEmail),
        globalSearch:
            (globalSearch != null ? globalSearch.value : this.globalSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class Rating {
  Rating({
    this.rating,
  });

  factory Rating.fromJson(Map<String, dynamic> json) => _$RatingFromJson(json);

  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  static const fromJsonFactory = _$RatingFromJson;
  static const toJsonFactory = _$RatingToJson;
  Map<String, dynamic> toJson() => _$RatingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Rating &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rating) ^ runtimeType.hashCode;
}

extension $RatingExtension on Rating {
  Rating copyWith({double? rating}) {
    return Rating(rating: rating ?? this.rating);
  }

  Rating copyWithWrapped({Wrapped<double?>? rating}) {
    return Rating(rating: (rating != null ? rating.value : this.rating));
  }
}

typedef Ratings = List<Rating>;

@JsonSerializable(explicitToJson: true)
class PaymentIntent {
  PaymentIntent({
    this.id,
    this.orderId,
    required this.currency,
    required this.amount,
    this.clientSecret,
    this.status,
  });

  factory PaymentIntent.fromJson(Map<String, dynamic> json) =>
      _$PaymentIntentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'orderId', includeIfNull: false, defaultValue: '')
  final String? orderId;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String currency;
  @JsonKey(name: 'amount', includeIfNull: false)
  final double amount;
  @JsonKey(name: 'clientSecret', includeIfNull: false, defaultValue: '')
  final String? clientSecret;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: intentStatusToJson,
    fromJson: intentStatusFromJson,
  )
  final enums.IntentStatus? status;
  static const fromJsonFactory = _$PaymentIntentFromJson;
  static const toJsonFactory = _$PaymentIntentToJson;
  Map<String, dynamic> toJson() => _$PaymentIntentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PaymentIntent &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.orderId, orderId) ||
                const DeepCollectionEquality()
                    .equals(other.orderId, orderId)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.clientSecret, clientSecret) ||
                const DeepCollectionEquality()
                    .equals(other.clientSecret, clientSecret)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(orderId) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(clientSecret) ^
      const DeepCollectionEquality().hash(status) ^
      runtimeType.hashCode;
}

extension $PaymentIntentExtension on PaymentIntent {
  PaymentIntent copyWith(
      {String? id,
      String? orderId,
      String? currency,
      double? amount,
      String? clientSecret,
      enums.IntentStatus? status}) {
    return PaymentIntent(
        id: id ?? this.id,
        orderId: orderId ?? this.orderId,
        currency: currency ?? this.currency,
        amount: amount ?? this.amount,
        clientSecret: clientSecret ?? this.clientSecret,
        status: status ?? this.status);
  }

  PaymentIntent copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? orderId,
      Wrapped<String>? currency,
      Wrapped<double>? amount,
      Wrapped<String?>? clientSecret,
      Wrapped<enums.IntentStatus?>? status}) {
    return PaymentIntent(
        id: (id != null ? id.value : this.id),
        orderId: (orderId != null ? orderId.value : this.orderId),
        currency: (currency != null ? currency.value : this.currency),
        amount: (amount != null ? amount.value : this.amount),
        clientSecret:
            (clientSecret != null ? clientSecret.value : this.clientSecret),
        status: (status != null ? status.value : this.status));
  }
}

@JsonSerializable(explicitToJson: true)
class SetupIntent {
  SetupIntent({
    this.id,
    this.clientSecret,
  });

  factory SetupIntent.fromJson(Map<String, dynamic> json) =>
      _$SetupIntentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'clientSecret', includeIfNull: false, defaultValue: '')
  final String? clientSecret;
  static const fromJsonFactory = _$SetupIntentFromJson;
  static const toJsonFactory = _$SetupIntentToJson;
  Map<String, dynamic> toJson() => _$SetupIntentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SetupIntent &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.clientSecret, clientSecret) ||
                const DeepCollectionEquality()
                    .equals(other.clientSecret, clientSecret)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(clientSecret) ^
      runtimeType.hashCode;
}

extension $SetupIntentExtension on SetupIntent {
  SetupIntent copyWith({String? id, String? clientSecret}) {
    return SetupIntent(
        id: id ?? this.id, clientSecret: clientSecret ?? this.clientSecret);
  }

  SetupIntent copyWithWrapped(
      {Wrapped<String?>? id, Wrapped<String?>? clientSecret}) {
    return SetupIntent(
        id: (id != null ? id.value : this.id),
        clientSecret:
            (clientSecret != null ? clientSecret.value : this.clientSecret));
  }
}

@JsonSerializable(explicitToJson: true)
class PaymentMethod {
  PaymentMethod({
    this.id,
    this.type,
    this.card,
  });

  factory PaymentMethod.fromJson(Map<String, dynamic> json) =>
      _$PaymentMethodFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: paymentMethodTypeToJson,
    fromJson: paymentMethodTypeFromJson,
  )
  final enums.PaymentMethodType? type;
  @JsonKey(name: 'card', includeIfNull: false)
  final PaymentMethod$Card? card;
  static const fromJsonFactory = _$PaymentMethodFromJson;
  static const toJsonFactory = _$PaymentMethodToJson;
  Map<String, dynamic> toJson() => _$PaymentMethodToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PaymentMethod &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.card, card) ||
                const DeepCollectionEquality().equals(other.card, card)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(card) ^
      runtimeType.hashCode;
}

extension $PaymentMethodExtension on PaymentMethod {
  PaymentMethod copyWith(
      {String? id, enums.PaymentMethodType? type, PaymentMethod$Card? card}) {
    return PaymentMethod(
        id: id ?? this.id, type: type ?? this.type, card: card ?? this.card);
  }

  PaymentMethod copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<enums.PaymentMethodType?>? type,
      Wrapped<PaymentMethod$Card?>? card}) {
    return PaymentMethod(
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type),
        card: (card != null ? card.value : this.card));
  }
}

@JsonSerializable(explicitToJson: true)
class PartnerApp {
  PartnerApp({
    this.id,
    required this.name,
    this.description,
    required this.endpointUrl,
    this.apiKey,
    required this.partnerAppType,
  });

  factory PartnerApp.fromJson(Map<String, dynamic> json) =>
      _$PartnerAppFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'endpointUrl', includeIfNull: false, defaultValue: '')
  final String endpointUrl;
  @JsonKey(name: 'apiKey', includeIfNull: false, defaultValue: '')
  final String? apiKey;
  @JsonKey(name: 'partnerAppType', includeIfNull: false)
  final PartnerAppType partnerAppType;
  static const fromJsonFactory = _$PartnerAppFromJson;
  static const toJsonFactory = _$PartnerAppToJson;
  Map<String, dynamic> toJson() => _$PartnerAppToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PartnerApp &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.endpointUrl, endpointUrl) ||
                const DeepCollectionEquality()
                    .equals(other.endpointUrl, endpointUrl)) &&
            (identical(other.apiKey, apiKey) ||
                const DeepCollectionEquality().equals(other.apiKey, apiKey)) &&
            (identical(other.partnerAppType, partnerAppType) ||
                const DeepCollectionEquality()
                    .equals(other.partnerAppType, partnerAppType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(endpointUrl) ^
      const DeepCollectionEquality().hash(apiKey) ^
      const DeepCollectionEquality().hash(partnerAppType) ^
      runtimeType.hashCode;
}

extension $PartnerAppExtension on PartnerApp {
  PartnerApp copyWith(
      {num? id,
      String? name,
      String? description,
      String? endpointUrl,
      String? apiKey,
      PartnerAppType? partnerAppType}) {
    return PartnerApp(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        endpointUrl: endpointUrl ?? this.endpointUrl,
        apiKey: apiKey ?? this.apiKey,
        partnerAppType: partnerAppType ?? this.partnerAppType);
  }

  PartnerApp copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String>? endpointUrl,
      Wrapped<String?>? apiKey,
      Wrapped<PartnerAppType>? partnerAppType}) {
    return PartnerApp(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        endpointUrl:
            (endpointUrl != null ? endpointUrl.value : this.endpointUrl),
        apiKey: (apiKey != null ? apiKey.value : this.apiKey),
        partnerAppType: (partnerAppType != null
            ? partnerAppType.value
            : this.partnerAppType));
  }
}

typedef PartnerApps = List<PartnerApp>;

@JsonSerializable(explicitToJson: true)
class PartnerAppType {
  PartnerAppType({
    this.id,
    required this.name,
    this.description,
  });

  factory PartnerAppType.fromJson(Map<String, dynamic> json) =>
      _$PartnerAppTypeFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$PartnerAppTypeFromJson;
  static const toJsonFactory = _$PartnerAppTypeToJson;
  Map<String, dynamic> toJson() => _$PartnerAppTypeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PartnerAppType &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $PartnerAppTypeExtension on PartnerAppType {
  PartnerAppType copyWith({num? id, String? name, String? description}) {
    return PartnerAppType(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description);
  }

  PartnerAppType copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description}) {
    return PartnerAppType(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description));
  }
}

typedef PartnerAppTypes = List<PartnerAppType>;

@JsonSerializable(explicitToJson: true)
class Order {
  Order({
    this.id,
    this.date,
    this.shippingAddress,
    this.deliveryInstructions,
    this.contactInfo,
    this.paymentMethod,
    this.paymentIntent,
    this.setupIntent,
    this.status,
    this.shippingCost,
    this.subtotal,
    this.taxAmount,
    this.shipmentAmount,
    this.total,
    this.discountAmount,
    this.discount,
    this.promotionCode,
    this.currency,
    this.aggregatedCosts,
    this.jobId,
    this.job,
    this.items,
    this.deliveryRequired,
  });

  factory Order.fromJson(Map<String, dynamic> json) => _$OrderFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'shippingAddress', includeIfNull: false)
  final OrderAddress? shippingAddress;
  @JsonKey(name: 'deliveryInstructions', includeIfNull: false, defaultValue: '')
  final String? deliveryInstructions;
  @JsonKey(name: 'contactInfo', includeIfNull: false)
  final ContactInfo? contactInfo;
  @JsonKey(name: 'paymentMethod', includeIfNull: false)
  final PaymentMethod? paymentMethod;
  @JsonKey(name: 'paymentIntent', includeIfNull: false)
  final PaymentIntent? paymentIntent;
  @JsonKey(name: 'setupIntent', includeIfNull: false)
  final SetupIntent? setupIntent;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: orderStatusToJson,
    fromJson: orderStatusFromJson,
  )
  final enums.OrderStatus? status;
  @JsonKey(name: 'shippingCost', includeIfNull: false)
  final double? shippingCost;
  @JsonKey(name: 'subtotal', includeIfNull: false)
  final double? subtotal;
  @JsonKey(name: 'taxAmount', includeIfNull: false)
  final double? taxAmount;
  @JsonKey(name: 'shipmentAmount', includeIfNull: false)
  final double? shipmentAmount;
  @JsonKey(name: 'total', includeIfNull: false)
  final double? total;
  @JsonKey(name: 'discountAmount', includeIfNull: false)
  final double? discountAmount;
  @JsonKey(name: 'discount', includeIfNull: false)
  final Discount? discount;
  @JsonKey(name: 'promotionCode', includeIfNull: false, defaultValue: '')
  final String? promotionCode;
  @JsonKey(name: 'currency', includeIfNull: false, defaultValue: '')
  final String? currency;
  @JsonKey(
      name: 'aggregatedCosts',
      includeIfNull: false,
      defaultValue: <PriceOption>[])
  final List<PriceOption>? aggregatedCosts;
  @JsonKey(name: 'jobId', includeIfNull: false)
  final num? jobId;
  @JsonKey(name: 'job', includeIfNull: false)
  final Job? job;
  @JsonKey(name: 'items', includeIfNull: false, defaultValue: <OrderItem>[])
  final List<OrderItem>? items;
  @JsonKey(name: 'deliveryRequired', includeIfNull: false)
  final bool? deliveryRequired;
  static const fromJsonFactory = _$OrderFromJson;
  static const toJsonFactory = _$OrderToJson;
  Map<String, dynamic> toJson() => _$OrderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Order &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.shippingAddress, shippingAddress) ||
                const DeepCollectionEquality()
                    .equals(other.shippingAddress, shippingAddress)) &&
            (identical(other.deliveryInstructions, deliveryInstructions) ||
                const DeepCollectionEquality().equals(
                    other.deliveryInstructions, deliveryInstructions)) &&
            (identical(other.contactInfo, contactInfo) ||
                const DeepCollectionEquality()
                    .equals(other.contactInfo, contactInfo)) &&
            (identical(other.paymentMethod, paymentMethod) ||
                const DeepCollectionEquality()
                    .equals(other.paymentMethod, paymentMethod)) &&
            (identical(other.paymentIntent, paymentIntent) ||
                const DeepCollectionEquality()
                    .equals(other.paymentIntent, paymentIntent)) &&
            (identical(other.setupIntent, setupIntent) ||
                const DeepCollectionEquality()
                    .equals(other.setupIntent, setupIntent)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.shippingCost, shippingCost) ||
                const DeepCollectionEquality()
                    .equals(other.shippingCost, shippingCost)) &&
            (identical(other.subtotal, subtotal) ||
                const DeepCollectionEquality()
                    .equals(other.subtotal, subtotal)) &&
            (identical(other.taxAmount, taxAmount) ||
                const DeepCollectionEquality()
                    .equals(other.taxAmount, taxAmount)) &&
            (identical(other.shipmentAmount, shipmentAmount) ||
                const DeepCollectionEquality()
                    .equals(other.shipmentAmount, shipmentAmount)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)) &&
            (identical(other.discountAmount, discountAmount) ||
                const DeepCollectionEquality()
                    .equals(other.discountAmount, discountAmount)) &&
            (identical(other.discount, discount) ||
                const DeepCollectionEquality()
                    .equals(other.discount, discount)) &&
            (identical(other.promotionCode, promotionCode) ||
                const DeepCollectionEquality()
                    .equals(other.promotionCode, promotionCode)) &&
            (identical(other.currency, currency) ||
                const DeepCollectionEquality()
                    .equals(other.currency, currency)) &&
            (identical(other.aggregatedCosts, aggregatedCosts) ||
                const DeepCollectionEquality()
                    .equals(other.aggregatedCosts, aggregatedCosts)) &&
            (identical(other.jobId, jobId) ||
                const DeepCollectionEquality().equals(other.jobId, jobId)) &&
            (identical(other.job, job) ||
                const DeepCollectionEquality().equals(other.job, job)) &&
            (identical(other.items, items) ||
                const DeepCollectionEquality().equals(other.items, items)) &&
            (identical(other.deliveryRequired, deliveryRequired) ||
                const DeepCollectionEquality()
                    .equals(other.deliveryRequired, deliveryRequired)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(shippingAddress) ^
      const DeepCollectionEquality().hash(deliveryInstructions) ^
      const DeepCollectionEquality().hash(contactInfo) ^
      const DeepCollectionEquality().hash(paymentMethod) ^
      const DeepCollectionEquality().hash(paymentIntent) ^
      const DeepCollectionEquality().hash(setupIntent) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(shippingCost) ^
      const DeepCollectionEquality().hash(subtotal) ^
      const DeepCollectionEquality().hash(taxAmount) ^
      const DeepCollectionEquality().hash(shipmentAmount) ^
      const DeepCollectionEquality().hash(total) ^
      const DeepCollectionEquality().hash(discountAmount) ^
      const DeepCollectionEquality().hash(discount) ^
      const DeepCollectionEquality().hash(promotionCode) ^
      const DeepCollectionEquality().hash(currency) ^
      const DeepCollectionEquality().hash(aggregatedCosts) ^
      const DeepCollectionEquality().hash(jobId) ^
      const DeepCollectionEquality().hash(job) ^
      const DeepCollectionEquality().hash(items) ^
      const DeepCollectionEquality().hash(deliveryRequired) ^
      runtimeType.hashCode;
}

extension $OrderExtension on Order {
  Order copyWith(
      {num? id,
      DateTime? date,
      OrderAddress? shippingAddress,
      String? deliveryInstructions,
      ContactInfo? contactInfo,
      PaymentMethod? paymentMethod,
      PaymentIntent? paymentIntent,
      SetupIntent? setupIntent,
      enums.OrderStatus? status,
      double? shippingCost,
      double? subtotal,
      double? taxAmount,
      double? shipmentAmount,
      double? total,
      double? discountAmount,
      Discount? discount,
      String? promotionCode,
      String? currency,
      List<PriceOption>? aggregatedCosts,
      num? jobId,
      Job? job,
      List<OrderItem>? items,
      bool? deliveryRequired}) {
    return Order(
        id: id ?? this.id,
        date: date ?? this.date,
        shippingAddress: shippingAddress ?? this.shippingAddress,
        deliveryInstructions: deliveryInstructions ?? this.deliveryInstructions,
        contactInfo: contactInfo ?? this.contactInfo,
        paymentMethod: paymentMethod ?? this.paymentMethod,
        paymentIntent: paymentIntent ?? this.paymentIntent,
        setupIntent: setupIntent ?? this.setupIntent,
        status: status ?? this.status,
        shippingCost: shippingCost ?? this.shippingCost,
        subtotal: subtotal ?? this.subtotal,
        taxAmount: taxAmount ?? this.taxAmount,
        shipmentAmount: shipmentAmount ?? this.shipmentAmount,
        total: total ?? this.total,
        discountAmount: discountAmount ?? this.discountAmount,
        discount: discount ?? this.discount,
        promotionCode: promotionCode ?? this.promotionCode,
        currency: currency ?? this.currency,
        aggregatedCosts: aggregatedCosts ?? this.aggregatedCosts,
        jobId: jobId ?? this.jobId,
        job: job ?? this.job,
        items: items ?? this.items,
        deliveryRequired: deliveryRequired ?? this.deliveryRequired);
  }

  Order copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<DateTime?>? date,
      Wrapped<OrderAddress?>? shippingAddress,
      Wrapped<String?>? deliveryInstructions,
      Wrapped<ContactInfo?>? contactInfo,
      Wrapped<PaymentMethod?>? paymentMethod,
      Wrapped<PaymentIntent?>? paymentIntent,
      Wrapped<SetupIntent?>? setupIntent,
      Wrapped<enums.OrderStatus?>? status,
      Wrapped<double?>? shippingCost,
      Wrapped<double?>? subtotal,
      Wrapped<double?>? taxAmount,
      Wrapped<double?>? shipmentAmount,
      Wrapped<double?>? total,
      Wrapped<double?>? discountAmount,
      Wrapped<Discount?>? discount,
      Wrapped<String?>? promotionCode,
      Wrapped<String?>? currency,
      Wrapped<List<PriceOption>?>? aggregatedCosts,
      Wrapped<num?>? jobId,
      Wrapped<Job?>? job,
      Wrapped<List<OrderItem>?>? items,
      Wrapped<bool?>? deliveryRequired}) {
    return Order(
        id: (id != null ? id.value : this.id),
        date: (date != null ? date.value : this.date),
        shippingAddress: (shippingAddress != null
            ? shippingAddress.value
            : this.shippingAddress),
        deliveryInstructions: (deliveryInstructions != null
            ? deliveryInstructions.value
            : this.deliveryInstructions),
        contactInfo:
            (contactInfo != null ? contactInfo.value : this.contactInfo),
        paymentMethod:
            (paymentMethod != null ? paymentMethod.value : this.paymentMethod),
        paymentIntent:
            (paymentIntent != null ? paymentIntent.value : this.paymentIntent),
        setupIntent:
            (setupIntent != null ? setupIntent.value : this.setupIntent),
        status: (status != null ? status.value : this.status),
        shippingCost:
            (shippingCost != null ? shippingCost.value : this.shippingCost),
        subtotal: (subtotal != null ? subtotal.value : this.subtotal),
        taxAmount: (taxAmount != null ? taxAmount.value : this.taxAmount),
        shipmentAmount: (shipmentAmount != null
            ? shipmentAmount.value
            : this.shipmentAmount),
        total: (total != null ? total.value : this.total),
        discountAmount: (discountAmount != null
            ? discountAmount.value
            : this.discountAmount),
        discount: (discount != null ? discount.value : this.discount),
        promotionCode:
            (promotionCode != null ? promotionCode.value : this.promotionCode),
        currency: (currency != null ? currency.value : this.currency),
        aggregatedCosts: (aggregatedCosts != null
            ? aggregatedCosts.value
            : this.aggregatedCosts),
        jobId: (jobId != null ? jobId.value : this.jobId),
        job: (job != null ? job.value : this.job),
        items: (items != null ? items.value : this.items),
        deliveryRequired: (deliveryRequired != null
            ? deliveryRequired.value
            : this.deliveryRequired));
  }
}

@JsonSerializable(explicitToJson: true)
class Orders {
  Orders({
    this.orders,
  });

  factory Orders.fromJson(Map<String, dynamic> json) => _$OrdersFromJson(json);

  @JsonKey(name: 'orders', includeIfNull: false, defaultValue: <Order>[])
  final List<Order>? orders;
  static const fromJsonFactory = _$OrdersFromJson;
  static const toJsonFactory = _$OrdersToJson;
  Map<String, dynamic> toJson() => _$OrdersToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Orders &&
            (identical(other.orders, orders) ||
                const DeepCollectionEquality().equals(other.orders, orders)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(orders) ^ runtimeType.hashCode;
}

extension $OrdersExtension on Orders {
  Orders copyWith({List<Order>? orders}) {
    return Orders(orders: orders ?? this.orders);
  }

  Orders copyWithWrapped({Wrapped<List<Order>?>? orders}) {
    return Orders(orders: (orders != null ? orders.value : this.orders));
  }
}

@JsonSerializable(explicitToJson: true)
class OrderConfirmation {
  OrderConfirmation({
    this.id,
    this.shippingAddress,
    this.deliveryInstructions,
    this.contactInfo,
    this.paymentMethod,
    this.paymentIntent,
  });

  factory OrderConfirmation.fromJson(Map<String, dynamic> json) =>
      _$OrderConfirmationFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'shippingAddress', includeIfNull: false)
  final OrderAddress? shippingAddress;
  @JsonKey(name: 'deliveryInstructions', includeIfNull: false, defaultValue: '')
  final String? deliveryInstructions;
  @JsonKey(name: 'contactInfo', includeIfNull: false)
  final ContactInfo? contactInfo;
  @JsonKey(name: 'paymentMethod', includeIfNull: false)
  final PaymentMethod? paymentMethod;
  @JsonKey(name: 'paymentIntent', includeIfNull: false)
  final PaymentIntent? paymentIntent;
  static const fromJsonFactory = _$OrderConfirmationFromJson;
  static const toJsonFactory = _$OrderConfirmationToJson;
  Map<String, dynamic> toJson() => _$OrderConfirmationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OrderConfirmation &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.shippingAddress, shippingAddress) ||
                const DeepCollectionEquality()
                    .equals(other.shippingAddress, shippingAddress)) &&
            (identical(other.deliveryInstructions, deliveryInstructions) ||
                const DeepCollectionEquality().equals(
                    other.deliveryInstructions, deliveryInstructions)) &&
            (identical(other.contactInfo, contactInfo) ||
                const DeepCollectionEquality()
                    .equals(other.contactInfo, contactInfo)) &&
            (identical(other.paymentMethod, paymentMethod) ||
                const DeepCollectionEquality()
                    .equals(other.paymentMethod, paymentMethod)) &&
            (identical(other.paymentIntent, paymentIntent) ||
                const DeepCollectionEquality()
                    .equals(other.paymentIntent, paymentIntent)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(shippingAddress) ^
      const DeepCollectionEquality().hash(deliveryInstructions) ^
      const DeepCollectionEquality().hash(contactInfo) ^
      const DeepCollectionEquality().hash(paymentMethod) ^
      const DeepCollectionEquality().hash(paymentIntent) ^
      runtimeType.hashCode;
}

extension $OrderConfirmationExtension on OrderConfirmation {
  OrderConfirmation copyWith(
      {num? id,
      OrderAddress? shippingAddress,
      String? deliveryInstructions,
      ContactInfo? contactInfo,
      PaymentMethod? paymentMethod,
      PaymentIntent? paymentIntent}) {
    return OrderConfirmation(
        id: id ?? this.id,
        shippingAddress: shippingAddress ?? this.shippingAddress,
        deliveryInstructions: deliveryInstructions ?? this.deliveryInstructions,
        contactInfo: contactInfo ?? this.contactInfo,
        paymentMethod: paymentMethod ?? this.paymentMethod,
        paymentIntent: paymentIntent ?? this.paymentIntent);
  }

  OrderConfirmation copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<OrderAddress?>? shippingAddress,
      Wrapped<String?>? deliveryInstructions,
      Wrapped<ContactInfo?>? contactInfo,
      Wrapped<PaymentMethod?>? paymentMethod,
      Wrapped<PaymentIntent?>? paymentIntent}) {
    return OrderConfirmation(
        id: (id != null ? id.value : this.id),
        shippingAddress: (shippingAddress != null
            ? shippingAddress.value
            : this.shippingAddress),
        deliveryInstructions: (deliveryInstructions != null
            ? deliveryInstructions.value
            : this.deliveryInstructions),
        contactInfo:
            (contactInfo != null ? contactInfo.value : this.contactInfo),
        paymentMethod:
            (paymentMethod != null ? paymentMethod.value : this.paymentMethod),
        paymentIntent:
            (paymentIntent != null ? paymentIntent.value : this.paymentIntent));
  }
}

@JsonSerializable(explicitToJson: true)
class OrderCriteria {
  OrderCriteria({
    this.id,
    this.status,
    this.date,
    this.address,
    this.floor,
    this.city,
    this.zip,
    this.province,
    this.country,
    this.deliveryInstructions,
    this.firstName,
    this.lastName,
    this.email,
    this.companyName,
    this.phone,
    this.paymentMethodId,
    this.paymentIntentId,
    this.checkInId,
    this.jobId,
    this.userLogin,
    this.userId,
    this.globalSearch,
  });

  factory OrderCriteria.fromJson(Map<String, dynamic> json) =>
      _$OrderCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'status', includeIfNull: false)
  final OrderStatusFilter? status;
  @JsonKey(name: 'date', includeIfNull: false)
  final InstantFilter? date;
  @JsonKey(name: 'address', includeIfNull: false)
  final StringFilter? address;
  @JsonKey(name: 'floor', includeIfNull: false)
  final StringFilter? floor;
  @JsonKey(name: 'city', includeIfNull: false)
  final StringFilter? city;
  @JsonKey(name: 'zip', includeIfNull: false)
  final StringFilter? zip;
  @JsonKey(name: 'province', includeIfNull: false)
  final StringFilter? province;
  @JsonKey(name: 'country', includeIfNull: false)
  final StringFilter? country;
  @JsonKey(name: 'deliveryInstructions', includeIfNull: false)
  final StringFilter? deliveryInstructions;
  @JsonKey(name: 'firstName', includeIfNull: false)
  final StringFilter? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false)
  final StringFilter? lastName;
  @JsonKey(name: 'email', includeIfNull: false)
  final StringFilter? email;
  @JsonKey(name: 'companyName', includeIfNull: false)
  final StringFilter? companyName;
  @JsonKey(name: 'phone', includeIfNull: false)
  final StringFilter? phone;
  @JsonKey(name: 'paymentMethodId', includeIfNull: false)
  final StringFilter? paymentMethodId;
  @JsonKey(name: 'paymentIntentId', includeIfNull: false)
  final StringFilter? paymentIntentId;
  @JsonKey(name: 'checkInId', includeIfNull: false)
  final LongFilter? checkInId;
  @JsonKey(name: 'jobId', includeIfNull: false)
  final LongFilter? jobId;
  @JsonKey(name: 'userLogin', includeIfNull: false)
  final StringFilter? userLogin;
  @JsonKey(name: 'userId', includeIfNull: false)
  final StringFilter? userId;
  @JsonKey(name: 'globalSearch', includeIfNull: false)
  final StringFilter? globalSearch;
  static const fromJsonFactory = _$OrderCriteriaFromJson;
  static const toJsonFactory = _$OrderCriteriaToJson;
  Map<String, dynamic> toJson() => _$OrderCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OrderCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.floor, floor) ||
                const DeepCollectionEquality().equals(other.floor, floor)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.zip, zip) ||
                const DeepCollectionEquality().equals(other.zip, zip)) &&
            (identical(other.province, province) ||
                const DeepCollectionEquality()
                    .equals(other.province, province)) &&
            (identical(other.country, country) ||
                const DeepCollectionEquality()
                    .equals(other.country, country)) &&
            (identical(other.deliveryInstructions, deliveryInstructions) ||
                const DeepCollectionEquality().equals(
                    other.deliveryInstructions, deliveryInstructions)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.companyName, companyName) ||
                const DeepCollectionEquality()
                    .equals(other.companyName, companyName)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.paymentMethodId, paymentMethodId) ||
                const DeepCollectionEquality()
                    .equals(other.paymentMethodId, paymentMethodId)) &&
            (identical(other.paymentIntentId, paymentIntentId) ||
                const DeepCollectionEquality()
                    .equals(other.paymentIntentId, paymentIntentId)) &&
            (identical(other.checkInId, checkInId) ||
                const DeepCollectionEquality()
                    .equals(other.checkInId, checkInId)) &&
            (identical(other.jobId, jobId) ||
                const DeepCollectionEquality().equals(other.jobId, jobId)) &&
            (identical(other.userLogin, userLogin) ||
                const DeepCollectionEquality()
                    .equals(other.userLogin, userLogin)) &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)) &&
            (identical(other.globalSearch, globalSearch) ||
                const DeepCollectionEquality()
                    .equals(other.globalSearch, globalSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(floor) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(zip) ^
      const DeepCollectionEquality().hash(province) ^
      const DeepCollectionEquality().hash(country) ^
      const DeepCollectionEquality().hash(deliveryInstructions) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(companyName) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(paymentMethodId) ^
      const DeepCollectionEquality().hash(paymentIntentId) ^
      const DeepCollectionEquality().hash(checkInId) ^
      const DeepCollectionEquality().hash(jobId) ^
      const DeepCollectionEquality().hash(userLogin) ^
      const DeepCollectionEquality().hash(userId) ^
      const DeepCollectionEquality().hash(globalSearch) ^
      runtimeType.hashCode;
}

extension $OrderCriteriaExtension on OrderCriteria {
  OrderCriteria copyWith(
      {LongFilter? id,
      OrderStatusFilter? status,
      InstantFilter? date,
      StringFilter? address,
      StringFilter? floor,
      StringFilter? city,
      StringFilter? zip,
      StringFilter? province,
      StringFilter? country,
      StringFilter? deliveryInstructions,
      StringFilter? firstName,
      StringFilter? lastName,
      StringFilter? email,
      StringFilter? companyName,
      StringFilter? phone,
      StringFilter? paymentMethodId,
      StringFilter? paymentIntentId,
      LongFilter? checkInId,
      LongFilter? jobId,
      StringFilter? userLogin,
      StringFilter? userId,
      StringFilter? globalSearch}) {
    return OrderCriteria(
        id: id ?? this.id,
        status: status ?? this.status,
        date: date ?? this.date,
        address: address ?? this.address,
        floor: floor ?? this.floor,
        city: city ?? this.city,
        zip: zip ?? this.zip,
        province: province ?? this.province,
        country: country ?? this.country,
        deliveryInstructions: deliveryInstructions ?? this.deliveryInstructions,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        email: email ?? this.email,
        companyName: companyName ?? this.companyName,
        phone: phone ?? this.phone,
        paymentMethodId: paymentMethodId ?? this.paymentMethodId,
        paymentIntentId: paymentIntentId ?? this.paymentIntentId,
        checkInId: checkInId ?? this.checkInId,
        jobId: jobId ?? this.jobId,
        userLogin: userLogin ?? this.userLogin,
        userId: userId ?? this.userId,
        globalSearch: globalSearch ?? this.globalSearch);
  }

  OrderCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<OrderStatusFilter?>? status,
      Wrapped<InstantFilter?>? date,
      Wrapped<StringFilter?>? address,
      Wrapped<StringFilter?>? floor,
      Wrapped<StringFilter?>? city,
      Wrapped<StringFilter?>? zip,
      Wrapped<StringFilter?>? province,
      Wrapped<StringFilter?>? country,
      Wrapped<StringFilter?>? deliveryInstructions,
      Wrapped<StringFilter?>? firstName,
      Wrapped<StringFilter?>? lastName,
      Wrapped<StringFilter?>? email,
      Wrapped<StringFilter?>? companyName,
      Wrapped<StringFilter?>? phone,
      Wrapped<StringFilter?>? paymentMethodId,
      Wrapped<StringFilter?>? paymentIntentId,
      Wrapped<LongFilter?>? checkInId,
      Wrapped<LongFilter?>? jobId,
      Wrapped<StringFilter?>? userLogin,
      Wrapped<StringFilter?>? userId,
      Wrapped<StringFilter?>? globalSearch}) {
    return OrderCriteria(
        id: (id != null ? id.value : this.id),
        status: (status != null ? status.value : this.status),
        date: (date != null ? date.value : this.date),
        address: (address != null ? address.value : this.address),
        floor: (floor != null ? floor.value : this.floor),
        city: (city != null ? city.value : this.city),
        zip: (zip != null ? zip.value : this.zip),
        province: (province != null ? province.value : this.province),
        country: (country != null ? country.value : this.country),
        deliveryInstructions: (deliveryInstructions != null
            ? deliveryInstructions.value
            : this.deliveryInstructions),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        email: (email != null ? email.value : this.email),
        companyName:
            (companyName != null ? companyName.value : this.companyName),
        phone: (phone != null ? phone.value : this.phone),
        paymentMethodId: (paymentMethodId != null
            ? paymentMethodId.value
            : this.paymentMethodId),
        paymentIntentId: (paymentIntentId != null
            ? paymentIntentId.value
            : this.paymentIntentId),
        checkInId: (checkInId != null ? checkInId.value : this.checkInId),
        jobId: (jobId != null ? jobId.value : this.jobId),
        userLogin: (userLogin != null ? userLogin.value : this.userLogin),
        userId: (userId != null ? userId.value : this.userId),
        globalSearch:
            (globalSearch != null ? globalSearch.value : this.globalSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class ContactInfo {
  ContactInfo({
    this.firstName,
    this.lastName,
    this.email,
    this.companyName,
    this.phone,
  });

  factory ContactInfo.fromJson(Map<String, dynamic> json) =>
      _$ContactInfoFromJson(json);

  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(name: 'companyName', includeIfNull: false, defaultValue: '')
  final String? companyName;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  static const fromJsonFactory = _$ContactInfoFromJson;
  static const toJsonFactory = _$ContactInfoToJson;
  Map<String, dynamic> toJson() => _$ContactInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContactInfo &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.companyName, companyName) ||
                const DeepCollectionEquality()
                    .equals(other.companyName, companyName)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(companyName) ^
      const DeepCollectionEquality().hash(phone) ^
      runtimeType.hashCode;
}

extension $ContactInfoExtension on ContactInfo {
  ContactInfo copyWith(
      {String? firstName,
      String? lastName,
      String? email,
      String? companyName,
      String? phone}) {
    return ContactInfo(
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        email: email ?? this.email,
        companyName: companyName ?? this.companyName,
        phone: phone ?? this.phone);
  }

  ContactInfo copyWithWrapped(
      {Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? email,
      Wrapped<String?>? companyName,
      Wrapped<String?>? phone}) {
    return ContactInfo(
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        email: (email != null ? email.value : this.email),
        companyName:
            (companyName != null ? companyName.value : this.companyName),
        phone: (phone != null ? phone.value : this.phone));
  }
}

@JsonSerializable(explicitToJson: true)
class OrderAddress {
  OrderAddress({
    this.address,
    this.floor,
    this.city,
    this.province,
    this.zip,
    this.country,
  });

  factory OrderAddress.fromJson(Map<String, dynamic> json) =>
      _$OrderAddressFromJson(json);

  @JsonKey(name: 'address', includeIfNull: false, defaultValue: '')
  final String? address;
  @JsonKey(name: 'floor', includeIfNull: false, defaultValue: '')
  final String? floor;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String? city;
  @JsonKey(name: 'province', includeIfNull: false, defaultValue: '')
  final String? province;
  @JsonKey(name: 'zip', includeIfNull: false, defaultValue: '')
  final String? zip;
  @JsonKey(name: 'country', includeIfNull: false, defaultValue: '')
  final String? country;
  static const fromJsonFactory = _$OrderAddressFromJson;
  static const toJsonFactory = _$OrderAddressToJson;
  Map<String, dynamic> toJson() => _$OrderAddressToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OrderAddress &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.floor, floor) ||
                const DeepCollectionEquality().equals(other.floor, floor)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.province, province) ||
                const DeepCollectionEquality()
                    .equals(other.province, province)) &&
            (identical(other.zip, zip) ||
                const DeepCollectionEquality().equals(other.zip, zip)) &&
            (identical(other.country, country) ||
                const DeepCollectionEquality().equals(other.country, country)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(floor) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(province) ^
      const DeepCollectionEquality().hash(zip) ^
      const DeepCollectionEquality().hash(country) ^
      runtimeType.hashCode;
}

extension $OrderAddressExtension on OrderAddress {
  OrderAddress copyWith(
      {String? address,
      String? floor,
      String? city,
      String? province,
      String? zip,
      String? country}) {
    return OrderAddress(
        address: address ?? this.address,
        floor: floor ?? this.floor,
        city: city ?? this.city,
        province: province ?? this.province,
        zip: zip ?? this.zip,
        country: country ?? this.country);
  }

  OrderAddress copyWithWrapped(
      {Wrapped<String?>? address,
      Wrapped<String?>? floor,
      Wrapped<String?>? city,
      Wrapped<String?>? province,
      Wrapped<String?>? zip,
      Wrapped<String?>? country}) {
    return OrderAddress(
        address: (address != null ? address.value : this.address),
        floor: (floor != null ? floor.value : this.floor),
        city: (city != null ? city.value : this.city),
        province: (province != null ? province.value : this.province),
        zip: (zip != null ? zip.value : this.zip),
        country: (country != null ? country.value : this.country));
  }
}

@JsonSerializable(explicitToJson: true)
class OrderItem {
  OrderItem({
    this.id,
    this.priceOption,
    this.serviceOption,
    this.partner,
    this.simplrService,
    this.serviceCategory,
    this.subscriptionId,
    this.orderId,
    this.discount,
    this.depositAmount,
    this.quantity,
  });

  factory OrderItem.fromJson(Map<String, dynamic> json) =>
      _$OrderItemFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'priceOption', includeIfNull: false)
  final PriceOption? priceOption;
  @JsonKey(name: 'serviceOption', includeIfNull: false)
  final ServiceOption? serviceOption;
  @JsonKey(name: 'partner', includeIfNull: false)
  final Partner? partner;
  @JsonKey(name: 'simplrService', includeIfNull: false)
  final SimplrService? simplrService;
  @JsonKey(name: 'serviceCategory', includeIfNull: false)
  final ServiceCategory? serviceCategory;
  @JsonKey(name: 'subscriptionId', includeIfNull: false)
  final num? subscriptionId;
  @JsonKey(name: 'orderId', includeIfNull: false)
  final num? orderId;
  @JsonKey(name: 'discount', includeIfNull: false)
  final Discount? discount;
  @JsonKey(name: 'depositAmount', includeIfNull: false)
  final double? depositAmount;
  @JsonKey(name: 'quantity', includeIfNull: false)
  final num? quantity;
  static const fromJsonFactory = _$OrderItemFromJson;
  static const toJsonFactory = _$OrderItemToJson;
  Map<String, dynamic> toJson() => _$OrderItemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OrderItem &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.priceOption, priceOption) ||
                const DeepCollectionEquality()
                    .equals(other.priceOption, priceOption)) &&
            (identical(other.serviceOption, serviceOption) ||
                const DeepCollectionEquality()
                    .equals(other.serviceOption, serviceOption)) &&
            (identical(other.partner, partner) ||
                const DeepCollectionEquality()
                    .equals(other.partner, partner)) &&
            (identical(other.simplrService, simplrService) ||
                const DeepCollectionEquality()
                    .equals(other.simplrService, simplrService)) &&
            (identical(other.serviceCategory, serviceCategory) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategory, serviceCategory)) &&
            (identical(other.subscriptionId, subscriptionId) ||
                const DeepCollectionEquality()
                    .equals(other.subscriptionId, subscriptionId)) &&
            (identical(other.orderId, orderId) ||
                const DeepCollectionEquality()
                    .equals(other.orderId, orderId)) &&
            (identical(other.discount, discount) ||
                const DeepCollectionEquality()
                    .equals(other.discount, discount)) &&
            (identical(other.depositAmount, depositAmount) ||
                const DeepCollectionEquality()
                    .equals(other.depositAmount, depositAmount)) &&
            (identical(other.quantity, quantity) ||
                const DeepCollectionEquality()
                    .equals(other.quantity, quantity)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(priceOption) ^
      const DeepCollectionEquality().hash(serviceOption) ^
      const DeepCollectionEquality().hash(partner) ^
      const DeepCollectionEquality().hash(simplrService) ^
      const DeepCollectionEquality().hash(serviceCategory) ^
      const DeepCollectionEquality().hash(subscriptionId) ^
      const DeepCollectionEquality().hash(orderId) ^
      const DeepCollectionEquality().hash(discount) ^
      const DeepCollectionEquality().hash(depositAmount) ^
      const DeepCollectionEquality().hash(quantity) ^
      runtimeType.hashCode;
}

extension $OrderItemExtension on OrderItem {
  OrderItem copyWith(
      {num? id,
      PriceOption? priceOption,
      ServiceOption? serviceOption,
      Partner? partner,
      SimplrService? simplrService,
      ServiceCategory? serviceCategory,
      num? subscriptionId,
      num? orderId,
      Discount? discount,
      double? depositAmount,
      num? quantity}) {
    return OrderItem(
        id: id ?? this.id,
        priceOption: priceOption ?? this.priceOption,
        serviceOption: serviceOption ?? this.serviceOption,
        partner: partner ?? this.partner,
        simplrService: simplrService ?? this.simplrService,
        serviceCategory: serviceCategory ?? this.serviceCategory,
        subscriptionId: subscriptionId ?? this.subscriptionId,
        orderId: orderId ?? this.orderId,
        discount: discount ?? this.discount,
        depositAmount: depositAmount ?? this.depositAmount,
        quantity: quantity ?? this.quantity);
  }

  OrderItem copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<PriceOption?>? priceOption,
      Wrapped<ServiceOption?>? serviceOption,
      Wrapped<Partner?>? partner,
      Wrapped<SimplrService?>? simplrService,
      Wrapped<ServiceCategory?>? serviceCategory,
      Wrapped<num?>? subscriptionId,
      Wrapped<num?>? orderId,
      Wrapped<Discount?>? discount,
      Wrapped<double?>? depositAmount,
      Wrapped<num?>? quantity}) {
    return OrderItem(
        id: (id != null ? id.value : this.id),
        priceOption:
            (priceOption != null ? priceOption.value : this.priceOption),
        serviceOption:
            (serviceOption != null ? serviceOption.value : this.serviceOption),
        partner: (partner != null ? partner.value : this.partner),
        simplrService:
            (simplrService != null ? simplrService.value : this.simplrService),
        serviceCategory: (serviceCategory != null
            ? serviceCategory.value
            : this.serviceCategory),
        subscriptionId: (subscriptionId != null
            ? subscriptionId.value
            : this.subscriptionId),
        orderId: (orderId != null ? orderId.value : this.orderId),
        discount: (discount != null ? discount.value : this.discount),
        depositAmount:
            (depositAmount != null ? depositAmount.value : this.depositAmount),
        quantity: (quantity != null ? quantity.value : this.quantity));
  }
}

@JsonSerializable(explicitToJson: true)
class Contact {
  Contact({
    this.id,
    this.email,
    this.phone,
    this.name,
    this.isPartner,
    this.companyName,
    this.products,
    this.userLanguage,
    this.newsletterSignupValidated,
    this.isB2B,
    this.productOfInterest,
    this.bestTimeToContact,
    this.associate,
  });

  factory Contact.fromJson(Map<String, dynamic> json) =>
      _$ContactFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'isPartner', includeIfNull: false)
  final bool? isPartner;
  @JsonKey(name: 'companyName', includeIfNull: false, defaultValue: '')
  final String? companyName;
  @JsonKey(name: 'products', includeIfNull: false, defaultValue: '')
  final String? products;
  @JsonKey(name: 'userLanguage', includeIfNull: false, defaultValue: '')
  final String? userLanguage;
  @JsonKey(name: 'newsletterSignupValidated', includeIfNull: false)
  final bool? newsletterSignupValidated;
  @JsonKey(name: 'isB2B', includeIfNull: false, defaultValue: false)
  final bool? isB2B;
  @JsonKey(name: 'productOfInterest', includeIfNull: false, defaultValue: '')
  final String? productOfInterest;
  @JsonKey(name: 'bestTimeToContact', includeIfNull: false, defaultValue: '')
  final String? bestTimeToContact;
  @JsonKey(name: 'associate', includeIfNull: false, defaultValue: '')
  final String? associate;
  static const fromJsonFactory = _$ContactFromJson;
  static const toJsonFactory = _$ContactToJson;
  Map<String, dynamic> toJson() => _$ContactToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Contact &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.isPartner, isPartner) ||
                const DeepCollectionEquality()
                    .equals(other.isPartner, isPartner)) &&
            (identical(other.companyName, companyName) ||
                const DeepCollectionEquality()
                    .equals(other.companyName, companyName)) &&
            (identical(other.products, products) ||
                const DeepCollectionEquality()
                    .equals(other.products, products)) &&
            (identical(other.userLanguage, userLanguage) ||
                const DeepCollectionEquality()
                    .equals(other.userLanguage, userLanguage)) &&
            (identical(other.newsletterSignupValidated,
                    newsletterSignupValidated) ||
                const DeepCollectionEquality().equals(
                    other.newsletterSignupValidated,
                    newsletterSignupValidated)) &&
            (identical(other.isB2B, isB2B) ||
                const DeepCollectionEquality().equals(other.isB2B, isB2B)) &&
            (identical(other.productOfInterest, productOfInterest) ||
                const DeepCollectionEquality()
                    .equals(other.productOfInterest, productOfInterest)) &&
            (identical(other.bestTimeToContact, bestTimeToContact) ||
                const DeepCollectionEquality()
                    .equals(other.bestTimeToContact, bestTimeToContact)) &&
            (identical(other.associate, associate) ||
                const DeepCollectionEquality()
                    .equals(other.associate, associate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(isPartner) ^
      const DeepCollectionEquality().hash(companyName) ^
      const DeepCollectionEquality().hash(products) ^
      const DeepCollectionEquality().hash(userLanguage) ^
      const DeepCollectionEquality().hash(newsletterSignupValidated) ^
      const DeepCollectionEquality().hash(isB2B) ^
      const DeepCollectionEquality().hash(productOfInterest) ^
      const DeepCollectionEquality().hash(bestTimeToContact) ^
      const DeepCollectionEquality().hash(associate) ^
      runtimeType.hashCode;
}

extension $ContactExtension on Contact {
  Contact copyWith(
      {num? id,
      String? email,
      String? phone,
      String? name,
      bool? isPartner,
      String? companyName,
      String? products,
      String? userLanguage,
      bool? newsletterSignupValidated,
      bool? isB2B,
      String? productOfInterest,
      String? bestTimeToContact,
      String? associate}) {
    return Contact(
        id: id ?? this.id,
        email: email ?? this.email,
        phone: phone ?? this.phone,
        name: name ?? this.name,
        isPartner: isPartner ?? this.isPartner,
        companyName: companyName ?? this.companyName,
        products: products ?? this.products,
        userLanguage: userLanguage ?? this.userLanguage,
        newsletterSignupValidated:
            newsletterSignupValidated ?? this.newsletterSignupValidated,
        isB2B: isB2B ?? this.isB2B,
        productOfInterest: productOfInterest ?? this.productOfInterest,
        bestTimeToContact: bestTimeToContact ?? this.bestTimeToContact,
        associate: associate ?? this.associate);
  }

  Contact copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? email,
      Wrapped<String?>? phone,
      Wrapped<String?>? name,
      Wrapped<bool?>? isPartner,
      Wrapped<String?>? companyName,
      Wrapped<String?>? products,
      Wrapped<String?>? userLanguage,
      Wrapped<bool?>? newsletterSignupValidated,
      Wrapped<bool?>? isB2B,
      Wrapped<String?>? productOfInterest,
      Wrapped<String?>? bestTimeToContact,
      Wrapped<String?>? associate}) {
    return Contact(
        id: (id != null ? id.value : this.id),
        email: (email != null ? email.value : this.email),
        phone: (phone != null ? phone.value : this.phone),
        name: (name != null ? name.value : this.name),
        isPartner: (isPartner != null ? isPartner.value : this.isPartner),
        companyName:
            (companyName != null ? companyName.value : this.companyName),
        products: (products != null ? products.value : this.products),
        userLanguage:
            (userLanguage != null ? userLanguage.value : this.userLanguage),
        newsletterSignupValidated: (newsletterSignupValidated != null
            ? newsletterSignupValidated.value
            : this.newsletterSignupValidated),
        isB2B: (isB2B != null ? isB2B.value : this.isB2B),
        productOfInterest: (productOfInterest != null
            ? productOfInterest.value
            : this.productOfInterest),
        bestTimeToContact: (bestTimeToContact != null
            ? bestTimeToContact.value
            : this.bestTimeToContact),
        associate: (associate != null ? associate.value : this.associate));
  }
}

@JsonSerializable(explicitToJson: true)
class Suggestion {
  Suggestion({
    this.id,
    this.description,
    this.created,
  });

  factory Suggestion.fromJson(Map<String, dynamic> json) =>
      _$SuggestionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'created', includeIfNull: false)
  final DateTime? created;
  static const fromJsonFactory = _$SuggestionFromJson;
  static const toJsonFactory = _$SuggestionToJson;
  Map<String, dynamic> toJson() => _$SuggestionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Suggestion &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.created, created) ||
                const DeepCollectionEquality().equals(other.created, created)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(created) ^
      runtimeType.hashCode;
}

extension $SuggestionExtension on Suggestion {
  Suggestion copyWith({num? id, String? description, DateTime? created}) {
    return Suggestion(
        id: id ?? this.id,
        description: description ?? this.description,
        created: created ?? this.created);
  }

  Suggestion copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? description,
      Wrapped<DateTime?>? created}) {
    return Suggestion(
        id: (id != null ? id.value : this.id),
        description:
            (description != null ? description.value : this.description),
        created: (created != null ? created.value : this.created));
  }
}

@JsonSerializable(explicitToJson: true)
class Suggestions {
  Suggestions({
    this.suggestions,
  });

  factory Suggestions.fromJson(Map<String, dynamic> json) =>
      _$SuggestionsFromJson(json);

  @JsonKey(
      name: 'suggestions', includeIfNull: false, defaultValue: <Suggestion>[])
  final List<Suggestion>? suggestions;
  static const fromJsonFactory = _$SuggestionsFromJson;
  static const toJsonFactory = _$SuggestionsToJson;
  Map<String, dynamic> toJson() => _$SuggestionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Suggestions &&
            (identical(other.suggestions, suggestions) ||
                const DeepCollectionEquality()
                    .equals(other.suggestions, suggestions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(suggestions) ^ runtimeType.hashCode;
}

extension $SuggestionsExtension on Suggestions {
  Suggestions copyWith({List<Suggestion>? suggestions}) {
    return Suggestions(suggestions: suggestions ?? this.suggestions);
  }

  Suggestions copyWithWrapped({Wrapped<List<Suggestion>?>? suggestions}) {
    return Suggestions(
        suggestions:
            (suggestions != null ? suggestions.value : this.suggestions));
  }
}

@JsonSerializable(explicitToJson: true)
class PartnerOptions {
  PartnerOptions({
    this.partner,
    this.options,
  });

  factory PartnerOptions.fromJson(Map<String, dynamic> json) =>
      _$PartnerOptionsFromJson(json);

  @JsonKey(name: 'partner', includeIfNull: false)
  final Partner? partner;
  @JsonKey(
      name: 'options', includeIfNull: false, defaultValue: <ServiceOption>[])
  final List<ServiceOption>? options;
  static const fromJsonFactory = _$PartnerOptionsFromJson;
  static const toJsonFactory = _$PartnerOptionsToJson;
  Map<String, dynamic> toJson() => _$PartnerOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PartnerOptions &&
            (identical(other.partner, partner) ||
                const DeepCollectionEquality()
                    .equals(other.partner, partner)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality().equals(other.options, options)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(partner) ^
      const DeepCollectionEquality().hash(options) ^
      runtimeType.hashCode;
}

extension $PartnerOptionsExtension on PartnerOptions {
  PartnerOptions copyWith({Partner? partner, List<ServiceOption>? options}) {
    return PartnerOptions(
        partner: partner ?? this.partner, options: options ?? this.options);
  }

  PartnerOptions copyWithWrapped(
      {Wrapped<Partner?>? partner, Wrapped<List<ServiceOption>?>? options}) {
    return PartnerOptions(
        partner: (partner != null ? partner.value : this.partner),
        options: (options != null ? options.value : this.options));
  }
}

@JsonSerializable(explicitToJson: true)
class TaskSummary {
  TaskSummary({
    this.partnerOptions,
  });

  factory TaskSummary.fromJson(Map<String, dynamic> json) =>
      _$TaskSummaryFromJson(json);

  @JsonKey(
      name: 'partnerOptions',
      includeIfNull: false,
      defaultValue: <PartnerOptions>[])
  final List<PartnerOptions>? partnerOptions;
  static const fromJsonFactory = _$TaskSummaryFromJson;
  static const toJsonFactory = _$TaskSummaryToJson;
  Map<String, dynamic> toJson() => _$TaskSummaryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaskSummary &&
            (identical(other.partnerOptions, partnerOptions) ||
                const DeepCollectionEquality()
                    .equals(other.partnerOptions, partnerOptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(partnerOptions) ^
      runtimeType.hashCode;
}

extension $TaskSummaryExtension on TaskSummary {
  TaskSummary copyWith({List<PartnerOptions>? partnerOptions}) {
    return TaskSummary(partnerOptions: partnerOptions ?? this.partnerOptions);
  }

  TaskSummary copyWithWrapped(
      {Wrapped<List<PartnerOptions>?>? partnerOptions}) {
    return TaskSummary(
        partnerOptions: (partnerOptions != null
            ? partnerOptions.value
            : this.partnerOptions));
  }
}

@JsonSerializable(explicitToJson: true)
class Subscription {
  Subscription({
    this.id,
    this.startDate,
    this.dueDate,
    this.active,
    this.archived,
    this.cancelAtPeriodEnd,
    this.quantity,
    this.permanenceDate,
    this.billing,
    this.serviceOption,
    this.partner,
    this.simplrService,
    this.orderItem,
    this.priceOption,
    this.status,
    this.userEmail,
    this.userFirstName,
    this.userLastName,
    this.rating,
  });

  factory Subscription.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'dueDate', includeIfNull: false)
  final DateTime? dueDate;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: false)
  final bool? active;
  @JsonKey(name: 'archived', includeIfNull: false, defaultValue: false)
  final bool? archived;
  @JsonKey(name: 'cancelAtPeriodEnd', includeIfNull: false)
  final bool? cancelAtPeriodEnd;
  @JsonKey(name: 'quantity', includeIfNull: false)
  final int? quantity;
  @JsonKey(name: 'permanenceDate', includeIfNull: false)
  final DateTime? permanenceDate;
  @JsonKey(name: 'billing', includeIfNull: false)
  final SubscriptionBilling? billing;
  @JsonKey(name: 'serviceOption', includeIfNull: false)
  final ServiceOption? serviceOption;
  @JsonKey(name: 'partner', includeIfNull: false)
  final Partner? partner;
  @JsonKey(name: 'simplrService', includeIfNull: false)
  final SimplrService? simplrService;
  @JsonKey(name: 'orderItem', includeIfNull: false)
  final OrderItem? orderItem;
  @JsonKey(name: 'priceOption', includeIfNull: false)
  final PriceOption? priceOption;
  @JsonKey(
    name: 'status',
    includeIfNull: false,
    toJson: subscriptionStatusToJson,
    fromJson: subscriptionStatusFromJson,
  )
  final enums.SubscriptionStatus? status;
  @JsonKey(name: 'userEmail', includeIfNull: false, defaultValue: '')
  final String? userEmail;
  @JsonKey(name: 'userFirstName', includeIfNull: false, defaultValue: '')
  final String? userFirstName;
  @JsonKey(name: 'userLastName', includeIfNull: false, defaultValue: '')
  final String? userLastName;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  static const fromJsonFactory = _$SubscriptionFromJson;
  static const toJsonFactory = _$SubscriptionToJson;
  Map<String, dynamic> toJson() => _$SubscriptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Subscription &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.dueDate, dueDate) ||
                const DeepCollectionEquality()
                    .equals(other.dueDate, dueDate)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.archived, archived) ||
                const DeepCollectionEquality()
                    .equals(other.archived, archived)) &&
            (identical(other.cancelAtPeriodEnd, cancelAtPeriodEnd) ||
                const DeepCollectionEquality()
                    .equals(other.cancelAtPeriodEnd, cancelAtPeriodEnd)) &&
            (identical(other.quantity, quantity) ||
                const DeepCollectionEquality()
                    .equals(other.quantity, quantity)) &&
            (identical(other.permanenceDate, permanenceDate) ||
                const DeepCollectionEquality()
                    .equals(other.permanenceDate, permanenceDate)) &&
            (identical(other.billing, billing) ||
                const DeepCollectionEquality()
                    .equals(other.billing, billing)) &&
            (identical(other.serviceOption, serviceOption) ||
                const DeepCollectionEquality()
                    .equals(other.serviceOption, serviceOption)) &&
            (identical(other.partner, partner) ||
                const DeepCollectionEquality()
                    .equals(other.partner, partner)) &&
            (identical(other.simplrService, simplrService) ||
                const DeepCollectionEquality()
                    .equals(other.simplrService, simplrService)) &&
            (identical(other.orderItem, orderItem) ||
                const DeepCollectionEquality()
                    .equals(other.orderItem, orderItem)) &&
            (identical(other.priceOption, priceOption) ||
                const DeepCollectionEquality()
                    .equals(other.priceOption, priceOption)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.userEmail, userEmail) ||
                const DeepCollectionEquality()
                    .equals(other.userEmail, userEmail)) &&
            (identical(other.userFirstName, userFirstName) ||
                const DeepCollectionEquality()
                    .equals(other.userFirstName, userFirstName)) &&
            (identical(other.userLastName, userLastName) ||
                const DeepCollectionEquality()
                    .equals(other.userLastName, userLastName)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(dueDate) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(archived) ^
      const DeepCollectionEquality().hash(cancelAtPeriodEnd) ^
      const DeepCollectionEquality().hash(quantity) ^
      const DeepCollectionEquality().hash(permanenceDate) ^
      const DeepCollectionEquality().hash(billing) ^
      const DeepCollectionEquality().hash(serviceOption) ^
      const DeepCollectionEquality().hash(partner) ^
      const DeepCollectionEquality().hash(simplrService) ^
      const DeepCollectionEquality().hash(orderItem) ^
      const DeepCollectionEquality().hash(priceOption) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(userEmail) ^
      const DeepCollectionEquality().hash(userFirstName) ^
      const DeepCollectionEquality().hash(userLastName) ^
      const DeepCollectionEquality().hash(rating) ^
      runtimeType.hashCode;
}

extension $SubscriptionExtension on Subscription {
  Subscription copyWith(
      {num? id,
      DateTime? startDate,
      DateTime? dueDate,
      bool? active,
      bool? archived,
      bool? cancelAtPeriodEnd,
      int? quantity,
      DateTime? permanenceDate,
      SubscriptionBilling? billing,
      ServiceOption? serviceOption,
      Partner? partner,
      SimplrService? simplrService,
      OrderItem? orderItem,
      PriceOption? priceOption,
      enums.SubscriptionStatus? status,
      String? userEmail,
      String? userFirstName,
      String? userLastName,
      double? rating}) {
    return Subscription(
        id: id ?? this.id,
        startDate: startDate ?? this.startDate,
        dueDate: dueDate ?? this.dueDate,
        active: active ?? this.active,
        archived: archived ?? this.archived,
        cancelAtPeriodEnd: cancelAtPeriodEnd ?? this.cancelAtPeriodEnd,
        quantity: quantity ?? this.quantity,
        permanenceDate: permanenceDate ?? this.permanenceDate,
        billing: billing ?? this.billing,
        serviceOption: serviceOption ?? this.serviceOption,
        partner: partner ?? this.partner,
        simplrService: simplrService ?? this.simplrService,
        orderItem: orderItem ?? this.orderItem,
        priceOption: priceOption ?? this.priceOption,
        status: status ?? this.status,
        userEmail: userEmail ?? this.userEmail,
        userFirstName: userFirstName ?? this.userFirstName,
        userLastName: userLastName ?? this.userLastName,
        rating: rating ?? this.rating);
  }

  Subscription copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? dueDate,
      Wrapped<bool?>? active,
      Wrapped<bool?>? archived,
      Wrapped<bool?>? cancelAtPeriodEnd,
      Wrapped<int?>? quantity,
      Wrapped<DateTime?>? permanenceDate,
      Wrapped<SubscriptionBilling?>? billing,
      Wrapped<ServiceOption?>? serviceOption,
      Wrapped<Partner?>? partner,
      Wrapped<SimplrService?>? simplrService,
      Wrapped<OrderItem?>? orderItem,
      Wrapped<PriceOption?>? priceOption,
      Wrapped<enums.SubscriptionStatus?>? status,
      Wrapped<String?>? userEmail,
      Wrapped<String?>? userFirstName,
      Wrapped<String?>? userLastName,
      Wrapped<double?>? rating}) {
    return Subscription(
        id: (id != null ? id.value : this.id),
        startDate: (startDate != null ? startDate.value : this.startDate),
        dueDate: (dueDate != null ? dueDate.value : this.dueDate),
        active: (active != null ? active.value : this.active),
        archived: (archived != null ? archived.value : this.archived),
        cancelAtPeriodEnd: (cancelAtPeriodEnd != null
            ? cancelAtPeriodEnd.value
            : this.cancelAtPeriodEnd),
        quantity: (quantity != null ? quantity.value : this.quantity),
        permanenceDate: (permanenceDate != null
            ? permanenceDate.value
            : this.permanenceDate),
        billing: (billing != null ? billing.value : this.billing),
        serviceOption:
            (serviceOption != null ? serviceOption.value : this.serviceOption),
        partner: (partner != null ? partner.value : this.partner),
        simplrService:
            (simplrService != null ? simplrService.value : this.simplrService),
        orderItem: (orderItem != null ? orderItem.value : this.orderItem),
        priceOption:
            (priceOption != null ? priceOption.value : this.priceOption),
        status: (status != null ? status.value : this.status),
        userEmail: (userEmail != null ? userEmail.value : this.userEmail),
        userFirstName:
            (userFirstName != null ? userFirstName.value : this.userFirstName),
        userLastName:
            (userLastName != null ? userLastName.value : this.userLastName),
        rating: (rating != null ? rating.value : this.rating));
  }
}

@JsonSerializable(explicitToJson: true)
class Subscriptions {
  Subscriptions({
    this.subscriptions,
  });

  factory Subscriptions.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionsFromJson(json);

  @JsonKey(
      name: 'subscriptions',
      includeIfNull: false,
      defaultValue: <Subscription>[])
  final List<Subscription>? subscriptions;
  static const fromJsonFactory = _$SubscriptionsFromJson;
  static const toJsonFactory = _$SubscriptionsToJson;
  Map<String, dynamic> toJson() => _$SubscriptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Subscriptions &&
            (identical(other.subscriptions, subscriptions) ||
                const DeepCollectionEquality()
                    .equals(other.subscriptions, subscriptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(subscriptions) ^ runtimeType.hashCode;
}

extension $SubscriptionsExtension on Subscriptions {
  Subscriptions copyWith({List<Subscription>? subscriptions}) {
    return Subscriptions(subscriptions: subscriptions ?? this.subscriptions);
  }

  Subscriptions copyWithWrapped({Wrapped<List<Subscription>?>? subscriptions}) {
    return Subscriptions(
        subscriptions:
            (subscriptions != null ? subscriptions.value : this.subscriptions));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionCriteria {
  SubscriptionCriteria({
    this.id,
    this.dueDate,
    this.startDate,
    this.active,
    this.archived,
    this.rating,
    this.jobId,
    this.orderItemId,
    this.orderId,
    this.simplrServiceOptionId,
    this.userLogin,
    this.userId,
    this.userEmail,
    this.status,
  });

  factory SubscriptionCriteria.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'dueDate', includeIfNull: false)
  final InstantFilter? dueDate;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final InstantFilter? startDate;
  @JsonKey(name: 'active', includeIfNull: false)
  final BooleanFilter? active;
  @JsonKey(name: 'archived', includeIfNull: false)
  final BooleanFilter? archived;
  @JsonKey(name: 'rating', includeIfNull: false)
  final BigDecimalFilter? rating;
  @JsonKey(name: 'jobId', includeIfNull: false)
  final LongFilter? jobId;
  @JsonKey(name: 'orderItemId', includeIfNull: false)
  final LongFilter? orderItemId;
  @JsonKey(name: 'orderId', includeIfNull: false)
  final LongFilter? orderId;
  @JsonKey(name: 'simplrServiceOptionId', includeIfNull: false)
  final LongFilter? simplrServiceOptionId;
  @JsonKey(name: 'userLogin', includeIfNull: false)
  final StringFilter? userLogin;
  @JsonKey(name: 'userId', includeIfNull: false)
  final StringFilter? userId;
  @JsonKey(name: 'userEmail', includeIfNull: false)
  final StringFilter? userEmail;
  @JsonKey(name: 'status', includeIfNull: false)
  final SubscriptionStatusFilter? status;
  static const fromJsonFactory = _$SubscriptionCriteriaFromJson;
  static const toJsonFactory = _$SubscriptionCriteriaToJson;
  Map<String, dynamic> toJson() => _$SubscriptionCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.dueDate, dueDate) ||
                const DeepCollectionEquality()
                    .equals(other.dueDate, dueDate)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.archived, archived) ||
                const DeepCollectionEquality()
                    .equals(other.archived, archived)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.jobId, jobId) ||
                const DeepCollectionEquality().equals(other.jobId, jobId)) &&
            (identical(other.orderItemId, orderItemId) ||
                const DeepCollectionEquality()
                    .equals(other.orderItemId, orderItemId)) &&
            (identical(other.orderId, orderId) ||
                const DeepCollectionEquality()
                    .equals(other.orderId, orderId)) &&
            (identical(other.simplrServiceOptionId, simplrServiceOptionId) ||
                const DeepCollectionEquality().equals(
                    other.simplrServiceOptionId, simplrServiceOptionId)) &&
            (identical(other.userLogin, userLogin) ||
                const DeepCollectionEquality()
                    .equals(other.userLogin, userLogin)) &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)) &&
            (identical(other.userEmail, userEmail) ||
                const DeepCollectionEquality()
                    .equals(other.userEmail, userEmail)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(dueDate) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(archived) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(jobId) ^
      const DeepCollectionEquality().hash(orderItemId) ^
      const DeepCollectionEquality().hash(orderId) ^
      const DeepCollectionEquality().hash(simplrServiceOptionId) ^
      const DeepCollectionEquality().hash(userLogin) ^
      const DeepCollectionEquality().hash(userId) ^
      const DeepCollectionEquality().hash(userEmail) ^
      const DeepCollectionEquality().hash(status) ^
      runtimeType.hashCode;
}

extension $SubscriptionCriteriaExtension on SubscriptionCriteria {
  SubscriptionCriteria copyWith(
      {LongFilter? id,
      InstantFilter? dueDate,
      InstantFilter? startDate,
      BooleanFilter? active,
      BooleanFilter? archived,
      BigDecimalFilter? rating,
      LongFilter? jobId,
      LongFilter? orderItemId,
      LongFilter? orderId,
      LongFilter? simplrServiceOptionId,
      StringFilter? userLogin,
      StringFilter? userId,
      StringFilter? userEmail,
      SubscriptionStatusFilter? status}) {
    return SubscriptionCriteria(
        id: id ?? this.id,
        dueDate: dueDate ?? this.dueDate,
        startDate: startDate ?? this.startDate,
        active: active ?? this.active,
        archived: archived ?? this.archived,
        rating: rating ?? this.rating,
        jobId: jobId ?? this.jobId,
        orderItemId: orderItemId ?? this.orderItemId,
        orderId: orderId ?? this.orderId,
        simplrServiceOptionId:
            simplrServiceOptionId ?? this.simplrServiceOptionId,
        userLogin: userLogin ?? this.userLogin,
        userId: userId ?? this.userId,
        userEmail: userEmail ?? this.userEmail,
        status: status ?? this.status);
  }

  SubscriptionCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<InstantFilter?>? dueDate,
      Wrapped<InstantFilter?>? startDate,
      Wrapped<BooleanFilter?>? active,
      Wrapped<BooleanFilter?>? archived,
      Wrapped<BigDecimalFilter?>? rating,
      Wrapped<LongFilter?>? jobId,
      Wrapped<LongFilter?>? orderItemId,
      Wrapped<LongFilter?>? orderId,
      Wrapped<LongFilter?>? simplrServiceOptionId,
      Wrapped<StringFilter?>? userLogin,
      Wrapped<StringFilter?>? userId,
      Wrapped<StringFilter?>? userEmail,
      Wrapped<SubscriptionStatusFilter?>? status}) {
    return SubscriptionCriteria(
        id: (id != null ? id.value : this.id),
        dueDate: (dueDate != null ? dueDate.value : this.dueDate),
        startDate: (startDate != null ? startDate.value : this.startDate),
        active: (active != null ? active.value : this.active),
        archived: (archived != null ? archived.value : this.archived),
        rating: (rating != null ? rating.value : this.rating),
        jobId: (jobId != null ? jobId.value : this.jobId),
        orderItemId:
            (orderItemId != null ? orderItemId.value : this.orderItemId),
        orderId: (orderId != null ? orderId.value : this.orderId),
        simplrServiceOptionId: (simplrServiceOptionId != null
            ? simplrServiceOptionId.value
            : this.simplrServiceOptionId),
        userLogin: (userLogin != null ? userLogin.value : this.userLogin),
        userId: (userId != null ? userId.value : this.userId),
        userEmail: (userEmail != null ? userEmail.value : this.userEmail),
        status: (status != null ? status.value : this.status));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionBilling {
  SubscriptionBilling({
    this.date,
    this.total,
  });

  factory SubscriptionBilling.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionBillingFromJson(json);

  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'total', includeIfNull: false)
  final double? total;
  static const fromJsonFactory = _$SubscriptionBillingFromJson;
  static const toJsonFactory = _$SubscriptionBillingToJson;
  Map<String, dynamic> toJson() => _$SubscriptionBillingToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionBilling &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.total, total) ||
                const DeepCollectionEquality().equals(other.total, total)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(total) ^
      runtimeType.hashCode;
}

extension $SubscriptionBillingExtension on SubscriptionBilling {
  SubscriptionBilling copyWith({DateTime? date, double? total}) {
    return SubscriptionBilling(
        date: date ?? this.date, total: total ?? this.total);
  }

  SubscriptionBilling copyWithWrapped(
      {Wrapped<DateTime?>? date, Wrapped<double?>? total}) {
    return SubscriptionBilling(
        date: (date != null ? date.value : this.date),
        total: (total != null ? total.value : this.total));
  }
}

@JsonSerializable(explicitToJson: true)
class Issue {
  Issue({
    this.id,
    this.subject,
    this.category,
    this.description,
    this.imageUrl,
    this.crmId,
    this.crmEmailContact,
    this.createDate,
    this.serviceId,
    this.serviceOptionId,
  });

  factory Issue.fromJson(Map<String, dynamic> json) => _$IssueFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'subject', includeIfNull: false, defaultValue: '')
  final String? subject;
  @JsonKey(name: 'category', includeIfNull: false, defaultValue: '')
  final String? category;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'crmId', includeIfNull: false, defaultValue: '')
  final String? crmId;
  @JsonKey(name: 'crmEmailContact', includeIfNull: false, defaultValue: '')
  final String? crmEmailContact;
  @JsonKey(name: 'createDate', includeIfNull: false, defaultValue: '')
  final String? createDate;
  @JsonKey(name: 'serviceId', includeIfNull: false, defaultValue: '')
  final String? serviceId;
  @JsonKey(name: 'serviceOptionId', includeIfNull: false, defaultValue: '')
  final String? serviceOptionId;
  static const fromJsonFactory = _$IssueFromJson;
  static const toJsonFactory = _$IssueToJson;
  Map<String, dynamic> toJson() => _$IssueToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Issue &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.subject, subject) ||
                const DeepCollectionEquality()
                    .equals(other.subject, subject)) &&
            (identical(other.category, category) ||
                const DeepCollectionEquality()
                    .equals(other.category, category)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.crmId, crmId) ||
                const DeepCollectionEquality().equals(other.crmId, crmId)) &&
            (identical(other.crmEmailContact, crmEmailContact) ||
                const DeepCollectionEquality()
                    .equals(other.crmEmailContact, crmEmailContact)) &&
            (identical(other.createDate, createDate) ||
                const DeepCollectionEquality()
                    .equals(other.createDate, createDate)) &&
            (identical(other.serviceId, serviceId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceId, serviceId)) &&
            (identical(other.serviceOptionId, serviceOptionId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceOptionId, serviceOptionId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(subject) ^
      const DeepCollectionEquality().hash(category) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(crmId) ^
      const DeepCollectionEquality().hash(crmEmailContact) ^
      const DeepCollectionEquality().hash(createDate) ^
      const DeepCollectionEquality().hash(serviceId) ^
      const DeepCollectionEquality().hash(serviceOptionId) ^
      runtimeType.hashCode;
}

extension $IssueExtension on Issue {
  Issue copyWith(
      {num? id,
      String? subject,
      String? category,
      String? description,
      String? imageUrl,
      String? crmId,
      String? crmEmailContact,
      String? createDate,
      String? serviceId,
      String? serviceOptionId}) {
    return Issue(
        id: id ?? this.id,
        subject: subject ?? this.subject,
        category: category ?? this.category,
        description: description ?? this.description,
        imageUrl: imageUrl ?? this.imageUrl,
        crmId: crmId ?? this.crmId,
        crmEmailContact: crmEmailContact ?? this.crmEmailContact,
        createDate: createDate ?? this.createDate,
        serviceId: serviceId ?? this.serviceId,
        serviceOptionId: serviceOptionId ?? this.serviceOptionId);
  }

  Issue copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? subject,
      Wrapped<String?>? category,
      Wrapped<String?>? description,
      Wrapped<String?>? imageUrl,
      Wrapped<String?>? crmId,
      Wrapped<String?>? crmEmailContact,
      Wrapped<String?>? createDate,
      Wrapped<String?>? serviceId,
      Wrapped<String?>? serviceOptionId}) {
    return Issue(
        id: (id != null ? id.value : this.id),
        subject: (subject != null ? subject.value : this.subject),
        category: (category != null ? category.value : this.category),
        description:
            (description != null ? description.value : this.description),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        crmId: (crmId != null ? crmId.value : this.crmId),
        crmEmailContact: (crmEmailContact != null
            ? crmEmailContact.value
            : this.crmEmailContact),
        createDate: (createDate != null ? createDate.value : this.createDate),
        serviceId: (serviceId != null ? serviceId.value : this.serviceId),
        serviceOptionId: (serviceOptionId != null
            ? serviceOptionId.value
            : this.serviceOptionId));
  }
}

typedef Issues = List<Issue>;

@JsonSerializable(explicitToJson: true)
class User {
  User({
    this.id,
    this.firstName,
    this.lastName,
    required this.email,
    this.address,
    this.newUser,
    this.associateId,
    this.associateName,
  });

  factory User.fromJson(Map<String, dynamic> json) => _$UserFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'address', includeIfNull: false, defaultValue: '')
  final String? address;
  @JsonKey(name: 'newUser', includeIfNull: false)
  final bool? newUser;
  @JsonKey(name: 'associateId', includeIfNull: false)
  final num? associateId;
  @JsonKey(name: 'associateName', includeIfNull: false, defaultValue: '')
  final String? associateName;
  static const fromJsonFactory = _$UserFromJson;
  static const toJsonFactory = _$UserToJson;
  Map<String, dynamic> toJson() => _$UserToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is User &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.newUser, newUser) ||
                const DeepCollectionEquality()
                    .equals(other.newUser, newUser)) &&
            (identical(other.associateId, associateId) ||
                const DeepCollectionEquality()
                    .equals(other.associateId, associateId)) &&
            (identical(other.associateName, associateName) ||
                const DeepCollectionEquality()
                    .equals(other.associateName, associateName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(newUser) ^
      const DeepCollectionEquality().hash(associateId) ^
      const DeepCollectionEquality().hash(associateName) ^
      runtimeType.hashCode;
}

extension $UserExtension on User {
  User copyWith(
      {String? id,
      String? firstName,
      String? lastName,
      String? email,
      String? address,
      bool? newUser,
      num? associateId,
      String? associateName}) {
    return User(
        id: id ?? this.id,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        email: email ?? this.email,
        address: address ?? this.address,
        newUser: newUser ?? this.newUser,
        associateId: associateId ?? this.associateId,
        associateName: associateName ?? this.associateName);
  }

  User copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String>? email,
      Wrapped<String?>? address,
      Wrapped<bool?>? newUser,
      Wrapped<num?>? associateId,
      Wrapped<String?>? associateName}) {
    return User(
        id: (id != null ? id.value : this.id),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        email: (email != null ? email.value : this.email),
        address: (address != null ? address.value : this.address),
        newUser: (newUser != null ? newUser.value : this.newUser),
        associateId:
            (associateId != null ? associateId.value : this.associateId),
        associateName:
            (associateName != null ? associateName.value : this.associateName));
  }
}

typedef Users = List<User>;

@JsonSerializable(explicitToJson: true)
class UserRegister {
  UserRegister({
    required this.email,
    required this.password,
    this.subNewsletter,
  });

  factory UserRegister.fromJson(Map<String, dynamic> json) =>
      _$UserRegisterFromJson(json);

  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  @JsonKey(name: 'subNewsletter', includeIfNull: false)
  final bool? subNewsletter;
  static const fromJsonFactory = _$UserRegisterFromJson;
  static const toJsonFactory = _$UserRegisterToJson;
  Map<String, dynamic> toJson() => _$UserRegisterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserRegister &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.subNewsletter, subNewsletter) ||
                const DeepCollectionEquality()
                    .equals(other.subNewsletter, subNewsletter)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(subNewsletter) ^
      runtimeType.hashCode;
}

extension $UserRegisterExtension on UserRegister {
  UserRegister copyWith(
      {String? email, String? password, bool? subNewsletter}) {
    return UserRegister(
        email: email ?? this.email,
        password: password ?? this.password,
        subNewsletter: subNewsletter ?? this.subNewsletter);
  }

  UserRegister copyWithWrapped(
      {Wrapped<String>? email,
      Wrapped<String>? password,
      Wrapped<bool?>? subNewsletter}) {
    return UserRegister(
        email: (email != null ? email.value : this.email),
        password: (password != null ? password.value : this.password),
        subNewsletter:
            (subNewsletter != null ? subNewsletter.value : this.subNewsletter));
  }
}

@JsonSerializable(explicitToJson: true)
class UserNewPassword {
  UserNewPassword({
    required this.key,
    required this.newPassword,
  });

  factory UserNewPassword.fromJson(Map<String, dynamic> json) =>
      _$UserNewPasswordFromJson(json);

  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String key;
  @JsonKey(name: 'newPassword', includeIfNull: false, defaultValue: '')
  final String newPassword;
  static const fromJsonFactory = _$UserNewPasswordFromJson;
  static const toJsonFactory = _$UserNewPasswordToJson;
  Map<String, dynamic> toJson() => _$UserNewPasswordToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserNewPassword &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.newPassword, newPassword) ||
                const DeepCollectionEquality()
                    .equals(other.newPassword, newPassword)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(newPassword) ^
      runtimeType.hashCode;
}

extension $UserNewPasswordExtension on UserNewPassword {
  UserNewPassword copyWith({String? key, String? newPassword}) {
    return UserNewPassword(
        key: key ?? this.key, newPassword: newPassword ?? this.newPassword);
  }

  UserNewPassword copyWithWrapped(
      {Wrapped<String>? key, Wrapped<String>? newPassword}) {
    return UserNewPassword(
        key: (key != null ? key.value : this.key),
        newPassword:
            (newPassword != null ? newPassword.value : this.newPassword));
  }
}

@JsonSerializable(explicitToJson: true)
class UserProfile {
  UserProfile({
    this.id,
    this.email,
    this.firstName,
    this.lastName,
    this.company,
    this.phone,
    this.taxId,
    this.taxIdType,
  });

  factory UserProfile.fromJson(Map<String, dynamic> json) =>
      _$UserProfileFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  @JsonKey(name: 'taxId', includeIfNull: false, defaultValue: '')
  final String? taxId;
  @JsonKey(name: 'taxIdType', includeIfNull: false, defaultValue: '')
  final String? taxIdType;
  static const fromJsonFactory = _$UserProfileFromJson;
  static const toJsonFactory = _$UserProfileToJson;
  Map<String, dynamic> toJson() => _$UserProfileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserProfile &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.taxId, taxId) ||
                const DeepCollectionEquality().equals(other.taxId, taxId)) &&
            (identical(other.taxIdType, taxIdType) ||
                const DeepCollectionEquality()
                    .equals(other.taxIdType, taxIdType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(taxId) ^
      const DeepCollectionEquality().hash(taxIdType) ^
      runtimeType.hashCode;
}

extension $UserProfileExtension on UserProfile {
  UserProfile copyWith(
      {String? id,
      String? email,
      String? firstName,
      String? lastName,
      String? company,
      String? phone,
      String? taxId,
      String? taxIdType}) {
    return UserProfile(
        id: id ?? this.id,
        email: email ?? this.email,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        company: company ?? this.company,
        phone: phone ?? this.phone,
        taxId: taxId ?? this.taxId,
        taxIdType: taxIdType ?? this.taxIdType);
  }

  UserProfile copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String?>? email,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? company,
      Wrapped<String?>? phone,
      Wrapped<String?>? taxId,
      Wrapped<String?>? taxIdType}) {
    return UserProfile(
        id: (id != null ? id.value : this.id),
        email: (email != null ? email.value : this.email),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        company: (company != null ? company.value : this.company),
        phone: (phone != null ? phone.value : this.phone),
        taxId: (taxId != null ? taxId.value : this.taxId),
        taxIdType: (taxIdType != null ? taxIdType.value : this.taxIdType));
  }
}

@JsonSerializable(explicitToJson: true)
class Address {
  Address({
    this.id,
    this.address1,
    this.address2,
    this.city,
    this.company,
    this.country,
    this.firstName,
    this.lastName,
    this.phone,
    this.province,
    this.zip,
    this.additional,
    this.type,
  });

  factory Address.fromJson(Map<String, dynamic> json) =>
      _$AddressFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'address1', includeIfNull: false, defaultValue: '')
  final String? address1;
  @JsonKey(name: 'address2', includeIfNull: false, defaultValue: '')
  final String? address2;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String? city;
  @JsonKey(name: 'company', includeIfNull: false, defaultValue: '')
  final String? company;
  @JsonKey(name: 'country', includeIfNull: false, defaultValue: '')
  final String? country;
  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  @JsonKey(name: 'province', includeIfNull: false, defaultValue: '')
  final String? province;
  @JsonKey(name: 'zip', includeIfNull: false, defaultValue: '')
  final String? zip;
  @JsonKey(name: 'additional', includeIfNull: false, defaultValue: '')
  final String? additional;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: addressTypeToJson,
    fromJson: addressTypeFromJson,
  )
  final enums.AddressType? type;
  static const fromJsonFactory = _$AddressFromJson;
  static const toJsonFactory = _$AddressToJson;
  Map<String, dynamic> toJson() => _$AddressToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Address &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.address1, address1) ||
                const DeepCollectionEquality()
                    .equals(other.address1, address1)) &&
            (identical(other.address2, address2) ||
                const DeepCollectionEquality()
                    .equals(other.address2, address2)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.company, company) ||
                const DeepCollectionEquality()
                    .equals(other.company, company)) &&
            (identical(other.country, country) ||
                const DeepCollectionEquality()
                    .equals(other.country, country)) &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.province, province) ||
                const DeepCollectionEquality()
                    .equals(other.province, province)) &&
            (identical(other.zip, zip) ||
                const DeepCollectionEquality().equals(other.zip, zip)) &&
            (identical(other.additional, additional) ||
                const DeepCollectionEquality()
                    .equals(other.additional, additional)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(address1) ^
      const DeepCollectionEquality().hash(address2) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(company) ^
      const DeepCollectionEquality().hash(country) ^
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(province) ^
      const DeepCollectionEquality().hash(zip) ^
      const DeepCollectionEquality().hash(additional) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $AddressExtension on Address {
  Address copyWith(
      {num? id,
      String? address1,
      String? address2,
      String? city,
      String? company,
      String? country,
      String? firstName,
      String? lastName,
      String? phone,
      String? province,
      String? zip,
      String? additional,
      enums.AddressType? type}) {
    return Address(
        id: id ?? this.id,
        address1: address1 ?? this.address1,
        address2: address2 ?? this.address2,
        city: city ?? this.city,
        company: company ?? this.company,
        country: country ?? this.country,
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        phone: phone ?? this.phone,
        province: province ?? this.province,
        zip: zip ?? this.zip,
        additional: additional ?? this.additional,
        type: type ?? this.type);
  }

  Address copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? address1,
      Wrapped<String?>? address2,
      Wrapped<String?>? city,
      Wrapped<String?>? company,
      Wrapped<String?>? country,
      Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String?>? phone,
      Wrapped<String?>? province,
      Wrapped<String?>? zip,
      Wrapped<String?>? additional,
      Wrapped<enums.AddressType?>? type}) {
    return Address(
        id: (id != null ? id.value : this.id),
        address1: (address1 != null ? address1.value : this.address1),
        address2: (address2 != null ? address2.value : this.address2),
        city: (city != null ? city.value : this.city),
        company: (company != null ? company.value : this.company),
        country: (country != null ? country.value : this.country),
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        phone: (phone != null ? phone.value : this.phone),
        province: (province != null ? province.value : this.province),
        zip: (zip != null ? zip.value : this.zip),
        additional: (additional != null ? additional.value : this.additional),
        type: (type != null ? type.value : this.type));
  }
}

typedef Addresses = List<Address>;

@JsonSerializable(explicitToJson: true)
class File {
  File({
    this.id,
  });

  factory File.fromJson(Map<String, dynamic> json) => _$FileFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$FileFromJson;
  static const toJsonFactory = _$FileToJson;
  Map<String, dynamic> toJson() => _$FileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is File &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $FileExtension on File {
  File copyWith({String? id}) {
    return File(id: id ?? this.id);
  }

  File copyWithWrapped({Wrapped<String?>? id}) {
    return File(id: (id != null ? id.value : this.id));
  }
}

typedef Files = List<File>;

@JsonSerializable(explicitToJson: true)
class UserFile {
  UserFile({
    required this.id,
  });

  factory UserFile.fromJson(Map<String, dynamic> json) =>
      _$UserFileFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  static const fromJsonFactory = _$UserFileFromJson;
  static const toJsonFactory = _$UserFileToJson;
  Map<String, dynamic> toJson() => _$UserFileToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserFile &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $UserFileExtension on UserFile {
  UserFile copyWith({String? id}) {
    return UserFile(id: id ?? this.id);
  }

  UserFile copyWithWrapped({Wrapped<String>? id}) {
    return UserFile(id: (id != null ? id.value : this.id));
  }
}

typedef UserFiles = List<UserFile>;

@JsonSerializable(explicitToJson: true)
class UserPartnerData {
  UserPartnerData({
    this.id,
    this.key,
    this.value,
    this.partnerId,
    this.userId,
  });

  factory UserPartnerData.fromJson(Map<String, dynamic> json) =>
      _$UserPartnerDataFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(
    name: 'key',
    includeIfNull: false,
    toJson: userPartnerDataKeyToJson,
    fromJson: userPartnerDataKeyFromJson,
  )
  final enums.UserPartnerDataKey? key;
  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  @JsonKey(name: 'partnerId', includeIfNull: false)
  final num? partnerId;
  @JsonKey(name: 'userId', includeIfNull: false, defaultValue: '')
  final String? userId;
  static const fromJsonFactory = _$UserPartnerDataFromJson;
  static const toJsonFactory = _$UserPartnerDataToJson;
  Map<String, dynamic> toJson() => _$UserPartnerDataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserPartnerData &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)) &&
            (identical(other.partnerId, partnerId) ||
                const DeepCollectionEquality()
                    .equals(other.partnerId, partnerId)) &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(value) ^
      const DeepCollectionEquality().hash(partnerId) ^
      const DeepCollectionEquality().hash(userId) ^
      runtimeType.hashCode;
}

extension $UserPartnerDataExtension on UserPartnerData {
  UserPartnerData copyWith(
      {num? id,
      enums.UserPartnerDataKey? key,
      String? value,
      num? partnerId,
      String? userId}) {
    return UserPartnerData(
        id: id ?? this.id,
        key: key ?? this.key,
        value: value ?? this.value,
        partnerId: partnerId ?? this.partnerId,
        userId: userId ?? this.userId);
  }

  UserPartnerData copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<enums.UserPartnerDataKey?>? key,
      Wrapped<String?>? value,
      Wrapped<num?>? partnerId,
      Wrapped<String?>? userId}) {
    return UserPartnerData(
        id: (id != null ? id.value : this.id),
        key: (key != null ? key.value : this.key),
        value: (value != null ? value.value : this.value),
        partnerId: (partnerId != null ? partnerId.value : this.partnerId),
        userId: (userId != null ? userId.value : this.userId));
  }
}

typedef UsersPartnersData = List<UserPartnerData>;

@JsonSerializable(explicitToJson: true)
class ValidationRequest {
  ValidationRequest({
    this.id,
    this.name,
    this.date,
    this.uxValid,
    this.uxInvalidReason,
    this.productValid,
    this.productInvalidReason,
    this.marketingValid,
    this.marketingInvalidReason,
    this.softwareValid,
    this.softwareInvalidReason,
    this.job,
    this.simplrService,
  });

  factory ValidationRequest.fromJson(Map<String, dynamic> json) =>
      _$ValidationRequestFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'uxValid', includeIfNull: false)
  final bool? uxValid;
  @JsonKey(name: 'uxInvalidReason', includeIfNull: false, defaultValue: '')
  final String? uxInvalidReason;
  @JsonKey(name: 'productValid', includeIfNull: false)
  final bool? productValid;
  @JsonKey(name: 'productInvalidReason', includeIfNull: false, defaultValue: '')
  final String? productInvalidReason;
  @JsonKey(name: 'marketingValid', includeIfNull: false)
  final bool? marketingValid;
  @JsonKey(
      name: 'marketingInvalidReason', includeIfNull: false, defaultValue: '')
  final String? marketingInvalidReason;
  @JsonKey(name: 'softwareValid', includeIfNull: false)
  final bool? softwareValid;
  @JsonKey(
      name: 'softwareInvalidReason', includeIfNull: false, defaultValue: '')
  final String? softwareInvalidReason;
  @JsonKey(name: 'job', includeIfNull: false)
  final Job? job;
  @JsonKey(name: 'simplrService', includeIfNull: false)
  final SimplrService? simplrService;
  static const fromJsonFactory = _$ValidationRequestFromJson;
  static const toJsonFactory = _$ValidationRequestToJson;
  Map<String, dynamic> toJson() => _$ValidationRequestToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ValidationRequest &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.uxValid, uxValid) ||
                const DeepCollectionEquality()
                    .equals(other.uxValid, uxValid)) &&
            (identical(other.uxInvalidReason, uxInvalidReason) ||
                const DeepCollectionEquality()
                    .equals(other.uxInvalidReason, uxInvalidReason)) &&
            (identical(other.productValid, productValid) ||
                const DeepCollectionEquality()
                    .equals(other.productValid, productValid)) &&
            (identical(other.productInvalidReason, productInvalidReason) ||
                const DeepCollectionEquality().equals(
                    other.productInvalidReason, productInvalidReason)) &&
            (identical(other.marketingValid, marketingValid) ||
                const DeepCollectionEquality()
                    .equals(other.marketingValid, marketingValid)) &&
            (identical(other.marketingInvalidReason, marketingInvalidReason) ||
                const DeepCollectionEquality().equals(
                    other.marketingInvalidReason, marketingInvalidReason)) &&
            (identical(other.softwareValid, softwareValid) ||
                const DeepCollectionEquality()
                    .equals(other.softwareValid, softwareValid)) &&
            (identical(other.softwareInvalidReason, softwareInvalidReason) ||
                const DeepCollectionEquality().equals(
                    other.softwareInvalidReason, softwareInvalidReason)) &&
            (identical(other.job, job) ||
                const DeepCollectionEquality().equals(other.job, job)) &&
            (identical(other.simplrService, simplrService) ||
                const DeepCollectionEquality()
                    .equals(other.simplrService, simplrService)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(uxValid) ^
      const DeepCollectionEquality().hash(uxInvalidReason) ^
      const DeepCollectionEquality().hash(productValid) ^
      const DeepCollectionEquality().hash(productInvalidReason) ^
      const DeepCollectionEquality().hash(marketingValid) ^
      const DeepCollectionEquality().hash(marketingInvalidReason) ^
      const DeepCollectionEquality().hash(softwareValid) ^
      const DeepCollectionEquality().hash(softwareInvalidReason) ^
      const DeepCollectionEquality().hash(job) ^
      const DeepCollectionEquality().hash(simplrService) ^
      runtimeType.hashCode;
}

extension $ValidationRequestExtension on ValidationRequest {
  ValidationRequest copyWith(
      {num? id,
      String? name,
      DateTime? date,
      bool? uxValid,
      String? uxInvalidReason,
      bool? productValid,
      String? productInvalidReason,
      bool? marketingValid,
      String? marketingInvalidReason,
      bool? softwareValid,
      String? softwareInvalidReason,
      Job? job,
      SimplrService? simplrService}) {
    return ValidationRequest(
        id: id ?? this.id,
        name: name ?? this.name,
        date: date ?? this.date,
        uxValid: uxValid ?? this.uxValid,
        uxInvalidReason: uxInvalidReason ?? this.uxInvalidReason,
        productValid: productValid ?? this.productValid,
        productInvalidReason: productInvalidReason ?? this.productInvalidReason,
        marketingValid: marketingValid ?? this.marketingValid,
        marketingInvalidReason:
            marketingInvalidReason ?? this.marketingInvalidReason,
        softwareValid: softwareValid ?? this.softwareValid,
        softwareInvalidReason:
            softwareInvalidReason ?? this.softwareInvalidReason,
        job: job ?? this.job,
        simplrService: simplrService ?? this.simplrService);
  }

  ValidationRequest copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<DateTime?>? date,
      Wrapped<bool?>? uxValid,
      Wrapped<String?>? uxInvalidReason,
      Wrapped<bool?>? productValid,
      Wrapped<String?>? productInvalidReason,
      Wrapped<bool?>? marketingValid,
      Wrapped<String?>? marketingInvalidReason,
      Wrapped<bool?>? softwareValid,
      Wrapped<String?>? softwareInvalidReason,
      Wrapped<Job?>? job,
      Wrapped<SimplrService?>? simplrService}) {
    return ValidationRequest(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        date: (date != null ? date.value : this.date),
        uxValid: (uxValid != null ? uxValid.value : this.uxValid),
        uxInvalidReason: (uxInvalidReason != null
            ? uxInvalidReason.value
            : this.uxInvalidReason),
        productValid:
            (productValid != null ? productValid.value : this.productValid),
        productInvalidReason: (productInvalidReason != null
            ? productInvalidReason.value
            : this.productInvalidReason),
        marketingValid: (marketingValid != null
            ? marketingValid.value
            : this.marketingValid),
        marketingInvalidReason: (marketingInvalidReason != null
            ? marketingInvalidReason.value
            : this.marketingInvalidReason),
        softwareValid:
            (softwareValid != null ? softwareValid.value : this.softwareValid),
        softwareInvalidReason: (softwareInvalidReason != null
            ? softwareInvalidReason.value
            : this.softwareInvalidReason),
        job: (job != null ? job.value : this.job),
        simplrService:
            (simplrService != null ? simplrService.value : this.simplrService));
  }
}

typedef ValidationRequests = List<ValidationRequest>;

@JsonSerializable(explicitToJson: true)
class RecommenderElement {
  RecommenderElement({
    this.id,
  });

  factory RecommenderElement.fromJson(Map<String, dynamic> json) =>
      _$RecommenderElementFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  static const fromJsonFactory = _$RecommenderElementFromJson;
  static const toJsonFactory = _$RecommenderElementToJson;
  Map<String, dynamic> toJson() => _$RecommenderElementToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecommenderElement &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^ runtimeType.hashCode;
}

extension $RecommenderElementExtension on RecommenderElement {
  RecommenderElement copyWith({num? id}) {
    return RecommenderElement(id: id ?? this.id);
  }

  RecommenderElement copyWithWrapped({Wrapped<num?>? id}) {
    return RecommenderElement(id: (id != null ? id.value : this.id));
  }
}

typedef RecommenderElements = List<RecommenderElement>;

@JsonSerializable(explicitToJson: true)
class RecommenderData {
  RecommenderData({
    this.itemIds,
    this.userIds,
    this.nbOfRecommendations,
  });

  factory RecommenderData.fromJson(Map<String, dynamic> json) =>
      _$RecommenderDataFromJson(json);

  @JsonKey(name: 'itemIds', includeIfNull: false)
  final List<RecommenderElement>? itemIds;
  @JsonKey(name: 'userIds', includeIfNull: false)
  final List<RecommenderElement>? userIds;
  @JsonKey(name: 'nbOfRecommendations', includeIfNull: false)
  final int? nbOfRecommendations;
  static const fromJsonFactory = _$RecommenderDataFromJson;
  static const toJsonFactory = _$RecommenderDataToJson;
  Map<String, dynamic> toJson() => _$RecommenderDataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RecommenderData &&
            (identical(other.itemIds, itemIds) ||
                const DeepCollectionEquality()
                    .equals(other.itemIds, itemIds)) &&
            (identical(other.userIds, userIds) ||
                const DeepCollectionEquality()
                    .equals(other.userIds, userIds)) &&
            (identical(other.nbOfRecommendations, nbOfRecommendations) ||
                const DeepCollectionEquality()
                    .equals(other.nbOfRecommendations, nbOfRecommendations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(itemIds) ^
      const DeepCollectionEquality().hash(userIds) ^
      const DeepCollectionEquality().hash(nbOfRecommendations) ^
      runtimeType.hashCode;
}

extension $RecommenderDataExtension on RecommenderData {
  RecommenderData copyWith(
      {List<RecommenderElement>? itemIds,
      List<RecommenderElement>? userIds,
      int? nbOfRecommendations}) {
    return RecommenderData(
        itemIds: itemIds ?? this.itemIds,
        userIds: userIds ?? this.userIds,
        nbOfRecommendations: nbOfRecommendations ?? this.nbOfRecommendations);
  }

  RecommenderData copyWithWrapped(
      {Wrapped<List<RecommenderElement>?>? itemIds,
      Wrapped<List<RecommenderElement>?>? userIds,
      Wrapped<int?>? nbOfRecommendations}) {
    return RecommenderData(
        itemIds: (itemIds != null ? itemIds.value : this.itemIds),
        userIds: (userIds != null ? userIds.value : this.userIds),
        nbOfRecommendations: (nbOfRecommendations != null
            ? nbOfRecommendations.value
            : this.nbOfRecommendations));
  }
}

@JsonSerializable(explicitToJson: true)
class ContentPromotionPackageInfo {
  ContentPromotionPackageInfo({
    this.contentDescription,
    this.entityType,
    this.entityKey,
    this.version,
    this.databaseVersion,
    this.releasedDate,
    this.installedDate,
  });

  factory ContentPromotionPackageInfo.fromJson(Map<String, dynamic> json) =>
      _$ContentPromotionPackageInfoFromJson(json);

  @JsonKey(name: 'contentDescription', includeIfNull: false, defaultValue: '')
  final String? contentDescription;
  @JsonKey(name: 'entityType', includeIfNull: false, defaultValue: '')
  final String? entityType;
  @JsonKey(name: 'entityKey', includeIfNull: false, defaultValue: '')
  final String? entityKey;
  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String? version;
  @JsonKey(name: 'databaseVersion', includeIfNull: false, defaultValue: '')
  final String? databaseVersion;
  @JsonKey(name: 'releasedDate', includeIfNull: false)
  final DateTime? releasedDate;
  @JsonKey(name: 'installedDate', includeIfNull: false)
  final DateTime? installedDate;
  static const fromJsonFactory = _$ContentPromotionPackageInfoFromJson;
  static const toJsonFactory = _$ContentPromotionPackageInfoToJson;
  Map<String, dynamic> toJson() => _$ContentPromotionPackageInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ContentPromotionPackageInfo &&
            (identical(other.contentDescription, contentDescription) ||
                const DeepCollectionEquality()
                    .equals(other.contentDescription, contentDescription)) &&
            (identical(other.entityType, entityType) ||
                const DeepCollectionEquality()
                    .equals(other.entityType, entityType)) &&
            (identical(other.entityKey, entityKey) ||
                const DeepCollectionEquality()
                    .equals(other.entityKey, entityKey)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.databaseVersion, databaseVersion) ||
                const DeepCollectionEquality()
                    .equals(other.databaseVersion, databaseVersion)) &&
            (identical(other.releasedDate, releasedDate) ||
                const DeepCollectionEquality()
                    .equals(other.releasedDate, releasedDate)) &&
            (identical(other.installedDate, installedDate) ||
                const DeepCollectionEquality()
                    .equals(other.installedDate, installedDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contentDescription) ^
      const DeepCollectionEquality().hash(entityType) ^
      const DeepCollectionEquality().hash(entityKey) ^
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(databaseVersion) ^
      const DeepCollectionEquality().hash(releasedDate) ^
      const DeepCollectionEquality().hash(installedDate) ^
      runtimeType.hashCode;
}

extension $ContentPromotionPackageInfoExtension on ContentPromotionPackageInfo {
  ContentPromotionPackageInfo copyWith(
      {String? contentDescription,
      String? entityType,
      String? entityKey,
      String? version,
      String? databaseVersion,
      DateTime? releasedDate,
      DateTime? installedDate}) {
    return ContentPromotionPackageInfo(
        contentDescription: contentDescription ?? this.contentDescription,
        entityType: entityType ?? this.entityType,
        entityKey: entityKey ?? this.entityKey,
        version: version ?? this.version,
        databaseVersion: databaseVersion ?? this.databaseVersion,
        releasedDate: releasedDate ?? this.releasedDate,
        installedDate: installedDate ?? this.installedDate);
  }

  ContentPromotionPackageInfo copyWithWrapped(
      {Wrapped<String?>? contentDescription,
      Wrapped<String?>? entityType,
      Wrapped<String?>? entityKey,
      Wrapped<String?>? version,
      Wrapped<String?>? databaseVersion,
      Wrapped<DateTime?>? releasedDate,
      Wrapped<DateTime?>? installedDate}) {
    return ContentPromotionPackageInfo(
        contentDescription: (contentDescription != null
            ? contentDescription.value
            : this.contentDescription),
        entityType: (entityType != null ? entityType.value : this.entityType),
        entityKey: (entityKey != null ? entityKey.value : this.entityKey),
        version: (version != null ? version.value : this.version),
        databaseVersion: (databaseVersion != null
            ? databaseVersion.value
            : this.databaseVersion),
        releasedDate:
            (releasedDate != null ? releasedDate.value : this.releasedDate),
        installedDate:
            (installedDate != null ? installedDate.value : this.installedDate));
  }
}

typedef ContentPromotionPackageInfos = List<ContentPromotionPackageInfo>;

@JsonSerializable(explicitToJson: true)
class PropertyManager {
  PropertyManager({
    this.id,
    required this.name,
    this.description,
    this.taxId,
    this.imageUrl,
    this.logoUrl,
    this.active,
    this.userEmail,
  });

  factory PropertyManager.fromJson(Map<String, dynamic> json) =>
      _$PropertyManagerFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'taxId', includeIfNull: false, defaultValue: '')
  final String? taxId;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'logoUrl', includeIfNull: false, defaultValue: '')
  final String? logoUrl;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  @JsonKey(name: 'userEmail', includeIfNull: false, defaultValue: '')
  final String? userEmail;
  static const fromJsonFactory = _$PropertyManagerFromJson;
  static const toJsonFactory = _$PropertyManagerToJson;
  Map<String, dynamic> toJson() => _$PropertyManagerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PropertyManager &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.taxId, taxId) ||
                const DeepCollectionEquality().equals(other.taxId, taxId)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.logoUrl, logoUrl) ||
                const DeepCollectionEquality()
                    .equals(other.logoUrl, logoUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.userEmail, userEmail) ||
                const DeepCollectionEquality()
                    .equals(other.userEmail, userEmail)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(taxId) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(logoUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(userEmail) ^
      runtimeType.hashCode;
}

extension $PropertyManagerExtension on PropertyManager {
  PropertyManager copyWith(
      {num? id,
      String? name,
      String? description,
      String? taxId,
      String? imageUrl,
      String? logoUrl,
      bool? active,
      String? userEmail}) {
    return PropertyManager(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        taxId: taxId ?? this.taxId,
        imageUrl: imageUrl ?? this.imageUrl,
        logoUrl: logoUrl ?? this.logoUrl,
        active: active ?? this.active,
        userEmail: userEmail ?? this.userEmail);
  }

  PropertyManager copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? taxId,
      Wrapped<String?>? imageUrl,
      Wrapped<String?>? logoUrl,
      Wrapped<bool?>? active,
      Wrapped<String?>? userEmail}) {
    return PropertyManager(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        taxId: (taxId != null ? taxId.value : this.taxId),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        logoUrl: (logoUrl != null ? logoUrl.value : this.logoUrl),
        active: (active != null ? active.value : this.active),
        userEmail: (userEmail != null ? userEmail.value : this.userEmail));
  }
}

typedef PropertyManagers = List<PropertyManager>;

@JsonSerializable(explicitToJson: true)
class InvitedUser {
  InvitedUser({
    this.firstName,
    this.lastName,
    required this.email,
    this.address,
    this.appointmentDate,
  });

  factory InvitedUser.fromJson(Map<String, dynamic> json) =>
      _$InvitedUserFromJson(json);

  @JsonKey(name: 'firstName', includeIfNull: false, defaultValue: '')
  final String? firstName;
  @JsonKey(name: 'lastName', includeIfNull: false, defaultValue: '')
  final String? lastName;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String email;
  @JsonKey(name: 'address', includeIfNull: false, defaultValue: '')
  final String? address;
  @JsonKey(name: 'appointmentDate', includeIfNull: false)
  final DateTime? appointmentDate;
  static const fromJsonFactory = _$InvitedUserFromJson;
  static const toJsonFactory = _$InvitedUserToJson;
  Map<String, dynamic> toJson() => _$InvitedUserToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InvitedUser &&
            (identical(other.firstName, firstName) ||
                const DeepCollectionEquality()
                    .equals(other.firstName, firstName)) &&
            (identical(other.lastName, lastName) ||
                const DeepCollectionEquality()
                    .equals(other.lastName, lastName)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.address, address) ||
                const DeepCollectionEquality()
                    .equals(other.address, address)) &&
            (identical(other.appointmentDate, appointmentDate) ||
                const DeepCollectionEquality()
                    .equals(other.appointmentDate, appointmentDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(firstName) ^
      const DeepCollectionEquality().hash(lastName) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(address) ^
      const DeepCollectionEquality().hash(appointmentDate) ^
      runtimeType.hashCode;
}

extension $InvitedUserExtension on InvitedUser {
  InvitedUser copyWith(
      {String? firstName,
      String? lastName,
      String? email,
      String? address,
      DateTime? appointmentDate}) {
    return InvitedUser(
        firstName: firstName ?? this.firstName,
        lastName: lastName ?? this.lastName,
        email: email ?? this.email,
        address: address ?? this.address,
        appointmentDate: appointmentDate ?? this.appointmentDate);
  }

  InvitedUser copyWithWrapped(
      {Wrapped<String?>? firstName,
      Wrapped<String?>? lastName,
      Wrapped<String>? email,
      Wrapped<String?>? address,
      Wrapped<DateTime?>? appointmentDate}) {
    return InvitedUser(
        firstName: (firstName != null ? firstName.value : this.firstName),
        lastName: (lastName != null ? lastName.value : this.lastName),
        email: (email != null ? email.value : this.email),
        address: (address != null ? address.value : this.address),
        appointmentDate: (appointmentDate != null
            ? appointmentDate.value
            : this.appointmentDate));
  }
}

typedef InvitedUsers = List<InvitedUser>;

@JsonSerializable(explicitToJson: true)
class CheckIn {
  CheckIn({
    this.id,
    required this.invitedUser,
    required this.property,
    this.order,
    this.confirmed,
  });

  factory CheckIn.fromJson(Map<String, dynamic> json) =>
      _$CheckInFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'invitedUser', includeIfNull: false)
  final InvitedUser invitedUser;
  @JsonKey(name: 'property', includeIfNull: false)
  final Property property;
  @JsonKey(name: 'order', includeIfNull: false)
  final Order? order;
  @JsonKey(name: 'confirmed', includeIfNull: false)
  final bool? confirmed;
  static const fromJsonFactory = _$CheckInFromJson;
  static const toJsonFactory = _$CheckInToJson;
  Map<String, dynamic> toJson() => _$CheckInToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CheckIn &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.invitedUser, invitedUser) ||
                const DeepCollectionEquality()
                    .equals(other.invitedUser, invitedUser)) &&
            (identical(other.property, property) ||
                const DeepCollectionEquality()
                    .equals(other.property, property)) &&
            (identical(other.order, order) ||
                const DeepCollectionEquality().equals(other.order, order)) &&
            (identical(other.confirmed, confirmed) ||
                const DeepCollectionEquality()
                    .equals(other.confirmed, confirmed)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(invitedUser) ^
      const DeepCollectionEquality().hash(property) ^
      const DeepCollectionEquality().hash(order) ^
      const DeepCollectionEquality().hash(confirmed) ^
      runtimeType.hashCode;
}

extension $CheckInExtension on CheckIn {
  CheckIn copyWith(
      {num? id,
      InvitedUser? invitedUser,
      Property? property,
      Order? order,
      bool? confirmed}) {
    return CheckIn(
        id: id ?? this.id,
        invitedUser: invitedUser ?? this.invitedUser,
        property: property ?? this.property,
        order: order ?? this.order,
        confirmed: confirmed ?? this.confirmed);
  }

  CheckIn copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<InvitedUser>? invitedUser,
      Wrapped<Property>? property,
      Wrapped<Order?>? order,
      Wrapped<bool?>? confirmed}) {
    return CheckIn(
        id: (id != null ? id.value : this.id),
        invitedUser:
            (invitedUser != null ? invitedUser.value : this.invitedUser),
        property: (property != null ? property.value : this.property),
        order: (order != null ? order.value : this.order),
        confirmed: (confirmed != null ? confirmed.value : this.confirmed));
  }
}

typedef CheckIns = List<CheckIn>;

@JsonSerializable(explicitToJson: true)
class Property {
  Property({
    this.id,
    this.title,
    this.description,
    required this.propertyType,
    this.imageUrl,
    this.active,
    this.featured,
    this.bedrooms,
    this.bathrooms,
    this.garages,
    this.yearBuilt,
    this.catastro,
    this.cupsElectricity,
    this.cupsGas,
    this.propertyManager,
  });

  factory Property.fromJson(Map<String, dynamic> json) =>
      _$PropertyFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(
    name: 'propertyType',
    includeIfNull: false,
    toJson: propertyTypeToJson,
    fromJson: propertyTypeFromJson,
  )
  final enums.PropertyType propertyType;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  @JsonKey(name: 'featured', includeIfNull: false)
  final bool? featured;
  @JsonKey(name: 'bedrooms', includeIfNull: false)
  final num? bedrooms;
  @JsonKey(name: 'bathrooms', includeIfNull: false)
  final num? bathrooms;
  @JsonKey(name: 'garages', includeIfNull: false)
  final num? garages;
  @JsonKey(name: 'yearBuilt', includeIfNull: false)
  final num? yearBuilt;
  @JsonKey(name: 'catastro', includeIfNull: false, defaultValue: '')
  final String? catastro;
  @JsonKey(name: 'cupsElectricity', includeIfNull: false, defaultValue: '')
  final String? cupsElectricity;
  @JsonKey(name: 'cupsGas', includeIfNull: false, defaultValue: '')
  final String? cupsGas;
  @JsonKey(name: 'propertyManager', includeIfNull: false)
  final PropertyManager? propertyManager;
  static const fromJsonFactory = _$PropertyFromJson;
  static const toJsonFactory = _$PropertyToJson;
  Map<String, dynamic> toJson() => _$PropertyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Property &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.propertyType, propertyType) ||
                const DeepCollectionEquality()
                    .equals(other.propertyType, propertyType)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.featured, featured) ||
                const DeepCollectionEquality()
                    .equals(other.featured, featured)) &&
            (identical(other.bedrooms, bedrooms) ||
                const DeepCollectionEquality()
                    .equals(other.bedrooms, bedrooms)) &&
            (identical(other.bathrooms, bathrooms) ||
                const DeepCollectionEquality()
                    .equals(other.bathrooms, bathrooms)) &&
            (identical(other.garages, garages) ||
                const DeepCollectionEquality()
                    .equals(other.garages, garages)) &&
            (identical(other.yearBuilt, yearBuilt) ||
                const DeepCollectionEquality()
                    .equals(other.yearBuilt, yearBuilt)) &&
            (identical(other.catastro, catastro) ||
                const DeepCollectionEquality()
                    .equals(other.catastro, catastro)) &&
            (identical(other.cupsElectricity, cupsElectricity) ||
                const DeepCollectionEquality()
                    .equals(other.cupsElectricity, cupsElectricity)) &&
            (identical(other.cupsGas, cupsGas) ||
                const DeepCollectionEquality()
                    .equals(other.cupsGas, cupsGas)) &&
            (identical(other.propertyManager, propertyManager) ||
                const DeepCollectionEquality()
                    .equals(other.propertyManager, propertyManager)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(propertyType) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(featured) ^
      const DeepCollectionEquality().hash(bedrooms) ^
      const DeepCollectionEquality().hash(bathrooms) ^
      const DeepCollectionEquality().hash(garages) ^
      const DeepCollectionEquality().hash(yearBuilt) ^
      const DeepCollectionEquality().hash(catastro) ^
      const DeepCollectionEquality().hash(cupsElectricity) ^
      const DeepCollectionEquality().hash(cupsGas) ^
      const DeepCollectionEquality().hash(propertyManager) ^
      runtimeType.hashCode;
}

extension $PropertyExtension on Property {
  Property copyWith(
      {num? id,
      String? title,
      String? description,
      enums.PropertyType? propertyType,
      String? imageUrl,
      bool? active,
      bool? featured,
      num? bedrooms,
      num? bathrooms,
      num? garages,
      num? yearBuilt,
      String? catastro,
      String? cupsElectricity,
      String? cupsGas,
      PropertyManager? propertyManager}) {
    return Property(
        id: id ?? this.id,
        title: title ?? this.title,
        description: description ?? this.description,
        propertyType: propertyType ?? this.propertyType,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        featured: featured ?? this.featured,
        bedrooms: bedrooms ?? this.bedrooms,
        bathrooms: bathrooms ?? this.bathrooms,
        garages: garages ?? this.garages,
        yearBuilt: yearBuilt ?? this.yearBuilt,
        catastro: catastro ?? this.catastro,
        cupsElectricity: cupsElectricity ?? this.cupsElectricity,
        cupsGas: cupsGas ?? this.cupsGas,
        propertyManager: propertyManager ?? this.propertyManager);
  }

  Property copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? title,
      Wrapped<String?>? description,
      Wrapped<enums.PropertyType>? propertyType,
      Wrapped<String?>? imageUrl,
      Wrapped<bool?>? active,
      Wrapped<bool?>? featured,
      Wrapped<num?>? bedrooms,
      Wrapped<num?>? bathrooms,
      Wrapped<num?>? garages,
      Wrapped<num?>? yearBuilt,
      Wrapped<String?>? catastro,
      Wrapped<String?>? cupsElectricity,
      Wrapped<String?>? cupsGas,
      Wrapped<PropertyManager?>? propertyManager}) {
    return Property(
        id: (id != null ? id.value : this.id),
        title: (title != null ? title.value : this.title),
        description:
            (description != null ? description.value : this.description),
        propertyType:
            (propertyType != null ? propertyType.value : this.propertyType),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        featured: (featured != null ? featured.value : this.featured),
        bedrooms: (bedrooms != null ? bedrooms.value : this.bedrooms),
        bathrooms: (bathrooms != null ? bathrooms.value : this.bathrooms),
        garages: (garages != null ? garages.value : this.garages),
        yearBuilt: (yearBuilt != null ? yearBuilt.value : this.yearBuilt),
        catastro: (catastro != null ? catastro.value : this.catastro),
        cupsElectricity: (cupsElectricity != null
            ? cupsElectricity.value
            : this.cupsElectricity),
        cupsGas: (cupsGas != null ? cupsGas.value : this.cupsGas),
        propertyManager: (propertyManager != null
            ? propertyManager.value
            : this.propertyManager));
  }
}

typedef Properties = List<Property>;

@JsonSerializable(explicitToJson: true)
class Location {
  Location({
    this.id,
    this.streetAddress,
    this.postalCode,
    this.city,
    this.stateProvince,
    this.lat,
    this.lng,
    this.region,
  });

  factory Location.fromJson(Map<String, dynamic> json) =>
      _$LocationFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'streetAddress', includeIfNull: false, defaultValue: '')
  final String? streetAddress;
  @JsonKey(name: 'postalCode', includeIfNull: false, defaultValue: '')
  final String? postalCode;
  @JsonKey(name: 'city', includeIfNull: false, defaultValue: '')
  final String? city;
  @JsonKey(name: 'stateProvince', includeIfNull: false, defaultValue: '')
  final String? stateProvince;
  @JsonKey(name: 'lat', includeIfNull: false)
  final double? lat;
  @JsonKey(name: 'lng', includeIfNull: false)
  final double? lng;
  @JsonKey(name: 'Region', includeIfNull: false)
  final Region? region;
  static const fromJsonFactory = _$LocationFromJson;
  static const toJsonFactory = _$LocationToJson;
  Map<String, dynamic> toJson() => _$LocationToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Location &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.streetAddress, streetAddress) ||
                const DeepCollectionEquality()
                    .equals(other.streetAddress, streetAddress)) &&
            (identical(other.postalCode, postalCode) ||
                const DeepCollectionEquality()
                    .equals(other.postalCode, postalCode)) &&
            (identical(other.city, city) ||
                const DeepCollectionEquality().equals(other.city, city)) &&
            (identical(other.stateProvince, stateProvince) ||
                const DeepCollectionEquality()
                    .equals(other.stateProvince, stateProvince)) &&
            (identical(other.lat, lat) ||
                const DeepCollectionEquality().equals(other.lat, lat)) &&
            (identical(other.lng, lng) ||
                const DeepCollectionEquality().equals(other.lng, lng)) &&
            (identical(other.region, region) ||
                const DeepCollectionEquality().equals(other.region, region)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(streetAddress) ^
      const DeepCollectionEquality().hash(postalCode) ^
      const DeepCollectionEquality().hash(city) ^
      const DeepCollectionEquality().hash(stateProvince) ^
      const DeepCollectionEquality().hash(lat) ^
      const DeepCollectionEquality().hash(lng) ^
      const DeepCollectionEquality().hash(region) ^
      runtimeType.hashCode;
}

extension $LocationExtension on Location {
  Location copyWith(
      {num? id,
      String? streetAddress,
      String? postalCode,
      String? city,
      String? stateProvince,
      double? lat,
      double? lng,
      Region? region}) {
    return Location(
        id: id ?? this.id,
        streetAddress: streetAddress ?? this.streetAddress,
        postalCode: postalCode ?? this.postalCode,
        city: city ?? this.city,
        stateProvince: stateProvince ?? this.stateProvince,
        lat: lat ?? this.lat,
        lng: lng ?? this.lng,
        region: region ?? this.region);
  }

  Location copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? streetAddress,
      Wrapped<String?>? postalCode,
      Wrapped<String?>? city,
      Wrapped<String?>? stateProvince,
      Wrapped<double?>? lat,
      Wrapped<double?>? lng,
      Wrapped<Region?>? region}) {
    return Location(
        id: (id != null ? id.value : this.id),
        streetAddress:
            (streetAddress != null ? streetAddress.value : this.streetAddress),
        postalCode: (postalCode != null ? postalCode.value : this.postalCode),
        city: (city != null ? city.value : this.city),
        stateProvince:
            (stateProvince != null ? stateProvince.value : this.stateProvince),
        lat: (lat != null ? lat.value : this.lat),
        lng: (lng != null ? lng.value : this.lng),
        region: (region != null ? region.value : this.region));
  }
}

@JsonSerializable(explicitToJson: true)
class Locations {
  Locations({
    this.locations,
  });

  factory Locations.fromJson(Map<String, dynamic> json) =>
      _$LocationsFromJson(json);

  @JsonKey(name: 'locations', includeIfNull: false, defaultValue: <Location>[])
  final List<Location>? locations;
  static const fromJsonFactory = _$LocationsFromJson;
  static const toJsonFactory = _$LocationsToJson;
  Map<String, dynamic> toJson() => _$LocationsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Locations &&
            (identical(other.locations, locations) ||
                const DeepCollectionEquality()
                    .equals(other.locations, locations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(locations) ^ runtimeType.hashCode;
}

extension $LocationsExtension on Locations {
  Locations copyWith({List<Location>? locations}) {
    return Locations(locations: locations ?? this.locations);
  }

  Locations copyWithWrapped({Wrapped<List<Location>?>? locations}) {
    return Locations(
        locations: (locations != null ? locations.value : this.locations));
  }
}

@JsonSerializable(explicitToJson: true)
class Region {
  Region({
    this.id,
    required this.name,
    this.country,
  });

  factory Region.fromJson(Map<String, dynamic> json) => _$RegionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'Country', includeIfNull: false)
  final Country? country;
  static const fromJsonFactory = _$RegionFromJson;
  static const toJsonFactory = _$RegionToJson;
  Map<String, dynamic> toJson() => _$RegionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Region &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.country, country) ||
                const DeepCollectionEquality().equals(other.country, country)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(country) ^
      runtimeType.hashCode;
}

extension $RegionExtension on Region {
  Region copyWith({num? id, String? name, Country? country}) {
    return Region(
        id: id ?? this.id,
        name: name ?? this.name,
        country: country ?? this.country);
  }

  Region copyWithWrapped(
      {Wrapped<num?>? id, Wrapped<String>? name, Wrapped<Country?>? country}) {
    return Region(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        country: (country != null ? country.value : this.country));
  }
}

typedef Regions = List<Region>;

@JsonSerializable(explicitToJson: true)
class Country {
  Country({
    this.id,
    required this.name,
  });

  factory Country.fromJson(Map<String, dynamic> json) =>
      _$CountryFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$CountryFromJson;
  static const toJsonFactory = _$CountryToJson;
  Map<String, dynamic> toJson() => _$CountryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Country &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $CountryExtension on Country {
  Country copyWith({num? id, String? name}) {
    return Country(id: id ?? this.id, name: name ?? this.name);
  }

  Country copyWithWrapped({Wrapped<num?>? id, Wrapped<String>? name}) {
    return Country(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name));
  }
}

typedef Countries = List<Country>;

@JsonSerializable(explicitToJson: true)
class LegalDocument {
  LegalDocument({
    this.id,
    required this.version,
    required this.url,
    required this.activationDate,
    this.expirationDate,
    required this.documentType,
  });

  factory LegalDocument.fromJson(Map<String, dynamic> json) =>
      _$LegalDocumentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String version;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  @JsonKey(name: 'activationDate', includeIfNull: false)
  final DateTime activationDate;
  @JsonKey(name: 'expirationDate', includeIfNull: false)
  final DateTime? expirationDate;
  @JsonKey(
    name: 'documentType',
    includeIfNull: false,
    toJson: legalDocumentTypeToJson,
    fromJson: legalDocumentTypeFromJson,
  )
  final enums.LegalDocumentType documentType;
  static const fromJsonFactory = _$LegalDocumentFromJson;
  static const toJsonFactory = _$LegalDocumentToJson;
  Map<String, dynamic> toJson() => _$LegalDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LegalDocument &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.activationDate, activationDate) ||
                const DeepCollectionEquality()
                    .equals(other.activationDate, activationDate)) &&
            (identical(other.expirationDate, expirationDate) ||
                const DeepCollectionEquality()
                    .equals(other.expirationDate, expirationDate)) &&
            (identical(other.documentType, documentType) ||
                const DeepCollectionEquality()
                    .equals(other.documentType, documentType)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(activationDate) ^
      const DeepCollectionEquality().hash(expirationDate) ^
      const DeepCollectionEquality().hash(documentType) ^
      runtimeType.hashCode;
}

extension $LegalDocumentExtension on LegalDocument {
  LegalDocument copyWith(
      {num? id,
      String? version,
      String? url,
      DateTime? activationDate,
      DateTime? expirationDate,
      enums.LegalDocumentType? documentType}) {
    return LegalDocument(
        id: id ?? this.id,
        version: version ?? this.version,
        url: url ?? this.url,
        activationDate: activationDate ?? this.activationDate,
        expirationDate: expirationDate ?? this.expirationDate,
        documentType: documentType ?? this.documentType);
  }

  LegalDocument copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String>? version,
      Wrapped<String>? url,
      Wrapped<DateTime>? activationDate,
      Wrapped<DateTime?>? expirationDate,
      Wrapped<enums.LegalDocumentType>? documentType}) {
    return LegalDocument(
        id: (id != null ? id.value : this.id),
        version: (version != null ? version.value : this.version),
        url: (url != null ? url.value : this.url),
        activationDate: (activationDate != null
            ? activationDate.value
            : this.activationDate),
        expirationDate: (expirationDate != null
            ? expirationDate.value
            : this.expirationDate),
        documentType:
            (documentType != null ? documentType.value : this.documentType));
  }
}

typedef LegalDocuments = List<LegalDocument>;

@JsonSerializable(explicitToJson: true)
class UserLegalAudit {
  UserLegalAudit({
    this.id,
    this.userId,
    this.legalDocument,
    this.context,
    this.createdDate,
  });

  factory UserLegalAudit.fromJson(Map<String, dynamic> json) =>
      _$UserLegalAuditFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'userId', includeIfNull: false, defaultValue: '')
  final String? userId;
  @JsonKey(name: 'legalDocument', includeIfNull: false)
  final LegalDocument? legalDocument;
  @JsonKey(
    name: 'context',
    includeIfNull: false,
    toJson: userLegalContextToJson,
    fromJson: userLegalContextFromJson,
  )
  final enums.UserLegalContext? context;
  @JsonKey(name: 'createdDate', includeIfNull: false)
  final DateTime? createdDate;
  static const fromJsonFactory = _$UserLegalAuditFromJson;
  static const toJsonFactory = _$UserLegalAuditToJson;
  Map<String, dynamic> toJson() => _$UserLegalAuditToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserLegalAudit &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)) &&
            (identical(other.legalDocument, legalDocument) ||
                const DeepCollectionEquality()
                    .equals(other.legalDocument, legalDocument)) &&
            (identical(other.context, context) ||
                const DeepCollectionEquality()
                    .equals(other.context, context)) &&
            (identical(other.createdDate, createdDate) ||
                const DeepCollectionEquality()
                    .equals(other.createdDate, createdDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(userId) ^
      const DeepCollectionEquality().hash(legalDocument) ^
      const DeepCollectionEquality().hash(context) ^
      const DeepCollectionEquality().hash(createdDate) ^
      runtimeType.hashCode;
}

extension $UserLegalAuditExtension on UserLegalAudit {
  UserLegalAudit copyWith(
      {num? id,
      String? userId,
      LegalDocument? legalDocument,
      enums.UserLegalContext? context,
      DateTime? createdDate}) {
    return UserLegalAudit(
        id: id ?? this.id,
        userId: userId ?? this.userId,
        legalDocument: legalDocument ?? this.legalDocument,
        context: context ?? this.context,
        createdDate: createdDate ?? this.createdDate);
  }

  UserLegalAudit copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? userId,
      Wrapped<LegalDocument?>? legalDocument,
      Wrapped<enums.UserLegalContext?>? context,
      Wrapped<DateTime?>? createdDate}) {
    return UserLegalAudit(
        id: (id != null ? id.value : this.id),
        userId: (userId != null ? userId.value : this.userId),
        legalDocument:
            (legalDocument != null ? legalDocument.value : this.legalDocument),
        context: (context != null ? context.value : this.context),
        createdDate:
            (createdDate != null ? createdDate.value : this.createdDate));
  }
}

typedef UserLegalAudits = List<UserLegalAudit>;

@JsonSerializable(explicitToJson: true)
class Image {
  Image({
    this.id,
    this.orderNb,
    this.isDefault,
    this.imageUrl,
  });

  factory Image.fromJson(Map<String, dynamic> json) => _$ImageFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'orderNb', includeIfNull: false)
  final num? orderNb;
  @JsonKey(name: 'isDefault', includeIfNull: false, defaultValue: false)
  final bool? isDefault;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  static const fromJsonFactory = _$ImageFromJson;
  static const toJsonFactory = _$ImageToJson;
  Map<String, dynamic> toJson() => _$ImageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Image &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.orderNb, orderNb) ||
                const DeepCollectionEquality()
                    .equals(other.orderNb, orderNb)) &&
            (identical(other.isDefault, isDefault) ||
                const DeepCollectionEquality()
                    .equals(other.isDefault, isDefault)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(orderNb) ^
      const DeepCollectionEquality().hash(isDefault) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      runtimeType.hashCode;
}

extension $ImageExtension on Image {
  Image copyWith({num? id, num? orderNb, bool? isDefault, String? imageUrl}) {
    return Image(
        id: id ?? this.id,
        orderNb: orderNb ?? this.orderNb,
        isDefault: isDefault ?? this.isDefault,
        imageUrl: imageUrl ?? this.imageUrl);
  }

  Image copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<num?>? orderNb,
      Wrapped<bool?>? isDefault,
      Wrapped<String?>? imageUrl}) {
    return Image(
        id: (id != null ? id.value : this.id),
        orderNb: (orderNb != null ? orderNb.value : this.orderNb),
        isDefault: (isDefault != null ? isDefault.value : this.isDefault),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl));
  }
}

typedef Images = List<Image>;

@JsonSerializable(explicitToJson: true)
class NewsletterAcceptance {
  NewsletterAcceptance({
    this.id,
    this.email,
    this.phone,
    this.ip,
    this.legalDocument,
    this.acceptanceDate,
  });

  factory NewsletterAcceptance.fromJson(Map<String, dynamic> json) =>
      _$NewsletterAcceptanceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'email', includeIfNull: false, defaultValue: '')
  final String? email;
  @JsonKey(name: 'phone', includeIfNull: false, defaultValue: '')
  final String? phone;
  @JsonKey(name: 'ip', includeIfNull: false, defaultValue: '')
  final String? ip;
  @JsonKey(name: 'legalDocument', includeIfNull: false)
  final LegalDocument? legalDocument;
  @JsonKey(name: 'acceptanceDate', includeIfNull: false)
  final DateTime? acceptanceDate;
  static const fromJsonFactory = _$NewsletterAcceptanceFromJson;
  static const toJsonFactory = _$NewsletterAcceptanceToJson;
  Map<String, dynamic> toJson() => _$NewsletterAcceptanceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is NewsletterAcceptance &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.email, email) ||
                const DeepCollectionEquality().equals(other.email, email)) &&
            (identical(other.phone, phone) ||
                const DeepCollectionEquality().equals(other.phone, phone)) &&
            (identical(other.ip, ip) ||
                const DeepCollectionEquality().equals(other.ip, ip)) &&
            (identical(other.legalDocument, legalDocument) ||
                const DeepCollectionEquality()
                    .equals(other.legalDocument, legalDocument)) &&
            (identical(other.acceptanceDate, acceptanceDate) ||
                const DeepCollectionEquality()
                    .equals(other.acceptanceDate, acceptanceDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(email) ^
      const DeepCollectionEquality().hash(phone) ^
      const DeepCollectionEquality().hash(ip) ^
      const DeepCollectionEquality().hash(legalDocument) ^
      const DeepCollectionEquality().hash(acceptanceDate) ^
      runtimeType.hashCode;
}

extension $NewsletterAcceptanceExtension on NewsletterAcceptance {
  NewsletterAcceptance copyWith(
      {num? id,
      String? email,
      String? phone,
      String? ip,
      LegalDocument? legalDocument,
      DateTime? acceptanceDate}) {
    return NewsletterAcceptance(
        id: id ?? this.id,
        email: email ?? this.email,
        phone: phone ?? this.phone,
        ip: ip ?? this.ip,
        legalDocument: legalDocument ?? this.legalDocument,
        acceptanceDate: acceptanceDate ?? this.acceptanceDate);
  }

  NewsletterAcceptance copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? email,
      Wrapped<String?>? phone,
      Wrapped<String?>? ip,
      Wrapped<LegalDocument?>? legalDocument,
      Wrapped<DateTime?>? acceptanceDate}) {
    return NewsletterAcceptance(
        id: (id != null ? id.value : this.id),
        email: (email != null ? email.value : this.email),
        phone: (phone != null ? phone.value : this.phone),
        ip: (ip != null ? ip.value : this.ip),
        legalDocument:
            (legalDocument != null ? legalDocument.value : this.legalDocument),
        acceptanceDate: (acceptanceDate != null
            ? acceptanceDate.value
            : this.acceptanceDate));
  }
}

typedef NewsletterAcceptances = List<NewsletterAcceptance>;

@JsonSerializable(explicitToJson: true)
class OrderStatusFilter {
  OrderStatusFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory OrderStatusFilter.fromJson(Map<String, dynamic> json) =>
      _$OrderStatusFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$OrderStatusFilterFromJson;
  static const toJsonFactory = _$OrderStatusFilterToJson;
  Map<String, dynamic> toJson() => _$OrderStatusFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OrderStatusFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $OrderStatusFilterExtension on OrderStatusFilter {
  OrderStatusFilter copyWith(
      {String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return OrderStatusFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  OrderStatusFilter copyWithWrapped(
      {Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return OrderStatusFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionStatusFilter {
  SubscriptionStatusFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory SubscriptionStatusFilter.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionStatusFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$SubscriptionStatusFilterFromJson;
  static const toJsonFactory = _$SubscriptionStatusFilterToJson;
  Map<String, dynamic> toJson() => _$SubscriptionStatusFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionStatusFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $SubscriptionStatusFilterExtension on SubscriptionStatusFilter {
  SubscriptionStatusFilter copyWith(
      {String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return SubscriptionStatusFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  SubscriptionStatusFilter copyWithWrapped(
      {Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return SubscriptionStatusFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class TaxTypeFilter {
  TaxTypeFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory TaxTypeFilter.fromJson(Map<String, dynamic> json) =>
      _$TaxTypeFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$TaxTypeFilterFromJson;
  static const toJsonFactory = _$TaxTypeFilterToJson;
  Map<String, dynamic> toJson() => _$TaxTypeFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaxTypeFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $TaxTypeFilterExtension on TaxTypeFilter {
  TaxTypeFilter copyWith(
      {String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return TaxTypeFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  TaxTypeFilter copyWithWrapped(
      {Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return TaxTypeFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class PromotionCode {
  PromotionCode({
    required this.promotionCode,
  });

  factory PromotionCode.fromJson(Map<String, dynamic> json) =>
      _$PromotionCodeFromJson(json);

  @JsonKey(name: 'promotionCode', includeIfNull: false, defaultValue: '')
  final String promotionCode;
  static const fromJsonFactory = _$PromotionCodeFromJson;
  static const toJsonFactory = _$PromotionCodeToJson;
  Map<String, dynamic> toJson() => _$PromotionCodeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PromotionCode &&
            (identical(other.promotionCode, promotionCode) ||
                const DeepCollectionEquality()
                    .equals(other.promotionCode, promotionCode)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(promotionCode) ^ runtimeType.hashCode;
}

extension $PromotionCodeExtension on PromotionCode {
  PromotionCode copyWith({String? promotionCode}) {
    return PromotionCode(promotionCode: promotionCode ?? this.promotionCode);
  }

  PromotionCode copyWithWrapped({Wrapped<String>? promotionCode}) {
    return PromotionCode(
        promotionCode:
            (promotionCode != null ? promotionCode.value : this.promotionCode));
  }
}

typedef PromotionCodes = List<PromotionCode>;

@JsonSerializable(explicitToJson: true)
class Discount {
  Discount({
    this.id,
    this.promotion,
    this.originalAmount,
    this.discountAmount,
    this.finalAmount,
  });

  factory Discount.fromJson(Map<String, dynamic> json) =>
      _$DiscountFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'promotion', includeIfNull: false)
  final Promotion? promotion;
  @JsonKey(name: 'originalAmount', includeIfNull: false)
  final double? originalAmount;
  @JsonKey(name: 'discountAmount', includeIfNull: false)
  final double? discountAmount;
  @JsonKey(name: 'finalAmount', includeIfNull: false)
  final double? finalAmount;
  static const fromJsonFactory = _$DiscountFromJson;
  static const toJsonFactory = _$DiscountToJson;
  Map<String, dynamic> toJson() => _$DiscountToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Discount &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.promotion, promotion) ||
                const DeepCollectionEquality()
                    .equals(other.promotion, promotion)) &&
            (identical(other.originalAmount, originalAmount) ||
                const DeepCollectionEquality()
                    .equals(other.originalAmount, originalAmount)) &&
            (identical(other.discountAmount, discountAmount) ||
                const DeepCollectionEquality()
                    .equals(other.discountAmount, discountAmount)) &&
            (identical(other.finalAmount, finalAmount) ||
                const DeepCollectionEquality()
                    .equals(other.finalAmount, finalAmount)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(promotion) ^
      const DeepCollectionEquality().hash(originalAmount) ^
      const DeepCollectionEquality().hash(discountAmount) ^
      const DeepCollectionEquality().hash(finalAmount) ^
      runtimeType.hashCode;
}

extension $DiscountExtension on Discount {
  Discount copyWith(
      {num? id,
      Promotion? promotion,
      double? originalAmount,
      double? discountAmount,
      double? finalAmount}) {
    return Discount(
        id: id ?? this.id,
        promotion: promotion ?? this.promotion,
        originalAmount: originalAmount ?? this.originalAmount,
        discountAmount: discountAmount ?? this.discountAmount,
        finalAmount: finalAmount ?? this.finalAmount);
  }

  Discount copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<Promotion?>? promotion,
      Wrapped<double?>? originalAmount,
      Wrapped<double?>? discountAmount,
      Wrapped<double?>? finalAmount}) {
    return Discount(
        id: (id != null ? id.value : this.id),
        promotion: (promotion != null ? promotion.value : this.promotion),
        originalAmount: (originalAmount != null
            ? originalAmount.value
            : this.originalAmount),
        discountAmount: (discountAmount != null
            ? discountAmount.value
            : this.discountAmount),
        finalAmount:
            (finalAmount != null ? finalAmount.value : this.finalAmount));
  }
}

typedef Discounts = List<Discount>;

@JsonSerializable(explicitToJson: true)
class Promotion {
  Promotion({
    this.id,
    this.name,
    this.active,
    this.type,
    this.namespace,
    this.amount,
    this.startDate,
    this.endDate,
    this.intervalDuration,
    this.serviceCategoryIds,
    this.simplrServiceIds,
    this.description,
    this.shortDescription,
    this.marketId,
    this.businessIds,
  });

  factory Promotion.fromJson(Map<String, dynamic> json) =>
      _$PromotionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: false)
  final bool? active;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: promotionTypeToJson,
    fromJson: promotionTypeFromJson,
  )
  final enums.PromotionType? type;
  @JsonKey(
    name: 'namespace',
    includeIfNull: false,
    toJson: promotionNamespaceToJson,
    fromJson: promotionNamespaceFromJson,
  )
  final enums.PromotionNamespace? namespace;
  @JsonKey(name: 'amount', includeIfNull: false)
  final double? amount;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  @JsonKey(name: 'intervalDuration', includeIfNull: false)
  final int? intervalDuration;
  @JsonKey(
      name: 'serviceCategoryIds', includeIfNull: false, defaultValue: <num>[])
  final List<num>? serviceCategoryIds;
  @JsonKey(
      name: 'simplrServiceIds', includeIfNull: false, defaultValue: <num>[])
  final List<num>? simplrServiceIds;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  @JsonKey(name: 'marketId', includeIfNull: false)
  final num? marketId;
  @JsonKey(name: 'businessIds', includeIfNull: false, defaultValue: <String>[])
  final List<String>? businessIds;
  static const fromJsonFactory = _$PromotionFromJson;
  static const toJsonFactory = _$PromotionToJson;
  Map<String, dynamic> toJson() => _$PromotionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Promotion &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.namespace, namespace) ||
                const DeepCollectionEquality()
                    .equals(other.namespace, namespace)) &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.intervalDuration, intervalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.intervalDuration, intervalDuration)) &&
            (identical(other.serviceCategoryIds, serviceCategoryIds) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategoryIds, serviceCategoryIds)) &&
            (identical(other.simplrServiceIds, simplrServiceIds) ||
                const DeepCollectionEquality()
                    .equals(other.simplrServiceIds, simplrServiceIds)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)) &&
            (identical(other.marketId, marketId) ||
                const DeepCollectionEquality()
                    .equals(other.marketId, marketId)) &&
            (identical(other.businessIds, businessIds) ||
                const DeepCollectionEquality()
                    .equals(other.businessIds, businessIds)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(namespace) ^
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(intervalDuration) ^
      const DeepCollectionEquality().hash(serviceCategoryIds) ^
      const DeepCollectionEquality().hash(simplrServiceIds) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      const DeepCollectionEquality().hash(marketId) ^
      const DeepCollectionEquality().hash(businessIds) ^
      runtimeType.hashCode;
}

extension $PromotionExtension on Promotion {
  Promotion copyWith(
      {num? id,
      String? name,
      bool? active,
      enums.PromotionType? type,
      enums.PromotionNamespace? namespace,
      double? amount,
      DateTime? startDate,
      DateTime? endDate,
      int? intervalDuration,
      List<num>? serviceCategoryIds,
      List<num>? simplrServiceIds,
      String? description,
      String? shortDescription,
      num? marketId,
      List<String>? businessIds}) {
    return Promotion(
        id: id ?? this.id,
        name: name ?? this.name,
        active: active ?? this.active,
        type: type ?? this.type,
        namespace: namespace ?? this.namespace,
        amount: amount ?? this.amount,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        intervalDuration: intervalDuration ?? this.intervalDuration,
        serviceCategoryIds: serviceCategoryIds ?? this.serviceCategoryIds,
        simplrServiceIds: simplrServiceIds ?? this.simplrServiceIds,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription,
        marketId: marketId ?? this.marketId,
        businessIds: businessIds ?? this.businessIds);
  }

  Promotion copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<bool?>? active,
      Wrapped<enums.PromotionType?>? type,
      Wrapped<enums.PromotionNamespace?>? namespace,
      Wrapped<double?>? amount,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate,
      Wrapped<int?>? intervalDuration,
      Wrapped<List<num>?>? serviceCategoryIds,
      Wrapped<List<num>?>? simplrServiceIds,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription,
      Wrapped<num?>? marketId,
      Wrapped<List<String>?>? businessIds}) {
    return Promotion(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        active: (active != null ? active.value : this.active),
        type: (type != null ? type.value : this.type),
        namespace: (namespace != null ? namespace.value : this.namespace),
        amount: (amount != null ? amount.value : this.amount),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        intervalDuration: (intervalDuration != null
            ? intervalDuration.value
            : this.intervalDuration),
        serviceCategoryIds: (serviceCategoryIds != null
            ? serviceCategoryIds.value
            : this.serviceCategoryIds),
        simplrServiceIds: (simplrServiceIds != null
            ? simplrServiceIds.value
            : this.simplrServiceIds),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription),
        marketId: (marketId != null ? marketId.value : this.marketId),
        businessIds:
            (businessIds != null ? businessIds.value : this.businessIds));
  }
}

@JsonSerializable(explicitToJson: true)
class Promotions {
  Promotions({
    this.promotions,
  });

  factory Promotions.fromJson(Map<String, dynamic> json) =>
      _$PromotionsFromJson(json);

  @JsonKey(
      name: 'promotions', includeIfNull: false, defaultValue: <Promotion>[])
  final List<Promotion>? promotions;
  static const fromJsonFactory = _$PromotionsFromJson;
  static const toJsonFactory = _$PromotionsToJson;
  Map<String, dynamic> toJson() => _$PromotionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Promotions &&
            (identical(other.promotions, promotions) ||
                const DeepCollectionEquality()
                    .equals(other.promotions, promotions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(promotions) ^ runtimeType.hashCode;
}

extension $PromotionsExtension on Promotions {
  Promotions copyWith({List<Promotion>? promotions}) {
    return Promotions(promotions: promotions ?? this.promotions);
  }

  Promotions copyWithWrapped({Wrapped<List<Promotion>?>? promotions}) {
    return Promotions(
        promotions: (promotions != null ? promotions.value : this.promotions));
  }
}

@JsonSerializable(explicitToJson: true)
class PromotionTypeFilter {
  PromotionTypeFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory PromotionTypeFilter.fromJson(Map<String, dynamic> json) =>
      _$PromotionTypeFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$PromotionTypeFilterFromJson;
  static const toJsonFactory = _$PromotionTypeFilterToJson;
  Map<String, dynamic> toJson() => _$PromotionTypeFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PromotionTypeFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $PromotionTypeFilterExtension on PromotionTypeFilter {
  PromotionTypeFilter copyWith(
      {String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return PromotionTypeFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  PromotionTypeFilter copyWithWrapped(
      {Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return PromotionTypeFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class PromotionCriteria {
  PromotionCriteria({
    this.id,
    this.name,
    this.active,
    this.startDate,
    this.endDate,
    this.promotionType,
    this.amount,
    this.intervalDuration,
    this.simplrServiceId,
    this.serviceCategoryId,
  });

  factory PromotionCriteria.fromJson(Map<String, dynamic> json) =>
      _$PromotionCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'name', includeIfNull: false)
  final StringFilter? name;
  @JsonKey(name: 'active', includeIfNull: false)
  final BooleanFilter? active;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final InstantFilter? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final InstantFilter? endDate;
  @JsonKey(name: 'promotionType', includeIfNull: false)
  final PromotionTypeFilter? promotionType;
  @JsonKey(name: 'amount', includeIfNull: false)
  final BigDecimalFilter? amount;
  @JsonKey(name: 'intervalDuration', includeIfNull: false)
  final IntegerFilter? intervalDuration;
  @JsonKey(name: 'simplrServiceId', includeIfNull: false)
  final LongFilter? simplrServiceId;
  @JsonKey(name: 'serviceCategoryId', includeIfNull: false)
  final LongFilter? serviceCategoryId;
  static const fromJsonFactory = _$PromotionCriteriaFromJson;
  static const toJsonFactory = _$PromotionCriteriaToJson;
  Map<String, dynamic> toJson() => _$PromotionCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PromotionCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality()
                    .equals(other.endDate, endDate)) &&
            (identical(other.promotionType, promotionType) ||
                const DeepCollectionEquality()
                    .equals(other.promotionType, promotionType)) &&
            (identical(other.amount, amount) ||
                const DeepCollectionEquality().equals(other.amount, amount)) &&
            (identical(other.intervalDuration, intervalDuration) ||
                const DeepCollectionEquality()
                    .equals(other.intervalDuration, intervalDuration)) &&
            (identical(other.simplrServiceId, simplrServiceId) ||
                const DeepCollectionEquality()
                    .equals(other.simplrServiceId, simplrServiceId)) &&
            (identical(other.serviceCategoryId, serviceCategoryId) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategoryId, serviceCategoryId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      const DeepCollectionEquality().hash(promotionType) ^
      const DeepCollectionEquality().hash(amount) ^
      const DeepCollectionEquality().hash(intervalDuration) ^
      const DeepCollectionEquality().hash(simplrServiceId) ^
      const DeepCollectionEquality().hash(serviceCategoryId) ^
      runtimeType.hashCode;
}

extension $PromotionCriteriaExtension on PromotionCriteria {
  PromotionCriteria copyWith(
      {LongFilter? id,
      StringFilter? name,
      BooleanFilter? active,
      InstantFilter? startDate,
      InstantFilter? endDate,
      PromotionTypeFilter? promotionType,
      BigDecimalFilter? amount,
      IntegerFilter? intervalDuration,
      LongFilter? simplrServiceId,
      LongFilter? serviceCategoryId}) {
    return PromotionCriteria(
        id: id ?? this.id,
        name: name ?? this.name,
        active: active ?? this.active,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate,
        promotionType: promotionType ?? this.promotionType,
        amount: amount ?? this.amount,
        intervalDuration: intervalDuration ?? this.intervalDuration,
        simplrServiceId: simplrServiceId ?? this.simplrServiceId,
        serviceCategoryId: serviceCategoryId ?? this.serviceCategoryId);
  }

  PromotionCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<StringFilter?>? name,
      Wrapped<BooleanFilter?>? active,
      Wrapped<InstantFilter?>? startDate,
      Wrapped<InstantFilter?>? endDate,
      Wrapped<PromotionTypeFilter?>? promotionType,
      Wrapped<BigDecimalFilter?>? amount,
      Wrapped<IntegerFilter?>? intervalDuration,
      Wrapped<LongFilter?>? simplrServiceId,
      Wrapped<LongFilter?>? serviceCategoryId}) {
    return PromotionCriteria(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        active: (active != null ? active.value : this.active),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate),
        promotionType:
            (promotionType != null ? promotionType.value : this.promotionType),
        amount: (amount != null ? amount.value : this.amount),
        intervalDuration: (intervalDuration != null
            ? intervalDuration.value
            : this.intervalDuration),
        simplrServiceId: (simplrServiceId != null
            ? simplrServiceId.value
            : this.simplrServiceId),
        serviceCategoryId: (serviceCategoryId != null
            ? serviceCategoryId.value
            : this.serviceCategoryId));
  }
}

@JsonSerializable(explicitToJson: true)
class Associate {
  Associate({
    this.id,
    required this.name,
    this.description,
    this.active,
    this.imageUrl,
    this.urlName,
    this.couponCode,
    this.couponValue,
    this.percentCoupon,
    this.hideDiscount,
    this.firstColor,
    this.secondColor,
    this.thirdColor,
    this.lightText,
    this.title,
    this.subtitle,
    this.cta,
    this.priceHelper,
    this.disclaimer,
    this.firstPost,
    this.secondPost,
    this.associatePromotedService,
    this.serviceCategory,
    this.associateCategories,
    this.jobs,
  });

  factory Associate.fromJson(Map<String, dynamic> json) =>
      _$AssociateFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'urlName', includeIfNull: false, defaultValue: '')
  final String? urlName;
  @JsonKey(name: 'couponCode', includeIfNull: false, defaultValue: '')
  final String? couponCode;
  @JsonKey(name: 'couponValue', includeIfNull: false)
  final double? couponValue;
  @JsonKey(name: 'percentCoupon', includeIfNull: false)
  final bool? percentCoupon;
  @JsonKey(name: 'hideDiscount', includeIfNull: false)
  final bool? hideDiscount;
  @JsonKey(name: 'firstColor', includeIfNull: false, defaultValue: '')
  final String? firstColor;
  @JsonKey(name: 'secondColor', includeIfNull: false, defaultValue: '')
  final String? secondColor;
  @JsonKey(name: 'thirdColor', includeIfNull: false, defaultValue: '')
  final String? thirdColor;
  @JsonKey(name: 'lightText', includeIfNull: false)
  final bool? lightText;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'subtitle', includeIfNull: false, defaultValue: '')
  final String? subtitle;
  @JsonKey(name: 'cta', includeIfNull: false, defaultValue: '')
  final String? cta;
  @JsonKey(name: 'priceHelper', includeIfNull: false, defaultValue: '')
  final String? priceHelper;
  @JsonKey(name: 'disclaimer', includeIfNull: false, defaultValue: '')
  final String? disclaimer;
  @JsonKey(name: 'firstPost', includeIfNull: false, defaultValue: '')
  final String? firstPost;
  @JsonKey(name: 'secondPost', includeIfNull: false, defaultValue: '')
  final String? secondPost;
  @JsonKey(name: 'associatePromotedService', includeIfNull: false)
  final AssociatePromotedService? associatePromotedService;
  @JsonKey(name: 'serviceCategory', includeIfNull: false)
  final ServiceCategory? serviceCategory;
  @JsonKey(name: 'associateCategories', includeIfNull: false)
  final List<AssociateCategory>? associateCategories;
  @JsonKey(name: 'jobs', includeIfNull: false, defaultValue: <Job>[])
  final List<Job>? jobs;
  static const fromJsonFactory = _$AssociateFromJson;
  static const toJsonFactory = _$AssociateToJson;
  Map<String, dynamic> toJson() => _$AssociateToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Associate &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.urlName, urlName) ||
                const DeepCollectionEquality()
                    .equals(other.urlName, urlName)) &&
            (identical(other.couponCode, couponCode) ||
                const DeepCollectionEquality()
                    .equals(other.couponCode, couponCode)) &&
            (identical(other.couponValue, couponValue) ||
                const DeepCollectionEquality()
                    .equals(other.couponValue, couponValue)) &&
            (identical(other.percentCoupon, percentCoupon) ||
                const DeepCollectionEquality()
                    .equals(other.percentCoupon, percentCoupon)) &&
            (identical(other.hideDiscount, hideDiscount) ||
                const DeepCollectionEquality()
                    .equals(other.hideDiscount, hideDiscount)) &&
            (identical(other.firstColor, firstColor) ||
                const DeepCollectionEquality()
                    .equals(other.firstColor, firstColor)) &&
            (identical(other.secondColor, secondColor) ||
                const DeepCollectionEquality()
                    .equals(other.secondColor, secondColor)) &&
            (identical(other.thirdColor, thirdColor) ||
                const DeepCollectionEquality()
                    .equals(other.thirdColor, thirdColor)) &&
            (identical(other.lightText, lightText) ||
                const DeepCollectionEquality()
                    .equals(other.lightText, lightText)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.subtitle, subtitle) ||
                const DeepCollectionEquality()
                    .equals(other.subtitle, subtitle)) &&
            (identical(other.cta, cta) ||
                const DeepCollectionEquality().equals(other.cta, cta)) &&
            (identical(other.priceHelper, priceHelper) ||
                const DeepCollectionEquality()
                    .equals(other.priceHelper, priceHelper)) &&
            (identical(other.disclaimer, disclaimer) ||
                const DeepCollectionEquality()
                    .equals(other.disclaimer, disclaimer)) &&
            (identical(other.firstPost, firstPost) ||
                const DeepCollectionEquality()
                    .equals(other.firstPost, firstPost)) &&
            (identical(other.secondPost, secondPost) ||
                const DeepCollectionEquality()
                    .equals(other.secondPost, secondPost)) &&
            (identical(other.associatePromotedService, associatePromotedService) ||
                const DeepCollectionEquality().equals(
                    other.associatePromotedService,
                    associatePromotedService)) &&
            (identical(other.serviceCategory, serviceCategory) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategory, serviceCategory)) &&
            (identical(other.associateCategories, associateCategories) || const DeepCollectionEquality().equals(other.associateCategories, associateCategories)) &&
            (identical(other.jobs, jobs) || const DeepCollectionEquality().equals(other.jobs, jobs)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(urlName) ^
      const DeepCollectionEquality().hash(couponCode) ^
      const DeepCollectionEquality().hash(couponValue) ^
      const DeepCollectionEquality().hash(percentCoupon) ^
      const DeepCollectionEquality().hash(hideDiscount) ^
      const DeepCollectionEquality().hash(firstColor) ^
      const DeepCollectionEquality().hash(secondColor) ^
      const DeepCollectionEquality().hash(thirdColor) ^
      const DeepCollectionEquality().hash(lightText) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(subtitle) ^
      const DeepCollectionEquality().hash(cta) ^
      const DeepCollectionEquality().hash(priceHelper) ^
      const DeepCollectionEquality().hash(disclaimer) ^
      const DeepCollectionEquality().hash(firstPost) ^
      const DeepCollectionEquality().hash(secondPost) ^
      const DeepCollectionEquality().hash(associatePromotedService) ^
      const DeepCollectionEquality().hash(serviceCategory) ^
      const DeepCollectionEquality().hash(associateCategories) ^
      const DeepCollectionEquality().hash(jobs) ^
      runtimeType.hashCode;
}

extension $AssociateExtension on Associate {
  Associate copyWith(
      {num? id,
      String? name,
      String? description,
      bool? active,
      String? imageUrl,
      String? urlName,
      String? couponCode,
      double? couponValue,
      bool? percentCoupon,
      bool? hideDiscount,
      String? firstColor,
      String? secondColor,
      String? thirdColor,
      bool? lightText,
      String? title,
      String? subtitle,
      String? cta,
      String? priceHelper,
      String? disclaimer,
      String? firstPost,
      String? secondPost,
      AssociatePromotedService? associatePromotedService,
      ServiceCategory? serviceCategory,
      List<AssociateCategory>? associateCategories,
      List<Job>? jobs}) {
    return Associate(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        active: active ?? this.active,
        imageUrl: imageUrl ?? this.imageUrl,
        urlName: urlName ?? this.urlName,
        couponCode: couponCode ?? this.couponCode,
        couponValue: couponValue ?? this.couponValue,
        percentCoupon: percentCoupon ?? this.percentCoupon,
        hideDiscount: hideDiscount ?? this.hideDiscount,
        firstColor: firstColor ?? this.firstColor,
        secondColor: secondColor ?? this.secondColor,
        thirdColor: thirdColor ?? this.thirdColor,
        lightText: lightText ?? this.lightText,
        title: title ?? this.title,
        subtitle: subtitle ?? this.subtitle,
        cta: cta ?? this.cta,
        priceHelper: priceHelper ?? this.priceHelper,
        disclaimer: disclaimer ?? this.disclaimer,
        firstPost: firstPost ?? this.firstPost,
        secondPost: secondPost ?? this.secondPost,
        associatePromotedService:
            associatePromotedService ?? this.associatePromotedService,
        serviceCategory: serviceCategory ?? this.serviceCategory,
        associateCategories: associateCategories ?? this.associateCategories,
        jobs: jobs ?? this.jobs);
  }

  Associate copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<bool?>? active,
      Wrapped<String?>? imageUrl,
      Wrapped<String?>? urlName,
      Wrapped<String?>? couponCode,
      Wrapped<double?>? couponValue,
      Wrapped<bool?>? percentCoupon,
      Wrapped<bool?>? hideDiscount,
      Wrapped<String?>? firstColor,
      Wrapped<String?>? secondColor,
      Wrapped<String?>? thirdColor,
      Wrapped<bool?>? lightText,
      Wrapped<String?>? title,
      Wrapped<String?>? subtitle,
      Wrapped<String?>? cta,
      Wrapped<String?>? priceHelper,
      Wrapped<String?>? disclaimer,
      Wrapped<String?>? firstPost,
      Wrapped<String?>? secondPost,
      Wrapped<AssociatePromotedService?>? associatePromotedService,
      Wrapped<ServiceCategory?>? serviceCategory,
      Wrapped<List<AssociateCategory>?>? associateCategories,
      Wrapped<List<Job>?>? jobs}) {
    return Associate(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        active: (active != null ? active.value : this.active),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        urlName: (urlName != null ? urlName.value : this.urlName),
        couponCode: (couponCode != null ? couponCode.value : this.couponCode),
        couponValue:
            (couponValue != null ? couponValue.value : this.couponValue),
        percentCoupon:
            (percentCoupon != null ? percentCoupon.value : this.percentCoupon),
        hideDiscount:
            (hideDiscount != null ? hideDiscount.value : this.hideDiscount),
        firstColor: (firstColor != null ? firstColor.value : this.firstColor),
        secondColor:
            (secondColor != null ? secondColor.value : this.secondColor),
        thirdColor: (thirdColor != null ? thirdColor.value : this.thirdColor),
        lightText: (lightText != null ? lightText.value : this.lightText),
        title: (title != null ? title.value : this.title),
        subtitle: (subtitle != null ? subtitle.value : this.subtitle),
        cta: (cta != null ? cta.value : this.cta),
        priceHelper:
            (priceHelper != null ? priceHelper.value : this.priceHelper),
        disclaimer: (disclaimer != null ? disclaimer.value : this.disclaimer),
        firstPost: (firstPost != null ? firstPost.value : this.firstPost),
        secondPost: (secondPost != null ? secondPost.value : this.secondPost),
        associatePromotedService: (associatePromotedService != null
            ? associatePromotedService.value
            : this.associatePromotedService),
        serviceCategory: (serviceCategory != null
            ? serviceCategory.value
            : this.serviceCategory),
        associateCategories: (associateCategories != null
            ? associateCategories.value
            : this.associateCategories),
        jobs: (jobs != null ? jobs.value : this.jobs));
  }
}

typedef Associates = List<Associate>;

@JsonSerializable(explicitToJson: true)
class AssociatePromotedService {
  AssociatePromotedService({
    this.id,
    this.couponCode,
    this.couponValue,
    this.percentCoupon,
    this.finalPrice,
    this.simplrService,
    this.simplrServiceOption,
  });

  factory AssociatePromotedService.fromJson(Map<String, dynamic> json) =>
      _$AssociatePromotedServiceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'couponCode', includeIfNull: false, defaultValue: '')
  final String? couponCode;
  @JsonKey(name: 'couponValue', includeIfNull: false)
  final double? couponValue;
  @JsonKey(name: 'percentCoupon', includeIfNull: false)
  final bool? percentCoupon;
  @JsonKey(name: 'finalPrice', includeIfNull: false)
  final double? finalPrice;
  @JsonKey(name: 'simplrService', includeIfNull: false)
  final SimplrService? simplrService;
  @JsonKey(name: 'simplrServiceOption', includeIfNull: false)
  final ServiceOption? simplrServiceOption;
  static const fromJsonFactory = _$AssociatePromotedServiceFromJson;
  static const toJsonFactory = _$AssociatePromotedServiceToJson;
  Map<String, dynamic> toJson() => _$AssociatePromotedServiceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AssociatePromotedService &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.couponCode, couponCode) ||
                const DeepCollectionEquality()
                    .equals(other.couponCode, couponCode)) &&
            (identical(other.couponValue, couponValue) ||
                const DeepCollectionEquality()
                    .equals(other.couponValue, couponValue)) &&
            (identical(other.percentCoupon, percentCoupon) ||
                const DeepCollectionEquality()
                    .equals(other.percentCoupon, percentCoupon)) &&
            (identical(other.finalPrice, finalPrice) ||
                const DeepCollectionEquality()
                    .equals(other.finalPrice, finalPrice)) &&
            (identical(other.simplrService, simplrService) ||
                const DeepCollectionEquality()
                    .equals(other.simplrService, simplrService)) &&
            (identical(other.simplrServiceOption, simplrServiceOption) ||
                const DeepCollectionEquality()
                    .equals(other.simplrServiceOption, simplrServiceOption)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(couponCode) ^
      const DeepCollectionEquality().hash(couponValue) ^
      const DeepCollectionEquality().hash(percentCoupon) ^
      const DeepCollectionEquality().hash(finalPrice) ^
      const DeepCollectionEquality().hash(simplrService) ^
      const DeepCollectionEquality().hash(simplrServiceOption) ^
      runtimeType.hashCode;
}

extension $AssociatePromotedServiceExtension on AssociatePromotedService {
  AssociatePromotedService copyWith(
      {num? id,
      String? couponCode,
      double? couponValue,
      bool? percentCoupon,
      double? finalPrice,
      SimplrService? simplrService,
      ServiceOption? simplrServiceOption}) {
    return AssociatePromotedService(
        id: id ?? this.id,
        couponCode: couponCode ?? this.couponCode,
        couponValue: couponValue ?? this.couponValue,
        percentCoupon: percentCoupon ?? this.percentCoupon,
        finalPrice: finalPrice ?? this.finalPrice,
        simplrService: simplrService ?? this.simplrService,
        simplrServiceOption: simplrServiceOption ?? this.simplrServiceOption);
  }

  AssociatePromotedService copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? couponCode,
      Wrapped<double?>? couponValue,
      Wrapped<bool?>? percentCoupon,
      Wrapped<double?>? finalPrice,
      Wrapped<SimplrService?>? simplrService,
      Wrapped<ServiceOption?>? simplrServiceOption}) {
    return AssociatePromotedService(
        id: (id != null ? id.value : this.id),
        couponCode: (couponCode != null ? couponCode.value : this.couponCode),
        couponValue:
            (couponValue != null ? couponValue.value : this.couponValue),
        percentCoupon:
            (percentCoupon != null ? percentCoupon.value : this.percentCoupon),
        finalPrice: (finalPrice != null ? finalPrice.value : this.finalPrice),
        simplrService:
            (simplrService != null ? simplrService.value : this.simplrService),
        simplrServiceOption: (simplrServiceOption != null
            ? simplrServiceOption.value
            : this.simplrServiceOption));
  }
}

@JsonSerializable(explicitToJson: true)
class AssociateCategory {
  AssociateCategory({
    this.id,
    this.associateId,
    this.name,
    this.order,
    this.serviceCategory,
    this.associateCategoryServices,
  });

  factory AssociateCategory.fromJson(Map<String, dynamic> json) =>
      _$AssociateCategoryFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'associateId', includeIfNull: false)
  final num? associateId;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'order', includeIfNull: false)
  final num? order;
  @JsonKey(name: 'serviceCategory', includeIfNull: false)
  final ServiceCategory? serviceCategory;
  @JsonKey(name: 'associateCategoryServices', includeIfNull: false)
  final List<AssociateCategoryService>? associateCategoryServices;
  static const fromJsonFactory = _$AssociateCategoryFromJson;
  static const toJsonFactory = _$AssociateCategoryToJson;
  Map<String, dynamic> toJson() => _$AssociateCategoryToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AssociateCategory &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.associateId, associateId) ||
                const DeepCollectionEquality()
                    .equals(other.associateId, associateId)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.order, order) ||
                const DeepCollectionEquality().equals(other.order, order)) &&
            (identical(other.serviceCategory, serviceCategory) ||
                const DeepCollectionEquality()
                    .equals(other.serviceCategory, serviceCategory)) &&
            (identical(other.associateCategoryServices,
                    associateCategoryServices) ||
                const DeepCollectionEquality().equals(
                    other.associateCategoryServices,
                    associateCategoryServices)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(associateId) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(order) ^
      const DeepCollectionEquality().hash(serviceCategory) ^
      const DeepCollectionEquality().hash(associateCategoryServices) ^
      runtimeType.hashCode;
}

extension $AssociateCategoryExtension on AssociateCategory {
  AssociateCategory copyWith(
      {num? id,
      num? associateId,
      String? name,
      num? order,
      ServiceCategory? serviceCategory,
      List<AssociateCategoryService>? associateCategoryServices}) {
    return AssociateCategory(
        id: id ?? this.id,
        associateId: associateId ?? this.associateId,
        name: name ?? this.name,
        order: order ?? this.order,
        serviceCategory: serviceCategory ?? this.serviceCategory,
        associateCategoryServices:
            associateCategoryServices ?? this.associateCategoryServices);
  }

  AssociateCategory copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<num?>? associateId,
      Wrapped<String?>? name,
      Wrapped<num?>? order,
      Wrapped<ServiceCategory?>? serviceCategory,
      Wrapped<List<AssociateCategoryService>?>? associateCategoryServices}) {
    return AssociateCategory(
        id: (id != null ? id.value : this.id),
        associateId:
            (associateId != null ? associateId.value : this.associateId),
        name: (name != null ? name.value : this.name),
        order: (order != null ? order.value : this.order),
        serviceCategory: (serviceCategory != null
            ? serviceCategory.value
            : this.serviceCategory),
        associateCategoryServices: (associateCategoryServices != null
            ? associateCategoryServices.value
            : this.associateCategoryServices));
  }
}

typedef AssociateCategories = List<AssociateCategory>;

@JsonSerializable(explicitToJson: true)
class AssociateCategoryService {
  AssociateCategoryService({
    this.id,
    this.simplrService,
    this.order,
  });

  factory AssociateCategoryService.fromJson(Map<String, dynamic> json) =>
      _$AssociateCategoryServiceFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'simplrService', includeIfNull: false)
  final SimplrService? simplrService;
  @JsonKey(name: 'order', includeIfNull: false)
  final num? order;
  static const fromJsonFactory = _$AssociateCategoryServiceFromJson;
  static const toJsonFactory = _$AssociateCategoryServiceToJson;
  Map<String, dynamic> toJson() => _$AssociateCategoryServiceToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AssociateCategoryService &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.simplrService, simplrService) ||
                const DeepCollectionEquality()
                    .equals(other.simplrService, simplrService)) &&
            (identical(other.order, order) ||
                const DeepCollectionEquality().equals(other.order, order)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(simplrService) ^
      const DeepCollectionEquality().hash(order) ^
      runtimeType.hashCode;
}

extension $AssociateCategoryServiceExtension on AssociateCategoryService {
  AssociateCategoryService copyWith(
      {num? id, SimplrService? simplrService, num? order}) {
    return AssociateCategoryService(
        id: id ?? this.id,
        simplrService: simplrService ?? this.simplrService,
        order: order ?? this.order);
  }

  AssociateCategoryService copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<SimplrService?>? simplrService,
      Wrapped<num?>? order}) {
    return AssociateCategoryService(
        id: (id != null ? id.value : this.id),
        simplrService:
            (simplrService != null ? simplrService.value : this.simplrService),
        order: (order != null ? order.value : this.order));
  }
}

typedef AssociateCategoryServices = List<AssociateCategoryService>;

@JsonSerializable(explicitToJson: true)
class AssociateCriteria {
  AssociateCriteria({
    this.id,
    this.active,
    this.landingName,
    this.associateName,
    this.globalSearch,
  });

  factory AssociateCriteria.fromJson(Map<String, dynamic> json) =>
      _$AssociateCriteriaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final LongFilter? id;
  @JsonKey(name: 'active', includeIfNull: false)
  final BooleanFilter? active;
  @JsonKey(name: 'landingName', includeIfNull: false)
  final StringFilter? landingName;
  @JsonKey(name: 'associateName', includeIfNull: false)
  final StringFilter? associateName;
  @JsonKey(name: 'globalSearch', includeIfNull: false)
  final StringFilter? globalSearch;
  static const fromJsonFactory = _$AssociateCriteriaFromJson;
  static const toJsonFactory = _$AssociateCriteriaToJson;
  Map<String, dynamic> toJson() => _$AssociateCriteriaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AssociateCriteria &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.landingName, landingName) ||
                const DeepCollectionEquality()
                    .equals(other.landingName, landingName)) &&
            (identical(other.associateName, associateName) ||
                const DeepCollectionEquality()
                    .equals(other.associateName, associateName)) &&
            (identical(other.globalSearch, globalSearch) ||
                const DeepCollectionEquality()
                    .equals(other.globalSearch, globalSearch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(landingName) ^
      const DeepCollectionEquality().hash(associateName) ^
      const DeepCollectionEquality().hash(globalSearch) ^
      runtimeType.hashCode;
}

extension $AssociateCriteriaExtension on AssociateCriteria {
  AssociateCriteria copyWith(
      {LongFilter? id,
      BooleanFilter? active,
      StringFilter? landingName,
      StringFilter? associateName,
      StringFilter? globalSearch}) {
    return AssociateCriteria(
        id: id ?? this.id,
        active: active ?? this.active,
        landingName: landingName ?? this.landingName,
        associateName: associateName ?? this.associateName,
        globalSearch: globalSearch ?? this.globalSearch);
  }

  AssociateCriteria copyWithWrapped(
      {Wrapped<LongFilter?>? id,
      Wrapped<BooleanFilter?>? active,
      Wrapped<StringFilter?>? landingName,
      Wrapped<StringFilter?>? associateName,
      Wrapped<StringFilter?>? globalSearch}) {
    return AssociateCriteria(
        id: (id != null ? id.value : this.id),
        active: (active != null ? active.value : this.active),
        landingName:
            (landingName != null ? landingName.value : this.landingName),
        associateName:
            (associateName != null ? associateName.value : this.associateName),
        globalSearch:
            (globalSearch != null ? globalSearch.value : this.globalSearch));
  }
}

@JsonSerializable(explicitToJson: true)
class HeroBanner {
  HeroBanner({
    this.id,
    this.name,
    this.header,
    this.subHeader,
    this.subHeader2,
    this.buttonText,
    this.buttonCta,
    this.buttonColor,
    this.primaryColor,
    this.order,
    this.imageUrl,
    this.active,
    this.$dynamic,
    this.textDynamic1,
    this.textDynamic2,
    this.textDynamic3,
    this.textDynamic4,
    this.textDynamic5,
    this.startDate,
    this.endDate,
  });

  factory HeroBanner.fromJson(Map<String, dynamic> json) =>
      _$HeroBannerFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'header', includeIfNull: false, defaultValue: '')
  final String? header;
  @JsonKey(name: 'subHeader', includeIfNull: false, defaultValue: '')
  final String? subHeader;
  @JsonKey(name: 'subHeader2', includeIfNull: false, defaultValue: '')
  final String? subHeader2;
  @JsonKey(name: 'buttonText', includeIfNull: false, defaultValue: '')
  final String? buttonText;
  @JsonKey(name: 'buttonCta', includeIfNull: false, defaultValue: '')
  final String? buttonCta;
  @JsonKey(name: 'buttonColor', includeIfNull: false, defaultValue: '')
  final String? buttonColor;
  @JsonKey(name: 'primaryColor', includeIfNull: false, defaultValue: '')
  final String? primaryColor;
  @JsonKey(name: 'order', includeIfNull: false)
  final double? order;
  @JsonKey(name: 'imageUrl', includeIfNull: false)
  final String? imageUrl;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: false)
  final bool? active;
  @JsonKey(name: 'dynamic', includeIfNull: false, defaultValue: false)
  final bool? $dynamic;
  @JsonKey(name: 'textDynamic1', includeIfNull: false, defaultValue: '')
  final String? textDynamic1;
  @JsonKey(name: 'textDynamic2', includeIfNull: false, defaultValue: '')
  final String? textDynamic2;
  @JsonKey(name: 'textDynamic3', includeIfNull: false, defaultValue: '')
  final String? textDynamic3;
  @JsonKey(name: 'textDynamic4', includeIfNull: false, defaultValue: '')
  final String? textDynamic4;
  @JsonKey(name: 'textDynamic5', includeIfNull: false, defaultValue: '')
  final String? textDynamic5;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  static const fromJsonFactory = _$HeroBannerFromJson;
  static const toJsonFactory = _$HeroBannerToJson;
  Map<String, dynamic> toJson() => _$HeroBannerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is HeroBanner &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.header, header) ||
                const DeepCollectionEquality().equals(other.header, header)) &&
            (identical(other.subHeader, subHeader) ||
                const DeepCollectionEquality()
                    .equals(other.subHeader, subHeader)) &&
            (identical(other.subHeader2, subHeader2) ||
                const DeepCollectionEquality()
                    .equals(other.subHeader2, subHeader2)) &&
            (identical(other.buttonText, buttonText) ||
                const DeepCollectionEquality()
                    .equals(other.buttonText, buttonText)) &&
            (identical(other.buttonCta, buttonCta) ||
                const DeepCollectionEquality()
                    .equals(other.buttonCta, buttonCta)) &&
            (identical(other.buttonColor, buttonColor) ||
                const DeepCollectionEquality()
                    .equals(other.buttonColor, buttonColor)) &&
            (identical(other.primaryColor, primaryColor) ||
                const DeepCollectionEquality()
                    .equals(other.primaryColor, primaryColor)) &&
            (identical(other.order, order) ||
                const DeepCollectionEquality().equals(other.order, order)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.$dynamic, $dynamic) ||
                const DeepCollectionEquality()
                    .equals(other.$dynamic, $dynamic)) &&
            (identical(other.textDynamic1, textDynamic1) ||
                const DeepCollectionEquality()
                    .equals(other.textDynamic1, textDynamic1)) &&
            (identical(other.textDynamic2, textDynamic2) ||
                const DeepCollectionEquality()
                    .equals(other.textDynamic2, textDynamic2)) &&
            (identical(other.textDynamic3, textDynamic3) ||
                const DeepCollectionEquality()
                    .equals(other.textDynamic3, textDynamic3)) &&
            (identical(other.textDynamic4, textDynamic4) ||
                const DeepCollectionEquality()
                    .equals(other.textDynamic4, textDynamic4)) &&
            (identical(other.textDynamic5, textDynamic5) ||
                const DeepCollectionEquality()
                    .equals(other.textDynamic5, textDynamic5)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality().equals(other.endDate, endDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(header) ^
      const DeepCollectionEquality().hash(subHeader) ^
      const DeepCollectionEquality().hash(subHeader2) ^
      const DeepCollectionEquality().hash(buttonText) ^
      const DeepCollectionEquality().hash(buttonCta) ^
      const DeepCollectionEquality().hash(buttonColor) ^
      const DeepCollectionEquality().hash(primaryColor) ^
      const DeepCollectionEquality().hash(order) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash($dynamic) ^
      const DeepCollectionEquality().hash(textDynamic1) ^
      const DeepCollectionEquality().hash(textDynamic2) ^
      const DeepCollectionEquality().hash(textDynamic3) ^
      const DeepCollectionEquality().hash(textDynamic4) ^
      const DeepCollectionEquality().hash(textDynamic5) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      runtimeType.hashCode;
}

extension $HeroBannerExtension on HeroBanner {
  HeroBanner copyWith(
      {num? id,
      String? name,
      String? header,
      String? subHeader,
      String? subHeader2,
      String? buttonText,
      String? buttonCta,
      String? buttonColor,
      String? primaryColor,
      double? order,
      String? imageUrl,
      bool? active,
      bool? $dynamic,
      String? textDynamic1,
      String? textDynamic2,
      String? textDynamic3,
      String? textDynamic4,
      String? textDynamic5,
      DateTime? startDate,
      DateTime? endDate}) {
    return HeroBanner(
        id: id ?? this.id,
        name: name ?? this.name,
        header: header ?? this.header,
        subHeader: subHeader ?? this.subHeader,
        subHeader2: subHeader2 ?? this.subHeader2,
        buttonText: buttonText ?? this.buttonText,
        buttonCta: buttonCta ?? this.buttonCta,
        buttonColor: buttonColor ?? this.buttonColor,
        primaryColor: primaryColor ?? this.primaryColor,
        order: order ?? this.order,
        imageUrl: imageUrl ?? this.imageUrl,
        active: active ?? this.active,
        $dynamic: $dynamic ?? this.$dynamic,
        textDynamic1: textDynamic1 ?? this.textDynamic1,
        textDynamic2: textDynamic2 ?? this.textDynamic2,
        textDynamic3: textDynamic3 ?? this.textDynamic3,
        textDynamic4: textDynamic4 ?? this.textDynamic4,
        textDynamic5: textDynamic5 ?? this.textDynamic5,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate);
  }

  HeroBanner copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? header,
      Wrapped<String?>? subHeader,
      Wrapped<String?>? subHeader2,
      Wrapped<String?>? buttonText,
      Wrapped<String?>? buttonCta,
      Wrapped<String?>? buttonColor,
      Wrapped<String?>? primaryColor,
      Wrapped<double?>? order,
      Wrapped<String?>? imageUrl,
      Wrapped<bool?>? active,
      Wrapped<bool?>? $dynamic,
      Wrapped<String?>? textDynamic1,
      Wrapped<String?>? textDynamic2,
      Wrapped<String?>? textDynamic3,
      Wrapped<String?>? textDynamic4,
      Wrapped<String?>? textDynamic5,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate}) {
    return HeroBanner(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        header: (header != null ? header.value : this.header),
        subHeader: (subHeader != null ? subHeader.value : this.subHeader),
        subHeader2: (subHeader2 != null ? subHeader2.value : this.subHeader2),
        buttonText: (buttonText != null ? buttonText.value : this.buttonText),
        buttonCta: (buttonCta != null ? buttonCta.value : this.buttonCta),
        buttonColor:
            (buttonColor != null ? buttonColor.value : this.buttonColor),
        primaryColor:
            (primaryColor != null ? primaryColor.value : this.primaryColor),
        order: (order != null ? order.value : this.order),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        active: (active != null ? active.value : this.active),
        $dynamic: ($dynamic != null ? $dynamic.value : this.$dynamic),
        textDynamic1:
            (textDynamic1 != null ? textDynamic1.value : this.textDynamic1),
        textDynamic2:
            (textDynamic2 != null ? textDynamic2.value : this.textDynamic2),
        textDynamic3:
            (textDynamic3 != null ? textDynamic3.value : this.textDynamic3),
        textDynamic4:
            (textDynamic4 != null ? textDynamic4.value : this.textDynamic4),
        textDynamic5:
            (textDynamic5 != null ? textDynamic5.value : this.textDynamic5),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate));
  }
}

typedef HeroBanners = List<HeroBanner>;

@JsonSerializable(explicitToJson: true)
class InfoBanner {
  InfoBanner({
    this.id,
    this.active,
    this.name,
    this.desktopDescription,
    this.mobileDescription,
    this.startDate,
    this.endDate,
  });

  factory InfoBanner.fromJson(Map<String, dynamic> json) =>
      _$InfoBannerFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: false)
  final bool? active;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'desktopDescription', includeIfNull: false, defaultValue: '')
  final String? desktopDescription;
  @JsonKey(name: 'mobileDescription', includeIfNull: false, defaultValue: '')
  final String? mobileDescription;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'endDate', includeIfNull: false)
  final DateTime? endDate;
  static const fromJsonFactory = _$InfoBannerFromJson;
  static const toJsonFactory = _$InfoBannerToJson;
  Map<String, dynamic> toJson() => _$InfoBannerToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InfoBanner &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.desktopDescription, desktopDescription) ||
                const DeepCollectionEquality()
                    .equals(other.desktopDescription, desktopDescription)) &&
            (identical(other.mobileDescription, mobileDescription) ||
                const DeepCollectionEquality()
                    .equals(other.mobileDescription, mobileDescription)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.endDate, endDate) ||
                const DeepCollectionEquality().equals(other.endDate, endDate)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(desktopDescription) ^
      const DeepCollectionEquality().hash(mobileDescription) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(endDate) ^
      runtimeType.hashCode;
}

extension $InfoBannerExtension on InfoBanner {
  InfoBanner copyWith(
      {num? id,
      bool? active,
      String? name,
      String? desktopDescription,
      String? mobileDescription,
      DateTime? startDate,
      DateTime? endDate}) {
    return InfoBanner(
        id: id ?? this.id,
        active: active ?? this.active,
        name: name ?? this.name,
        desktopDescription: desktopDescription ?? this.desktopDescription,
        mobileDescription: mobileDescription ?? this.mobileDescription,
        startDate: startDate ?? this.startDate,
        endDate: endDate ?? this.endDate);
  }

  InfoBanner copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<bool?>? active,
      Wrapped<String?>? name,
      Wrapped<String?>? desktopDescription,
      Wrapped<String?>? mobileDescription,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? endDate}) {
    return InfoBanner(
        id: (id != null ? id.value : this.id),
        active: (active != null ? active.value : this.active),
        name: (name != null ? name.value : this.name),
        desktopDescription: (desktopDescription != null
            ? desktopDescription.value
            : this.desktopDescription),
        mobileDescription: (mobileDescription != null
            ? mobileDescription.value
            : this.mobileDescription),
        startDate: (startDate != null ? startDate.value : this.startDate),
        endDate: (endDate != null ? endDate.value : this.endDate));
  }
}

typedef InfoBanners = List<InfoBanner>;

@JsonSerializable(explicitToJson: true)
class BoundingArea {
  BoundingArea({
    this.id,
    this.displayName,
    this.area,
    this.type,
  });

  factory BoundingArea.fromJson(Map<String, dynamic> json) =>
      _$BoundingAreaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'displayName', includeIfNull: false, defaultValue: '')
  final String? displayName;
  @JsonKey(name: 'area', includeIfNull: false, defaultValue: '')
  final String? area;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: boundingAreaTypeEnumToJson,
    fromJson: boundingAreaTypeEnumFromJson,
  )
  final enums.BoundingAreaTypeEnum? type;
  static const fromJsonFactory = _$BoundingAreaFromJson;
  static const toJsonFactory = _$BoundingAreaToJson;
  Map<String, dynamic> toJson() => _$BoundingAreaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BoundingArea &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.displayName, displayName) ||
                const DeepCollectionEquality()
                    .equals(other.displayName, displayName)) &&
            (identical(other.area, area) ||
                const DeepCollectionEquality().equals(other.area, area)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(displayName) ^
      const DeepCollectionEquality().hash(area) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $BoundingAreaExtension on BoundingArea {
  BoundingArea copyWith(
      {num? id,
      String? displayName,
      String? area,
      enums.BoundingAreaTypeEnum? type}) {
    return BoundingArea(
        id: id ?? this.id,
        displayName: displayName ?? this.displayName,
        area: area ?? this.area,
        type: type ?? this.type);
  }

  BoundingArea copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? displayName,
      Wrapped<String?>? area,
      Wrapped<enums.BoundingAreaTypeEnum?>? type}) {
    return BoundingArea(
        id: (id != null ? id.value : this.id),
        displayName:
            (displayName != null ? displayName.value : this.displayName),
        area: (area != null ? area.value : this.area),
        type: (type != null ? type.value : this.type));
  }
}

typedef BoundingAreas = List<BoundingArea>;

@JsonSerializable(explicitToJson: true)
class Coordinate {
  Coordinate({
    this.displayName,
    this.lat,
    this.lon,
  });

  factory Coordinate.fromJson(Map<String, dynamic> json) =>
      _$CoordinateFromJson(json);

  @JsonKey(name: 'displayName', includeIfNull: false, defaultValue: '')
  final String? displayName;
  @JsonKey(name: 'lat', includeIfNull: false, defaultValue: '')
  final String? lat;
  @JsonKey(name: 'lon', includeIfNull: false, defaultValue: '')
  final String? lon;
  static const fromJsonFactory = _$CoordinateFromJson;
  static const toJsonFactory = _$CoordinateToJson;
  Map<String, dynamic> toJson() => _$CoordinateToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Coordinate &&
            (identical(other.displayName, displayName) ||
                const DeepCollectionEquality()
                    .equals(other.displayName, displayName)) &&
            (identical(other.lat, lat) ||
                const DeepCollectionEquality().equals(other.lat, lat)) &&
            (identical(other.lon, lon) ||
                const DeepCollectionEquality().equals(other.lon, lon)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(displayName) ^
      const DeepCollectionEquality().hash(lat) ^
      const DeepCollectionEquality().hash(lon) ^
      runtimeType.hashCode;
}

extension $CoordinateExtension on Coordinate {
  Coordinate copyWith({String? displayName, String? lat, String? lon}) {
    return Coordinate(
        displayName: displayName ?? this.displayName,
        lat: lat ?? this.lat,
        lon: lon ?? this.lon);
  }

  Coordinate copyWithWrapped(
      {Wrapped<String?>? displayName,
      Wrapped<String?>? lat,
      Wrapped<String?>? lon}) {
    return Coordinate(
        displayName:
            (displayName != null ? displayName.value : this.displayName),
        lat: (lat != null ? lat.value : this.lat),
        lon: (lon != null ? lon.value : this.lon));
  }
}

typedef Coordinates = List<Coordinate>;

@JsonSerializable(explicitToJson: true)
class PredefinedBoundingArea {
  PredefinedBoundingArea({
    this.id,
    this.areaName,
  });

  factory PredefinedBoundingArea.fromJson(Map<String, dynamic> json) =>
      _$PredefinedBoundingAreaFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'areaName', includeIfNull: false, defaultValue: '')
  final String? areaName;
  static const fromJsonFactory = _$PredefinedBoundingAreaFromJson;
  static const toJsonFactory = _$PredefinedBoundingAreaToJson;
  Map<String, dynamic> toJson() => _$PredefinedBoundingAreaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PredefinedBoundingArea &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.areaName, areaName) ||
                const DeepCollectionEquality()
                    .equals(other.areaName, areaName)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(areaName) ^
      runtimeType.hashCode;
}

extension $PredefinedBoundingAreaExtension on PredefinedBoundingArea {
  PredefinedBoundingArea copyWith({num? id, String? areaName}) {
    return PredefinedBoundingArea(
        id: id ?? this.id, areaName: areaName ?? this.areaName);
  }

  PredefinedBoundingArea copyWithWrapped(
      {Wrapped<num?>? id, Wrapped<String?>? areaName}) {
    return PredefinedBoundingArea(
        id: (id != null ? id.value : this.id),
        areaName: (areaName != null ? areaName.value : this.areaName));
  }
}

typedef PredefinedBoundingAreas = List<PredefinedBoundingArea>;

@JsonSerializable(explicitToJson: true)
class TaxRate {
  TaxRate({
    this.id,
    this.percentage,
    this.name,
    this.taxType,
    this.country,
    this.state,
    this.active,
  });

  factory TaxRate.fromJson(Map<String, dynamic> json) =>
      _$TaxRateFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'percentage', includeIfNull: false)
  final double? percentage;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(
    name: 'taxType',
    includeIfNull: false,
    toJson: taxTypeEnumToJson,
    fromJson: taxTypeEnumFromJson,
  )
  final enums.TaxTypeEnum? taxType;
  @JsonKey(
    name: 'country',
    includeIfNull: false,
    toJson: countryCodeEnumToJson,
    fromJson: countryCodeEnumFromJson,
  )
  final enums.CountryCodeEnum? country;
  @JsonKey(
    name: 'state',
    includeIfNull: false,
    toJson: stateCodeEnumToJson,
    fromJson: stateCodeEnumFromJson,
  )
  final enums.StateCodeEnum? state;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  static const fromJsonFactory = _$TaxRateFromJson;
  static const toJsonFactory = _$TaxRateToJson;
  Map<String, dynamic> toJson() => _$TaxRateToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaxRate &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.percentage, percentage) ||
                const DeepCollectionEquality()
                    .equals(other.percentage, percentage)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.taxType, taxType) ||
                const DeepCollectionEquality()
                    .equals(other.taxType, taxType)) &&
            (identical(other.country, country) ||
                const DeepCollectionEquality()
                    .equals(other.country, country)) &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(percentage) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(taxType) ^
      const DeepCollectionEquality().hash(country) ^
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(active) ^
      runtimeType.hashCode;
}

extension $TaxRateExtension on TaxRate {
  TaxRate copyWith(
      {num? id,
      double? percentage,
      String? name,
      enums.TaxTypeEnum? taxType,
      enums.CountryCodeEnum? country,
      enums.StateCodeEnum? state,
      bool? active}) {
    return TaxRate(
        id: id ?? this.id,
        percentage: percentage ?? this.percentage,
        name: name ?? this.name,
        taxType: taxType ?? this.taxType,
        country: country ?? this.country,
        state: state ?? this.state,
        active: active ?? this.active);
  }

  TaxRate copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<double?>? percentage,
      Wrapped<String?>? name,
      Wrapped<enums.TaxTypeEnum?>? taxType,
      Wrapped<enums.CountryCodeEnum?>? country,
      Wrapped<enums.StateCodeEnum?>? state,
      Wrapped<bool?>? active}) {
    return TaxRate(
        id: (id != null ? id.value : this.id),
        percentage: (percentage != null ? percentage.value : this.percentage),
        name: (name != null ? name.value : this.name),
        taxType: (taxType != null ? taxType.value : this.taxType),
        country: (country != null ? country.value : this.country),
        state: (state != null ? state.value : this.state),
        active: (active != null ? active.value : this.active));
  }
}

typedef TaxRates = List<TaxRate>;

@JsonSerializable(explicitToJson: true)
class TaxRatesPage {
  TaxRatesPage({
    this.services,
  });

  factory TaxRatesPage.fromJson(Map<String, dynamic> json) =>
      _$TaxRatesPageFromJson(json);

  @JsonKey(name: 'services', includeIfNull: false)
  final List<TaxRate>? services;
  static const fromJsonFactory = _$TaxRatesPageFromJson;
  static const toJsonFactory = _$TaxRatesPageToJson;
  Map<String, dynamic> toJson() => _$TaxRatesPageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TaxRatesPage &&
            (identical(other.services, services) ||
                const DeepCollectionEquality()
                    .equals(other.services, services)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(services) ^ runtimeType.hashCode;
}

extension $TaxRatesPageExtension on TaxRatesPage {
  TaxRatesPage copyWith({List<TaxRate>? services}) {
    return TaxRatesPage(services: services ?? this.services);
  }

  TaxRatesPage copyWithWrapped({Wrapped<List<TaxRate>?>? services}) {
    return TaxRatesPage(
        services: (services != null ? services.value : this.services));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServicePrioritisedField {
  SimplrServicePrioritisedField({
    this.field,
    this.value,
  });

  factory SimplrServicePrioritisedField.fromJson(Map<String, dynamic> json) =>
      _$SimplrServicePrioritisedFieldFromJson(json);

  @JsonKey(
    name: 'field',
    includeIfNull: false,
    toJson: simplrServicePrioritisedFieldFieldToJson,
    fromJson: simplrServicePrioritisedFieldFieldFromJson,
  )
  final enums.SimplrServicePrioritisedFieldField? field;
  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String? value;
  static const fromJsonFactory = _$SimplrServicePrioritisedFieldFromJson;
  static const toJsonFactory = _$SimplrServicePrioritisedFieldToJson;
  Map<String, dynamic> toJson() => _$SimplrServicePrioritisedFieldToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServicePrioritisedField &&
            (identical(other.field, field) ||
                const DeepCollectionEquality().equals(other.field, field)) &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(field) ^
      const DeepCollectionEquality().hash(value) ^
      runtimeType.hashCode;
}

extension $SimplrServicePrioritisedFieldExtension
    on SimplrServicePrioritisedField {
  SimplrServicePrioritisedField copyWith(
      {enums.SimplrServicePrioritisedFieldField? field, String? value}) {
    return SimplrServicePrioritisedField(
        field: field ?? this.field, value: value ?? this.value);
  }

  SimplrServicePrioritisedField copyWithWrapped(
      {Wrapped<enums.SimplrServicePrioritisedFieldField?>? field,
      Wrapped<String?>? value}) {
    return SimplrServicePrioritisedField(
        field: (field != null ? field.value : this.field),
        value: (value != null ? value.value : this.value));
  }
}

typedef SimplrServiceExpands = List<String>;

@JsonSerializable(explicitToJson: true)
class Pageable {
  Pageable({
    this.page,
    this.size,
    this.sort,
  });

  factory Pageable.fromJson(Map<String, dynamic> json) =>
      _$PageableFromJson(json);

  @JsonKey(name: 'page', includeIfNull: false)
  final int? page;
  @JsonKey(name: 'size', includeIfNull: false)
  final int? size;
  @JsonKey(name: 'sort', includeIfNull: false, defaultValue: <String>[])
  final List<String>? sort;
  static const fromJsonFactory = _$PageableFromJson;
  static const toJsonFactory = _$PageableToJson;
  Map<String, dynamic> toJson() => _$PageableToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Pageable &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.sort, sort) ||
                const DeepCollectionEquality().equals(other.sort, sort)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(page) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(sort) ^
      runtimeType.hashCode;
}

extension $PageableExtension on Pageable {
  Pageable copyWith({int? page, int? size, List<String>? sort}) {
    return Pageable(
        page: page ?? this.page,
        size: size ?? this.size,
        sort: sort ?? this.sort);
  }

  Pageable copyWithWrapped(
      {Wrapped<int?>? page,
      Wrapped<int?>? size,
      Wrapped<List<String>?>? sort}) {
    return Pageable(
        page: (page != null ? page.value : this.page),
        size: (size != null ? size.value : this.size),
        sort: (sort != null ? sort.value : this.sort));
  }
}

@JsonSerializable(explicitToJson: true)
class Page {
  Page({
    this.totalElements,
    this.totalPages,
    this.page,
    this.size,
    this.sort,
  });

  factory Page.fromJson(Map<String, dynamic> json) => _$PageFromJson(json);

  @JsonKey(name: 'totalElements', includeIfNull: false)
  final int? totalElements;
  @JsonKey(name: 'totalPages', includeIfNull: false)
  final int? totalPages;
  @JsonKey(name: 'page', includeIfNull: false)
  final int? page;
  @JsonKey(name: 'size', includeIfNull: false)
  final int? size;
  @JsonKey(name: 'sort', includeIfNull: false, defaultValue: <String>[])
  final List<String>? sort;
  static const fromJsonFactory = _$PageFromJson;
  static const toJsonFactory = _$PageToJson;
  Map<String, dynamic> toJson() => _$PageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Page &&
            (identical(other.totalElements, totalElements) ||
                const DeepCollectionEquality()
                    .equals(other.totalElements, totalElements)) &&
            (identical(other.totalPages, totalPages) ||
                const DeepCollectionEquality()
                    .equals(other.totalPages, totalPages)) &&
            (identical(other.page, page) ||
                const DeepCollectionEquality().equals(other.page, page)) &&
            (identical(other.size, size) ||
                const DeepCollectionEquality().equals(other.size, size)) &&
            (identical(other.sort, sort) ||
                const DeepCollectionEquality().equals(other.sort, sort)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(totalElements) ^
      const DeepCollectionEquality().hash(totalPages) ^
      const DeepCollectionEquality().hash(page) ^
      const DeepCollectionEquality().hash(size) ^
      const DeepCollectionEquality().hash(sort) ^
      runtimeType.hashCode;
}

extension $PageExtension on Page {
  Page copyWith(
      {int? totalElements,
      int? totalPages,
      int? page,
      int? size,
      List<String>? sort}) {
    return Page(
        totalElements: totalElements ?? this.totalElements,
        totalPages: totalPages ?? this.totalPages,
        page: page ?? this.page,
        size: size ?? this.size,
        sort: sort ?? this.sort);
  }

  Page copyWithWrapped(
      {Wrapped<int?>? totalElements,
      Wrapped<int?>? totalPages,
      Wrapped<int?>? page,
      Wrapped<int?>? size,
      Wrapped<List<String>?>? sort}) {
    return Page(
        totalElements:
            (totalElements != null ? totalElements.value : this.totalElements),
        totalPages: (totalPages != null ? totalPages.value : this.totalPages),
        page: (page != null ? page.value : this.page),
        size: (size != null ? size.value : this.size),
        sort: (sort != null ? sort.value : this.sort));
  }
}

@JsonSerializable(explicitToJson: true)
class Filter {
  Filter({
    this.specified,
  });

  factory Filter.fromJson(Map<String, dynamic> json) => _$FilterFromJson(json);

  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$FilterFromJson;
  static const toJsonFactory = _$FilterToJson;
  Map<String, dynamic> toJson() => _$FilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Filter &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(specified) ^ runtimeType.hashCode;
}

extension $FilterExtension on Filter {
  Filter copyWith({bool? specified}) {
    return Filter(specified: specified ?? this.specified);
  }

  Filter copyWithWrapped({Wrapped<bool?>? specified}) {
    return Filter(
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class StringFilter {
  StringFilter({
    this.contains,
    this.doesNotContain,
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory StringFilter.fromJson(Map<String, dynamic> json) =>
      _$StringFilterFromJson(json);

  @JsonKey(name: 'contains', includeIfNull: false, defaultValue: '')
  final String? contains;
  @JsonKey(name: 'doesNotContain', includeIfNull: false, defaultValue: '')
  final String? doesNotContain;
  @JsonKey(name: 'equals', includeIfNull: false, defaultValue: '')
  final String? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false, defaultValue: '')
  final String? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <String>[])
  final List<String>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <String>[])
  final List<String>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$StringFilterFromJson;
  static const toJsonFactory = _$StringFilterToJson;
  Map<String, dynamic> toJson() => _$StringFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is StringFilter &&
            (identical(other.contains, contains) ||
                const DeepCollectionEquality()
                    .equals(other.contains, contains)) &&
            (identical(other.doesNotContain, doesNotContain) ||
                const DeepCollectionEquality()
                    .equals(other.doesNotContain, doesNotContain)) &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(contains) ^
      const DeepCollectionEquality().hash(doesNotContain) ^
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $StringFilterExtension on StringFilter {
  StringFilter copyWith(
      {String? contains,
      String? doesNotContain,
      String? equals,
      String? notEquals,
      List<String>? $in,
      List<String>? notIn,
      bool? specified}) {
    return StringFilter(
        contains: contains ?? this.contains,
        doesNotContain: doesNotContain ?? this.doesNotContain,
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  StringFilter copyWithWrapped(
      {Wrapped<String?>? contains,
      Wrapped<String?>? doesNotContain,
      Wrapped<String?>? equals,
      Wrapped<String?>? notEquals,
      Wrapped<List<String>?>? $in,
      Wrapped<List<String>?>? notIn,
      Wrapped<bool?>? specified}) {
    return StringFilter(
        contains: (contains != null ? contains.value : this.contains),
        doesNotContain: (doesNotContain != null
            ? doesNotContain.value
            : this.doesNotContain),
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class LongFilter {
  LongFilter({
    this.greaterThan,
    this.lessThan,
    this.greaterThanOrEqual,
    this.lessThanOrEqual,
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory LongFilter.fromJson(Map<String, dynamic> json) =>
      _$LongFilterFromJson(json);

  @JsonKey(name: 'greaterThan', includeIfNull: false)
  final num? greaterThan;
  @JsonKey(name: 'lessThan', includeIfNull: false)
  final num? lessThan;
  @JsonKey(name: 'greaterThanOrEqual', includeIfNull: false)
  final num? greaterThanOrEqual;
  @JsonKey(name: 'lessThanOrEqual', includeIfNull: false)
  final num? lessThanOrEqual;
  @JsonKey(name: 'equals', includeIfNull: false)
  final num? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false)
  final num? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <num>[])
  final List<num>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <num>[])
  final List<num>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$LongFilterFromJson;
  static const toJsonFactory = _$LongFilterToJson;
  Map<String, dynamic> toJson() => _$LongFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LongFilter &&
            (identical(other.greaterThan, greaterThan) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThan, greaterThan)) &&
            (identical(other.lessThan, lessThan) ||
                const DeepCollectionEquality()
                    .equals(other.lessThan, lessThan)) &&
            (identical(other.greaterThanOrEqual, greaterThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThanOrEqual, greaterThanOrEqual)) &&
            (identical(other.lessThanOrEqual, lessThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.lessThanOrEqual, lessThanOrEqual)) &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(greaterThan) ^
      const DeepCollectionEquality().hash(lessThan) ^
      const DeepCollectionEquality().hash(greaterThanOrEqual) ^
      const DeepCollectionEquality().hash(lessThanOrEqual) ^
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $LongFilterExtension on LongFilter {
  LongFilter copyWith(
      {num? greaterThan,
      num? lessThan,
      num? greaterThanOrEqual,
      num? lessThanOrEqual,
      num? equals,
      num? notEquals,
      List<num>? $in,
      List<num>? notIn,
      bool? specified}) {
    return LongFilter(
        greaterThan: greaterThan ?? this.greaterThan,
        lessThan: lessThan ?? this.lessThan,
        greaterThanOrEqual: greaterThanOrEqual ?? this.greaterThanOrEqual,
        lessThanOrEqual: lessThanOrEqual ?? this.lessThanOrEqual,
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  LongFilter copyWithWrapped(
      {Wrapped<num?>? greaterThan,
      Wrapped<num?>? lessThan,
      Wrapped<num?>? greaterThanOrEqual,
      Wrapped<num?>? lessThanOrEqual,
      Wrapped<num?>? equals,
      Wrapped<num?>? notEquals,
      Wrapped<List<num>?>? $in,
      Wrapped<List<num>?>? notIn,
      Wrapped<bool?>? specified}) {
    return LongFilter(
        greaterThan:
            (greaterThan != null ? greaterThan.value : this.greaterThan),
        lessThan: (lessThan != null ? lessThan.value : this.lessThan),
        greaterThanOrEqual: (greaterThanOrEqual != null
            ? greaterThanOrEqual.value
            : this.greaterThanOrEqual),
        lessThanOrEqual: (lessThanOrEqual != null
            ? lessThanOrEqual.value
            : this.lessThanOrEqual),
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class IntegerFilter {
  IntegerFilter({
    this.greaterThan,
    this.lessThan,
    this.greaterThanOrEqual,
    this.lessThanOrEqual,
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory IntegerFilter.fromJson(Map<String, dynamic> json) =>
      _$IntegerFilterFromJson(json);

  @JsonKey(name: 'greaterThan', includeIfNull: false)
  final num? greaterThan;
  @JsonKey(name: 'lessThan', includeIfNull: false)
  final num? lessThan;
  @JsonKey(name: 'greaterThanOrEqual', includeIfNull: false)
  final num? greaterThanOrEqual;
  @JsonKey(name: 'lessThanOrEqual', includeIfNull: false)
  final num? lessThanOrEqual;
  @JsonKey(name: 'equals', includeIfNull: false)
  final num? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false)
  final num? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <num>[])
  final List<num>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <num>[])
  final List<num>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$IntegerFilterFromJson;
  static const toJsonFactory = _$IntegerFilterToJson;
  Map<String, dynamic> toJson() => _$IntegerFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IntegerFilter &&
            (identical(other.greaterThan, greaterThan) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThan, greaterThan)) &&
            (identical(other.lessThan, lessThan) ||
                const DeepCollectionEquality()
                    .equals(other.lessThan, lessThan)) &&
            (identical(other.greaterThanOrEqual, greaterThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThanOrEqual, greaterThanOrEqual)) &&
            (identical(other.lessThanOrEqual, lessThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.lessThanOrEqual, lessThanOrEqual)) &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(greaterThan) ^
      const DeepCollectionEquality().hash(lessThan) ^
      const DeepCollectionEquality().hash(greaterThanOrEqual) ^
      const DeepCollectionEquality().hash(lessThanOrEqual) ^
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $IntegerFilterExtension on IntegerFilter {
  IntegerFilter copyWith(
      {num? greaterThan,
      num? lessThan,
      num? greaterThanOrEqual,
      num? lessThanOrEqual,
      num? equals,
      num? notEquals,
      List<num>? $in,
      List<num>? notIn,
      bool? specified}) {
    return IntegerFilter(
        greaterThan: greaterThan ?? this.greaterThan,
        lessThan: lessThan ?? this.lessThan,
        greaterThanOrEqual: greaterThanOrEqual ?? this.greaterThanOrEqual,
        lessThanOrEqual: lessThanOrEqual ?? this.lessThanOrEqual,
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  IntegerFilter copyWithWrapped(
      {Wrapped<num?>? greaterThan,
      Wrapped<num?>? lessThan,
      Wrapped<num?>? greaterThanOrEqual,
      Wrapped<num?>? lessThanOrEqual,
      Wrapped<num?>? equals,
      Wrapped<num?>? notEquals,
      Wrapped<List<num>?>? $in,
      Wrapped<List<num>?>? notIn,
      Wrapped<bool?>? specified}) {
    return IntegerFilter(
        greaterThan:
            (greaterThan != null ? greaterThan.value : this.greaterThan),
        lessThan: (lessThan != null ? lessThan.value : this.lessThan),
        greaterThanOrEqual: (greaterThanOrEqual != null
            ? greaterThanOrEqual.value
            : this.greaterThanOrEqual),
        lessThanOrEqual: (lessThanOrEqual != null
            ? lessThanOrEqual.value
            : this.lessThanOrEqual),
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class BigDecimalFilter {
  BigDecimalFilter({
    this.greaterThan,
    this.lessThan,
    this.greaterThanOrEqual,
    this.lessThanOrEqual,
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory BigDecimalFilter.fromJson(Map<String, dynamic> json) =>
      _$BigDecimalFilterFromJson(json);

  @JsonKey(name: 'greaterThan', includeIfNull: false)
  final double? greaterThan;
  @JsonKey(name: 'lessThan', includeIfNull: false)
  final double? lessThan;
  @JsonKey(name: 'greaterThanOrEqual', includeIfNull: false)
  final double? greaterThanOrEqual;
  @JsonKey(name: 'lessThanOrEqual', includeIfNull: false)
  final double? lessThanOrEqual;
  @JsonKey(name: 'equals', includeIfNull: false)
  final double? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false)
  final double? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <double>[])
  final List<double>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <double>[])
  final List<double>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$BigDecimalFilterFromJson;
  static const toJsonFactory = _$BigDecimalFilterToJson;
  Map<String, dynamic> toJson() => _$BigDecimalFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BigDecimalFilter &&
            (identical(other.greaterThan, greaterThan) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThan, greaterThan)) &&
            (identical(other.lessThan, lessThan) ||
                const DeepCollectionEquality()
                    .equals(other.lessThan, lessThan)) &&
            (identical(other.greaterThanOrEqual, greaterThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThanOrEqual, greaterThanOrEqual)) &&
            (identical(other.lessThanOrEqual, lessThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.lessThanOrEqual, lessThanOrEqual)) &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(greaterThan) ^
      const DeepCollectionEquality().hash(lessThan) ^
      const DeepCollectionEquality().hash(greaterThanOrEqual) ^
      const DeepCollectionEquality().hash(lessThanOrEqual) ^
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $BigDecimalFilterExtension on BigDecimalFilter {
  BigDecimalFilter copyWith(
      {double? greaterThan,
      double? lessThan,
      double? greaterThanOrEqual,
      double? lessThanOrEqual,
      double? equals,
      double? notEquals,
      List<double>? $in,
      List<double>? notIn,
      bool? specified}) {
    return BigDecimalFilter(
        greaterThan: greaterThan ?? this.greaterThan,
        lessThan: lessThan ?? this.lessThan,
        greaterThanOrEqual: greaterThanOrEqual ?? this.greaterThanOrEqual,
        lessThanOrEqual: lessThanOrEqual ?? this.lessThanOrEqual,
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  BigDecimalFilter copyWithWrapped(
      {Wrapped<double?>? greaterThan,
      Wrapped<double?>? lessThan,
      Wrapped<double?>? greaterThanOrEqual,
      Wrapped<double?>? lessThanOrEqual,
      Wrapped<double?>? equals,
      Wrapped<double?>? notEquals,
      Wrapped<List<double>?>? $in,
      Wrapped<List<double>?>? notIn,
      Wrapped<bool?>? specified}) {
    return BigDecimalFilter(
        greaterThan:
            (greaterThan != null ? greaterThan.value : this.greaterThan),
        lessThan: (lessThan != null ? lessThan.value : this.lessThan),
        greaterThanOrEqual: (greaterThanOrEqual != null
            ? greaterThanOrEqual.value
            : this.greaterThanOrEqual),
        lessThanOrEqual: (lessThanOrEqual != null
            ? lessThanOrEqual.value
            : this.lessThanOrEqual),
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class BooleanFilter {
  BooleanFilter({
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory BooleanFilter.fromJson(Map<String, dynamic> json) =>
      _$BooleanFilterFromJson(json);

  @JsonKey(name: 'equals', includeIfNull: false)
  final bool? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false)
  final bool? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <bool>[])
  final List<bool>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <bool>[])
  final List<bool>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$BooleanFilterFromJson;
  static const toJsonFactory = _$BooleanFilterToJson;
  Map<String, dynamic> toJson() => _$BooleanFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BooleanFilter &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $BooleanFilterExtension on BooleanFilter {
  BooleanFilter copyWith(
      {bool? equals,
      bool? notEquals,
      List<bool>? $in,
      List<bool>? notIn,
      bool? specified}) {
    return BooleanFilter(
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  BooleanFilter copyWithWrapped(
      {Wrapped<bool?>? equals,
      Wrapped<bool?>? notEquals,
      Wrapped<List<bool>?>? $in,
      Wrapped<List<bool>?>? notIn,
      Wrapped<bool?>? specified}) {
    return BooleanFilter(
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class InstantFilter {
  InstantFilter({
    this.greaterThan,
    this.lessThan,
    this.greaterThanOrEqual,
    this.lessThanOrEqual,
    this.equals,
    this.notEquals,
    this.$in,
    this.notIn,
    this.specified,
  });

  factory InstantFilter.fromJson(Map<String, dynamic> json) =>
      _$InstantFilterFromJson(json);

  @JsonKey(name: 'greaterThan', includeIfNull: false)
  final DateTime? greaterThan;
  @JsonKey(name: 'lessThan', includeIfNull: false)
  final DateTime? lessThan;
  @JsonKey(name: 'greaterThanOrEqual', includeIfNull: false)
  final DateTime? greaterThanOrEqual;
  @JsonKey(name: 'lessThanOrEqual', includeIfNull: false)
  final DateTime? lessThanOrEqual;
  @JsonKey(name: 'equals', includeIfNull: false)
  final DateTime? equals;
  @JsonKey(name: 'notEquals', includeIfNull: false)
  final DateTime? notEquals;
  @JsonKey(name: 'in', includeIfNull: false, defaultValue: <DateTime>[])
  final List<DateTime>? $in;
  @JsonKey(name: 'notIn', includeIfNull: false, defaultValue: <DateTime>[])
  final List<DateTime>? notIn;
  @JsonKey(name: 'specified', includeIfNull: false)
  final bool? specified;
  static const fromJsonFactory = _$InstantFilterFromJson;
  static const toJsonFactory = _$InstantFilterToJson;
  Map<String, dynamic> toJson() => _$InstantFilterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InstantFilter &&
            (identical(other.greaterThan, greaterThan) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThan, greaterThan)) &&
            (identical(other.lessThan, lessThan) ||
                const DeepCollectionEquality()
                    .equals(other.lessThan, lessThan)) &&
            (identical(other.greaterThanOrEqual, greaterThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.greaterThanOrEqual, greaterThanOrEqual)) &&
            (identical(other.lessThanOrEqual, lessThanOrEqual) ||
                const DeepCollectionEquality()
                    .equals(other.lessThanOrEqual, lessThanOrEqual)) &&
            (identical(other.equals, equals) ||
                const DeepCollectionEquality().equals(other.equals, equals)) &&
            (identical(other.notEquals, notEquals) ||
                const DeepCollectionEquality()
                    .equals(other.notEquals, notEquals)) &&
            (identical(other.$in, $in) ||
                const DeepCollectionEquality().equals(other.$in, $in)) &&
            (identical(other.notIn, notIn) ||
                const DeepCollectionEquality().equals(other.notIn, notIn)) &&
            (identical(other.specified, specified) ||
                const DeepCollectionEquality()
                    .equals(other.specified, specified)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(greaterThan) ^
      const DeepCollectionEquality().hash(lessThan) ^
      const DeepCollectionEquality().hash(greaterThanOrEqual) ^
      const DeepCollectionEquality().hash(lessThanOrEqual) ^
      const DeepCollectionEquality().hash(equals) ^
      const DeepCollectionEquality().hash(notEquals) ^
      const DeepCollectionEquality().hash($in) ^
      const DeepCollectionEquality().hash(notIn) ^
      const DeepCollectionEquality().hash(specified) ^
      runtimeType.hashCode;
}

extension $InstantFilterExtension on InstantFilter {
  InstantFilter copyWith(
      {DateTime? greaterThan,
      DateTime? lessThan,
      DateTime? greaterThanOrEqual,
      DateTime? lessThanOrEqual,
      DateTime? equals,
      DateTime? notEquals,
      List<DateTime>? $in,
      List<DateTime>? notIn,
      bool? specified}) {
    return InstantFilter(
        greaterThan: greaterThan ?? this.greaterThan,
        lessThan: lessThan ?? this.lessThan,
        greaterThanOrEqual: greaterThanOrEqual ?? this.greaterThanOrEqual,
        lessThanOrEqual: lessThanOrEqual ?? this.lessThanOrEqual,
        equals: equals ?? this.equals,
        notEquals: notEquals ?? this.notEquals,
        $in: $in ?? this.$in,
        notIn: notIn ?? this.notIn,
        specified: specified ?? this.specified);
  }

  InstantFilter copyWithWrapped(
      {Wrapped<DateTime?>? greaterThan,
      Wrapped<DateTime?>? lessThan,
      Wrapped<DateTime?>? greaterThanOrEqual,
      Wrapped<DateTime?>? lessThanOrEqual,
      Wrapped<DateTime?>? equals,
      Wrapped<DateTime?>? notEquals,
      Wrapped<List<DateTime>?>? $in,
      Wrapped<List<DateTime>?>? notIn,
      Wrapped<bool?>? specified}) {
    return InstantFilter(
        greaterThan:
            (greaterThan != null ? greaterThan.value : this.greaterThan),
        lessThan: (lessThan != null ? lessThan.value : this.lessThan),
        greaterThanOrEqual: (greaterThanOrEqual != null
            ? greaterThanOrEqual.value
            : this.greaterThanOrEqual),
        lessThanOrEqual: (lessThanOrEqual != null
            ? lessThanOrEqual.value
            : this.lessThanOrEqual),
        equals: (equals != null ? equals.value : this.equals),
        notEquals: (notEquals != null ? notEquals.value : this.notEquals),
        $in: ($in != null ? $in.value : this.$in),
        notIn: (notIn != null ? notIn.value : this.notIn),
        specified: (specified != null ? specified.value : this.specified));
  }
}

@JsonSerializable(explicitToJson: true)
class MapBoolean {
  MapBoolean({
    this.$default,
  });

  factory MapBoolean.fromJson(Map<String, dynamic> json) =>
      _$MapBooleanFromJson(json);

  @JsonKey(name: 'default', includeIfNull: false)
  final bool? $default;
  static const fromJsonFactory = _$MapBooleanFromJson;
  static const toJsonFactory = _$MapBooleanToJson;
  Map<String, dynamic> toJson() => _$MapBooleanToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MapBoolean &&
            (identical(other.$default, $default) ||
                const DeepCollectionEquality()
                    .equals(other.$default, $default)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash($default) ^ runtimeType.hashCode;
}

extension $MapBooleanExtension on MapBoolean {
  MapBoolean copyWith({bool? $default}) {
    return MapBoolean($default: $default ?? this.$default);
  }

  MapBoolean copyWithWrapped({Wrapped<bool?>? $default}) {
    return MapBoolean(
        $default: ($default != null ? $default.value : this.$default));
  }
}

@JsonSerializable(explicitToJson: true)
class MapNumber {
  MapNumber({
    this.value,
  });

  factory MapNumber.fromJson(Map<String, dynamic> json) =>
      _$MapNumberFromJson(json);

  @JsonKey(name: 'value', includeIfNull: false)
  final int? value;
  static const fromJsonFactory = _$MapNumberFromJson;
  static const toJsonFactory = _$MapNumberToJson;
  Map<String, dynamic> toJson() => _$MapNumberToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is MapNumber &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^ runtimeType.hashCode;
}

extension $MapNumberExtension on MapNumber {
  MapNumber copyWith({int? value}) {
    return MapNumber(value: value ?? this.value);
  }

  MapNumber copyWithWrapped({Wrapped<int?>? value}) {
    return MapNumber(value: (value != null ? value.value : this.value));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionRequestBody {
  SubscriptionRequestBody({
    this.active,
    this.archived,
    this.cancelAtPeriodEnd,
    this.rating,
  });

  factory SubscriptionRequestBody.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionRequestBodyFromJson(json);

  @JsonKey(name: 'active', includeIfNull: false, defaultValue: false)
  final bool? active;
  @JsonKey(name: 'archived', includeIfNull: false, defaultValue: false)
  final bool? archived;
  @JsonKey(name: 'cancelAtPeriodEnd', includeIfNull: false)
  final bool? cancelAtPeriodEnd;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  static const fromJsonFactory = _$SubscriptionRequestBodyFromJson;
  static const toJsonFactory = _$SubscriptionRequestBodyToJson;
  Map<String, dynamic> toJson() => _$SubscriptionRequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionRequestBody &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.archived, archived) ||
                const DeepCollectionEquality()
                    .equals(other.archived, archived)) &&
            (identical(other.cancelAtPeriodEnd, cancelAtPeriodEnd) ||
                const DeepCollectionEquality()
                    .equals(other.cancelAtPeriodEnd, cancelAtPeriodEnd)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(archived) ^
      const DeepCollectionEquality().hash(cancelAtPeriodEnd) ^
      const DeepCollectionEquality().hash(rating) ^
      runtimeType.hashCode;
}

extension $SubscriptionRequestBodyExtension on SubscriptionRequestBody {
  SubscriptionRequestBody copyWith(
      {bool? active, bool? archived, bool? cancelAtPeriodEnd, double? rating}) {
    return SubscriptionRequestBody(
        active: active ?? this.active,
        archived: archived ?? this.archived,
        cancelAtPeriodEnd: cancelAtPeriodEnd ?? this.cancelAtPeriodEnd,
        rating: rating ?? this.rating);
  }

  SubscriptionRequestBody copyWithWrapped(
      {Wrapped<bool?>? active,
      Wrapped<bool?>? archived,
      Wrapped<bool?>? cancelAtPeriodEnd,
      Wrapped<double?>? rating}) {
    return SubscriptionRequestBody(
        active: (active != null ? active.value : this.active),
        archived: (archived != null ? archived.value : this.archived),
        cancelAtPeriodEnd: (cancelAtPeriodEnd != null
            ? cancelAtPeriodEnd.value
            : this.cancelAtPeriodEnd),
        rating: (rating != null ? rating.value : this.rating));
  }
}

@JsonSerializable(explicitToJson: true)
class SubscriptionCreateBody {
  SubscriptionCreateBody({
    this.userId,
    this.startDate,
    this.dueDate,
    this.priceOptionId,
    this.promotionId,
    this.quantity,
    this.paymentMethodId,
    this.skipFirstPeriod,
    this.prorationDisabled,
  });

  factory SubscriptionCreateBody.fromJson(Map<String, dynamic> json) =>
      _$SubscriptionCreateBodyFromJson(json);

  @JsonKey(name: 'userId', includeIfNull: false, defaultValue: '')
  final String? userId;
  @JsonKey(name: 'startDate', includeIfNull: false)
  final DateTime? startDate;
  @JsonKey(name: 'dueDate', includeIfNull: false)
  final DateTime? dueDate;
  @JsonKey(name: 'priceOptionId', includeIfNull: false)
  final num? priceOptionId;
  @JsonKey(name: 'promotionId', includeIfNull: false)
  final num? promotionId;
  @JsonKey(name: 'quantity', includeIfNull: false)
  final int? quantity;
  @JsonKey(name: 'paymentMethodId', includeIfNull: false, defaultValue: '')
  final String? paymentMethodId;
  @JsonKey(name: 'skipFirstPeriod', includeIfNull: false)
  final bool? skipFirstPeriod;
  @JsonKey(name: 'prorationDisabled', includeIfNull: false)
  final bool? prorationDisabled;
  static const fromJsonFactory = _$SubscriptionCreateBodyFromJson;
  static const toJsonFactory = _$SubscriptionCreateBodyToJson;
  Map<String, dynamic> toJson() => _$SubscriptionCreateBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SubscriptionCreateBody &&
            (identical(other.userId, userId) ||
                const DeepCollectionEquality().equals(other.userId, userId)) &&
            (identical(other.startDate, startDate) ||
                const DeepCollectionEquality()
                    .equals(other.startDate, startDate)) &&
            (identical(other.dueDate, dueDate) ||
                const DeepCollectionEquality()
                    .equals(other.dueDate, dueDate)) &&
            (identical(other.priceOptionId, priceOptionId) ||
                const DeepCollectionEquality()
                    .equals(other.priceOptionId, priceOptionId)) &&
            (identical(other.promotionId, promotionId) ||
                const DeepCollectionEquality()
                    .equals(other.promotionId, promotionId)) &&
            (identical(other.quantity, quantity) ||
                const DeepCollectionEquality()
                    .equals(other.quantity, quantity)) &&
            (identical(other.paymentMethodId, paymentMethodId) ||
                const DeepCollectionEquality()
                    .equals(other.paymentMethodId, paymentMethodId)) &&
            (identical(other.skipFirstPeriod, skipFirstPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.skipFirstPeriod, skipFirstPeriod)) &&
            (identical(other.prorationDisabled, prorationDisabled) ||
                const DeepCollectionEquality()
                    .equals(other.prorationDisabled, prorationDisabled)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(userId) ^
      const DeepCollectionEquality().hash(startDate) ^
      const DeepCollectionEquality().hash(dueDate) ^
      const DeepCollectionEquality().hash(priceOptionId) ^
      const DeepCollectionEquality().hash(promotionId) ^
      const DeepCollectionEquality().hash(quantity) ^
      const DeepCollectionEquality().hash(paymentMethodId) ^
      const DeepCollectionEquality().hash(skipFirstPeriod) ^
      const DeepCollectionEquality().hash(prorationDisabled) ^
      runtimeType.hashCode;
}

extension $SubscriptionCreateBodyExtension on SubscriptionCreateBody {
  SubscriptionCreateBody copyWith(
      {String? userId,
      DateTime? startDate,
      DateTime? dueDate,
      num? priceOptionId,
      num? promotionId,
      int? quantity,
      String? paymentMethodId,
      bool? skipFirstPeriod,
      bool? prorationDisabled}) {
    return SubscriptionCreateBody(
        userId: userId ?? this.userId,
        startDate: startDate ?? this.startDate,
        dueDate: dueDate ?? this.dueDate,
        priceOptionId: priceOptionId ?? this.priceOptionId,
        promotionId: promotionId ?? this.promotionId,
        quantity: quantity ?? this.quantity,
        paymentMethodId: paymentMethodId ?? this.paymentMethodId,
        skipFirstPeriod: skipFirstPeriod ?? this.skipFirstPeriod,
        prorationDisabled: prorationDisabled ?? this.prorationDisabled);
  }

  SubscriptionCreateBody copyWithWrapped(
      {Wrapped<String?>? userId,
      Wrapped<DateTime?>? startDate,
      Wrapped<DateTime?>? dueDate,
      Wrapped<num?>? priceOptionId,
      Wrapped<num?>? promotionId,
      Wrapped<int?>? quantity,
      Wrapped<String?>? paymentMethodId,
      Wrapped<bool?>? skipFirstPeriod,
      Wrapped<bool?>? prorationDisabled}) {
    return SubscriptionCreateBody(
        userId: (userId != null ? userId.value : this.userId),
        startDate: (startDate != null ? startDate.value : this.startDate),
        dueDate: (dueDate != null ? dueDate.value : this.dueDate),
        priceOptionId:
            (priceOptionId != null ? priceOptionId.value : this.priceOptionId),
        promotionId:
            (promotionId != null ? promotionId.value : this.promotionId),
        quantity: (quantity != null ? quantity.value : this.quantity),
        paymentMethodId: (paymentMethodId != null
            ? paymentMethodId.value
            : this.paymentMethodId),
        skipFirstPeriod: (skipFirstPeriod != null
            ? skipFirstPeriod.value
            : this.skipFirstPeriod),
        prorationDisabled: (prorationDisabled != null
            ? prorationDisabled.value
            : this.prorationDisabled));
  }
}

@JsonSerializable(explicitToJson: true)
class LocalizedOptionFeatureDocument {
  LocalizedOptionFeatureDocument({
    this.locale,
    this.description,
    this.shortDescription,
  });

  factory LocalizedOptionFeatureDocument.fromJson(Map<String, dynamic> json) =>
      _$LocalizedOptionFeatureDocumentFromJson(json);

  @JsonKey(name: 'locale', includeIfNull: false, defaultValue: '')
  final String? locale;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  static const fromJsonFactory = _$LocalizedOptionFeatureDocumentFromJson;
  static const toJsonFactory = _$LocalizedOptionFeatureDocumentToJson;
  Map<String, dynamic> toJson() => _$LocalizedOptionFeatureDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalizedOptionFeatureDocument &&
            (identical(other.locale, locale) ||
                const DeepCollectionEquality().equals(other.locale, locale)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(locale) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      runtimeType.hashCode;
}

extension $LocalizedOptionFeatureDocumentExtension
    on LocalizedOptionFeatureDocument {
  LocalizedOptionFeatureDocument copyWith(
      {String? locale, String? description, String? shortDescription}) {
    return LocalizedOptionFeatureDocument(
        locale: locale ?? this.locale,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription);
  }

  LocalizedOptionFeatureDocument copyWithWrapped(
      {Wrapped<String?>? locale,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription}) {
    return LocalizedOptionFeatureDocument(
        locale: (locale != null ? locale.value : this.locale),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription));
  }
}

typedef LocalizedOptionFeatureDocuments = List<LocalizedOptionFeatureDocument>;

@JsonSerializable(explicitToJson: true)
class LocalizedCategoryDocument {
  LocalizedCategoryDocument({
    this.locale,
    this.name,
    this.description,
    this.shortDescription,
  });

  factory LocalizedCategoryDocument.fromJson(Map<String, dynamic> json) =>
      _$LocalizedCategoryDocumentFromJson(json);

  @JsonKey(name: 'locale', includeIfNull: false, defaultValue: '')
  final String? locale;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  static const fromJsonFactory = _$LocalizedCategoryDocumentFromJson;
  static const toJsonFactory = _$LocalizedCategoryDocumentToJson;
  Map<String, dynamic> toJson() => _$LocalizedCategoryDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalizedCategoryDocument &&
            (identical(other.locale, locale) ||
                const DeepCollectionEquality().equals(other.locale, locale)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(locale) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      runtimeType.hashCode;
}

extension $LocalizedCategoryDocumentExtension on LocalizedCategoryDocument {
  LocalizedCategoryDocument copyWith(
      {String? locale,
      String? name,
      String? description,
      String? shortDescription}) {
    return LocalizedCategoryDocument(
        locale: locale ?? this.locale,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription);
  }

  LocalizedCategoryDocument copyWithWrapped(
      {Wrapped<String?>? locale,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription}) {
    return LocalizedCategoryDocument(
        locale: (locale != null ? locale.value : this.locale),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription));
  }
}

typedef LocalizedCategoryDocuments = List<LocalizedCategoryDocument>;

@JsonSerializable(explicitToJson: true)
class LocalizedPartnerDocument {
  LocalizedPartnerDocument({
    this.locale,
    this.name,
    this.description,
    this.shortDescription,
  });

  factory LocalizedPartnerDocument.fromJson(Map<String, dynamic> json) =>
      _$LocalizedPartnerDocumentFromJson(json);

  @JsonKey(name: 'locale', includeIfNull: false, defaultValue: '')
  final String? locale;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  static const fromJsonFactory = _$LocalizedPartnerDocumentFromJson;
  static const toJsonFactory = _$LocalizedPartnerDocumentToJson;
  Map<String, dynamic> toJson() => _$LocalizedPartnerDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalizedPartnerDocument &&
            (identical(other.locale, locale) ||
                const DeepCollectionEquality().equals(other.locale, locale)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(locale) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      runtimeType.hashCode;
}

extension $LocalizedPartnerDocumentExtension on LocalizedPartnerDocument {
  LocalizedPartnerDocument copyWith(
      {String? locale,
      String? name,
      String? description,
      String? shortDescription}) {
    return LocalizedPartnerDocument(
        locale: locale ?? this.locale,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription);
  }

  LocalizedPartnerDocument copyWithWrapped(
      {Wrapped<String?>? locale,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription}) {
    return LocalizedPartnerDocument(
        locale: (locale != null ? locale.value : this.locale),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription));
  }
}

typedef LocalizedPartnerDocuments = List<LocalizedPartnerDocument>;

@JsonSerializable(explicitToJson: true)
class LocalizedServiceOptionDocument {
  LocalizedServiceOptionDocument({
    this.locale,
    this.name,
    this.description,
    this.shortDescription,
  });

  factory LocalizedServiceOptionDocument.fromJson(Map<String, dynamic> json) =>
      _$LocalizedServiceOptionDocumentFromJson(json);

  @JsonKey(name: 'locale', includeIfNull: false, defaultValue: '')
  final String? locale;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  static const fromJsonFactory = _$LocalizedServiceOptionDocumentFromJson;
  static const toJsonFactory = _$LocalizedServiceOptionDocumentToJson;
  Map<String, dynamic> toJson() => _$LocalizedServiceOptionDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalizedServiceOptionDocument &&
            (identical(other.locale, locale) ||
                const DeepCollectionEquality().equals(other.locale, locale)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(locale) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      runtimeType.hashCode;
}

extension $LocalizedServiceOptionDocumentExtension
    on LocalizedServiceOptionDocument {
  LocalizedServiceOptionDocument copyWith(
      {String? locale,
      String? name,
      String? description,
      String? shortDescription}) {
    return LocalizedServiceOptionDocument(
        locale: locale ?? this.locale,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription);
  }

  LocalizedServiceOptionDocument copyWithWrapped(
      {Wrapped<String?>? locale,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription}) {
    return LocalizedServiceOptionDocument(
        locale: (locale != null ? locale.value : this.locale),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription));
  }
}

typedef LocalizedServiceOptionDocuments = List<LocalizedServiceOptionDocument>;

@JsonSerializable(explicitToJson: true)
class LocalizedSimplrServiceDocument {
  LocalizedSimplrServiceDocument({
    this.locale,
    this.name,
    this.description,
    this.shortDescription,
  });

  factory LocalizedSimplrServiceDocument.fromJson(Map<String, dynamic> json) =>
      _$LocalizedSimplrServiceDocumentFromJson(json);

  @JsonKey(name: 'locale', includeIfNull: false, defaultValue: '')
  final String? locale;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'shortDescription', includeIfNull: false, defaultValue: '')
  final String? shortDescription;
  static const fromJsonFactory = _$LocalizedSimplrServiceDocumentFromJson;
  static const toJsonFactory = _$LocalizedSimplrServiceDocumentToJson;
  Map<String, dynamic> toJson() => _$LocalizedSimplrServiceDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LocalizedSimplrServiceDocument &&
            (identical(other.locale, locale) ||
                const DeepCollectionEquality().equals(other.locale, locale)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.shortDescription, shortDescription) ||
                const DeepCollectionEquality()
                    .equals(other.shortDescription, shortDescription)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(locale) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(shortDescription) ^
      runtimeType.hashCode;
}

extension $LocalizedSimplrServiceDocumentExtension
    on LocalizedSimplrServiceDocument {
  LocalizedSimplrServiceDocument copyWith(
      {String? locale,
      String? name,
      String? description,
      String? shortDescription}) {
    return LocalizedSimplrServiceDocument(
        locale: locale ?? this.locale,
        name: name ?? this.name,
        description: description ?? this.description,
        shortDescription: shortDescription ?? this.shortDescription);
  }

  LocalizedSimplrServiceDocument copyWithWrapped(
      {Wrapped<String?>? locale,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? shortDescription}) {
    return LocalizedSimplrServiceDocument(
        locale: (locale != null ? locale.value : this.locale),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        shortDescription: (shortDescription != null
            ? shortDescription.value
            : this.shortDescription));
  }
}

typedef LocalizedSimplrServiceDocuments = List<LocalizedSimplrServiceDocument>;

@JsonSerializable(explicitToJson: true)
class OptionFeatureDocument {
  OptionFeatureDocument({
    this.id,
    this.localizations,
  });

  factory OptionFeatureDocument.fromJson(Map<String, dynamic> json) =>
      _$OptionFeatureDocumentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'localizations', includeIfNull: false)
  final Map<String, dynamic>? localizations;
  static const fromJsonFactory = _$OptionFeatureDocumentFromJson;
  static const toJsonFactory = _$OptionFeatureDocumentToJson;
  Map<String, dynamic> toJson() => _$OptionFeatureDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OptionFeatureDocument &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.localizations, localizations) ||
                const DeepCollectionEquality()
                    .equals(other.localizations, localizations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(localizations) ^
      runtimeType.hashCode;
}

extension $OptionFeatureDocumentExtension on OptionFeatureDocument {
  OptionFeatureDocument copyWith(
      {num? id, Map<String, dynamic>? localizations}) {
    return OptionFeatureDocument(
        id: id ?? this.id, localizations: localizations ?? this.localizations);
  }

  OptionFeatureDocument copyWithWrapped(
      {Wrapped<num?>? id, Wrapped<Map<String, dynamic>?>? localizations}) {
    return OptionFeatureDocument(
        id: (id != null ? id.value : this.id),
        localizations:
            (localizations != null ? localizations.value : this.localizations));
  }
}

typedef OptionFeatureDocuments = List<OptionFeatureDocument>;

@JsonSerializable(explicitToJson: true)
class CategoryDocument {
  CategoryDocument({
    this.id,
    this.parentId,
    this.enabled,
    this.imageUrl,
    this.localizations,
  });

  factory CategoryDocument.fromJson(Map<String, dynamic> json) =>
      _$CategoryDocumentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'parentId', includeIfNull: false)
  final num? parentId;
  @JsonKey(name: 'enabled', includeIfNull: false)
  final bool? enabled;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'localizations', includeIfNull: false)
  final Map<String, dynamic>? localizations;
  static const fromJsonFactory = _$CategoryDocumentFromJson;
  static const toJsonFactory = _$CategoryDocumentToJson;
  Map<String, dynamic> toJson() => _$CategoryDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CategoryDocument &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.parentId, parentId) ||
                const DeepCollectionEquality()
                    .equals(other.parentId, parentId)) &&
            (identical(other.enabled, enabled) ||
                const DeepCollectionEquality()
                    .equals(other.enabled, enabled)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.localizations, localizations) ||
                const DeepCollectionEquality()
                    .equals(other.localizations, localizations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(parentId) ^
      const DeepCollectionEquality().hash(enabled) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(localizations) ^
      runtimeType.hashCode;
}

extension $CategoryDocumentExtension on CategoryDocument {
  CategoryDocument copyWith(
      {num? id,
      num? parentId,
      bool? enabled,
      String? imageUrl,
      Map<String, dynamic>? localizations}) {
    return CategoryDocument(
        id: id ?? this.id,
        parentId: parentId ?? this.parentId,
        enabled: enabled ?? this.enabled,
        imageUrl: imageUrl ?? this.imageUrl,
        localizations: localizations ?? this.localizations);
  }

  CategoryDocument copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<num?>? parentId,
      Wrapped<bool?>? enabled,
      Wrapped<String?>? imageUrl,
      Wrapped<Map<String, dynamic>?>? localizations}) {
    return CategoryDocument(
        id: (id != null ? id.value : this.id),
        parentId: (parentId != null ? parentId.value : this.parentId),
        enabled: (enabled != null ? enabled.value : this.enabled),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        localizations:
            (localizations != null ? localizations.value : this.localizations));
  }
}

typedef CategoryDocuments = List<CategoryDocument>;

@JsonSerializable(explicitToJson: true)
class PartnerDocument {
  PartnerDocument({
    this.id,
    this.name,
    this.taxId,
    this.rating,
    this.partnerEmail,
    this.active,
    this.imageUrl,
    this.localizations,
  });

  factory PartnerDocument.fromJson(Map<String, dynamic> json) =>
      _$PartnerDocumentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'taxId', includeIfNull: false, defaultValue: '')
  final String? taxId;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  @JsonKey(name: 'partnerEmail', includeIfNull: false, defaultValue: '')
  final String? partnerEmail;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'localizations', includeIfNull: false)
  final Map<String, dynamic>? localizations;
  static const fromJsonFactory = _$PartnerDocumentFromJson;
  static const toJsonFactory = _$PartnerDocumentToJson;
  Map<String, dynamic> toJson() => _$PartnerDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PartnerDocument &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.taxId, taxId) ||
                const DeepCollectionEquality().equals(other.taxId, taxId)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.partnerEmail, partnerEmail) ||
                const DeepCollectionEquality()
                    .equals(other.partnerEmail, partnerEmail)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.localizations, localizations) ||
                const DeepCollectionEquality()
                    .equals(other.localizations, localizations)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(taxId) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(partnerEmail) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(localizations) ^
      runtimeType.hashCode;
}

extension $PartnerDocumentExtension on PartnerDocument {
  PartnerDocument copyWith(
      {num? id,
      String? name,
      String? taxId,
      double? rating,
      String? partnerEmail,
      bool? active,
      String? imageUrl,
      Map<String, dynamic>? localizations}) {
    return PartnerDocument(
        id: id ?? this.id,
        name: name ?? this.name,
        taxId: taxId ?? this.taxId,
        rating: rating ?? this.rating,
        partnerEmail: partnerEmail ?? this.partnerEmail,
        active: active ?? this.active,
        imageUrl: imageUrl ?? this.imageUrl,
        localizations: localizations ?? this.localizations);
  }

  PartnerDocument copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? taxId,
      Wrapped<double?>? rating,
      Wrapped<String?>? partnerEmail,
      Wrapped<bool?>? active,
      Wrapped<String?>? imageUrl,
      Wrapped<Map<String, dynamic>?>? localizations}) {
    return PartnerDocument(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        taxId: (taxId != null ? taxId.value : this.taxId),
        rating: (rating != null ? rating.value : this.rating),
        partnerEmail:
            (partnerEmail != null ? partnerEmail.value : this.partnerEmail),
        active: (active != null ? active.value : this.active),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        localizations:
            (localizations != null ? localizations.value : this.localizations));
  }
}

typedef PartnerDocuments = List<PartnerDocument>;

@JsonSerializable(explicitToJson: true)
class PartnerDocumentPage {
  PartnerDocumentPage({
    this.partners,
  });

  factory PartnerDocumentPage.fromJson(Map<String, dynamic> json) =>
      _$PartnerDocumentPageFromJson(json);

  @JsonKey(name: 'partners', includeIfNull: false)
  final List<PartnerDocument>? partners;
  static const fromJsonFactory = _$PartnerDocumentPageFromJson;
  static const toJsonFactory = _$PartnerDocumentPageToJson;
  Map<String, dynamic> toJson() => _$PartnerDocumentPageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PartnerDocumentPage &&
            (identical(other.partners, partners) ||
                const DeepCollectionEquality()
                    .equals(other.partners, partners)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(partners) ^ runtimeType.hashCode;
}

extension $PartnerDocumentPageExtension on PartnerDocumentPage {
  PartnerDocumentPage copyWith({List<PartnerDocument>? partners}) {
    return PartnerDocumentPage(partners: partners ?? this.partners);
  }

  PartnerDocumentPage copyWithWrapped(
      {Wrapped<List<PartnerDocument>?>? partners}) {
    return PartnerDocumentPage(
        partners: (partners != null ? partners.value : this.partners));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServiceOptionDocument {
  SimplrServiceOptionDocument({
    this.id,
    this.rating,
    this.active,
    this.imageUrl,
    this.localizations,
    this.features,
  });

  factory SimplrServiceOptionDocument.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceOptionDocumentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'localizations', includeIfNull: false)
  final Map<String, dynamic>? localizations;
  @JsonKey(name: 'features', includeIfNull: false)
  final List<OptionFeatureDocument>? features;
  static const fromJsonFactory = _$SimplrServiceOptionDocumentFromJson;
  static const toJsonFactory = _$SimplrServiceOptionDocumentToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceOptionDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceOptionDocument &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.localizations, localizations) ||
                const DeepCollectionEquality()
                    .equals(other.localizations, localizations)) &&
            (identical(other.features, features) ||
                const DeepCollectionEquality()
                    .equals(other.features, features)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(localizations) ^
      const DeepCollectionEquality().hash(features) ^
      runtimeType.hashCode;
}

extension $SimplrServiceOptionDocumentExtension on SimplrServiceOptionDocument {
  SimplrServiceOptionDocument copyWith(
      {num? id,
      double? rating,
      bool? active,
      String? imageUrl,
      Map<String, dynamic>? localizations,
      List<OptionFeatureDocument>? features}) {
    return SimplrServiceOptionDocument(
        id: id ?? this.id,
        rating: rating ?? this.rating,
        active: active ?? this.active,
        imageUrl: imageUrl ?? this.imageUrl,
        localizations: localizations ?? this.localizations,
        features: features ?? this.features);
  }

  SimplrServiceOptionDocument copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<double?>? rating,
      Wrapped<bool?>? active,
      Wrapped<String?>? imageUrl,
      Wrapped<Map<String, dynamic>?>? localizations,
      Wrapped<List<OptionFeatureDocument>?>? features}) {
    return SimplrServiceOptionDocument(
        id: (id != null ? id.value : this.id),
        rating: (rating != null ? rating.value : this.rating),
        active: (active != null ? active.value : this.active),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        localizations:
            (localizations != null ? localizations.value : this.localizations),
        features: (features != null ? features.value : this.features));
  }
}

typedef SimplrServiceOptionDocuments = List<SimplrServiceOptionDocument>;

@JsonSerializable(explicitToJson: true)
class SimplrServiceOptionDocumentPage {
  SimplrServiceOptionDocumentPage({
    this.serviceOptions,
  });

  factory SimplrServiceOptionDocumentPage.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceOptionDocumentPageFromJson(json);

  @JsonKey(name: 'serviceOptions', includeIfNull: false)
  final List<SimplrServiceOptionDocument>? serviceOptions;
  static const fromJsonFactory = _$SimplrServiceOptionDocumentPageFromJson;
  static const toJsonFactory = _$SimplrServiceOptionDocumentPageToJson;
  Map<String, dynamic> toJson() =>
      _$SimplrServiceOptionDocumentPageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceOptionDocumentPage &&
            (identical(other.serviceOptions, serviceOptions) ||
                const DeepCollectionEquality()
                    .equals(other.serviceOptions, serviceOptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(serviceOptions) ^
      runtimeType.hashCode;
}

extension $SimplrServiceOptionDocumentPageExtension
    on SimplrServiceOptionDocumentPage {
  SimplrServiceOptionDocumentPage copyWith(
      {List<SimplrServiceOptionDocument>? serviceOptions}) {
    return SimplrServiceOptionDocumentPage(
        serviceOptions: serviceOptions ?? this.serviceOptions);
  }

  SimplrServiceOptionDocumentPage copyWithWrapped(
      {Wrapped<List<SimplrServiceOptionDocument>?>? serviceOptions}) {
    return SimplrServiceOptionDocumentPage(
        serviceOptions: (serviceOptions != null
            ? serviceOptions.value
            : this.serviceOptions));
  }
}

@JsonSerializable(explicitToJson: true)
class SimplrServiceDocument {
  SimplrServiceDocument({
    this.id,
    this.rating,
    this.active,
    this.imageUrl,
    this.score,
    this.highlights,
    this.partner,
    this.localizations,
    this.categories,
    this.serviceOptions,
  });

  factory SimplrServiceDocument.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceDocumentFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'rating', includeIfNull: false)
  final double? rating;
  @JsonKey(name: 'active', includeIfNull: false)
  final bool? active;
  @JsonKey(name: 'imageUrl', includeIfNull: false, defaultValue: '')
  final String? imageUrl;
  @JsonKey(name: 'score', includeIfNull: false)
  final double? score;
  @JsonKey(name: 'highlights', includeIfNull: false)
  final Map<String, dynamic>? highlights;
  @JsonKey(name: 'partner', includeIfNull: false)
  final PartnerDocument? partner;
  @JsonKey(name: 'localizations', includeIfNull: false)
  final Map<String, dynamic>? localizations;
  @JsonKey(name: 'categories', includeIfNull: false)
  final List<CategoryDocument>? categories;
  @JsonKey(name: 'serviceOptions', includeIfNull: false)
  final List<SimplrServiceOptionDocument>? serviceOptions;
  static const fromJsonFactory = _$SimplrServiceDocumentFromJson;
  static const toJsonFactory = _$SimplrServiceDocumentToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceDocumentToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceDocument &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.rating, rating) ||
                const DeepCollectionEquality().equals(other.rating, rating)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)) &&
            (identical(other.imageUrl, imageUrl) ||
                const DeepCollectionEquality()
                    .equals(other.imageUrl, imageUrl)) &&
            (identical(other.score, score) ||
                const DeepCollectionEquality().equals(other.score, score)) &&
            (identical(other.highlights, highlights) ||
                const DeepCollectionEquality()
                    .equals(other.highlights, highlights)) &&
            (identical(other.partner, partner) ||
                const DeepCollectionEquality()
                    .equals(other.partner, partner)) &&
            (identical(other.localizations, localizations) ||
                const DeepCollectionEquality()
                    .equals(other.localizations, localizations)) &&
            (identical(other.categories, categories) ||
                const DeepCollectionEquality()
                    .equals(other.categories, categories)) &&
            (identical(other.serviceOptions, serviceOptions) ||
                const DeepCollectionEquality()
                    .equals(other.serviceOptions, serviceOptions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(rating) ^
      const DeepCollectionEquality().hash(active) ^
      const DeepCollectionEquality().hash(imageUrl) ^
      const DeepCollectionEquality().hash(score) ^
      const DeepCollectionEquality().hash(highlights) ^
      const DeepCollectionEquality().hash(partner) ^
      const DeepCollectionEquality().hash(localizations) ^
      const DeepCollectionEquality().hash(categories) ^
      const DeepCollectionEquality().hash(serviceOptions) ^
      runtimeType.hashCode;
}

extension $SimplrServiceDocumentExtension on SimplrServiceDocument {
  SimplrServiceDocument copyWith(
      {num? id,
      double? rating,
      bool? active,
      String? imageUrl,
      double? score,
      Map<String, dynamic>? highlights,
      PartnerDocument? partner,
      Map<String, dynamic>? localizations,
      List<CategoryDocument>? categories,
      List<SimplrServiceOptionDocument>? serviceOptions}) {
    return SimplrServiceDocument(
        id: id ?? this.id,
        rating: rating ?? this.rating,
        active: active ?? this.active,
        imageUrl: imageUrl ?? this.imageUrl,
        score: score ?? this.score,
        highlights: highlights ?? this.highlights,
        partner: partner ?? this.partner,
        localizations: localizations ?? this.localizations,
        categories: categories ?? this.categories,
        serviceOptions: serviceOptions ?? this.serviceOptions);
  }

  SimplrServiceDocument copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<double?>? rating,
      Wrapped<bool?>? active,
      Wrapped<String?>? imageUrl,
      Wrapped<double?>? score,
      Wrapped<Map<String, dynamic>?>? highlights,
      Wrapped<PartnerDocument?>? partner,
      Wrapped<Map<String, dynamic>?>? localizations,
      Wrapped<List<CategoryDocument>?>? categories,
      Wrapped<List<SimplrServiceOptionDocument>?>? serviceOptions}) {
    return SimplrServiceDocument(
        id: (id != null ? id.value : this.id),
        rating: (rating != null ? rating.value : this.rating),
        active: (active != null ? active.value : this.active),
        imageUrl: (imageUrl != null ? imageUrl.value : this.imageUrl),
        score: (score != null ? score.value : this.score),
        highlights: (highlights != null ? highlights.value : this.highlights),
        partner: (partner != null ? partner.value : this.partner),
        localizations:
            (localizations != null ? localizations.value : this.localizations),
        categories: (categories != null ? categories.value : this.categories),
        serviceOptions: (serviceOptions != null
            ? serviceOptions.value
            : this.serviceOptions));
  }
}

typedef SimplrServiceDocuments = List<SimplrServiceDocument>;

@JsonSerializable(explicitToJson: true)
class SimplrServiceDocumentPage {
  SimplrServiceDocumentPage({
    this.services,
  });

  factory SimplrServiceDocumentPage.fromJson(Map<String, dynamic> json) =>
      _$SimplrServiceDocumentPageFromJson(json);

  @JsonKey(name: 'services', includeIfNull: false)
  final List<SimplrServiceDocument>? services;
  static const fromJsonFactory = _$SimplrServiceDocumentPageFromJson;
  static const toJsonFactory = _$SimplrServiceDocumentPageToJson;
  Map<String, dynamic> toJson() => _$SimplrServiceDocumentPageToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SimplrServiceDocumentPage &&
            (identical(other.services, services) ||
                const DeepCollectionEquality()
                    .equals(other.services, services)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(services) ^ runtimeType.hashCode;
}

extension $SimplrServiceDocumentPageExtension on SimplrServiceDocumentPage {
  SimplrServiceDocumentPage copyWith({List<SimplrServiceDocument>? services}) {
    return SimplrServiceDocumentPage(services: services ?? this.services);
  }

  SimplrServiceDocumentPage copyWithWrapped(
      {Wrapped<List<SimplrServiceDocument>?>? services}) {
    return SimplrServiceDocumentPage(
        services: (services != null ? services.value : this.services));
  }
}

@JsonSerializable(explicitToJson: true)
class SearchInfo {
  SearchInfo({
    this.score,
    this.highlight,
    this.highlightIsDocumentNameField,
  });

  factory SearchInfo.fromJson(Map<String, dynamic> json) =>
      _$SearchInfoFromJson(json);

  @JsonKey(name: 'score', includeIfNull: false)
  final double? score;
  @JsonKey(name: 'highlight', includeIfNull: false, defaultValue: '')
  final String? highlight;
  @JsonKey(name: 'highlightIsDocumentNameField', includeIfNull: false)
  final bool? highlightIsDocumentNameField;
  static const fromJsonFactory = _$SearchInfoFromJson;
  static const toJsonFactory = _$SearchInfoToJson;
  Map<String, dynamic> toJson() => _$SearchInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SearchInfo &&
            (identical(other.score, score) ||
                const DeepCollectionEquality().equals(other.score, score)) &&
            (identical(other.highlight, highlight) ||
                const DeepCollectionEquality()
                    .equals(other.highlight, highlight)) &&
            (identical(other.highlightIsDocumentNameField,
                    highlightIsDocumentNameField) ||
                const DeepCollectionEquality().equals(
                    other.highlightIsDocumentNameField,
                    highlightIsDocumentNameField)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(score) ^
      const DeepCollectionEquality().hash(highlight) ^
      const DeepCollectionEquality().hash(highlightIsDocumentNameField) ^
      runtimeType.hashCode;
}

extension $SearchInfoExtension on SearchInfo {
  SearchInfo copyWith(
      {double? score, String? highlight, bool? highlightIsDocumentNameField}) {
    return SearchInfo(
        score: score ?? this.score,
        highlight: highlight ?? this.highlight,
        highlightIsDocumentNameField:
            highlightIsDocumentNameField ?? this.highlightIsDocumentNameField);
  }

  SearchInfo copyWithWrapped(
      {Wrapped<double?>? score,
      Wrapped<String?>? highlight,
      Wrapped<bool?>? highlightIsDocumentNameField}) {
    return SearchInfo(
        score: (score != null ? score.value : this.score),
        highlight: (highlight != null ? highlight.value : this.highlight),
        highlightIsDocumentNameField: (highlightIsDocumentNameField != null
            ? highlightIsDocumentNameField.value
            : this.highlightIsDocumentNameField));
  }
}

@JsonSerializable(explicitToJson: true)
class AliasIndices {
  AliasIndices({
    this.alias,
    this.indices,
  });

  factory AliasIndices.fromJson(Map<String, dynamic> json) =>
      _$AliasIndicesFromJson(json);

  @JsonKey(name: 'alias', includeIfNull: false, defaultValue: '')
  final String? alias;
  @JsonKey(name: 'indices', includeIfNull: false, defaultValue: <String>[])
  final List<String>? indices;
  static const fromJsonFactory = _$AliasIndicesFromJson;
  static const toJsonFactory = _$AliasIndicesToJson;
  Map<String, dynamic> toJson() => _$AliasIndicesToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AliasIndices &&
            (identical(other.alias, alias) ||
                const DeepCollectionEquality().equals(other.alias, alias)) &&
            (identical(other.indices, indices) ||
                const DeepCollectionEquality().equals(other.indices, indices)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(alias) ^
      const DeepCollectionEquality().hash(indices) ^
      runtimeType.hashCode;
}

extension $AliasIndicesExtension on AliasIndices {
  AliasIndices copyWith({String? alias, List<String>? indices}) {
    return AliasIndices(
        alias: alias ?? this.alias, indices: indices ?? this.indices);
  }

  AliasIndices copyWithWrapped(
      {Wrapped<String?>? alias, Wrapped<List<String>?>? indices}) {
    return AliasIndices(
        alias: (alias != null ? alias.value : this.alias),
        indices: (indices != null ? indices.value : this.indices));
  }
}

typedef AliasesIndices = List<AliasIndices>;

@JsonSerializable(explicitToJson: true)
class EventRegister {
  EventRegister({
    this.id,
    this.eventType,
    this.eventObjectType,
    this.objectId,
  });

  factory EventRegister.fromJson(Map<String, dynamic> json) =>
      _$EventRegisterFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(
    name: 'eventType',
    includeIfNull: false,
    toJson: eventRegisterEventTypeToJson,
    fromJson: eventRegisterEventTypeFromJson,
  )
  final enums.EventRegisterEventType? eventType;
  @JsonKey(
    name: 'eventObjectType',
    includeIfNull: false,
    toJson: eventRegisterEventObjectTypeToJson,
    fromJson: eventRegisterEventObjectTypeFromJson,
  )
  final enums.EventRegisterEventObjectType? eventObjectType;
  @JsonKey(name: 'objectId', includeIfNull: false)
  final num? objectId;
  static const fromJsonFactory = _$EventRegisterFromJson;
  static const toJsonFactory = _$EventRegisterToJson;
  Map<String, dynamic> toJson() => _$EventRegisterToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventRegister &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.eventType, eventType) ||
                const DeepCollectionEquality()
                    .equals(other.eventType, eventType)) &&
            (identical(other.eventObjectType, eventObjectType) ||
                const DeepCollectionEquality()
                    .equals(other.eventObjectType, eventObjectType)) &&
            (identical(other.objectId, objectId) ||
                const DeepCollectionEquality()
                    .equals(other.objectId, objectId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(eventType) ^
      const DeepCollectionEquality().hash(eventObjectType) ^
      const DeepCollectionEquality().hash(objectId) ^
      runtimeType.hashCode;
}

extension $EventRegisterExtension on EventRegister {
  EventRegister copyWith(
      {num? id,
      enums.EventRegisterEventType? eventType,
      enums.EventRegisterEventObjectType? eventObjectType,
      num? objectId}) {
    return EventRegister(
        id: id ?? this.id,
        eventType: eventType ?? this.eventType,
        eventObjectType: eventObjectType ?? this.eventObjectType,
        objectId: objectId ?? this.objectId);
  }

  EventRegister copyWithWrapped(
      {Wrapped<num?>? id,
      Wrapped<enums.EventRegisterEventType?>? eventType,
      Wrapped<enums.EventRegisterEventObjectType?>? eventObjectType,
      Wrapped<num?>? objectId}) {
    return EventRegister(
        id: (id != null ? id.value : this.id),
        eventType: (eventType != null ? eventType.value : this.eventType),
        eventObjectType: (eventObjectType != null
            ? eventObjectType.value
            : this.eventObjectType),
        objectId: (objectId != null ? objectId.value : this.objectId));
  }
}

typedef EventRegisters = List<EventRegister>;

@JsonSerializable(explicitToJson: true)
class Market {
  Market({
    this.id,
    this.name,
    this.active,
  });

  factory Market.fromJson(Map<String, dynamic> json) => _$MarketFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false)
  final num? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  static const fromJsonFactory = _$MarketFromJson;
  static const toJsonFactory = _$MarketToJson;
  Map<String, dynamic> toJson() => _$MarketToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Market &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(active) ^
      runtimeType.hashCode;
}

extension $MarketExtension on Market {
  Market copyWith({num? id, String? name, bool? active}) {
    return Market(
        id: id ?? this.id,
        name: name ?? this.name,
        active: active ?? this.active);
  }

  Market copyWithWrapped(
      {Wrapped<num?>? id, Wrapped<String?>? name, Wrapped<bool?>? active}) {
    return Market(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        active: (active != null ? active.value : this.active));
  }
}

typedef Markets = List<Market>;

@JsonSerializable(explicitToJson: true)
class Business {
  Business({
    this.name,
    this.code,
    this.active,
  });

  factory Business.fromJson(Map<String, dynamic> json) =>
      _$BusinessFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'code', includeIfNull: false)
  final num? code;
  @JsonKey(name: 'active', includeIfNull: false, defaultValue: true)
  final bool? active;
  static const fromJsonFactory = _$BusinessFromJson;
  static const toJsonFactory = _$BusinessToJson;
  Map<String, dynamic> toJson() => _$BusinessToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Business &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.active, active) ||
                const DeepCollectionEquality().equals(other.active, active)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(active) ^
      runtimeType.hashCode;
}

extension $BusinessExtension on Business {
  Business copyWith({String? name, num? code, bool? active}) {
    return Business(
        name: name ?? this.name,
        code: code ?? this.code,
        active: active ?? this.active);
  }

  Business copyWithWrapped(
      {Wrapped<String?>? name, Wrapped<num?>? code, Wrapped<bool?>? active}) {
    return Business(
        name: (name != null ? name.value : this.name),
        code: (code != null ? code.value : this.code),
        active: (active != null ? active.value : this.active));
  }
}

typedef Businesses = List<Business>;

@JsonSerializable(explicitToJson: true)
class PaymentMethod$Card {
  PaymentMethod$Card({
    this.last4,
    this.expiryMonth,
    this.expiryYear,
    this.brand,
  });

  factory PaymentMethod$Card.fromJson(Map<String, dynamic> json) =>
      _$PaymentMethod$CardFromJson(json);

  @JsonKey(name: 'last4', includeIfNull: false, defaultValue: '')
  final String? last4;
  @JsonKey(name: 'expiryMonth', includeIfNull: false, defaultValue: '')
  final String? expiryMonth;
  @JsonKey(name: 'expiryYear', includeIfNull: false, defaultValue: '')
  final String? expiryYear;
  @JsonKey(
    name: 'brand',
    includeIfNull: false,
    toJson: cardBrandToJson,
    fromJson: cardBrandFromJson,
  )
  final enums.CardBrand? brand;
  static const fromJsonFactory = _$PaymentMethod$CardFromJson;
  static const toJsonFactory = _$PaymentMethod$CardToJson;
  Map<String, dynamic> toJson() => _$PaymentMethod$CardToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PaymentMethod$Card &&
            (identical(other.last4, last4) ||
                const DeepCollectionEquality().equals(other.last4, last4)) &&
            (identical(other.expiryMonth, expiryMonth) ||
                const DeepCollectionEquality()
                    .equals(other.expiryMonth, expiryMonth)) &&
            (identical(other.expiryYear, expiryYear) ||
                const DeepCollectionEquality()
                    .equals(other.expiryYear, expiryYear)) &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(last4) ^
      const DeepCollectionEquality().hash(expiryMonth) ^
      const DeepCollectionEquality().hash(expiryYear) ^
      const DeepCollectionEquality().hash(brand) ^
      runtimeType.hashCode;
}

extension $PaymentMethod$CardExtension on PaymentMethod$Card {
  PaymentMethod$Card copyWith(
      {String? last4,
      String? expiryMonth,
      String? expiryYear,
      enums.CardBrand? brand}) {
    return PaymentMethod$Card(
        last4: last4 ?? this.last4,
        expiryMonth: expiryMonth ?? this.expiryMonth,
        expiryYear: expiryYear ?? this.expiryYear,
        brand: brand ?? this.brand);
  }

  PaymentMethod$Card copyWithWrapped(
      {Wrapped<String?>? last4,
      Wrapped<String?>? expiryMonth,
      Wrapped<String?>? expiryYear,
      Wrapped<enums.CardBrand?>? brand}) {
    return PaymentMethod$Card(
        last4: (last4 != null ? last4.value : this.last4),
        expiryMonth:
            (expiryMonth != null ? expiryMonth.value : this.expiryMonth),
        expiryYear: (expiryYear != null ? expiryYear.value : this.expiryYear),
        brand: (brand != null ? brand.value : this.brand));
  }
}

String? pricePeriodToJson(enums.PricePeriod? pricePeriod) {
  return enums.$PricePeriodMap[pricePeriod];
}

enums.PricePeriod pricePeriodFromJson(
  Object? pricePeriod, [
  enums.PricePeriod? defaultValue,
]) {
  if (pricePeriod is String) {
    return enums.$PricePeriodMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == pricePeriod.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PricePeriod.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PricePeriodMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PricePeriod.swaggerGeneratedUnknown;
}

List<String> pricePeriodListToJson(List<enums.PricePeriod>? pricePeriod) {
  if (pricePeriod == null) {
    return [];
  }

  return pricePeriod.map((e) => enums.$PricePeriodMap[e]!).toList();
}

List<enums.PricePeriod> pricePeriodListFromJson(
  List? pricePeriod, [
  List<enums.PricePeriod>? defaultValue,
]) {
  if (pricePeriod == null) {
    return defaultValue ?? [];
  }

  return pricePeriod.map((e) => pricePeriodFromJson(e.toString())).toList();
}

List<enums.PricePeriod>? pricePeriodNullableListFromJson(
  List? pricePeriod, [
  List<enums.PricePeriod>? defaultValue,
]) {
  if (pricePeriod == null) {
    return defaultValue;
  }

  return pricePeriod.map((e) => pricePeriodFromJson(e.toString())).toList();
}

String? usageTypeToJson(enums.UsageType? usageType) {
  return enums.$UsageTypeMap[usageType];
}

enums.UsageType usageTypeFromJson(
  Object? usageType, [
  enums.UsageType? defaultValue,
]) {
  if (usageType is String) {
    return enums.$UsageTypeMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == usageType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.UsageType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UsageTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UsageType.swaggerGeneratedUnknown;
}

List<String> usageTypeListToJson(List<enums.UsageType>? usageType) {
  if (usageType == null) {
    return [];
  }

  return usageType.map((e) => enums.$UsageTypeMap[e]!).toList();
}

List<enums.UsageType> usageTypeListFromJson(
  List? usageType, [
  List<enums.UsageType>? defaultValue,
]) {
  if (usageType == null) {
    return defaultValue ?? [];
  }

  return usageType.map((e) => usageTypeFromJson(e.toString())).toList();
}

List<enums.UsageType>? usageTypeNullableListFromJson(
  List? usageType, [
  List<enums.UsageType>? defaultValue,
]) {
  if (usageType == null) {
    return defaultValue;
  }

  return usageType.map((e) => usageTypeFromJson(e.toString())).toList();
}

String? serviceTypeGroupToJson(enums.ServiceTypeGroup? serviceTypeGroup) {
  return enums.$ServiceTypeGroupMap[serviceTypeGroup];
}

enums.ServiceTypeGroup serviceTypeGroupFromJson(
  Object? serviceTypeGroup, [
  enums.ServiceTypeGroup? defaultValue,
]) {
  if (serviceTypeGroup is String) {
    return enums.$ServiceTypeGroupMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == serviceTypeGroup.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ServiceTypeGroup.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ServiceTypeGroupMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ServiceTypeGroup.swaggerGeneratedUnknown;
}

List<String> serviceTypeGroupListToJson(
    List<enums.ServiceTypeGroup>? serviceTypeGroup) {
  if (serviceTypeGroup == null) {
    return [];
  }

  return serviceTypeGroup.map((e) => enums.$ServiceTypeGroupMap[e]!).toList();
}

List<enums.ServiceTypeGroup> serviceTypeGroupListFromJson(
  List? serviceTypeGroup, [
  List<enums.ServiceTypeGroup>? defaultValue,
]) {
  if (serviceTypeGroup == null) {
    return defaultValue ?? [];
  }

  return serviceTypeGroup
      .map((e) => serviceTypeGroupFromJson(e.toString()))
      .toList();
}

List<enums.ServiceTypeGroup>? serviceTypeGroupNullableListFromJson(
  List? serviceTypeGroup, [
  List<enums.ServiceTypeGroup>? defaultValue,
]) {
  if (serviceTypeGroup == null) {
    return defaultValue;
  }

  return serviceTypeGroup
      .map((e) => serviceTypeGroupFromJson(e.toString()))
      .toList();
}

String? serviceTypeStatusToJson(enums.ServiceTypeStatus? serviceTypeStatus) {
  return enums.$ServiceTypeStatusMap[serviceTypeStatus];
}

enums.ServiceTypeStatus serviceTypeStatusFromJson(
  Object? serviceTypeStatus, [
  enums.ServiceTypeStatus? defaultValue,
]) {
  if (serviceTypeStatus is String) {
    return enums.$ServiceTypeStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == serviceTypeStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ServiceTypeStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ServiceTypeStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ServiceTypeStatus.swaggerGeneratedUnknown;
}

List<String> serviceTypeStatusListToJson(
    List<enums.ServiceTypeStatus>? serviceTypeStatus) {
  if (serviceTypeStatus == null) {
    return [];
  }

  return serviceTypeStatus.map((e) => enums.$ServiceTypeStatusMap[e]!).toList();
}

List<enums.ServiceTypeStatus> serviceTypeStatusListFromJson(
  List? serviceTypeStatus, [
  List<enums.ServiceTypeStatus>? defaultValue,
]) {
  if (serviceTypeStatus == null) {
    return defaultValue ?? [];
  }

  return serviceTypeStatus
      .map((e) => serviceTypeStatusFromJson(e.toString()))
      .toList();
}

List<enums.ServiceTypeStatus>? serviceTypeStatusNullableListFromJson(
  List? serviceTypeStatus, [
  List<enums.ServiceTypeStatus>? defaultValue,
]) {
  if (serviceTypeStatus == null) {
    return defaultValue;
  }

  return serviceTypeStatus
      .map((e) => serviceTypeStatusFromJson(e.toString()))
      .toList();
}

String? jobsEmbedToJson(enums.JobsEmbed? jobsEmbed) {
  return enums.$JobsEmbedMap[jobsEmbed];
}

enums.JobsEmbed jobsEmbedFromJson(
  Object? jobsEmbed, [
  enums.JobsEmbed? defaultValue,
]) {
  if (jobsEmbed is String) {
    return enums.$JobsEmbedMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == jobsEmbed.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.JobsEmbed.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$JobsEmbedMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.JobsEmbed.swaggerGeneratedUnknown;
}

List<String> jobsEmbedListToJson(List<enums.JobsEmbed>? jobsEmbed) {
  if (jobsEmbed == null) {
    return [];
  }

  return jobsEmbed.map((e) => enums.$JobsEmbedMap[e]!).toList();
}

List<enums.JobsEmbed> jobsEmbedListFromJson(
  List? jobsEmbed, [
  List<enums.JobsEmbed>? defaultValue,
]) {
  if (jobsEmbed == null) {
    return defaultValue ?? [];
  }

  return jobsEmbed.map((e) => jobsEmbedFromJson(e.toString())).toList();
}

List<enums.JobsEmbed>? jobsEmbedNullableListFromJson(
  List? jobsEmbed, [
  List<enums.JobsEmbed>? defaultValue,
]) {
  if (jobsEmbed == null) {
    return defaultValue;
  }

  return jobsEmbed.map((e) => jobsEmbedFromJson(e.toString())).toList();
}

String? intentStatusToJson(enums.IntentStatus? intentStatus) {
  return enums.$IntentStatusMap[intentStatus];
}

enums.IntentStatus intentStatusFromJson(
  Object? intentStatus, [
  enums.IntentStatus? defaultValue,
]) {
  if (intentStatus is String) {
    return enums.$IntentStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == intentStatus.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.IntentStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$IntentStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.IntentStatus.swaggerGeneratedUnknown;
}

List<String> intentStatusListToJson(List<enums.IntentStatus>? intentStatus) {
  if (intentStatus == null) {
    return [];
  }

  return intentStatus.map((e) => enums.$IntentStatusMap[e]!).toList();
}

List<enums.IntentStatus> intentStatusListFromJson(
  List? intentStatus, [
  List<enums.IntentStatus>? defaultValue,
]) {
  if (intentStatus == null) {
    return defaultValue ?? [];
  }

  return intentStatus.map((e) => intentStatusFromJson(e.toString())).toList();
}

List<enums.IntentStatus>? intentStatusNullableListFromJson(
  List? intentStatus, [
  List<enums.IntentStatus>? defaultValue,
]) {
  if (intentStatus == null) {
    return defaultValue;
  }

  return intentStatus.map((e) => intentStatusFromJson(e.toString())).toList();
}

String? paymentMethodTypeToJson(enums.PaymentMethodType? paymentMethodType) {
  return enums.$PaymentMethodTypeMap[paymentMethodType];
}

enums.PaymentMethodType paymentMethodTypeFromJson(
  Object? paymentMethodType, [
  enums.PaymentMethodType? defaultValue,
]) {
  if (paymentMethodType is String) {
    return enums.$PaymentMethodTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == paymentMethodType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PaymentMethodType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PaymentMethodTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PaymentMethodType.swaggerGeneratedUnknown;
}

List<String> paymentMethodTypeListToJson(
    List<enums.PaymentMethodType>? paymentMethodType) {
  if (paymentMethodType == null) {
    return [];
  }

  return paymentMethodType.map((e) => enums.$PaymentMethodTypeMap[e]!).toList();
}

List<enums.PaymentMethodType> paymentMethodTypeListFromJson(
  List? paymentMethodType, [
  List<enums.PaymentMethodType>? defaultValue,
]) {
  if (paymentMethodType == null) {
    return defaultValue ?? [];
  }

  return paymentMethodType
      .map((e) => paymentMethodTypeFromJson(e.toString()))
      .toList();
}

List<enums.PaymentMethodType>? paymentMethodTypeNullableListFromJson(
  List? paymentMethodType, [
  List<enums.PaymentMethodType>? defaultValue,
]) {
  if (paymentMethodType == null) {
    return defaultValue;
  }

  return paymentMethodType
      .map((e) => paymentMethodTypeFromJson(e.toString()))
      .toList();
}

String? cardBrandToJson(enums.CardBrand? cardBrand) {
  return enums.$CardBrandMap[cardBrand];
}

enums.CardBrand cardBrandFromJson(
  Object? cardBrand, [
  enums.CardBrand? defaultValue,
]) {
  if (cardBrand is String) {
    return enums.$CardBrandMap.entries
        .firstWhere(
            (element) => element.value.toLowerCase() == cardBrand.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.CardBrand.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CardBrandMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CardBrand.swaggerGeneratedUnknown;
}

List<String> cardBrandListToJson(List<enums.CardBrand>? cardBrand) {
  if (cardBrand == null) {
    return [];
  }

  return cardBrand.map((e) => enums.$CardBrandMap[e]!).toList();
}

List<enums.CardBrand> cardBrandListFromJson(
  List? cardBrand, [
  List<enums.CardBrand>? defaultValue,
]) {
  if (cardBrand == null) {
    return defaultValue ?? [];
  }

  return cardBrand.map((e) => cardBrandFromJson(e.toString())).toList();
}

List<enums.CardBrand>? cardBrandNullableListFromJson(
  List? cardBrand, [
  List<enums.CardBrand>? defaultValue,
]) {
  if (cardBrand == null) {
    return defaultValue;
  }

  return cardBrand.map((e) => cardBrandFromJson(e.toString())).toList();
}

String? ordersEmbedToJson(enums.OrdersEmbed? ordersEmbed) {
  return enums.$OrdersEmbedMap[ordersEmbed];
}

enums.OrdersEmbed ordersEmbedFromJson(
  Object? ordersEmbed, [
  enums.OrdersEmbed? defaultValue,
]) {
  if (ordersEmbed is String) {
    return enums.$OrdersEmbedMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == ordersEmbed.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.OrdersEmbed.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$OrdersEmbedMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.OrdersEmbed.swaggerGeneratedUnknown;
}

List<String> ordersEmbedListToJson(List<enums.OrdersEmbed>? ordersEmbed) {
  if (ordersEmbed == null) {
    return [];
  }

  return ordersEmbed.map((e) => enums.$OrdersEmbedMap[e]!).toList();
}

List<enums.OrdersEmbed> ordersEmbedListFromJson(
  List? ordersEmbed, [
  List<enums.OrdersEmbed>? defaultValue,
]) {
  if (ordersEmbed == null) {
    return defaultValue ?? [];
  }

  return ordersEmbed.map((e) => ordersEmbedFromJson(e.toString())).toList();
}

List<enums.OrdersEmbed>? ordersEmbedNullableListFromJson(
  List? ordersEmbed, [
  List<enums.OrdersEmbed>? defaultValue,
]) {
  if (ordersEmbed == null) {
    return defaultValue;
  }

  return ordersEmbed.map((e) => ordersEmbedFromJson(e.toString())).toList();
}

String? orderStatusToJson(enums.OrderStatus? orderStatus) {
  return enums.$OrderStatusMap[orderStatus];
}

enums.OrderStatus orderStatusFromJson(
  Object? orderStatus, [
  enums.OrderStatus? defaultValue,
]) {
  if (orderStatus is String) {
    return enums.$OrderStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == orderStatus.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.OrderStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$OrderStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.OrderStatus.swaggerGeneratedUnknown;
}

List<String> orderStatusListToJson(List<enums.OrderStatus>? orderStatus) {
  if (orderStatus == null) {
    return [];
  }

  return orderStatus.map((e) => enums.$OrderStatusMap[e]!).toList();
}

List<enums.OrderStatus> orderStatusListFromJson(
  List? orderStatus, [
  List<enums.OrderStatus>? defaultValue,
]) {
  if (orderStatus == null) {
    return defaultValue ?? [];
  }

  return orderStatus.map((e) => orderStatusFromJson(e.toString())).toList();
}

List<enums.OrderStatus>? orderStatusNullableListFromJson(
  List? orderStatus, [
  List<enums.OrderStatus>? defaultValue,
]) {
  if (orderStatus == null) {
    return defaultValue;
  }

  return orderStatus.map((e) => orderStatusFromJson(e.toString())).toList();
}

String? subscriptionStatusToJson(enums.SubscriptionStatus? subscriptionStatus) {
  return enums.$SubscriptionStatusMap[subscriptionStatus];
}

enums.SubscriptionStatus subscriptionStatusFromJson(
  Object? subscriptionStatus, [
  enums.SubscriptionStatus? defaultValue,
]) {
  if (subscriptionStatus is String) {
    return enums.$SubscriptionStatusMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == subscriptionStatus.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SubscriptionStatus.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SubscriptionStatusMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SubscriptionStatus.swaggerGeneratedUnknown;
}

List<String> subscriptionStatusListToJson(
    List<enums.SubscriptionStatus>? subscriptionStatus) {
  if (subscriptionStatus == null) {
    return [];
  }

  return subscriptionStatus
      .map((e) => enums.$SubscriptionStatusMap[e]!)
      .toList();
}

List<enums.SubscriptionStatus> subscriptionStatusListFromJson(
  List? subscriptionStatus, [
  List<enums.SubscriptionStatus>? defaultValue,
]) {
  if (subscriptionStatus == null) {
    return defaultValue ?? [];
  }

  return subscriptionStatus
      .map((e) => subscriptionStatusFromJson(e.toString()))
      .toList();
}

List<enums.SubscriptionStatus>? subscriptionStatusNullableListFromJson(
  List? subscriptionStatus, [
  List<enums.SubscriptionStatus>? defaultValue,
]) {
  if (subscriptionStatus == null) {
    return defaultValue;
  }

  return subscriptionStatus
      .map((e) => subscriptionStatusFromJson(e.toString()))
      .toList();
}

String? addressTypeToJson(enums.AddressType? addressType) {
  return enums.$AddressTypeMap[addressType];
}

enums.AddressType addressTypeFromJson(
  Object? addressType, [
  enums.AddressType? defaultValue,
]) {
  if (addressType is String) {
    return enums.$AddressTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == addressType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.AddressType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$AddressTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.AddressType.swaggerGeneratedUnknown;
}

List<String> addressTypeListToJson(List<enums.AddressType>? addressType) {
  if (addressType == null) {
    return [];
  }

  return addressType.map((e) => enums.$AddressTypeMap[e]!).toList();
}

List<enums.AddressType> addressTypeListFromJson(
  List? addressType, [
  List<enums.AddressType>? defaultValue,
]) {
  if (addressType == null) {
    return defaultValue ?? [];
  }

  return addressType.map((e) => addressTypeFromJson(e.toString())).toList();
}

List<enums.AddressType>? addressTypeNullableListFromJson(
  List? addressType, [
  List<enums.AddressType>? defaultValue,
]) {
  if (addressType == null) {
    return defaultValue;
  }

  return addressType.map((e) => addressTypeFromJson(e.toString())).toList();
}

String? userPartnerDataKeyToJson(enums.UserPartnerDataKey? userPartnerDataKey) {
  return enums.$UserPartnerDataKeyMap[userPartnerDataKey];
}

enums.UserPartnerDataKey userPartnerDataKeyFromJson(
  Object? userPartnerDataKey, [
  enums.UserPartnerDataKey? defaultValue,
]) {
  if (userPartnerDataKey is String) {
    return enums.$UserPartnerDataKeyMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == userPartnerDataKey.toLowerCase(),
            orElse: () => const MapEntry(
                enums.UserPartnerDataKey.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserPartnerDataKeyMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserPartnerDataKey.swaggerGeneratedUnknown;
}

List<String> userPartnerDataKeyListToJson(
    List<enums.UserPartnerDataKey>? userPartnerDataKey) {
  if (userPartnerDataKey == null) {
    return [];
  }

  return userPartnerDataKey
      .map((e) => enums.$UserPartnerDataKeyMap[e]!)
      .toList();
}

List<enums.UserPartnerDataKey> userPartnerDataKeyListFromJson(
  List? userPartnerDataKey, [
  List<enums.UserPartnerDataKey>? defaultValue,
]) {
  if (userPartnerDataKey == null) {
    return defaultValue ?? [];
  }

  return userPartnerDataKey
      .map((e) => userPartnerDataKeyFromJson(e.toString()))
      .toList();
}

List<enums.UserPartnerDataKey>? userPartnerDataKeyNullableListFromJson(
  List? userPartnerDataKey, [
  List<enums.UserPartnerDataKey>? defaultValue,
]) {
  if (userPartnerDataKey == null) {
    return defaultValue;
  }

  return userPartnerDataKey
      .map((e) => userPartnerDataKeyFromJson(e.toString()))
      .toList();
}

String? propertyTypeToJson(enums.PropertyType? propertyType) {
  return enums.$PropertyTypeMap[propertyType];
}

enums.PropertyType propertyTypeFromJson(
  Object? propertyType, [
  enums.PropertyType? defaultValue,
]) {
  if (propertyType is String) {
    return enums.$PropertyTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == propertyType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PropertyType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PropertyTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PropertyType.swaggerGeneratedUnknown;
}

List<String> propertyTypeListToJson(List<enums.PropertyType>? propertyType) {
  if (propertyType == null) {
    return [];
  }

  return propertyType.map((e) => enums.$PropertyTypeMap[e]!).toList();
}

List<enums.PropertyType> propertyTypeListFromJson(
  List? propertyType, [
  List<enums.PropertyType>? defaultValue,
]) {
  if (propertyType == null) {
    return defaultValue ?? [];
  }

  return propertyType.map((e) => propertyTypeFromJson(e.toString())).toList();
}

List<enums.PropertyType>? propertyTypeNullableListFromJson(
  List? propertyType, [
  List<enums.PropertyType>? defaultValue,
]) {
  if (propertyType == null) {
    return defaultValue;
  }

  return propertyType.map((e) => propertyTypeFromJson(e.toString())).toList();
}

String? legalDocumentTypeToJson(enums.LegalDocumentType? legalDocumentType) {
  return enums.$LegalDocumentTypeMap[legalDocumentType];
}

enums.LegalDocumentType legalDocumentTypeFromJson(
  Object? legalDocumentType, [
  enums.LegalDocumentType? defaultValue,
]) {
  if (legalDocumentType is String) {
    return enums.$LegalDocumentTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == legalDocumentType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.LegalDocumentType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$LegalDocumentTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.LegalDocumentType.swaggerGeneratedUnknown;
}

List<String> legalDocumentTypeListToJson(
    List<enums.LegalDocumentType>? legalDocumentType) {
  if (legalDocumentType == null) {
    return [];
  }

  return legalDocumentType.map((e) => enums.$LegalDocumentTypeMap[e]!).toList();
}

List<enums.LegalDocumentType> legalDocumentTypeListFromJson(
  List? legalDocumentType, [
  List<enums.LegalDocumentType>? defaultValue,
]) {
  if (legalDocumentType == null) {
    return defaultValue ?? [];
  }

  return legalDocumentType
      .map((e) => legalDocumentTypeFromJson(e.toString()))
      .toList();
}

List<enums.LegalDocumentType>? legalDocumentTypeNullableListFromJson(
  List? legalDocumentType, [
  List<enums.LegalDocumentType>? defaultValue,
]) {
  if (legalDocumentType == null) {
    return defaultValue;
  }

  return legalDocumentType
      .map((e) => legalDocumentTypeFromJson(e.toString()))
      .toList();
}

String? userLegalContextToJson(enums.UserLegalContext? userLegalContext) {
  return enums.$UserLegalContextMap[userLegalContext];
}

enums.UserLegalContext userLegalContextFromJson(
  Object? userLegalContext, [
  enums.UserLegalContext? defaultValue,
]) {
  if (userLegalContext is String) {
    return enums.$UserLegalContextMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == userLegalContext.toLowerCase(),
            orElse: () => const MapEntry(
                enums.UserLegalContext.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$UserLegalContextMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.UserLegalContext.swaggerGeneratedUnknown;
}

List<String> userLegalContextListToJson(
    List<enums.UserLegalContext>? userLegalContext) {
  if (userLegalContext == null) {
    return [];
  }

  return userLegalContext.map((e) => enums.$UserLegalContextMap[e]!).toList();
}

List<enums.UserLegalContext> userLegalContextListFromJson(
  List? userLegalContext, [
  List<enums.UserLegalContext>? defaultValue,
]) {
  if (userLegalContext == null) {
    return defaultValue ?? [];
  }

  return userLegalContext
      .map((e) => userLegalContextFromJson(e.toString()))
      .toList();
}

List<enums.UserLegalContext>? userLegalContextNullableListFromJson(
  List? userLegalContext, [
  List<enums.UserLegalContext>? defaultValue,
]) {
  if (userLegalContext == null) {
    return defaultValue;
  }

  return userLegalContext
      .map((e) => userLegalContextFromJson(e.toString()))
      .toList();
}

String? promotionTypeToJson(enums.PromotionType? promotionType) {
  return enums.$PromotionTypeMap[promotionType];
}

enums.PromotionType promotionTypeFromJson(
  Object? promotionType, [
  enums.PromotionType? defaultValue,
]) {
  if (promotionType is String) {
    return enums.$PromotionTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == promotionType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PromotionType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PromotionTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PromotionType.swaggerGeneratedUnknown;
}

List<String> promotionTypeListToJson(List<enums.PromotionType>? promotionType) {
  if (promotionType == null) {
    return [];
  }

  return promotionType.map((e) => enums.$PromotionTypeMap[e]!).toList();
}

List<enums.PromotionType> promotionTypeListFromJson(
  List? promotionType, [
  List<enums.PromotionType>? defaultValue,
]) {
  if (promotionType == null) {
    return defaultValue ?? [];
  }

  return promotionType.map((e) => promotionTypeFromJson(e.toString())).toList();
}

List<enums.PromotionType>? promotionTypeNullableListFromJson(
  List? promotionType, [
  List<enums.PromotionType>? defaultValue,
]) {
  if (promotionType == null) {
    return defaultValue;
  }

  return promotionType.map((e) => promotionTypeFromJson(e.toString())).toList();
}

String? promotionNamespaceToJson(enums.PromotionNamespace? promotionNamespace) {
  return enums.$PromotionNamespaceMap[promotionNamespace];
}

enums.PromotionNamespace promotionNamespaceFromJson(
  Object? promotionNamespace, [
  enums.PromotionNamespace? defaultValue,
]) {
  if (promotionNamespace is String) {
    return enums.$PromotionNamespaceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == promotionNamespace.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PromotionNamespace.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PromotionNamespaceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PromotionNamespace.swaggerGeneratedUnknown;
}

List<String> promotionNamespaceListToJson(
    List<enums.PromotionNamespace>? promotionNamespace) {
  if (promotionNamespace == null) {
    return [];
  }

  return promotionNamespace
      .map((e) => enums.$PromotionNamespaceMap[e]!)
      .toList();
}

List<enums.PromotionNamespace> promotionNamespaceListFromJson(
  List? promotionNamespace, [
  List<enums.PromotionNamespace>? defaultValue,
]) {
  if (promotionNamespace == null) {
    return defaultValue ?? [];
  }

  return promotionNamespace
      .map((e) => promotionNamespaceFromJson(e.toString()))
      .toList();
}

List<enums.PromotionNamespace>? promotionNamespaceNullableListFromJson(
  List? promotionNamespace, [
  List<enums.PromotionNamespace>? defaultValue,
]) {
  if (promotionNamespace == null) {
    return defaultValue;
  }

  return promotionNamespace
      .map((e) => promotionNamespaceFromJson(e.toString()))
      .toList();
}

String? boundingAreaTypeEnumToJson(
    enums.BoundingAreaTypeEnum? boundingAreaTypeEnum) {
  return enums.$BoundingAreaTypeEnumMap[boundingAreaTypeEnum];
}

enums.BoundingAreaTypeEnum boundingAreaTypeEnumFromJson(
  Object? boundingAreaTypeEnum, [
  enums.BoundingAreaTypeEnum? defaultValue,
]) {
  if (boundingAreaTypeEnum is String) {
    return enums.$BoundingAreaTypeEnumMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                boundingAreaTypeEnum.toLowerCase(),
            orElse: () => const MapEntry(
                enums.BoundingAreaTypeEnum.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$BoundingAreaTypeEnumMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.BoundingAreaTypeEnum.swaggerGeneratedUnknown;
}

List<String> boundingAreaTypeEnumListToJson(
    List<enums.BoundingAreaTypeEnum>? boundingAreaTypeEnum) {
  if (boundingAreaTypeEnum == null) {
    return [];
  }

  return boundingAreaTypeEnum
      .map((e) => enums.$BoundingAreaTypeEnumMap[e]!)
      .toList();
}

List<enums.BoundingAreaTypeEnum> boundingAreaTypeEnumListFromJson(
  List? boundingAreaTypeEnum, [
  List<enums.BoundingAreaTypeEnum>? defaultValue,
]) {
  if (boundingAreaTypeEnum == null) {
    return defaultValue ?? [];
  }

  return boundingAreaTypeEnum
      .map((e) => boundingAreaTypeEnumFromJson(e.toString()))
      .toList();
}

List<enums.BoundingAreaTypeEnum>? boundingAreaTypeEnumNullableListFromJson(
  List? boundingAreaTypeEnum, [
  List<enums.BoundingAreaTypeEnum>? defaultValue,
]) {
  if (boundingAreaTypeEnum == null) {
    return defaultValue;
  }

  return boundingAreaTypeEnum
      .map((e) => boundingAreaTypeEnumFromJson(e.toString()))
      .toList();
}

String? taxTypeEnumToJson(enums.TaxTypeEnum? taxTypeEnum) {
  return enums.$TaxTypeEnumMap[taxTypeEnum];
}

enums.TaxTypeEnum taxTypeEnumFromJson(
  Object? taxTypeEnum, [
  enums.TaxTypeEnum? defaultValue,
]) {
  if (taxTypeEnum is String) {
    return enums.$TaxTypeEnumMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == taxTypeEnum.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.TaxTypeEnum.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$TaxTypeEnumMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.TaxTypeEnum.swaggerGeneratedUnknown;
}

List<String> taxTypeEnumListToJson(List<enums.TaxTypeEnum>? taxTypeEnum) {
  if (taxTypeEnum == null) {
    return [];
  }

  return taxTypeEnum.map((e) => enums.$TaxTypeEnumMap[e]!).toList();
}

List<enums.TaxTypeEnum> taxTypeEnumListFromJson(
  List? taxTypeEnum, [
  List<enums.TaxTypeEnum>? defaultValue,
]) {
  if (taxTypeEnum == null) {
    return defaultValue ?? [];
  }

  return taxTypeEnum.map((e) => taxTypeEnumFromJson(e.toString())).toList();
}

List<enums.TaxTypeEnum>? taxTypeEnumNullableListFromJson(
  List? taxTypeEnum, [
  List<enums.TaxTypeEnum>? defaultValue,
]) {
  if (taxTypeEnum == null) {
    return defaultValue;
  }

  return taxTypeEnum.map((e) => taxTypeEnumFromJson(e.toString())).toList();
}

String? stateCodeEnumToJson(enums.StateCodeEnum? stateCodeEnum) {
  return enums.$StateCodeEnumMap[stateCodeEnum];
}

enums.StateCodeEnum stateCodeEnumFromJson(
  Object? stateCodeEnum, [
  enums.StateCodeEnum? defaultValue,
]) {
  if (stateCodeEnum is String) {
    return enums.$StateCodeEnumMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == stateCodeEnum.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.StateCodeEnum.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$StateCodeEnumMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.StateCodeEnum.swaggerGeneratedUnknown;
}

List<String> stateCodeEnumListToJson(List<enums.StateCodeEnum>? stateCodeEnum) {
  if (stateCodeEnum == null) {
    return [];
  }

  return stateCodeEnum.map((e) => enums.$StateCodeEnumMap[e]!).toList();
}

List<enums.StateCodeEnum> stateCodeEnumListFromJson(
  List? stateCodeEnum, [
  List<enums.StateCodeEnum>? defaultValue,
]) {
  if (stateCodeEnum == null) {
    return defaultValue ?? [];
  }

  return stateCodeEnum.map((e) => stateCodeEnumFromJson(e.toString())).toList();
}

List<enums.StateCodeEnum>? stateCodeEnumNullableListFromJson(
  List? stateCodeEnum, [
  List<enums.StateCodeEnum>? defaultValue,
]) {
  if (stateCodeEnum == null) {
    return defaultValue;
  }

  return stateCodeEnum.map((e) => stateCodeEnumFromJson(e.toString())).toList();
}

String? countryCodeEnumToJson(enums.CountryCodeEnum? countryCodeEnum) {
  return enums.$CountryCodeEnumMap[countryCodeEnum];
}

enums.CountryCodeEnum countryCodeEnumFromJson(
  Object? countryCodeEnum, [
  enums.CountryCodeEnum? defaultValue,
]) {
  if (countryCodeEnum is String) {
    return enums.$CountryCodeEnumMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == countryCodeEnum.toLowerCase(),
            orElse: () => const MapEntry(
                enums.CountryCodeEnum.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$CountryCodeEnumMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.CountryCodeEnum.swaggerGeneratedUnknown;
}

List<String> countryCodeEnumListToJson(
    List<enums.CountryCodeEnum>? countryCodeEnum) {
  if (countryCodeEnum == null) {
    return [];
  }

  return countryCodeEnum.map((e) => enums.$CountryCodeEnumMap[e]!).toList();
}

List<enums.CountryCodeEnum> countryCodeEnumListFromJson(
  List? countryCodeEnum, [
  List<enums.CountryCodeEnum>? defaultValue,
]) {
  if (countryCodeEnum == null) {
    return defaultValue ?? [];
  }

  return countryCodeEnum
      .map((e) => countryCodeEnumFromJson(e.toString()))
      .toList();
}

List<enums.CountryCodeEnum>? countryCodeEnumNullableListFromJson(
  List? countryCodeEnum, [
  List<enums.CountryCodeEnum>? defaultValue,
]) {
  if (countryCodeEnum == null) {
    return defaultValue;
  }

  return countryCodeEnum
      .map((e) => countryCodeEnumFromJson(e.toString()))
      .toList();
}

String? deliveryTypeEnumToJson(enums.DeliveryTypeEnum? deliveryTypeEnum) {
  return enums.$DeliveryTypeEnumMap[deliveryTypeEnum];
}

enums.DeliveryTypeEnum deliveryTypeEnumFromJson(
  Object? deliveryTypeEnum, [
  enums.DeliveryTypeEnum? defaultValue,
]) {
  if (deliveryTypeEnum is String) {
    return enums.$DeliveryTypeEnumMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == deliveryTypeEnum.toLowerCase(),
            orElse: () => const MapEntry(
                enums.DeliveryTypeEnum.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$DeliveryTypeEnumMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.DeliveryTypeEnum.swaggerGeneratedUnknown;
}

List<String> deliveryTypeEnumListToJson(
    List<enums.DeliveryTypeEnum>? deliveryTypeEnum) {
  if (deliveryTypeEnum == null) {
    return [];
  }

  return deliveryTypeEnum.map((e) => enums.$DeliveryTypeEnumMap[e]!).toList();
}

List<enums.DeliveryTypeEnum> deliveryTypeEnumListFromJson(
  List? deliveryTypeEnum, [
  List<enums.DeliveryTypeEnum>? defaultValue,
]) {
  if (deliveryTypeEnum == null) {
    return defaultValue ?? [];
  }

  return deliveryTypeEnum
      .map((e) => deliveryTypeEnumFromJson(e.toString()))
      .toList();
}

List<enums.DeliveryTypeEnum>? deliveryTypeEnumNullableListFromJson(
  List? deliveryTypeEnum, [
  List<enums.DeliveryTypeEnum>? defaultValue,
]) {
  if (deliveryTypeEnum == null) {
    return defaultValue;
  }

  return deliveryTypeEnum
      .map((e) => deliveryTypeEnumFromJson(e.toString()))
      .toList();
}

String? simplrServiceExpandToJson(
    enums.SimplrServiceExpand? simplrServiceExpand) {
  return enums.$SimplrServiceExpandMap[simplrServiceExpand];
}

enums.SimplrServiceExpand simplrServiceExpandFromJson(
  Object? simplrServiceExpand, [
  enums.SimplrServiceExpand? defaultValue,
]) {
  if (simplrServiceExpand is String) {
    return enums.$SimplrServiceExpandMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                simplrServiceExpand.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SimplrServiceExpand.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SimplrServiceExpandMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SimplrServiceExpand.swaggerGeneratedUnknown;
}

List<String> simplrServiceExpandListToJson(
    List<enums.SimplrServiceExpand>? simplrServiceExpand) {
  if (simplrServiceExpand == null) {
    return [];
  }

  return simplrServiceExpand
      .map((e) => enums.$SimplrServiceExpandMap[e]!)
      .toList();
}

List<enums.SimplrServiceExpand> simplrServiceExpandListFromJson(
  List? simplrServiceExpand, [
  List<enums.SimplrServiceExpand>? defaultValue,
]) {
  if (simplrServiceExpand == null) {
    return defaultValue ?? [];
  }

  return simplrServiceExpand
      .map((e) => simplrServiceExpandFromJson(e.toString()))
      .toList();
}

List<enums.SimplrServiceExpand>? simplrServiceExpandNullableListFromJson(
  List? simplrServiceExpand, [
  List<enums.SimplrServiceExpand>? defaultValue,
]) {
  if (simplrServiceExpand == null) {
    return defaultValue;
  }

  return simplrServiceExpand
      .map((e) => simplrServiceExpandFromJson(e.toString()))
      .toList();
}

String? simplrServicePrioritisedFieldFieldToJson(
    enums.SimplrServicePrioritisedFieldField?
        simplrServicePrioritisedFieldField) {
  return enums.$SimplrServicePrioritisedFieldFieldMap[
      simplrServicePrioritisedFieldField];
}

enums.SimplrServicePrioritisedFieldField
    simplrServicePrioritisedFieldFieldFromJson(
  Object? simplrServicePrioritisedFieldField, [
  enums.SimplrServicePrioritisedFieldField? defaultValue,
]) {
  if (simplrServicePrioritisedFieldField is String) {
    return enums.$SimplrServicePrioritisedFieldFieldMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                simplrServicePrioritisedFieldField.toLowerCase(),
            orElse: () => const MapEntry(
                enums
                    .SimplrServicePrioritisedFieldField.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SimplrServicePrioritisedFieldFieldMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SimplrServicePrioritisedFieldField.swaggerGeneratedUnknown;
}

List<String> simplrServicePrioritisedFieldFieldListToJson(
    List<enums.SimplrServicePrioritisedFieldField>?
        simplrServicePrioritisedFieldField) {
  if (simplrServicePrioritisedFieldField == null) {
    return [];
  }

  return simplrServicePrioritisedFieldField
      .map((e) => enums.$SimplrServicePrioritisedFieldFieldMap[e]!)
      .toList();
}

List<enums.SimplrServicePrioritisedFieldField>
    simplrServicePrioritisedFieldFieldListFromJson(
  List? simplrServicePrioritisedFieldField, [
  List<enums.SimplrServicePrioritisedFieldField>? defaultValue,
]) {
  if (simplrServicePrioritisedFieldField == null) {
    return defaultValue ?? [];
  }

  return simplrServicePrioritisedFieldField
      .map((e) => simplrServicePrioritisedFieldFieldFromJson(e.toString()))
      .toList();
}

List<enums.SimplrServicePrioritisedFieldField>?
    simplrServicePrioritisedFieldFieldNullableListFromJson(
  List? simplrServicePrioritisedFieldField, [
  List<enums.SimplrServicePrioritisedFieldField>? defaultValue,
]) {
  if (simplrServicePrioritisedFieldField == null) {
    return defaultValue;
  }

  return simplrServicePrioritisedFieldField
      .map((e) => simplrServicePrioritisedFieldFieldFromJson(e.toString()))
      .toList();
}

String? aggregationFieldEnumToJson(
    enums.AggregationFieldEnum? aggregationFieldEnum) {
  return enums.$AggregationFieldEnumMap[aggregationFieldEnum];
}

enums.AggregationFieldEnum aggregationFieldEnumFromJson(
  Object? aggregationFieldEnum, [
  enums.AggregationFieldEnum? defaultValue,
]) {
  if (aggregationFieldEnum is String) {
    return enums.$AggregationFieldEnumMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                aggregationFieldEnum.toLowerCase(),
            orElse: () => const MapEntry(
                enums.AggregationFieldEnum.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$AggregationFieldEnumMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.AggregationFieldEnum.swaggerGeneratedUnknown;
}

List<String> aggregationFieldEnumListToJson(
    List<enums.AggregationFieldEnum>? aggregationFieldEnum) {
  if (aggregationFieldEnum == null) {
    return [];
  }

  return aggregationFieldEnum
      .map((e) => enums.$AggregationFieldEnumMap[e]!)
      .toList();
}

List<enums.AggregationFieldEnum> aggregationFieldEnumListFromJson(
  List? aggregationFieldEnum, [
  List<enums.AggregationFieldEnum>? defaultValue,
]) {
  if (aggregationFieldEnum == null) {
    return defaultValue ?? [];
  }

  return aggregationFieldEnum
      .map((e) => aggregationFieldEnumFromJson(e.toString()))
      .toList();
}

List<enums.AggregationFieldEnum>? aggregationFieldEnumNullableListFromJson(
  List? aggregationFieldEnum, [
  List<enums.AggregationFieldEnum>? defaultValue,
]) {
  if (aggregationFieldEnum == null) {
    return defaultValue;
  }

  return aggregationFieldEnum
      .map((e) => aggregationFieldEnumFromJson(e.toString()))
      .toList();
}

String? elasticsearchIndicesToJson(
    enums.ElasticsearchIndices? elasticsearchIndices) {
  return enums.$ElasticsearchIndicesMap[elasticsearchIndices];
}

enums.ElasticsearchIndices elasticsearchIndicesFromJson(
  Object? elasticsearchIndices, [
  enums.ElasticsearchIndices? defaultValue,
]) {
  if (elasticsearchIndices is String) {
    return enums.$ElasticsearchIndicesMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                elasticsearchIndices.toLowerCase(),
            orElse: () => const MapEntry(
                enums.ElasticsearchIndices.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$ElasticsearchIndicesMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.ElasticsearchIndices.swaggerGeneratedUnknown;
}

List<String> elasticsearchIndicesListToJson(
    List<enums.ElasticsearchIndices>? elasticsearchIndices) {
  if (elasticsearchIndices == null) {
    return [];
  }

  return elasticsearchIndices
      .map((e) => enums.$ElasticsearchIndicesMap[e]!)
      .toList();
}

List<enums.ElasticsearchIndices> elasticsearchIndicesListFromJson(
  List? elasticsearchIndices, [
  List<enums.ElasticsearchIndices>? defaultValue,
]) {
  if (elasticsearchIndices == null) {
    return defaultValue ?? [];
  }

  return elasticsearchIndices
      .map((e) => elasticsearchIndicesFromJson(e.toString()))
      .toList();
}

List<enums.ElasticsearchIndices>? elasticsearchIndicesNullableListFromJson(
  List? elasticsearchIndices, [
  List<enums.ElasticsearchIndices>? defaultValue,
]) {
  if (elasticsearchIndices == null) {
    return defaultValue;
  }

  return elasticsearchIndices
      .map((e) => elasticsearchIndicesFromJson(e.toString()))
      .toList();
}

String? eventRegisterEventTypeToJson(
    enums.EventRegisterEventType? eventRegisterEventType) {
  return enums.$EventRegisterEventTypeMap[eventRegisterEventType];
}

enums.EventRegisterEventType eventRegisterEventTypeFromJson(
  Object? eventRegisterEventType, [
  enums.EventRegisterEventType? defaultValue,
]) {
  if (eventRegisterEventType is String) {
    return enums.$EventRegisterEventTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                eventRegisterEventType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.EventRegisterEventType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EventRegisterEventTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EventRegisterEventType.swaggerGeneratedUnknown;
}

List<String> eventRegisterEventTypeListToJson(
    List<enums.EventRegisterEventType>? eventRegisterEventType) {
  if (eventRegisterEventType == null) {
    return [];
  }

  return eventRegisterEventType
      .map((e) => enums.$EventRegisterEventTypeMap[e]!)
      .toList();
}

List<enums.EventRegisterEventType> eventRegisterEventTypeListFromJson(
  List? eventRegisterEventType, [
  List<enums.EventRegisterEventType>? defaultValue,
]) {
  if (eventRegisterEventType == null) {
    return defaultValue ?? [];
  }

  return eventRegisterEventType
      .map((e) => eventRegisterEventTypeFromJson(e.toString()))
      .toList();
}

List<enums.EventRegisterEventType>? eventRegisterEventTypeNullableListFromJson(
  List? eventRegisterEventType, [
  List<enums.EventRegisterEventType>? defaultValue,
]) {
  if (eventRegisterEventType == null) {
    return defaultValue;
  }

  return eventRegisterEventType
      .map((e) => eventRegisterEventTypeFromJson(e.toString()))
      .toList();
}

String? eventRegisterEventObjectTypeToJson(
    enums.EventRegisterEventObjectType? eventRegisterEventObjectType) {
  return enums.$EventRegisterEventObjectTypeMap[eventRegisterEventObjectType];
}

enums.EventRegisterEventObjectType eventRegisterEventObjectTypeFromJson(
  Object? eventRegisterEventObjectType, [
  enums.EventRegisterEventObjectType? defaultValue,
]) {
  if (eventRegisterEventObjectType is String) {
    return enums.$EventRegisterEventObjectTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                eventRegisterEventObjectType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.EventRegisterEventObjectType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$EventRegisterEventObjectTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.EventRegisterEventObjectType.swaggerGeneratedUnknown;
}

List<String> eventRegisterEventObjectTypeListToJson(
    List<enums.EventRegisterEventObjectType>? eventRegisterEventObjectType) {
  if (eventRegisterEventObjectType == null) {
    return [];
  }

  return eventRegisterEventObjectType
      .map((e) => enums.$EventRegisterEventObjectTypeMap[e]!)
      .toList();
}

List<enums.EventRegisterEventObjectType>
    eventRegisterEventObjectTypeListFromJson(
  List? eventRegisterEventObjectType, [
  List<enums.EventRegisterEventObjectType>? defaultValue,
]) {
  if (eventRegisterEventObjectType == null) {
    return defaultValue ?? [];
  }

  return eventRegisterEventObjectType
      .map((e) => eventRegisterEventObjectTypeFromJson(e.toString()))
      .toList();
}

List<enums.EventRegisterEventObjectType>?
    eventRegisterEventObjectTypeNullableListFromJson(
  List? eventRegisterEventObjectType, [
  List<enums.EventRegisterEventObjectType>? defaultValue,
]) {
  if (eventRegisterEventObjectType == null) {
    return defaultValue;
  }

  return eventRegisterEventObjectType
      .map((e) => eventRegisterEventObjectTypeFromJson(e.toString()))
      .toList();
}

@JsonSerializable(explicitToJson: true)
class Problem {
  Problem({
    this.type,
    this.title,
    this.status,
    this.detail,
    this.instance,
  });

  factory Problem.fromJson(Map<String, dynamic> json) =>
      _$ProblemFromJson(json);

  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'title', includeIfNull: false, defaultValue: '')
  final String? title;
  @JsonKey(name: 'status', includeIfNull: false)
  final int? status;
  @JsonKey(name: 'detail', includeIfNull: false, defaultValue: '')
  final String? detail;
  @JsonKey(name: 'instance', includeIfNull: false, defaultValue: '')
  final String? instance;
  static const fromJsonFactory = _$ProblemFromJson;
  static const toJsonFactory = _$ProblemToJson;
  Map<String, dynamic> toJson() => _$ProblemToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Problem &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.title, title) ||
                const DeepCollectionEquality().equals(other.title, title)) &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.detail, detail) ||
                const DeepCollectionEquality().equals(other.detail, detail)) &&
            (identical(other.instance, instance) ||
                const DeepCollectionEquality()
                    .equals(other.instance, instance)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(title) ^
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(detail) ^
      const DeepCollectionEquality().hash(instance) ^
      runtimeType.hashCode;
}

extension $ProblemExtension on Problem {
  Problem copyWith(
      {String? type,
      String? title,
      int? status,
      String? detail,
      String? instance}) {
    return Problem(
        type: type ?? this.type,
        title: title ?? this.title,
        status: status ?? this.status,
        detail: detail ?? this.detail,
        instance: instance ?? this.instance);
  }

  Problem copyWithWrapped(
      {Wrapped<String?>? type,
      Wrapped<String?>? title,
      Wrapped<int?>? status,
      Wrapped<String?>? detail,
      Wrapped<String?>? instance}) {
    return Problem(
        type: (type != null ? type.value : this.type),
        title: (title != null ? title.value : this.title),
        status: (status != null ? status.value : this.status),
        detail: (detail != null ? detail.value : this.detail),
        instance: (instance != null ? instance.value : this.instance));
  }
}

class SubscriptionCreate {}

@JsonSerializable(explicitToJson: true)
class AccountFilesPost$RequestBody {
  AccountFilesPost$RequestBody({
    required this.id,
    required this.file,
  });

  factory AccountFilesPost$RequestBody.fromJson(Map<String, dynamic> json) =>
      _$AccountFilesPost$RequestBodyFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'file', includeIfNull: false, defaultValue: '')
  final String file;
  static const fromJsonFactory = _$AccountFilesPost$RequestBodyFromJson;
  static const toJsonFactory = _$AccountFilesPost$RequestBodyToJson;
  Map<String, dynamic> toJson() => _$AccountFilesPost$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AccountFilesPost$RequestBody &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.file, file) ||
                const DeepCollectionEquality().equals(other.file, file)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(file) ^
      runtimeType.hashCode;
}

extension $AccountFilesPost$RequestBodyExtension
    on AccountFilesPost$RequestBody {
  AccountFilesPost$RequestBody copyWith({String? id, String? file}) {
    return AccountFilesPost$RequestBody(
        id: id ?? this.id, file: file ?? this.file);
  }

  AccountFilesPost$RequestBody copyWithWrapped(
      {Wrapped<String>? id, Wrapped<String>? file}) {
    return AccountFilesPost$RequestBody(
        id: (id != null ? id.value : this.id),
        file: (file != null ? file.value : this.file));
  }
}

@JsonSerializable(explicitToJson: true)
class AccountFilesFileIdPut$RequestBody {
  AccountFilesFileIdPut$RequestBody({
    this.file,
  });

  factory AccountFilesFileIdPut$RequestBody.fromJson(
          Map<String, dynamic> json) =>
      _$AccountFilesFileIdPut$RequestBodyFromJson(json);

  @JsonKey(name: 'file', includeIfNull: false, defaultValue: '')
  final String? file;
  static const fromJsonFactory = _$AccountFilesFileIdPut$RequestBodyFromJson;
  static const toJsonFactory = _$AccountFilesFileIdPut$RequestBodyToJson;
  Map<String, dynamic> toJson() =>
      _$AccountFilesFileIdPut$RequestBodyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AccountFilesFileIdPut$RequestBody &&
            (identical(other.file, file) ||
                const DeepCollectionEquality().equals(other.file, file)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(file) ^ runtimeType.hashCode;
}

extension $AccountFilesFileIdPut$RequestBodyExtension
    on AccountFilesFileIdPut$RequestBody {
  AccountFilesFileIdPut$RequestBody copyWith({String? file}) {
    return AccountFilesFileIdPut$RequestBody(file: file ?? this.file);
  }

  AccountFilesFileIdPut$RequestBody copyWithWrapped({Wrapped<String?>? file}) {
    return AccountFilesFileIdPut$RequestBody(
        file: (file != null ? file.value : this.file));
  }
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
