// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'dart:async';
import 'package:chopper/chopper.dart' as chopper;
import 'swagger_from_issue.enums.swagger.dart' as enums;
export 'swagger_from_issue.enums.swagger.dart';

part 'swagger_from_issue.swagger.chopper.dart';
part 'swagger_from_issue.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class SwaggerFromIssue extends ChopperService {
  static SwaggerFromIssue create({
    ChopperClient? client,
    Authenticator? authenticator,
    String? baseUrl,
    Iterable<dynamic>? interceptors,
  }) {
    if (client != null) {
      return _$SwaggerFromIssue(client);
    }

    final newClient = ChopperClient(
        services: [_$SwaggerFromIssue()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://');
    return _$SwaggerFromIssue(newClient);
  }

  ///The token create path is used to create new tokens.
  Future<chopper.Response<TokenIssueResponse>> v1TokenIssuePost({
    String? cacheControl,
    required TokenIssueOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TokenIssueResponse, () => TokenIssueResponse.fromJsonFactory);

    return _v1TokenIssuePost(cacheControl: cacheControl, body: body);
  }

  ///The token create path is used to create new tokens.
  @Post(path: '/v1/token/issue')
  Future<chopper.Response<TokenIssueResponse>> _v1TokenIssuePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenIssueOptions? body,
  });

  ///This endpoint will lookup a token and its properties.
  Future<chopper.Response<TokenLookupSelfResponse>> v1TokenLookupSelfGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        TokenLookupSelfResponse, () => TokenLookupSelfResponse.fromJsonFactory);

    return _v1TokenLookupSelfGet(cacheControl: cacheControl);
  }

  ///This endpoint will lookup a token and its properties.
  @Get(path: '/v1/token/lookup-self')
  Future<chopper.Response<TokenLookupSelfResponse>> _v1TokenLookupSelfGet(
      {@Header('Cache-Control') String? cacheControl});

  ///This endpoint will lookup a token and its properties.
  Future<chopper.Response<TokenLookupResponse>> v1TokenLookupPost({
    String? cacheControl,
    required TokenLookupOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TokenLookupResponse, () => TokenLookupResponse.fromJsonFactory);

    return _v1TokenLookupPost(cacheControl: cacheControl, body: body);
  }

  ///This endpoint will lookup a token and its properties.
  @Post(path: '/v1/token/lookup')
  Future<chopper.Response<TokenLookupResponse>> _v1TokenLookupPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenLookupOptions? body,
  });

  ///This endpoint will renew the given token and prevent expiration.
  Future<chopper.Response<TokenRenewResponse>> v1TokenRenewPost({
    String? cacheControl,
    required TokenRenewOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TokenRenewResponse, () => TokenRenewResponse.fromJsonFactory);

    return _v1TokenRenewPost(cacheControl: cacheControl, body: body);
  }

  ///This endpoint will renew the given token and prevent expiration.
  @Post(path: '/v1/token/renew')
  Future<chopper.Response<TokenRenewResponse>> _v1TokenRenewPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenRenewOptions? body,
  });

  ///This endpoint will renew the token used to call it and prevent expiration.
  Future<chopper.Response<TokenRenewSelfResponse>> v1TokenRenewSelfPost({
    String? cacheControl,
    required TokenRenewSelfOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TokenRenewSelfResponse, () => TokenRenewSelfResponse.fromJsonFactory);

    return _v1TokenRenewSelfPost(cacheControl: cacheControl, body: body);
  }

  ///This endpoint will renew the token used to call it and prevent expiration.
  @Post(path: '/v1/token/renew-self')
  Future<chopper.Response<TokenRenewSelfResponse>> _v1TokenRenewSelfPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenRenewSelfOptions? body,
  });

  ///This endpoint will delete the given token and all of its child tokens.
  Future<chopper.Response<TokenRevokeResponse>> v1TokenRevokePost({
    String? cacheControl,
    required TokenRevokeOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TokenRevokeResponse, () => TokenRevokeResponse.fromJsonFactory);

    return _v1TokenRevokePost(cacheControl: cacheControl, body: body);
  }

  ///This endpoint will delete the given token and all of its child tokens.
  @Post(path: '/v1/token/revoke')
  Future<chopper.Response<TokenRevokeResponse>> _v1TokenRevokePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenRevokeOptions? body,
  });

  ///This endpoint will delete the token used to call it and all of its child tokens.
  Future<chopper.Response<TokenRevokeSelfResponse>> v1TokenRevokeSelfPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        TokenRevokeSelfResponse, () => TokenRevokeSelfResponse.fromJsonFactory);

    return _v1TokenRevokeSelfPost(cacheControl: cacheControl);
  }

  ///This endpoint will delete the token used to call it and all of its child tokens.
  @Post(
    path: '/v1/token/revoke-self',
    optionalBody: true,
  )
  Future<chopper.Response<TokenRevokeSelfResponse>> _v1TokenRevokeSelfPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Fetches the capabilities of the given token on the given path.
  Future<chopper.Response<List<TokenCapabilitiesResponse>>>
      v1TokenCapabilitiesPost({
    String? cacheControl,
    required TokenCapabilitiesOptions? body,
  }) {
    generatedMapping.putIfAbsent(TokenCapabilitiesResponse,
        () => TokenCapabilitiesResponse.fromJsonFactory);

    return _v1TokenCapabilitiesPost(cacheControl: cacheControl, body: body);
  }

  ///Fetches the capabilities of the given token on the given path.
  @Post(path: '/v1/token/capabilities')
  Future<chopper.Response<List<TokenCapabilitiesResponse>>>
      _v1TokenCapabilitiesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenCapabilitiesOptions? body,
  });

  ///Fetches the capabilities of the given token on the given path.
  Future<chopper.Response<List<TokenCapabilitiesSelfResponse>>>
      v1TokenCapabilitiesSelfPost({
    String? cacheControl,
    required TokenCapabilitiesSelfOptions? body,
  }) {
    generatedMapping.putIfAbsent(TokenCapabilitiesSelfResponse,
        () => TokenCapabilitiesSelfResponse.fromJsonFactory);

    return _v1TokenCapabilitiesSelfPost(cacheControl: cacheControl, body: body);
  }

  ///Fetches the capabilities of the given token on the given path.
  @Post(path: '/v1/token/capabilities-self')
  Future<chopper.Response<List<TokenCapabilitiesSelfResponse>>>
      _v1TokenCapabilitiesSelfPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenCapabilitiesSelfOptions? body,
  });

  ///Read the backend level settings.
  Future<chopper.Response<SecretsReadConfigResponse>> v1SecretsConfigGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(SecretsReadConfigResponse,
        () => SecretsReadConfigResponse.fromJsonFactory);

    return _v1SecretsConfigGet(cacheControl: cacheControl);
  }

  ///Read the backend level settings.
  @Get(path: '/v1/secrets/config')
  Future<chopper.Response<SecretsReadConfigResponse>> _v1SecretsConfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Configure backend level settings that are applied to every key in the key-value store.
  Future<chopper.Response<SecretsWriteConfigResponse>> v1SecretsConfigPost({
    String? cacheControl,
    required SecretsWriteConfigOptions? body,
  }) {
    generatedMapping.putIfAbsent(SecretsWriteConfigResponse,
        () => SecretsWriteConfigResponse.fromJsonFactory);

    return _v1SecretsConfigPost(cacheControl: cacheControl, body: body);
  }

  ///Configure backend level settings that are applied to every key in the key-value store.
  @Post(path: '/v1/secrets/config')
  Future<chopper.Response<SecretsWriteConfigResponse>> _v1SecretsConfigPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SecretsWriteConfigOptions? body,
  });

  ///Write, Read, and Delete data in the Key-Value Store.
  ///@param path
  ///@param version
  Future<chopper.Response<SecretsReadResponse>> v1SecretsDataGet({
    required String? path,
    num? version,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SecretsReadResponse, () => SecretsReadResponse.fromJsonFactory);

    return _v1SecretsDataGet(
        path: path, version: version, cacheControl: cacheControl);
  }

  ///Write, Read, and Delete data in the Key-Value Store.
  ///@param path
  ///@param version
  @Get(path: '/v1/secrets/data')
  Future<chopper.Response<SecretsReadResponse>> _v1SecretsDataGet({
    @Query('path') required String? path,
    @Query('version') num? version,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Write, Read, and Delete data in the Key-Value Store.
  Future<chopper.Response<SecretsWriteResponse>> v1SecretsDataPost({
    String? cacheControl,
    required SecretsWriteOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        SecretsWriteResponse, () => SecretsWriteResponse.fromJsonFactory);

    return _v1SecretsDataPost(cacheControl: cacheControl, body: body);
  }

  ///Write, Read, and Delete data in the Key-Value Store.
  @Post(path: '/v1/secrets/data')
  Future<chopper.Response<SecretsWriteResponse>> _v1SecretsDataPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SecretsWriteOptions? body,
  });

  ///Write, Read, and Delete data in the Key-Value Store.
  ///@param path
  Future<chopper.Response<SecretsDeleteResponse>> v1SecretsDataDelete({
    required String? path,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SecretsDeleteResponse, () => SecretsDeleteResponse.fromJsonFactory);

    return _v1SecretsDataDelete(path: path, cacheControl: cacheControl);
  }

  ///Write, Read, and Delete data in the Key-Value Store.
  ///@param path
  @Delete(path: '/v1/secrets/data')
  Future<chopper.Response<SecretsDeleteResponse>> _v1SecretsDataDelete({
    @Query('path') required String? path,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Marks one or more versions as deleted in the KV store.
  Future<chopper.Response<SecretsDeleteVersionsResponse>> v1SecretsDeletePost({
    String? cacheControl,
    required SecretsDeleteVersionsOptions? body,
  }) {
    generatedMapping.putIfAbsent(SecretsDeleteVersionsResponse,
        () => SecretsDeleteVersionsResponse.fromJsonFactory);

    return _v1SecretsDeletePost(cacheControl: cacheControl, body: body);
  }

  ///Marks one or more versions as deleted in the KV store.
  @Post(path: '/v1/secrets/delete')
  Future<chopper.Response<SecretsDeleteVersionsResponse>> _v1SecretsDeletePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SecretsDeleteVersionsOptions? body,
  });

  ///Permanently removes one or more versions in the KV store
  Future<chopper.Response<SecretsDestroyVersionsResponse>>
      v1SecretsDestroyPost({
    String? cacheControl,
    required SecretsDestroyVersionsOptions? body,
  }) {
    generatedMapping.putIfAbsent(SecretsDestroyVersionsResponse,
        () => SecretsDestroyVersionsResponse.fromJsonFactory);

    return _v1SecretsDestroyPost(cacheControl: cacheControl, body: body);
  }

  ///Permanently removes one or more versions in the KV store
  @Post(path: '/v1/secrets/destroy')
  Future<chopper.Response<SecretsDestroyVersionsResponse>>
      _v1SecretsDestroyPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SecretsDestroyVersionsOptions? body,
  });

  ///Configures settings for the KV store
  ///@param path
  Future<chopper.Response<SecretsListResponse>> v1SecretsMetadataGet({
    required String? path,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SecretsListResponse, () => SecretsListResponse.fromJsonFactory);

    return _v1SecretsMetadataGet(path: path, cacheControl: cacheControl);
  }

  ///Configures settings for the KV store
  ///@param path
  @Get(path: '/v1/secrets/metadata')
  Future<chopper.Response<SecretsListResponse>> _v1SecretsMetadataGet({
    @Query('path') required String? path,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Configures settings for the KV store
  Future<chopper.Response<SecretsConfigurePathResponse>> v1SecretsMetadataPost({
    String? cacheControl,
    required SecretsConfigurePathOptions? body,
  }) {
    generatedMapping.putIfAbsent(SecretsConfigurePathResponse,
        () => SecretsConfigurePathResponse.fromJsonFactory);

    return _v1SecretsMetadataPost(cacheControl: cacheControl, body: body);
  }

  ///Configures settings for the KV store
  @Post(path: '/v1/secrets/metadata')
  Future<chopper.Response<SecretsConfigurePathResponse>>
      _v1SecretsMetadataPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SecretsConfigurePathOptions? body,
  });

  ///Configures settings for the KV store
  ///@param path
  Future<chopper.Response<SecretsDestroyAllVersionsResponse>>
      v1SecretsMetadataDelete({
    required String? path,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(SecretsDestroyAllVersionsResponse,
        () => SecretsDestroyAllVersionsResponse.fromJsonFactory);

    return _v1SecretsMetadataDelete(path: path, cacheControl: cacheControl);
  }

  ///Configures settings for the KV store
  ///@param path
  @Delete(path: '/v1/secrets/metadata')
  Future<chopper.Response<SecretsDestroyAllVersionsResponse>>
      _v1SecretsMetadataDelete({
    @Query('path') required String? path,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Undeletes one or more versions from the KV store.
  Future<chopper.Response<SecretsUndeleteVersionsResponse>>
      v1SecretsUndeletePost({
    String? cacheControl,
    required SecretsUndeleteVersionsOptions? body,
  }) {
    generatedMapping.putIfAbsent(SecretsUndeleteVersionsResponse,
        () => SecretsUndeleteVersionsResponse.fromJsonFactory);

    return _v1SecretsUndeletePost(cacheControl: cacheControl, body: body);
  }

  ///Undeletes one or more versions from the KV store.
  @Post(path: '/v1/secrets/undelete')
  Future<chopper.Response<SecretsUndeleteVersionsResponse>>
      _v1SecretsUndeletePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SecretsUndeleteVersionsOptions? body,
  });

  ///Update entity
  ///@param id
  Future<chopper.Response<Identity>> v1IdentityIdentitiesIdPut({
    required String? id,
    String? cacheControl,
    required IdentityUpdateOptions? body,
  }) {
    generatedMapping.putIfAbsent(Identity, () => Identity.fromJsonFactory);

    return _v1IdentityIdentitiesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Update entity
  ///@param id
  @Put(path: '/v1/identity/identities/{id}')
  Future<chopper.Response<Identity>> _v1IdentityIdentitiesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required IdentityUpdateOptions? body,
  });

  ///fetch an entity
  ///@param id
  Future<chopper.Response<Identity>> v1IdentityIdentitiesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Identity, () => Identity.fromJsonFactory);

    return _v1IdentityIdentitiesIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an entity
  ///@param id
  @Get(path: '/v1/identity/identities/{id}')
  Future<chopper.Response<Identity>> _v1IdentityIdentitiesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete an entity and all related logins
  ///@param id
  Future<chopper.Response> v1IdentityIdentitiesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1IdentityIdentitiesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an entity and all related logins
  ///@param id
  @Delete(path: '/v1/identity/identities/{id}')
  Future<chopper.Response> _v1IdentityIdentitiesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create entity
  Future<chopper.Response<Identity>> v1IdentityIdentitiesPost({
    String? cacheControl,
    required IdentityCreateOptions? body,
  }) {
    generatedMapping.putIfAbsent(Identity, () => Identity.fromJsonFactory);

    return _v1IdentityIdentitiesPost(cacheControl: cacheControl, body: body);
  }

  ///Create entity
  @Post(path: '/v1/identity/identities')
  Future<chopper.Response<Identity>> _v1IdentityIdentitiesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required IdentityCreateOptions? body,
  });

  ///fetch all entities
  Future<chopper.Response<List<Identity>>> v1IdentityIdentitiesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(Identity, () => Identity.fromJsonFactory);

    return _v1IdentityIdentitiesGet(cacheControl: cacheControl);
  }

  ///fetch all entities
  @Get(path: '/v1/identity/identities')
  Future<chopper.Response<List<Identity>>> _v1IdentityIdentitiesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///login and retrieve authentication token
  Future<chopper.Response<LoginResponse>> v1LoginPost({
    String? cacheControl,
    required LoginOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        LoginResponse, () => LoginResponse.fromJsonFactory);

    return _v1LoginPost(cacheControl: cacheControl, body: body);
  }

  ///login and retrieve authentication token
  @Post(path: '/v1/login')
  Future<chopper.Response<LoginResponse>> _v1LoginPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required LoginOptions? body,
  });

  ///register for a totp qr code
  Future<chopper.Response<PostRegisterTotpResponse>> v1RegisterPost({
    String? cacheControl,
    required LoginOptions? body,
  }) {
    generatedMapping.putIfAbsent(PostRegisterTotpResponse,
        () => PostRegisterTotpResponse.fromJsonFactory);

    return _v1RegisterPost(cacheControl: cacheControl, body: body);
  }

  ///register for a totp qr code
  @Post(path: '/v1/register')
  Future<chopper.Response<PostRegisterTotpResponse>> _v1RegisterPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required LoginOptions? body,
  });

  ///exchange oauth for secureable token
  Future<chopper.Response<LoginResponse>> v1OidcexchangePost({
    String? cacheControl,
    required TokenExchange? body,
  }) {
    generatedMapping.putIfAbsent(
        LoginResponse, () => LoginResponse.fromJsonFactory);

    return _v1OidcexchangePost(cacheControl: cacheControl, body: body);
  }

  ///exchange oauth for secureable token
  @Post(path: '/v1/oidcexchange')
  Future<chopper.Response<LoginResponse>> _v1OidcexchangePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TokenExchange? body,
  });

  ///Merge two or more entities together
  Future<chopper.Response<Identity>> v1IdentityMergePost({
    String? cacheControl,
    required IdentityMergeOptions? body,
  }) {
    generatedMapping.putIfAbsent(Identity, () => Identity.fromJsonFactory);

    return _v1IdentityMergePost(cacheControl: cacheControl, body: body);
  }

  ///Merge two or more entities together
  @Post(path: '/v1/identity/merge')
  Future<chopper.Response<Identity>> _v1IdentityMergePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required IdentityMergeOptions? body,
  });

  ///Update tenant
  ///@param id
  Future<chopper.Response<TenantUpdateResponse>> v1TenantsIdPut({
    required String? id,
    String? cacheControl,
    required TenantCreateOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TenantUpdateResponse, () => TenantUpdateResponse.fromJsonFactory);

    return _v1TenantsIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Update tenant
  ///@param id
  @Put(path: '/v1/tenants/{id}')
  Future<chopper.Response<TenantUpdateResponse>> _v1TenantsIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required TenantCreateOptions? body,
  });

  ///fetch a tenant
  ///@param id
  Future<chopper.Response<Tenant>> v1TenantsIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Tenant, () => Tenant.fromJsonFactory);

    return _v1TenantsIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch a tenant
  ///@param id
  @Get(path: '/v1/tenants/{id}')
  Future<chopper.Response<Tenant>> _v1TenantsIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete an tenant and all related logins
  ///@param id
  Future<chopper.Response> v1TenantsIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1TenantsIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an tenant and all related logins
  ///@param id
  @Delete(path: '/v1/tenants/{id}')
  Future<chopper.Response> _v1TenantsIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create tenant
  Future<chopper.Response<TenantCreateResponse>> v1TenantsPost({
    String? cacheControl,
    required TenantCreateOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        TenantCreateResponse, () => TenantCreateResponse.fromJsonFactory);

    return _v1TenantsPost(cacheControl: cacheControl, body: body);
  }

  ///Create tenant
  @Post(path: '/v1/tenants')
  Future<chopper.Response<TenantCreateResponse>> _v1TenantsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required TenantCreateOptions? body,
  });

  ///fetch all tenants
  Future<chopper.Response<List<Tenant>>> v1TenantsGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Tenant, () => Tenant.fromJsonFactory);

    return _v1TenantsGet(cacheControl: cacheControl);
  }

  ///fetch all tenants
  @Get(path: '/v1/tenants')
  Future<chopper.Response<List<Tenant>>> _v1TenantsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Fetches the capabilities of the given token on the given path.
  Future<chopper.Response<List<AclCapabilitiesResponse>>>
      v1AclCapabilitiesPost({
    String? cacheControl,
    required AclCapabilitiesOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        AclCapabilitiesResponse, () => AclCapabilitiesResponse.fromJsonFactory);

    return _v1AclCapabilitiesPost(cacheControl: cacheControl, body: body);
  }

  ///Fetches the capabilities of the given token on the given path.
  @Post(path: '/v1/acl/capabilities')
  Future<chopper.Response<List<AclCapabilitiesResponse>>>
      _v1AclCapabilitiesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required AclCapabilitiesOptions? body,
  });

  ///CRUD operations for OIDC keys.
  ///@param name
  Future<chopper.Response> v1OidcKeysNameDelete({
    required String? name,
    String? cacheControl,
  }) {
    return _v1OidcKeysNameDelete(name: name, cacheControl: cacheControl);
  }

  ///CRUD operations for OIDC keys.
  ///@param name
  @Delete(path: '/v1/oidc/keys/{name}')
  Future<chopper.Response> _v1OidcKeysNameDelete({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///CRUD operations for OIDC keys.
  ///@param name
  Future<chopper.Response<OidcKey>> v1OidcKeysNameGet({
    required String? name,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(OidcKey, () => OidcKey.fromJsonFactory);

    return _v1OidcKeysNameGet(name: name, cacheControl: cacheControl);
  }

  ///CRUD operations for OIDC keys.
  ///@param name
  @Get(path: '/v1/oidc/keys/{name}')
  Future<chopper.Response<OidcKey>> _v1OidcKeysNameGet({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///CRUD operations for OIDC keys.
  ///@param name
  Future<chopper.Response<OidcKey>> v1OidcKeysNamePost({
    required String? name,
    String? cacheControl,
    required OidcKey? body,
  }) {
    generatedMapping.putIfAbsent(OidcKey, () => OidcKey.fromJsonFactory);

    return _v1OidcKeysNamePost(
        name: name, cacheControl: cacheControl, body: body);
  }

  ///CRUD operations for OIDC keys.
  ///@param name
  @Post(path: '/v1/oidc/keys/{name}')
  Future<chopper.Response<OidcKey>> _v1OidcKeysNamePost({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcKey? body,
  });

  ///CRUD operations on OIDC Roles
  ///@param name
  Future<chopper.Response> v1OidcRolesNameDelete({
    required String? name,
    String? cacheControl,
  }) {
    return _v1OidcRolesNameDelete(name: name, cacheControl: cacheControl);
  }

  ///CRUD operations on OIDC Roles
  ///@param name
  @Delete(path: '/v1/oidc/roles/{name}')
  Future<chopper.Response> _v1OidcRolesNameDelete({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///CRUD operations on OIDC Roles
  ///@param name
  Future<chopper.Response<OidcRole>> v1OidcRolesNameGet({
    required String? name,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(OidcRole, () => OidcRole.fromJsonFactory);

    return _v1OidcRolesNameGet(name: name, cacheControl: cacheControl);
  }

  ///CRUD operations on OIDC Roles
  ///@param name
  @Get(path: '/v1/oidc/roles/{name}')
  Future<chopper.Response<OidcRole>> _v1OidcRolesNameGet({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///CRUD operations on OIDC Roles
  ///@param name
  Future<chopper.Response<OidcRole>> v1OidcRolesNamePost({
    required String? name,
    String? cacheControl,
    required OidcRole? body,
  }) {
    generatedMapping.putIfAbsent(OidcRole, () => OidcRole.fromJsonFactory);

    return _v1OidcRolesNamePost(
        name: name, cacheControl: cacheControl, body: body);
  }

  ///CRUD operations on OIDC Roles
  ///@param name
  @Post(path: '/v1/oidc/roles/{name}')
  Future<chopper.Response<OidcRole>> _v1OidcRolesNamePost({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcRole? body,
  });

  ///OIDC configuration
  Future<chopper.Response<GetIdentityOidcConfigResponse>> v1OidcConfigGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(GetIdentityOidcConfigResponse,
        () => GetIdentityOidcConfigResponse.fromJsonFactory);

    return _v1OidcConfigGet(cacheControl: cacheControl);
  }

  ///OIDC configuration
  @Get(path: '/v1/oidc/config')
  Future<chopper.Response<GetIdentityOidcConfigResponse>> _v1OidcConfigGet(
      {@Header('Cache-Control') String? cacheControl});

  ///OIDC configuration
  Future<chopper.Response<PostIdentityOidcConfigResponse>> v1OidcConfigPost({
    String? cacheControl,
    required PostIdentityOidcConfig? body,
  }) {
    generatedMapping.putIfAbsent(PostIdentityOidcConfigResponse,
        () => PostIdentityOidcConfigResponse.fromJsonFactory);

    return _v1OidcConfigPost(cacheControl: cacheControl, body: body);
  }

  ///OIDC configuration
  @Post(path: '/v1/oidc/config')
  Future<chopper.Response<PostIdentityOidcConfigResponse>> _v1OidcConfigPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PostIdentityOidcConfig? body,
  });

  ///List OIDC keys
  Future<chopper.Response<List<OidcKey>>> v1OidcKeysGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(OidcKey, () => OidcKey.fromJsonFactory);

    return _v1OidcKeysGet(cacheControl: cacheControl);
  }

  ///List OIDC keys
  @Get(path: '/v1/oidc/keys')
  Future<chopper.Response<List<OidcKey>>> _v1OidcKeysGet(
      {@Header('Cache-Control') String? cacheControl});

  ///List configured OIDC roles
  Future<chopper.Response<List<OidcRole>>> v1OidcRolesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(OidcRole, () => OidcRole.fromJsonFactory);

    return _v1OidcRolesGet(cacheControl: cacheControl);
  }

  ///List configured OIDC roles
  @Get(path: '/v1/oidc/roles')
  Future<chopper.Response<List<OidcRole>>> _v1OidcRolesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Generate an OIDC token
  ///@param name
  Future<chopper.Response<OidcTokenName>> v1OidcTokenNameGet({
    required String? name,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        OidcTokenName, () => OidcTokenName.fromJsonFactory);

    return _v1OidcTokenNameGet(name: name, cacheControl: cacheControl);
  }

  ///Generate an OIDC token
  ///@param name
  @Get(path: '/v1/oidc/token/{name}')
  Future<chopper.Response<OidcTokenName>> _v1OidcTokenNameGet({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Verify the authenticity of an OIDC token
  Future<chopper.Response<PostIdentityOidcIntrospectResponse>>
      v1OidcIntrospectPost({
    String? cacheControl,
    required PostIdentityOidcIntrospect? body,
  }) {
    generatedMapping.putIfAbsent(PostIdentityOidcIntrospectResponse,
        () => PostIdentityOidcIntrospectResponse.fromJsonFactory);

    return _v1OidcIntrospectPost(cacheControl: cacheControl, body: body);
  }

  ///Verify the authenticity of an OIDC token
  @Post(path: '/v1/oidc/introspect')
  Future<chopper.Response<PostIdentityOidcIntrospectResponse>>
      _v1OidcIntrospectPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PostIdentityOidcIntrospect? body,
  });

  ///Rotate a named OIDC key.
  ///@param name
  Future<chopper.Response<PostIdentityOidcKeyNameRotateResponse>>
      v1OidcKeysNameRotatePost({
    required String? name,
    String? cacheControl,
    required PostIdentityOidcKeyNameRotate? body,
  }) {
    generatedMapping.putIfAbsent(PostIdentityOidcKeyNameRotateResponse,
        () => PostIdentityOidcKeyNameRotateResponse.fromJsonFactory);

    return _v1OidcKeysNameRotatePost(
        name: name, cacheControl: cacheControl, body: body);
  }

  ///Rotate a named OIDC key.
  ///@param name
  @Post(path: '/v1/oidc/keys/{name}/rotate')
  Future<chopper.Response<PostIdentityOidcKeyNameRotateResponse>>
      _v1OidcKeysNameRotatePost({
    @Path('name') required String? name,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PostIdentityOidcKeyNameRotate? body,
  });

  ///get template file
  ///@param role
  ///@param template
  Future<chopper.Response<String>> v1PasoeRoleTemplateGet({
    required String? role,
    required String? template,
    String? cacheControl,
  }) {
    return _v1PasoeRoleTemplateGet(
        role: role, template: template, cacheControl: cacheControl);
  }

  ///get template file
  ///@param role
  ///@param template
  @Get(path: '/v1/pasoe/{role}/{template}')
  Future<chopper.Response<String>> _v1PasoeRoleTemplateGet({
    @Path('role') required String? role,
    @Path('template') required String? template,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Retrieve public keys
  Future<chopper.Response<GetIdentityOidcWellKnownKeysResponse>>
      v1IdentityOidcWellKnownKeysGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(GetIdentityOidcWellKnownKeysResponse,
        () => GetIdentityOidcWellKnownKeysResponse.fromJsonFactory);

    return _v1IdentityOidcWellKnownKeysGet(cacheControl: cacheControl);
  }

  ///Retrieve public keys
  @Get(path: '/v1/identity/oidc/.well-known/keys')
  Future<chopper.Response<GetIdentityOidcWellKnownKeysResponse>>
      _v1IdentityOidcWellKnownKeysGet(
          {@Header('Cache-Control') String? cacheControl});

  ///Query OIDC configurations
  Future<chopper.Response<GetIdentityOidcWellKnownOpenidConfigurationResponse>>
      v1IdentityOidcWellKnownOpenidConfigurationGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(
        GetIdentityOidcWellKnownOpenidConfigurationResponse,
        () => GetIdentityOidcWellKnownOpenidConfigurationResponse
            .fromJsonFactory);

    return _v1IdentityOidcWellKnownOpenidConfigurationGet(
        cacheControl: cacheControl);
  }

  ///Query OIDC configurations
  @Get(path: '/v1/identity/oidc/.well-known/openid-configuration')
  Future<chopper.Response<GetIdentityOidcWellKnownOpenidConfigurationResponse>>
      _v1IdentityOidcWellKnownOpenidConfigurationGet(
          {@Header('Cache-Control') String? cacheControl});

  ///delete OIDC role templates.
  ///@param id
  Future<chopper.Response> v1OidcTemplatesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1OidcTemplatesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete OIDC role templates.
  ///@param id
  @Delete(path: '/v1/oidc/templates/{id}')
  Future<chopper.Response> _v1OidcTemplatesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///CRUD operations for OIDC keys.
  ///@param id
  Future<chopper.Response<OidcRoleTemplate>> v1OidcTemplatesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        OidcRoleTemplate, () => OidcRoleTemplate.fromJsonFactory);

    return _v1OidcTemplatesIdGet(id: id, cacheControl: cacheControl);
  }

  ///CRUD operations for OIDC keys.
  ///@param id
  @Get(path: '/v1/oidc/templates/{id}')
  Future<chopper.Response<OidcRoleTemplate>> _v1OidcTemplatesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Rotate a named OIDC key.
  ///@param id
  Future<chopper.Response<OidcRoleTemplate>> v1OidcTemplatesIdPut({
    required String? id,
    String? cacheControl,
    required OidcRoleTemplate? body,
  }) {
    generatedMapping.putIfAbsent(
        OidcRoleTemplate, () => OidcRoleTemplate.fromJsonFactory);

    return _v1OidcTemplatesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Rotate a named OIDC key.
  ///@param id
  @Put(path: '/v1/oidc/templates/{id}')
  Future<chopper.Response<OidcRoleTemplate>> _v1OidcTemplatesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcRoleTemplate? body,
  });

  ///List OIDC role templates
  Future<chopper.Response<List<OidcRoleTemplate>>> v1OidcTemplatesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        OidcRoleTemplate, () => OidcRoleTemplate.fromJsonFactory);

    return _v1OidcTemplatesGet(cacheControl: cacheControl);
  }

  ///List OIDC role templates
  @Get(path: '/v1/oidc/templates')
  Future<chopper.Response<List<OidcRoleTemplate>>> _v1OidcTemplatesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///create OIDC role template
  Future<chopper.Response<OidcRoleTemplate>> v1OidcTemplatesPost({
    String? cacheControl,
    required OidcRoleTemplate? body,
  }) {
    generatedMapping.putIfAbsent(
        OidcRoleTemplate, () => OidcRoleTemplate.fromJsonFactory);

    return _v1OidcTemplatesPost(cacheControl: cacheControl, body: body);
  }

  ///create OIDC role template
  @Post(path: '/v1/oidc/templates')
  Future<chopper.Response<OidcRoleTemplate>> _v1OidcTemplatesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcRoleTemplate? body,
  });

  ///fetch id and name of authenticationServices
  Future<chopper.Response<List<ProviderInfo>>> v1AuthServicesInfoGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ProviderInfo, () => ProviderInfo.fromJsonFactory);

    return _v1AuthServicesInfoGet(cacheControl: cacheControl);
  }

  ///fetch id and name of authenticationServices
  @Get(path: '/v1/auth/services/info')
  Future<chopper.Response<List<ProviderInfo>>> _v1AuthServicesInfoGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Update policy
  ///@param id
  Future<chopper.Response<Policy>> v1PoliciesIdPut({
    required String? id,
    String? cacheControl,
    required PolicyUpdateOptions? body,
  }) {
    generatedMapping.putIfAbsent(Policy, () => Policy.fromJsonFactory);

    return _v1PoliciesIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Update policy
  ///@param id
  @Put(path: '/v1/policies/{id}')
  Future<chopper.Response<Policy>> _v1PoliciesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PolicyUpdateOptions? body,
  });

  ///fetch a policy
  ///@param id
  Future<chopper.Response<Policy>> v1PoliciesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Policy, () => Policy.fromJsonFactory);

    return _v1PoliciesIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch a policy
  ///@param id
  @Get(path: '/v1/policies/{id}')
  Future<chopper.Response<Policy>> _v1PoliciesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete an policy and all related logins
  ///@param id
  Future<chopper.Response> v1PoliciesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1PoliciesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an policy and all related logins
  ///@param id
  @Delete(path: '/v1/policies/{id}')
  Future<chopper.Response> _v1PoliciesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create policy
  Future<chopper.Response<Policy>> v1PoliciesPost({
    String? cacheControl,
    required PolicyCreateOptions? body,
  }) {
    generatedMapping.putIfAbsent(Policy, () => Policy.fromJsonFactory);

    return _v1PoliciesPost(cacheControl: cacheControl, body: body);
  }

  ///Create policy
  @Post(path: '/v1/policies')
  Future<chopper.Response<Policy>> _v1PoliciesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PolicyCreateOptions? body,
  });

  ///fetch all policies
  Future<chopper.Response<List<Policy>>> v1PoliciesGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(Policy, () => Policy.fromJsonFactory);

    return _v1PoliciesGet(cacheControl: cacheControl);
  }

  ///fetch all policies
  @Get(path: '/v1/policies')
  Future<chopper.Response<List<Policy>>> _v1PoliciesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///fetch all policy templates!
  Future<chopper.Response<List<PolicyTemplate>>> v1PolicyTemplatesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        PolicyTemplate, () => PolicyTemplate.fromJsonFactory);

    return _v1PolicyTemplatesGet(cacheControl: cacheControl);
  }

  ///fetch all policy templates!
  @Get(path: '/v1/policy-templates')
  Future<chopper.Response<List<PolicyTemplate>>> _v1PolicyTemplatesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Create policy
  Future<chopper.Response<PolicyTemplate>> v1PolicyTemplatesPost({
    String? cacheControl,
    required PolicyTemplate? body,
  }) {
    generatedMapping.putIfAbsent(
        PolicyTemplate, () => PolicyTemplate.fromJsonFactory);

    return _v1PolicyTemplatesPost(cacheControl: cacheControl, body: body);
  }

  ///Create policy
  @Post(path: '/v1/policy-templates')
  Future<chopper.Response<PolicyTemplate>> _v1PolicyTemplatesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PolicyTemplate? body,
  });

  ///Update policy
  ///@param id
  Future<chopper.Response<PolicyTemplate>> v1PolicyTemplatesIdPut({
    required String? id,
    String? cacheControl,
    required PolicyTemplate? body,
  }) {
    generatedMapping.putIfAbsent(
        PolicyTemplate, () => PolicyTemplate.fromJsonFactory);

    return _v1PolicyTemplatesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Update policy
  ///@param id
  @Put(path: '/v1/policy-templates/{id}')
  Future<chopper.Response<PolicyTemplate>> _v1PolicyTemplatesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PolicyTemplate? body,
  });

  ///fetch a policy
  ///@param id
  Future<chopper.Response<PolicyTemplate>> v1PolicyTemplatesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        PolicyTemplate, () => PolicyTemplate.fromJsonFactory);

    return _v1PolicyTemplatesIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch a policy
  ///@param id
  @Get(path: '/v1/policy-templates/{id}')
  Future<chopper.Response<PolicyTemplate>> _v1PolicyTemplatesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete an policy and all related logins
  ///@param id
  Future<chopper.Response> v1PolicyTemplatesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1PolicyTemplatesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an policy and all related logins
  ///@param id
  @Delete(path: '/v1/policy-templates/{id}')
  Future<chopper.Response> _v1PolicyTemplatesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the keys that can be created with this backend.
  ///@param name
  ///@param id
  Future<chopper.Response<DeleteTotpKeysNameResponse>>
      v1CredentialsTotpIdKeysNameDelete({
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(DeleteTotpKeysNameResponse,
        () => DeleteTotpKeysNameResponse.fromJsonFactory);

    return _v1CredentialsTotpIdKeysNameDelete(
        name: name, id: id, cacheControl: cacheControl);
  }

  ///Manage the keys that can be created with this backend.
  ///@param name
  ///@param id
  @Delete(path: '/v1/credentials/totp/{id}/keys/{name}')
  Future<chopper.Response<DeleteTotpKeysNameResponse>>
      _v1CredentialsTotpIdKeysNameDelete({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the keys that can be created with this backend.
  ///@param name
  ///@param id
  Future<chopper.Response> v1CredentialsTotpIdKeysNameGet({
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    return _v1CredentialsTotpIdKeysNameGet(
        name: name, id: id, cacheControl: cacheControl);
  }

  ///Manage the keys that can be created with this backend.
  ///@param name
  ///@param id
  @Get(path: '/v1/credentials/totp/{id}/keys/{name}')
  Future<chopper.Response> _v1CredentialsTotpIdKeysNameGet({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the keys that can be created with this backend.
  ///@param name
  ///@param id
  Future<chopper.Response<PostTotpKeysNameResponse>>
      v1CredentialsTotpIdKeysNamePost({
    required String? name,
    required String? id,
    String? cacheControl,
    required TotpKeysNameOptions? body,
  }) {
    generatedMapping.putIfAbsent(PostTotpKeysNameResponse,
        () => PostTotpKeysNameResponse.fromJsonFactory);

    return _v1CredentialsTotpIdKeysNamePost(
        name: name, id: id, cacheControl: cacheControl, body: body);
  }

  ///Manage the keys that can be created with this backend.
  ///@param name
  ///@param id
  @Post(path: '/v1/credentials/totp/{id}/keys/{name}')
  Future<chopper.Response<PostTotpKeysNameResponse>>
      _v1CredentialsTotpIdKeysNamePost({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required TotpKeysNameOptions? body,
  });

  ///Request time-based one-time use password or validate a password for a certain key .
  ///@param name
  ///@param id
  Future<chopper.Response> v1CredentialsTotpIdCodeNameGet({
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    return _v1CredentialsTotpIdCodeNameGet(
        name: name, id: id, cacheControl: cacheControl);
  }

  ///Request time-based one-time use password or validate a password for a certain key .
  ///@param name
  ///@param id
  @Get(path: '/v1/credentials/totp/{id}/code/{name}')
  Future<chopper.Response> _v1CredentialsTotpIdCodeNameGet({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Request time-based one-time use password or validate a password for a certain key .
  ///@param name
  ///@param id
  Future<chopper.Response> v1CredentialsTotpIdCodeNamePost({
    required String? name,
    required String? id,
    String? cacheControl,
    required TotpCodeNameOptions? body,
  }) {
    return _v1CredentialsTotpIdCodeNamePost(
        name: name, id: id, cacheControl: cacheControl, body: body);
  }

  ///Request time-based one-time use password or validate a password for a certain key .
  ///@param name
  ///@param id
  @Post(path: '/v1/credentials/totp/{id}/code/{name}')
  Future<chopper.Response> _v1CredentialsTotpIdCodeNamePost({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required TotpCodeNameOptions? body,
  });

  ///Manage the keys that can be created with this backend.
  ///@param id
  Future<chopper.Response> v1CredentialsTotpIdKeysGet({
    required String? id,
    String? cacheControl,
  }) {
    return _v1CredentialsTotpIdKeysGet(id: id, cacheControl: cacheControl);
  }

  ///Manage the keys that can be created with this backend.
  ///@param id
  @Get(path: '/v1/credentials/totp/{id}/keys')
  Future<chopper.Response> _v1CredentialsTotpIdKeysGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete an OIDC authentication service and all related logins
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1OidcProviderIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1OidcProviderIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an OIDC authentication service and all related logins
  ///@param id
  @Delete(path: '/v1/oidc/provider/{id}')
  Future<chopper.Response<DeletedResponse>> _v1OidcProviderIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///fetch an OIDC authentication service
  ///@param id
  Future<chopper.Response<Provider>> v1OidcProviderIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Provider, () => Provider.fromJsonFactory);

    return _v1OidcProviderIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an OIDC authentication service
  ///@param id
  @Get(path: '/v1/oidc/provider/{id}')
  Future<chopper.Response<Provider>> _v1OidcProviderIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update OIDC authentication service
  ///@param id
  Future<chopper.Response<Provider>> v1OidcProviderIdPut({
    required String? id,
    String? cacheControl,
    required OidcProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(Provider, () => Provider.fromJsonFactory);

    return _v1OidcProviderIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Update OIDC authentication service
  ///@param id
  @Put(path: '/v1/oidc/provider/{id}')
  Future<chopper.Response<Provider>> _v1OidcProviderIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcProviderOptions? body,
  });

  ///Delete an existing role.
  ///@param name
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1OidcProviderIdRolesNameDelete({
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1OidcProviderIdRolesNameDelete(
        name: name, id: id, cacheControl: cacheControl);
  }

  ///Delete an existing role.
  ///@param name
  ///@param id
  @Delete(path: '/v1/oidc/provider/{id}/roles/{name}')
  Future<chopper.Response<DeletedResponse>> _v1OidcProviderIdRolesNameDelete({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Read an existing role.
  ///@param name
  ///@param id
  Future<chopper.Response<ProviderOidcRole>> v1OidcProviderIdRolesNameGet({
    required String? name,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProviderOidcRole, () => ProviderOidcRole.fromJsonFactory);

    return _v1OidcProviderIdRolesNameGet(
        name: name, id: id, cacheControl: cacheControl);
  }

  ///Read an existing role.
  ///@param name
  ///@param id
  @Get(path: '/v1/oidc/provider/{id}/roles/{name}')
  Future<chopper.Response<ProviderOidcRole>> _v1OidcProviderIdRolesNameGet({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Register an role with the backend.
  ///@param name
  ///@param id
  Future<chopper.Response<ProviderOidcRole>> v1OidcProviderIdRolesNamePost({
    required String? name,
    required String? id,
    String? cacheControl,
    required OidcProviderRoleNameOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        ProviderOidcRole, () => ProviderOidcRole.fromJsonFactory);

    return _v1OidcProviderIdRolesNamePost(
        name: name, id: id, cacheControl: cacheControl, body: body);
  }

  ///Register an role with the backend.
  ///@param name
  ///@param id
  @Post(path: '/v1/oidc/provider/{id}/roles/{name}')
  Future<chopper.Response<ProviderOidcRole>> _v1OidcProviderIdRolesNamePost({
    @Path('name') required String? name,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcProviderRoleNameOptions? body,
  });

  ///fetch all OIDC authentication services
  ///@param options
  Future<chopper.Response<List<Provider>>> v1OidcProviderGet({
    required String? options,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(Provider, () => Provider.fromJsonFactory);

    return _v1OidcProviderGet(options: options, cacheControl: cacheControl);
  }

  ///fetch all OIDC authentication services
  ///@param options
  @Get(path: '/v1/oidc/provider')
  Future<chopper.Response<List<Provider>>> _v1OidcProviderGet({
    @Query('options') required String? options,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create OIDC authentication service
  Future<chopper.Response<OidcProvider>> v1OidcProviderPost({
    String? cacheControl,
    required OidcProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        OidcProvider, () => OidcProvider.fromJsonFactory);

    return _v1OidcProviderPost(cacheControl: cacheControl, body: body);
  }

  ///Create OIDC authentication service
  @Post(path: '/v1/oidc/provider')
  Future<chopper.Response<OidcProvider>> _v1OidcProviderPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required OidcProviderOptions? body,
  });

  ///Lists all the roles registered with the backend.
  ///@param id
  Future<chopper.Response<List<ProviderOidcRole>>> v1OidcProviderIdRolesGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        ProviderOidcRole, () => ProviderOidcRole.fromJsonFactory);

    return _v1OidcProviderIdRolesGet(id: id, cacheControl: cacheControl);
  }

  ///Lists all the roles registered with the backend.
  ///@param id
  @Get(path: '/v1/oidc/provider/{id}/roles')
  Future<chopper.Response<List<ProviderOidcRole>>> _v1OidcProviderIdRolesGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///import an oidc service
  Future<chopper.Response> v1OidcProviderImportPost({String? cacheControl}) {
    return _v1OidcProviderImportPost(cacheControl: cacheControl);
  }

  ///import an oidc service
  @Post(
    path: '/v1/oidc/provider/import',
    optionalBody: true,
  )
  Future<chopper.Response> _v1OidcProviderImportPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Update group
  ///@param id
  Future<chopper.Response<IdentityGroup>> v1IdentityGroupsIdPut({
    required String? id,
    String? cacheControl,
    required PutGroup? body,
  }) {
    generatedMapping.putIfAbsent(
        IdentityGroup, () => IdentityGroup.fromJsonFactory);

    return _v1IdentityGroupsIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Update group
  ///@param id
  @Put(path: '/v1/identity/groups/{id}')
  Future<chopper.Response<IdentityGroup>> _v1IdentityGroupsIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required PutGroup? body,
  });

  ///fetch a group
  ///@param id
  ///@param relations
  ///@param loadEagerRelations
  Future<chopper.Response<IdentityGroup>> v1IdentityGroupsIdGet({
    required String? id,
    List<String>? relations,
    bool? loadEagerRelations,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        IdentityGroup, () => IdentityGroup.fromJsonFactory);

    return _v1IdentityGroupsIdGet(
        id: id,
        relations: relations,
        loadEagerRelations: loadEagerRelations,
        cacheControl: cacheControl);
  }

  ///fetch a group
  ///@param id
  ///@param relations
  ///@param loadEagerRelations
  @Get(path: '/v1/identity/groups/{id}')
  Future<chopper.Response<IdentityGroup>> _v1IdentityGroupsIdGet({
    @Path('id') required String? id,
    @Query('relations') List<String>? relations,
    @Query('loadEagerRelations') bool? loadEagerRelations,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete a group and all related logins
  ///@param id
  Future<chopper.Response> v1IdentityGroupsIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1IdentityGroupsIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete a group and all related logins
  ///@param id
  @Delete(path: '/v1/identity/groups/{id}')
  Future<chopper.Response> _v1IdentityGroupsIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create group
  Future<chopper.Response<IdentityGroup>> v1IdentityGroupsPost({
    String? cacheControl,
    required PostGroup? body,
  }) {
    generatedMapping.putIfAbsent(
        IdentityGroup, () => IdentityGroup.fromJsonFactory);

    return _v1IdentityGroupsPost(cacheControl: cacheControl, body: body);
  }

  ///Create group
  @Post(path: '/v1/identity/groups')
  Future<chopper.Response<IdentityGroup>> _v1IdentityGroupsPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required PostGroup? body,
  });

  ///fetch all groups
  ///@param relations
  ///@param skip
  ///@param take
  ///@param loadEagerRelations
  Future<chopper.Response<List<IdentityGroup>>> v1IdentityGroupsGet({
    List<String>? relations,
    num? skip,
    num? take,
    bool? loadEagerRelations,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        IdentityGroup, () => IdentityGroup.fromJsonFactory);

    return _v1IdentityGroupsGet(
        relations: relations,
        skip: skip,
        take: take,
        loadEagerRelations: loadEagerRelations,
        cacheControl: cacheControl);
  }

  ///fetch all groups
  ///@param relations
  ///@param skip
  ///@param take
  ///@param loadEagerRelations
  @Get(path: '/v1/identity/groups')
  Future<chopper.Response<List<IdentityGroup>>> _v1IdentityGroupsGet({
    @Query('relations') List<String>? relations,
    @Query('skip') num? skip,
    @Query('take') num? take,
    @Query('loadEagerRelations') bool? loadEagerRelations,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update alias
  ///@param id
  Future<chopper.Response<IdentityConnector>> v1IdentityAliasesIdPut({
    required String? id,
    String? cacheControl,
    required IdentityConnectorUpdateOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        IdentityConnector, () => IdentityConnector.fromJsonFactory);

    return _v1IdentityAliasesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Update alias
  ///@param id
  @Put(path: '/v1/identity/aliases/{id}')
  Future<chopper.Response<IdentityConnector>> _v1IdentityAliasesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required IdentityConnectorUpdateOptions? body,
  });

  ///fetch an alias
  ///@param id
  Future<chopper.Response<IdentityConnector>> v1IdentityAliasesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        IdentityConnector, () => IdentityConnector.fromJsonFactory);

    return _v1IdentityAliasesIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an alias
  ///@param id
  @Get(path: '/v1/identity/aliases/{id}')
  Future<chopper.Response<IdentityConnector>> _v1IdentityAliasesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///delete an alias and all related logins
  ///@param id
  Future<chopper.Response> v1IdentityAliasesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1IdentityAliasesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an alias and all related logins
  ///@param id
  @Delete(path: '/v1/identity/aliases/{id}')
  Future<chopper.Response> _v1IdentityAliasesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create alias
  Future<chopper.Response<IdentityConnector>> v1IdentityAliasesPost({
    String? cacheControl,
    required IdentityConnectorCreateOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        IdentityConnector, () => IdentityConnector.fromJsonFactory);

    return _v1IdentityAliasesPost(cacheControl: cacheControl, body: body);
  }

  ///Create alias
  @Post(path: '/v1/identity/aliases')
  Future<chopper.Response<IdentityConnector>> _v1IdentityAliasesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required IdentityConnectorCreateOptions? body,
  });

  ///fetch all entity aliases
  Future<chopper.Response<List<IdentityConnector>>> v1IdentityAliasesGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        IdentityConnector, () => IdentityConnector.fromJsonFactory);

    return _v1IdentityAliasesGet(cacheControl: cacheControl);
  }

  ///fetch all entity aliases
  @Get(path: '/v1/identity/aliases')
  Future<chopper.Response<List<IdentityConnector>>> _v1IdentityAliasesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///delete an authenticationService and all related logins
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1SamlProviderIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1SamlProviderIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an authenticationService and all related logins
  ///@param id
  @Delete(path: '/v1/saml/provider/{id}')
  Future<chopper.Response<DeletedResponse>> _v1SamlProviderIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///fetch an authenticationService
  ///@param id
  Future<chopper.Response<SamlProvider>> v1SamlProviderIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SamlProvider, () => SamlProvider.fromJsonFactory);

    return _v1SamlProviderIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an authenticationService
  ///@param id
  @Get(path: '/v1/saml/provider/{id}')
  Future<chopper.Response<SamlProvider>> _v1SamlProviderIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update authenticationService
  ///@param id
  Future<chopper.Response<SamlProvider>> v1SamlProviderIdPut({
    required String? id,
    String? cacheControl,
    required SamlProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        SamlProvider, () => SamlProvider.fromJsonFactory);

    return _v1SamlProviderIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Update authenticationService
  ///@param id
  @Put(path: '/v1/saml/provider/{id}')
  Future<chopper.Response<SamlProvider>> _v1SamlProviderIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required SamlProviderOptions? body,
  });

  ///fetch all authenticationServices
  ///@param options
  Future<chopper.Response<List<SamlProvider>>> v1SamlProviderGet({
    required String? options,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        SamlProvider, () => SamlProvider.fromJsonFactory);

    return _v1SamlProviderGet(options: options, cacheControl: cacheControl);
  }

  ///fetch all authenticationServices
  ///@param options
  @Get(path: '/v1/saml/provider')
  Future<chopper.Response<List<SamlProvider>>> _v1SamlProviderGet({
    @Query('options') required String? options,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create saml authentication service
  Future<chopper.Response<SamlProvider>> v1SamlProviderPost({
    String? cacheControl,
    required SamlProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        SamlProvider, () => SamlProvider.fromJsonFactory);

    return _v1SamlProviderPost(cacheControl: cacheControl, body: body);
  }

  ///Create saml authentication service
  @Post(path: '/v1/saml/provider')
  Future<chopper.Response<SamlProvider>> _v1SamlProviderPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SamlProviderOptions? body,
  });

  ///delete an Kerberos authentication service and all related logins
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1KerberosProviderIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1KerberosProviderIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an Kerberos authentication service and all related logins
  ///@param id
  @Delete(path: '/v1/kerberos/provider/{id}')
  Future<chopper.Response<DeletedResponse>> _v1KerberosProviderIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///fetch an Kerberos authentication service
  ///@param id
  Future<chopper.Response<KerberosProvider>> v1KerberosProviderIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        KerberosProvider, () => KerberosProvider.fromJsonFactory);

    return _v1KerberosProviderIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an Kerberos authentication service
  ///@param id
  @Get(path: '/v1/kerberos/provider/{id}')
  Future<chopper.Response<KerberosProvider>> _v1KerberosProviderIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update Kerberos authentication service
  ///@param id
  Future<chopper.Response<KerberosProvider>> v1KerberosProviderIdPut({
    required String? id,
    String? cacheControl,
    required KerberosProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        KerberosProvider, () => KerberosProvider.fromJsonFactory);

    return _v1KerberosProviderIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Update Kerberos authentication service
  ///@param id
  @Put(path: '/v1/kerberos/provider/{id}')
  Future<chopper.Response<KerberosProvider>> _v1KerberosProviderIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required KerberosProviderOptions? body,
  });

  ///fetch all Kerberos authentication services
  ///@param options
  Future<chopper.Response<List<KerberosProvider>>> v1KerberosProviderGet({
    required String? options,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        KerberosProvider, () => KerberosProvider.fromJsonFactory);

    return _v1KerberosProviderGet(options: options, cacheControl: cacheControl);
  }

  ///fetch all Kerberos authentication services
  ///@param options
  @Get(path: '/v1/kerberos/provider')
  Future<chopper.Response<List<KerberosProvider>>> _v1KerberosProviderGet({
    @Query('options') required String? options,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create Kerberos authentication service
  Future<chopper.Response<KerberosProvider>> v1KerberosProviderPost({
    String? cacheControl,
    required KerberosProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        KerberosProvider, () => KerberosProvider.fromJsonFactory);

    return _v1KerberosProviderPost(cacheControl: cacheControl, body: body);
  }

  ///Create Kerberos authentication service
  @Post(path: '/v1/kerberos/provider')
  Future<chopper.Response<KerberosProvider>> _v1KerberosProviderPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required KerberosProviderOptions? body,
  });

  ///postAuthKerberosLogin
  ///@param id
  Future<chopper.Response<Object>> v1KerberosProviderIdLoginPost({
    required String? id,
    String? cacheControl,
    required KerberosProviderLoginOptions? body,
  }) {
    return _v1KerberosProviderIdLoginPost(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///postAuthKerberosLogin
  ///@param id
  @Post(path: '/v1/kerberos/provider/{id}/login')
  Future<chopper.Response<Object>> _v1KerberosProviderIdLoginPost({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required KerberosProviderLoginOptions? body,
  });

  ///delete an authenticationService and all related logins
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1LdapProviderIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1LdapProviderIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an authenticationService and all related logins
  ///@param id
  @Delete(path: '/v1/ldap/provider/{id}')
  Future<chopper.Response<DeletedResponse>> _v1LdapProviderIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///fetch an authenticationService
  ///@param id
  Future<chopper.Response<LdapProvider>> v1LdapProviderIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LdapProvider, () => LdapProvider.fromJsonFactory);

    return _v1LdapProviderIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an authenticationService
  ///@param id
  @Get(path: '/v1/ldap/provider/{id}')
  Future<chopper.Response<LdapProvider>> _v1LdapProviderIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update authenticationService
  ///@param id
  Future<chopper.Response<LdapProvider>> v1LdapProviderIdPut({
    required String? id,
    String? cacheControl,
    required LdapProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        LdapProvider, () => LdapProvider.fromJsonFactory);

    return _v1LdapProviderIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///Update authenticationService
  ///@param id
  @Put(path: '/v1/ldap/provider/{id}')
  Future<chopper.Response<LdapProvider>> _v1LdapProviderIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required LdapProviderOptions? body,
  });

  ///fetch all authenticationServices
  ///@param options
  Future<chopper.Response<List<LdapProvider>>> v1LdapProviderGet({
    required String? options,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        LdapProvider, () => LdapProvider.fromJsonFactory);

    return _v1LdapProviderGet(options: options, cacheControl: cacheControl);
  }

  ///fetch all authenticationServices
  ///@param options
  @Get(path: '/v1/ldap/provider')
  Future<chopper.Response<List<LdapProvider>>> _v1LdapProviderGet({
    @Query('options') required String? options,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create authenticationService
  Future<chopper.Response<LdapProvider>> v1LdapProviderPost({
    String? cacheControl,
    required LdapProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        LdapProvider, () => LdapProvider.fromJsonFactory);

    return _v1LdapProviderPost(cacheControl: cacheControl, body: body);
  }

  ///Create authenticationService
  @Post(path: '/v1/ldap/provider')
  Future<chopper.Response<LdapProvider>> _v1LdapProviderPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required LdapProviderOptions? body,
  });

  ///delete an authenticationService and all related logins
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1UserpassProviderIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1UserpassProviderIdDelete(id: id, cacheControl: cacheControl);
  }

  ///delete an authenticationService and all related logins
  ///@param id
  @Delete(path: '/v1/userpass/provider/{id}')
  Future<chopper.Response<DeletedResponse>> _v1UserpassProviderIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///fetch an authenticationService
  ///@param id
  Future<chopper.Response<UserPassProvider>> v1UserpassProviderIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UserPassProvider, () => UserPassProvider.fromJsonFactory);

    return _v1UserpassProviderIdGet(id: id, cacheControl: cacheControl);
  }

  ///fetch an authenticationService
  ///@param id
  @Get(path: '/v1/userpass/provider/{id}')
  Future<chopper.Response<UserPassProvider>> _v1UserpassProviderIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update authenticationService
  ///@param id
  Future<chopper.Response<UserPassProvider>> v1UserpassProviderIdPut({
    required String? id,
    String? cacheControl,
    required UserpassProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        UserPassProvider, () => UserPassProvider.fromJsonFactory);

    return _v1UserpassProviderIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Update authenticationService
  ///@param id
  @Put(path: '/v1/userpass/provider/{id}')
  Future<chopper.Response<UserPassProvider>> _v1UserpassProviderIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserpassProviderOptions? body,
  });

  ///fetch all authenticationServices
  ///@param options
  Future<chopper.Response<List<UserPassProvider>>> v1UserpassProviderGet({
    required String? options,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        UserPassProvider, () => UserPassProvider.fromJsonFactory);

    return _v1UserpassProviderGet(options: options, cacheControl: cacheControl);
  }

  ///fetch all authenticationServices
  ///@param options
  @Get(path: '/v1/userpass/provider')
  Future<chopper.Response<List<UserPassProvider>>> _v1UserpassProviderGet({
    @Query('options') required String? options,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create authenticationService
  Future<chopper.Response<Provider>> v1UserpassProviderPost({
    String? cacheControl,
    required UserpassProviderOptions? body,
  }) {
    generatedMapping.putIfAbsent(Provider, () => Provider.fromJsonFactory);

    return _v1UserpassProviderPost(cacheControl: cacheControl, body: body);
  }

  ///Create authenticationService
  @Post(path: '/v1/userpass/provider')
  Future<chopper.Response<Provider>> _v1UserpassProviderPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required UserpassProviderOptions? body,
  });

  ///delete a cubbyhole secret
  ///@param path
  Future<chopper.Response<CubbyholeDeleteResponse>> v1CubbyholePathDelete({
    required String? path,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CubbyholeDeleteResponse, () => CubbyholeDeleteResponse.fromJsonFactory);

    return _v1CubbyholePathDelete(path: path, cacheControl: cacheControl);
  }

  ///delete a cubbyhole secret
  ///@param path
  @Delete(path: '/v1/cubbyhole/{path}')
  Future<chopper.Response<CubbyholeDeleteResponse>> _v1CubbyholePathDelete({
    @Query('path') required String? path,
    @Header('Cache-Control') String? cacheControl,
  });

  ///fetch a cubbyhole secret
  ///@param path
  Future<chopper.Response<CubbyholeReadResponse>> v1CubbyholePathGet({
    required String? path,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CubbyholeReadResponse, () => CubbyholeReadResponse.fromJsonFactory);

    return _v1CubbyholePathGet(path: path, cacheControl: cacheControl);
  }

  ///fetch a cubbyhole secret
  ///@param path
  @Get(path: '/v1/cubbyhole/{path}')
  Future<chopper.Response<CubbyholeReadResponse>> _v1CubbyholePathGet({
    @Query('path') required String? path,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Update cubbyhole
  Future<chopper.Response<CubbyholeWriteResponse>> v1CubbyholePathPut({
    String? cacheControl,
    required CubbyholeWriteOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        CubbyholeWriteResponse, () => CubbyholeWriteResponse.fromJsonFactory);

    return _v1CubbyholePathPut(cacheControl: cacheControl, body: body);
  }

  ///Update cubbyhole
  @Put(path: '/v1/cubbyhole/{path}')
  Future<chopper.Response<CubbyholeWriteResponse>> _v1CubbyholePathPut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required CubbyholeWriteOptions? body,
  });

  ///returns tables in the eventLogs
  Future<chopper.Response<List<String>>> v1AuditTablesGet(
      {String? cacheControl}) {
    return _v1AuditTablesGet(cacheControl: cacheControl);
  }

  ///returns tables in the eventLogs
  @Get(path: '/v1/audit/tables')
  Future<chopper.Response<List<String>>> _v1AuditTablesGet(
      {@Header('Cache-Control') String? cacheControl});

  ///returns events in the eventLogs
  Future<chopper.Response<List<String>>> v1AuditEventsGet(
      {String? cacheControl}) {
    return _v1AuditEventsGet(cacheControl: cacheControl);
  }

  ///returns events in the eventLogs
  @Get(path: '/v1/audit/events')
  Future<chopper.Response<List<String>>> _v1AuditEventsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///returns eventLogs
  ///@param relations
  ///@param loadEagerRelations
  ///@param id
  Future<chopper.Response<EventLog>> v1AuditIdGet({
    List<String>? relations,
    bool? loadEagerRelations,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(EventLog, () => EventLog.fromJsonFactory);

    return _v1AuditIdGet(
        relations: relations,
        loadEagerRelations: loadEagerRelations,
        id: id,
        cacheControl: cacheControl);
  }

  ///returns eventLogs
  ///@param relations
  ///@param loadEagerRelations
  ///@param id
  @Get(path: '/v1/audit/{id}')
  Future<chopper.Response<EventLog>> _v1AuditIdGet({
    @Query('relations') List<String>? relations,
    @Query('loadEagerRelations') bool? loadEagerRelations,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///returns eventLogs
  ///@param filter
  Future<chopper.Response<List<EventLog>>> v1AuditGet({
    required String? filter,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(EventLog, () => EventLog.fromJsonFactory);

    return _v1AuditGet(filter: filter, cacheControl: cacheControl);
  }

  ///returns eventLogs
  ///@param filter
  @Get(path: '/v1/audit')
  Future<chopper.Response<List<EventLog>>> _v1AuditGet({
    @Query('filter') required String? filter,
    @Header('Cache-Control') String? cacheControl,
  });

  ///creates a eventLog
  Future<chopper.Response<EventLog>> v1AuditPost({
    String? cacheControl,
    required EventLogCreateOptions? body,
  }) {
    generatedMapping.putIfAbsent(EventLog, () => EventLog.fromJsonFactory);

    return _v1AuditPost(cacheControl: cacheControl, body: body);
  }

  ///creates a eventLog
  @Post(path: '/v1/audit')
  Future<chopper.Response<EventLog>> _v1AuditPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required EventLogCreateOptions? body,
  });

  ///saml metadata
  ///@param id
  Future<chopper.Response> v1SamlIdMetadataXmlGet({
    required String? id,
    String? cacheControl,
  }) {
    return _v1SamlIdMetadataXmlGet(id: id, cacheControl: cacheControl);
  }

  ///saml metadata
  ///@param id
  @Get(path: '/v1/saml/{id}/metadata.xml')
  Future<chopper.Response> _v1SamlIdMetadataXmlGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///saml login
  ///@param id
  Future<chopper.Response> v1SamlIdLoginGet({
    required String? id,
    String? cacheControl,
  }) {
    return _v1SamlIdLoginGet(id: id, cacheControl: cacheControl);
  }

  ///saml login
  ///@param id
  @Get(path: '/v1/saml/{id}/login')
  Future<chopper.Response> _v1SamlIdLoginGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///saml assert
  ///@param id
  Future<chopper.Response> v1SamlIdAssertPost({
    required String? id,
    String? cacheControl,
  }) {
    return _v1SamlIdAssertPost(id: id, cacheControl: cacheControl);
  }

  ///saml assert
  ///@param id
  @Post(
    path: '/v1/saml/{id}/assert',
    optionalBody: true,
  )
  Future<chopper.Response> _v1SamlIdAssertPost({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Delete the Aws Secret backend.
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1CredentialsAwsIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1CredentialsAwsIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Delete the Aws Secret backend.
  ///@param id
  @Delete(path: '/v1/credentials/aws/{id}')
  Future<chopper.Response<DeletedResponse>> _v1CredentialsAwsIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get the Aws Secret backend.
  ///@param id
  Future<chopper.Response<AwsCredentials>> v1CredentialsAwsIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentials, () => AwsCredentials.fromJsonFactory);

    return _v1CredentialsAwsIdGet(id: id, cacheControl: cacheControl);
  }

  ///Get the Aws Secret backend.
  ///@param id
  @Get(path: '/v1/credentials/aws/{id}')
  Future<chopper.Response<AwsCredentials>> _v1CredentialsAwsIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///update the Aws Secret backend.
  ///@param id
  Future<chopper.Response<AwsCredentials>> v1CredentialsAwsIdPut({
    required String? id,
    String? cacheControl,
    required AwsCredentials? body,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentials, () => AwsCredentials.fromJsonFactory);

    return _v1CredentialsAwsIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///update the Aws Secret backend.
  ///@param id
  @Put(path: '/v1/credentials/aws/{id}')
  Future<chopper.Response<AwsCredentials>> _v1CredentialsAwsIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AwsCredentials? body,
  });

  ///Manage the secureable roles used to generate Aws credentials.
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1CredentialsAwsRolesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1CredentialsAwsRolesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Manage the secureable roles used to generate Aws credentials.
  ///@param id
  @Delete(path: '/v1/credentials/aws-roles/{id}')
  Future<chopper.Response<DeletedResponse>> _v1CredentialsAwsRolesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the secureable roles used to generate Aws credentials.
  ///@param id
  Future<chopper.Response<AwsCredentialsRole>> v1CredentialsAwsRolesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentialsRole, () => AwsCredentialsRole.fromJsonFactory);

    return _v1CredentialsAwsRolesIdGet(id: id, cacheControl: cacheControl);
  }

  ///Manage the secureable roles used to generate Aws credentials.
  ///@param id
  @Get(path: '/v1/credentials/aws-roles/{id}')
  Future<chopper.Response<AwsCredentialsRole>> _v1CredentialsAwsRolesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the secureable roles used to generate Aws credentials.
  ///@param id
  Future<chopper.Response<AwsCredentialsRole>> v1CredentialsAwsRolesIdPut({
    required String? id,
    String? cacheControl,
    required AwsCredentialsRole? body,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentialsRole, () => AwsCredentialsRole.fromJsonFactory);

    return _v1CredentialsAwsRolesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Manage the secureable roles used to generate Aws credentials.
  ///@param id
  @Put(path: '/v1/credentials/aws-roles/{id}')
  Future<chopper.Response<AwsCredentialsRole>> _v1CredentialsAwsRolesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AwsCredentialsRole? body,
  });

  ///List the Aws Secrets
  Future<chopper.Response<List<AwsCredentials>>> v1CredentialsAwsGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AwsCredentials, () => AwsCredentials.fromJsonFactory);

    return _v1CredentialsAwsGet(cacheControl: cacheControl);
  }

  ///List the Aws Secrets
  @Get(path: '/v1/credentials/aws')
  Future<chopper.Response<List<AwsCredentials>>> _v1CredentialsAwsGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Create the Aws Secret backend.
  ///@param id
  Future<chopper.Response<AwsCredentials>> v1CredentialsAwsPost({
    required String? id,
    String? cacheControl,
    required AwsCredentials? body,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentials, () => AwsCredentials.fromJsonFactory);

    return _v1CredentialsAwsPost(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Create the Aws Secret backend.
  ///@param id
  @Post(path: '/v1/credentials/aws')
  Future<chopper.Response<AwsCredentials>> _v1CredentialsAwsPost({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AwsCredentials? body,
  });

  ///Request Service Principal credentials for a given secureable role.
  ///@param role
  ///@param id
  Future<chopper.Response<AwsCreds>> v1CredentialsAwsIdCredsRoleGet({
    required String? role,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(AwsCreds, () => AwsCreds.fromJsonFactory);

    return _v1CredentialsAwsIdCredsRoleGet(
        role: role, id: id, cacheControl: cacheControl);
  }

  ///Request Service Principal credentials for a given secureable role.
  ///@param role
  ///@param id
  @Get(path: '/v1/credentials/aws/{id}/creds/{role}')
  Future<chopper.Response<AwsCreds>> _v1CredentialsAwsIdCredsRoleGet({
    @Path('role') required String? role,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List existing roles.
  ///@param id
  Future<chopper.Response<List<AwsCredentialsRole>>>
      v1CredentialsAwsIdRolesGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentialsRole, () => AwsCredentialsRole.fromJsonFactory);

    return _v1CredentialsAwsIdRolesGet(id: id, cacheControl: cacheControl);
  }

  ///List existing roles.
  ///@param id
  @Get(path: '/v1/credentials/aws/{id}/roles')
  Future<chopper.Response<List<AwsCredentialsRole>>>
      _v1CredentialsAwsIdRolesGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create the Aws Secret backend role.
  Future<chopper.Response<AwsCredentialsRole>> v1CredentialsAwsRolesPost({
    String? cacheControl,
    required AwsCredentialsRole? body,
  }) {
    generatedMapping.putIfAbsent(
        AwsCredentialsRole, () => AwsCredentialsRole.fromJsonFactory);

    return _v1CredentialsAwsRolesPost(cacheControl: cacheControl, body: body);
  }

  ///Create the Aws Secret backend role.
  @Post(path: '/v1/credentials/aws-roles')
  Future<chopper.Response<AwsCredentialsRole>> _v1CredentialsAwsRolesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required AwsCredentialsRole? body,
  });

  ///Delete the Azure Secret backend.
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1CredentialsAzureIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1CredentialsAzureIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Delete the Azure Secret backend.
  ///@param id
  @Delete(path: '/v1/credentials/azure/{id}')
  Future<chopper.Response<DeletedResponse>> _v1CredentialsAzureIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get the Azure Secret backend.
  ///@param id
  Future<chopper.Response<AzureCredentials>> v1CredentialsAzureIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentials, () => AzureCredentials.fromJsonFactory);

    return _v1CredentialsAzureIdGet(id: id, cacheControl: cacheControl);
  }

  ///Get the Azure Secret backend.
  ///@param id
  @Get(path: '/v1/credentials/azure/{id}')
  Future<chopper.Response<AzureCredentials>> _v1CredentialsAzureIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///update the Azure Secret backend.
  ///@param id
  Future<chopper.Response<AzureCredentials>> v1CredentialsAzureIdPut({
    required String? id,
    String? cacheControl,
    required AzureCredentials? body,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentials, () => AzureCredentials.fromJsonFactory);

    return _v1CredentialsAzureIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///update the Azure Secret backend.
  ///@param id
  @Put(path: '/v1/credentials/azure/{id}')
  Future<chopper.Response<AzureCredentials>> _v1CredentialsAzureIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AzureCredentials? body,
  });

  ///Manage the secureable roles used to generate Azure credentials.
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1CredentialsAzureRolesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1CredentialsAzureRolesIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Manage the secureable roles used to generate Azure credentials.
  ///@param id
  @Delete(path: '/v1/credentials/azure-roles/{id}')
  Future<chopper.Response<DeletedResponse>> _v1CredentialsAzureRolesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the secureable roles used to generate Azure credentials.
  ///@param id
  Future<chopper.Response<AzureCredentialsRole>> v1CredentialsAzureRolesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentialsRole, () => AzureCredentialsRole.fromJsonFactory);

    return _v1CredentialsAzureRolesIdGet(id: id, cacheControl: cacheControl);
  }

  ///Manage the secureable roles used to generate Azure credentials.
  ///@param id
  @Get(path: '/v1/credentials/azure-roles/{id}')
  Future<chopper.Response<AzureCredentialsRole>> _v1CredentialsAzureRolesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the secureable roles used to generate Azure credentials.
  ///@param id
  Future<chopper.Response<AzureCredentialsRole>> v1CredentialsAzureRolesIdPut({
    required String? id,
    String? cacheControl,
    required AzureCredentialsRole? body,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentialsRole, () => AzureCredentialsRole.fromJsonFactory);

    return _v1CredentialsAzureRolesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Manage the secureable roles used to generate Azure credentials.
  ///@param id
  @Put(path: '/v1/credentials/azure-roles/{id}')
  Future<chopper.Response<AzureCredentialsRole>> _v1CredentialsAzureRolesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AzureCredentialsRole? body,
  });

  ///List the Azure Secrets
  Future<chopper.Response<List<AzureCredentials>>> v1CredentialsAzureGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        AzureCredentials, () => AzureCredentials.fromJsonFactory);

    return _v1CredentialsAzureGet(cacheControl: cacheControl);
  }

  ///List the Azure Secrets
  @Get(path: '/v1/credentials/azure')
  Future<chopper.Response<List<AzureCredentials>>> _v1CredentialsAzureGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Create the Azure Secret backend.
  ///@param id
  Future<chopper.Response<AzureCredentials>> v1CredentialsAzurePost({
    required String? id,
    String? cacheControl,
    required AzureCredentials? body,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentials, () => AzureCredentials.fromJsonFactory);

    return _v1CredentialsAzurePost(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Create the Azure Secret backend.
  ///@param id
  @Post(path: '/v1/credentials/azure')
  Future<chopper.Response<AzureCredentials>> _v1CredentialsAzurePost({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required AzureCredentials? body,
  });

  ///Request Service Principal credentials for a given secureable role.
  ///@param role
  ///@param id
  Future<chopper.Response<GetAzureCredsRoleResponse>>
      v1CredentialsAzureIdCredsRoleGet({
    required String? role,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GetAzureCredsRoleResponse,
        () => GetAzureCredsRoleResponse.fromJsonFactory);

    return _v1CredentialsAzureIdCredsRoleGet(
        role: role, id: id, cacheControl: cacheControl);
  }

  ///Request Service Principal credentials for a given secureable role.
  ///@param role
  ///@param id
  @Get(path: '/v1/credentials/azure/{id}/creds/{role}')
  Future<chopper.Response<GetAzureCredsRoleResponse>>
      _v1CredentialsAzureIdCredsRoleGet({
    @Path('role') required String? role,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List existing roles.
  ///@param id
  Future<chopper.Response<List<AzureCredentialsRole>>>
      v1CredentialsAzureIdRolesGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentialsRole, () => AzureCredentialsRole.fromJsonFactory);

    return _v1CredentialsAzureIdRolesGet(id: id, cacheControl: cacheControl);
  }

  ///List existing roles.
  ///@param id
  @Get(path: '/v1/credentials/azure/{id}/roles')
  Future<chopper.Response<List<AzureCredentialsRole>>>
      _v1CredentialsAzureIdRolesGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create the Azure Secret backend role.
  Future<chopper.Response<AzureCredentialsRole>> v1CredentialsAzureRolesPost({
    String? cacheControl,
    required AzureCredentialsRole? body,
  }) {
    generatedMapping.putIfAbsent(
        AzureCredentialsRole, () => AzureCredentialsRole.fromJsonFactory);

    return _v1CredentialsAzureRolesPost(cacheControl: cacheControl, body: body);
  }

  ///Create the Azure Secret backend role.
  @Post(path: '/v1/credentials/azure-roles')
  Future<chopper.Response<AzureCredentialsRole>> _v1CredentialsAzureRolesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required AzureCredentialsRole? body,
  });

  ///Delete the RabbitMq Secret backend.
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1CredentialsRabbitmqIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1CredentialsRabbitmqIdDelete(id: id, cacheControl: cacheControl);
  }

  ///Delete the RabbitMq Secret backend.
  ///@param id
  @Delete(path: '/v1/credentials/rabbitmq/{id}')
  Future<chopper.Response<DeletedResponse>> _v1CredentialsRabbitmqIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Get the RabbitMq Secret backend.
  ///@param id
  Future<chopper.Response<RabbitMqCredentials>> v1CredentialsRabbitmqIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RabbitMqCredentials, () => RabbitMqCredentials.fromJsonFactory);

    return _v1CredentialsRabbitmqIdGet(id: id, cacheControl: cacheControl);
  }

  ///Get the RabbitMq Secret backend.
  ///@param id
  @Get(path: '/v1/credentials/rabbitmq/{id}')
  Future<chopper.Response<RabbitMqCredentials>> _v1CredentialsRabbitmqIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///update the RabbitMq Secret backend.
  ///@param id
  Future<chopper.Response<Credentials>> v1CredentialsRabbitmqIdPut({
    required String? id,
    String? cacheControl,
    required RabbitMqCredentials? body,
  }) {
    generatedMapping.putIfAbsent(
        Credentials, () => Credentials.fromJsonFactory);

    return _v1CredentialsRabbitmqIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///update the RabbitMq Secret backend.
  ///@param id
  @Put(path: '/v1/credentials/rabbitmq/{id}')
  Future<chopper.Response<Credentials>> _v1CredentialsRabbitmqIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required RabbitMqCredentials? body,
  });

  ///Manage the secureable roles used to generate RabbitMq credentials.
  ///@param id
  Future<chopper.Response<DeletedResponse>> v1CredentialsRabbitmqRolesIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        DeletedResponse, () => DeletedResponse.fromJsonFactory);

    return _v1CredentialsRabbitmqRolesIdDelete(
        id: id, cacheControl: cacheControl);
  }

  ///Manage the secureable roles used to generate RabbitMq credentials.
  ///@param id
  @Delete(path: '/v1/credentials/rabbitmq-roles/{id}')
  Future<chopper.Response<DeletedResponse>>
      _v1CredentialsRabbitmqRolesIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the secureable roles used to generate RabbitMq credentials.
  ///@param id
  Future<chopper.Response<CredentialsRole>> v1CredentialsRabbitmqRolesIdGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        CredentialsRole, () => CredentialsRole.fromJsonFactory);

    return _v1CredentialsRabbitmqRolesIdGet(id: id, cacheControl: cacheControl);
  }

  ///Manage the secureable roles used to generate RabbitMq credentials.
  ///@param id
  @Get(path: '/v1/credentials/rabbitmq-roles/{id}')
  Future<chopper.Response<CredentialsRole>> _v1CredentialsRabbitmqRolesIdGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Manage the secureable roles used to generate RabbitMq credentials.
  ///@param id
  Future<chopper.Response<RabbitMqCredentialsRole>>
      v1CredentialsRabbitmqRolesIdPut({
    required String? id,
    String? cacheControl,
    required RabbitMqCredentialsRole? body,
  }) {
    generatedMapping.putIfAbsent(
        RabbitMqCredentialsRole, () => RabbitMqCredentialsRole.fromJsonFactory);

    return _v1CredentialsRabbitmqRolesIdPut(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Manage the secureable roles used to generate RabbitMq credentials.
  ///@param id
  @Put(path: '/v1/credentials/rabbitmq-roles/{id}')
  Future<chopper.Response<RabbitMqCredentialsRole>>
      _v1CredentialsRabbitmqRolesIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required RabbitMqCredentialsRole? body,
  });

  ///List the RabbitMq Secrets
  Future<chopper.Response<List<RabbitMqCredentials>>> v1CredentialsRabbitmqGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        RabbitMqCredentials, () => RabbitMqCredentials.fromJsonFactory);

    return _v1CredentialsRabbitmqGet(cacheControl: cacheControl);
  }

  ///List the RabbitMq Secrets
  @Get(path: '/v1/credentials/rabbitmq')
  Future<chopper.Response<List<RabbitMqCredentials>>> _v1CredentialsRabbitmqGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Create the RabbitMq Secret backend.
  ///@param id
  Future<chopper.Response<Credentials>> v1CredentialsRabbitmqPost({
    required String? id,
    String? cacheControl,
    required RabbitMqCredentials? body,
  }) {
    generatedMapping.putIfAbsent(
        Credentials, () => Credentials.fromJsonFactory);

    return _v1CredentialsRabbitmqPost(
        id: id, cacheControl: cacheControl, body: body);
  }

  ///Create the RabbitMq Secret backend.
  ///@param id
  @Post(path: '/v1/credentials/rabbitmq')
  Future<chopper.Response<Credentials>> _v1CredentialsRabbitmqPost({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required RabbitMqCredentials? body,
  });

  ///Request Service Principal credentials for a given secureable role.
  ///@param role
  ///@param id
  Future<chopper.Response<GetRabbitmqCredsNameResponse>>
      v1CredentialsRabbitmqIdCredsRoleGet({
    required String? role,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(GetRabbitmqCredsNameResponse,
        () => GetRabbitmqCredsNameResponse.fromJsonFactory);

    return _v1CredentialsRabbitmqIdCredsRoleGet(
        role: role, id: id, cacheControl: cacheControl);
  }

  ///Request Service Principal credentials for a given secureable role.
  ///@param role
  ///@param id
  @Get(path: '/v1/credentials/rabbitmq/{id}/creds/{role}')
  Future<chopper.Response<GetRabbitmqCredsNameResponse>>
      _v1CredentialsRabbitmqIdCredsRoleGet({
    @Path('role') required String? role,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///List existing roles.
  ///@param id
  Future<chopper.Response<List<RabbitMqCredentialsRole>>>
      v1CredentialsRabbitmqIdRolesGet({
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        RabbitMqCredentialsRole, () => RabbitMqCredentialsRole.fromJsonFactory);

    return _v1CredentialsRabbitmqIdRolesGet(id: id, cacheControl: cacheControl);
  }

  ///List existing roles.
  ///@param id
  @Get(path: '/v1/credentials/rabbitmq/{id}/roles')
  Future<chopper.Response<List<RabbitMqCredentialsRole>>>
      _v1CredentialsRabbitmqIdRolesGet({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///Create the RabbitMq Secret backend role.
  Future<chopper.Response<RabbitMqCredentialsRole>>
      v1CredentialsRabbitmqRolesPost({
    String? cacheControl,
    required RabbitMqCredentialsRole? body,
  }) {
    generatedMapping.putIfAbsent(
        RabbitMqCredentialsRole, () => RabbitMqCredentialsRole.fromJsonFactory);

    return _v1CredentialsRabbitmqRolesPost(
        cacheControl: cacheControl, body: body);
  }

  ///Create the RabbitMq Secret backend role.
  @Post(path: '/v1/credentials/rabbitmq-roles')
  Future<chopper.Response<RabbitMqCredentialsRole>>
      _v1CredentialsRabbitmqRolesPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RabbitMqCredentialsRole? body,
  });

  ///returns queryBuilder
  ///@param relations
  ///@param loadEagerRelations
  ///@param id
  Future<chopper.Response<QueryBuilder>> v1FiltersIdGet({
    List<String>? relations,
    bool? loadEagerRelations,
    required String? id,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        QueryBuilder, () => QueryBuilder.fromJsonFactory);

    return _v1FiltersIdGet(
        relations: relations,
        loadEagerRelations: loadEagerRelations,
        id: id,
        cacheControl: cacheControl);
  }

  ///returns queryBuilder
  ///@param relations
  ///@param loadEagerRelations
  ///@param id
  @Get(path: '/v1/filters/{id}')
  Future<chopper.Response<QueryBuilder>> _v1FiltersIdGet({
    @Query('relations') List<String>? relations,
    @Query('loadEagerRelations') bool? loadEagerRelations,
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///updates a queryBuilder
  ///@param id
  Future<chopper.Response<QueryBuilder>> v1FiltersIdPut({
    required String? id,
    String? cacheControl,
    required QueryBuilder? body,
  }) {
    generatedMapping.putIfAbsent(
        QueryBuilder, () => QueryBuilder.fromJsonFactory);

    return _v1FiltersIdPut(id: id, cacheControl: cacheControl, body: body);
  }

  ///updates a queryBuilder
  ///@param id
  @Put(path: '/v1/filters/{id}')
  Future<chopper.Response<QueryBuilder>> _v1FiltersIdPut({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
    @Body() required QueryBuilder? body,
  });

  ///creates a queryBuilder
  ///@param id
  Future<chopper.Response> v1FiltersIdDelete({
    required String? id,
    String? cacheControl,
  }) {
    return _v1FiltersIdDelete(id: id, cacheControl: cacheControl);
  }

  ///creates a queryBuilder
  ///@param id
  @Delete(path: '/v1/filters/{id}')
  Future<chopper.Response> _v1FiltersIdDelete({
    @Path('id') required String? id,
    @Header('Cache-Control') String? cacheControl,
  });

  ///returns queryBuilder
  ///@param relations
  ///@param loadEagerRelations
  ///@param skip
  ///@param take
  Future<chopper.Response<List<QueryBuilder>>> v1FiltersGet({
    List<String>? relations,
    bool? loadEagerRelations,
    num? skip,
    num? take,
    String? cacheControl,
  }) {
    generatedMapping.putIfAbsent(
        QueryBuilder, () => QueryBuilder.fromJsonFactory);

    return _v1FiltersGet(
        relations: relations,
        loadEagerRelations: loadEagerRelations,
        skip: skip,
        take: take,
        cacheControl: cacheControl);
  }

  ///returns queryBuilder
  ///@param relations
  ///@param loadEagerRelations
  ///@param skip
  ///@param take
  @Get(path: '/v1/filters')
  Future<chopper.Response<List<QueryBuilder>>> _v1FiltersGet({
    @Query('relations') List<String>? relations,
    @Query('loadEagerRelations') bool? loadEagerRelations,
    @Query('skip') num? skip,
    @Query('take') num? take,
    @Header('Cache-Control') String? cacheControl,
  });

  ///creates a queryBuilder
  Future<chopper.Response<QueryBuilder>> v1FiltersPost({
    String? cacheControl,
    required QueryBuilder? body,
  }) {
    generatedMapping.putIfAbsent(
        QueryBuilder, () => QueryBuilder.fromJsonFactory);

    return _v1FiltersPost(cacheControl: cacheControl, body: body);
  }

  ///creates a queryBuilder
  @Post(path: '/v1/filters')
  Future<chopper.Response<QueryBuilder>> _v1FiltersPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required QueryBuilder? body,
  });

  ///Generate and return a random passphrase
  Future<chopper.Response<GeneratePassphraseResponse>>
      v1CredentialsGeneratorPassphrasePost({
    String? cacheControl,
    required GeneratePassphraseOptions? body,
  }) {
    generatedMapping.putIfAbsent(GeneratePassphraseResponse,
        () => GeneratePassphraseResponse.fromJsonFactory);

    return _v1CredentialsGeneratorPassphrasePost(
        cacheControl: cacheControl, body: body);
  }

  ///Generate and return a random passphrase
  @Post(path: '/v1/credentials/generator/passphrase')
  Future<chopper.Response<GeneratePassphraseResponse>>
      _v1CredentialsGeneratorPassphrasePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required GeneratePassphraseOptions? body,
  });

  ///Generate and return a random password
  Future<chopper.Response<GeneratePasswordResponse>>
      v1CredentialsGeneratorPasswordPost({
    String? cacheControl,
    required GeneratePasswordOptions? body,
  }) {
    generatedMapping.putIfAbsent(GeneratePasswordResponse,
        () => GeneratePasswordResponse.fromJsonFactory);

    return _v1CredentialsGeneratorPasswordPost(
        cacheControl: cacheControl, body: body);
  }

  ///Generate and return a random password
  @Post(path: '/v1/credentials/generator/password')
  Future<chopper.Response<GeneratePasswordResponse>>
      _v1CredentialsGeneratorPasswordPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required GeneratePasswordOptions? body,
  });

  ///Seal Secureable.
  Future<chopper.Response<ApiResponse>> v1SystemLockPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ApiResponse, () => ApiResponse.fromJsonFactory);

    return _v1SystemLockPost(cacheControl: cacheControl);
  }

  ///Seal Secureable.
  @Post(
    path: '/v1/system/lock',
    optionalBody: true,
  )
  Future<chopper.Response<ApiResponse>> _v1SystemLockPost(
      {@Header('Cache-Control') String? cacheControl});

  ///Check the seal status of Secureable.
  Future<chopper.Response<SystemSealStatusResponse>> v1SystemSealStatusGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(SystemSealStatusResponse,
        () => SystemSealStatusResponse.fromJsonFactory);

    return _v1SystemSealStatusGet(cacheControl: cacheControl);
  }

  ///Check the seal status of Secureable.
  @Get(path: '/v1/system/seal-status')
  Future<chopper.Response<SystemSealStatusResponse>> _v1SystemSealStatusGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Unseal Secureable.
  Future<chopper.Response<SystemSealUnlockResponse>> v1SystemUnlockPost({
    String? cacheControl,
    required SystemSealUnlockOptions? body,
  }) {
    generatedMapping.putIfAbsent(SystemSealUnlockResponse,
        () => SystemSealUnlockResponse.fromJsonFactory);

    return _v1SystemUnlockPost(cacheControl: cacheControl, body: body);
  }

  ///Unseal Secureable.
  @Post(path: '/v1/system/unlock')
  Future<chopper.Response<SystemSealUnlockResponse>> _v1SystemUnlockPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SystemSealUnlockOptions? body,
  });

  ///Returns the health status of Secureable.
  Future<chopper.Response<SystemStatusResponse>> v1SystemStatusGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        SystemStatusResponse, () => SystemStatusResponse.fromJsonFactory);

    return _v1SystemStatusGet(cacheControl: cacheControl);
  }

  ///Returns the health status of Secureable.
  @Get(path: '/v1/system/status')
  Future<chopper.Response<SystemStatusResponse>> _v1SystemStatusGet(
      {@Header('Cache-Control') String? cacheControl});

  ///reset secureable back to factory defaults
  Future<chopper.Response<ResetResponse>> v1SystemResetDelete(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        ResetResponse, () => ResetResponse.fromJsonFactory);

    return _v1SystemResetDelete(cacheControl: cacheControl);
  }

  ///reset secureable back to factory defaults
  @Delete(path: '/v1/system/reset')
  Future<chopper.Response<ResetResponse>> _v1SystemResetDelete(
      {@Header('Cache-Control') String? cacheControl});

  ///reset secureable policies back to factory defaults
  Future<chopper.Response> v1SystemResetPolicyDelete({String? cacheControl}) {
    return _v1SystemResetPolicyDelete(cacheControl: cacheControl);
  }

  ///reset secureable policies back to factory defaults
  @Delete(path: '/v1/system/reset-policy')
  Future<chopper.Response> _v1SystemResetPolicyDelete(
      {@Header('Cache-Control') String? cacheControl});

  ///Initialize a new Secureable.
  Future<chopper.Response<InitResponse>> v1SystemInitializePut({
    String? cacheControl,
    required InitOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        InitResponse, () => InitResponse.fromJsonFactory);

    return _v1SystemInitializePut(cacheControl: cacheControl, body: body);
  }

  ///Initialize a new Secureable.
  @Put(path: '/v1/system/initialize')
  Future<chopper.Response<InitResponse>> _v1SystemInitializePut({
    @Header('Cache-Control') String? cacheControl,
    @Body() required InitOptions? body,
  });

  ///download a backup file
  Future<chopper.Response<Object>> v1BackupDownloadPost({
    String? cacheControl,
    required BackupDownloadOptions? body,
  }) {
    return _v1BackupDownloadPost(cacheControl: cacheControl, body: body);
  }

  ///download a backup file
  @Post(path: '/v1/backup/download')
  Future<chopper.Response<Object>> _v1BackupDownloadPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required BackupDownloadOptions? body,
  });

  ///upload a backup file
  Future<chopper.Response> v1BackupUploadPost({String? cacheControl}) {
    return _v1BackupUploadPost(cacheControl: cacheControl);
  }

  ///upload a backup file
  @Post(
    path: '/v1/backup/upload',
    optionalBody: true,
  )
  Future<chopper.Response> _v1BackupUploadPost(
      {@Header('Cache-Control') String? cacheControl});

  ///start a backup
  Future<chopper.Response<BackupResponse>> v1BackupStartPost(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        BackupResponse, () => BackupResponse.fromJsonFactory);

    return _v1BackupStartPost(cacheControl: cacheControl);
  }

  ///start a backup
  @Post(
    path: '/v1/backup/start',
    optionalBody: true,
  )
  Future<chopper.Response<BackupResponse>> _v1BackupStartPost(
      {@Header('Cache-Control') String? cacheControl});

  ///restore from a backup file
  Future<chopper.Response<RestoreResponse>> v1BackupRestorePost({
    String? cacheControl,
    required RestoreOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        RestoreResponse, () => RestoreResponse.fromJsonFactory);

    return _v1BackupRestorePost(cacheControl: cacheControl, body: body);
  }

  ///restore from a backup file
  @Post(path: '/v1/backup/restore')
  Future<chopper.Response<RestoreResponse>> _v1BackupRestorePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required RestoreOptions? body,
  });

  ///delete a backup file
  Future<chopper.Response<BackupDeleteResponse>> v1BackupDeleteDelete({
    String? cacheControl,
    required BackupDeleteOptions? body,
  }) {
    generatedMapping.putIfAbsent(
        BackupDeleteResponse, () => BackupDeleteResponse.fromJsonFactory);

    return _v1BackupDeleteDelete(cacheControl: cacheControl, body: body);
  }

  ///delete a backup file
  @Delete(path: '/v1/backup/delete')
  Future<chopper.Response<BackupDeleteResponse>> _v1BackupDeleteDelete({
    @Header('Cache-Control') String? cacheControl,
    @Body() required BackupDeleteOptions? body,
  });

  ///list available backup files
  Future<chopper.Response<List<String>>> v1BackupListGet(
      {String? cacheControl}) {
    return _v1BackupListGet(cacheControl: cacheControl);
  }

  ///list available backup files
  @Get(path: '/v1/backup/list')
  Future<chopper.Response<List<String>>> _v1BackupListGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Read the configuration and progress of the current root generation attempt.
  Future<chopper.Response<SystemRootkeyStatusResponse>>
      v1SystemGenerateRootAttemptGet({String? cacheControl}) {
    generatedMapping.putIfAbsent(SystemRootkeyStatusResponse,
        () => SystemRootkeyStatusResponse.fromJsonFactory);

    return _v1SystemGenerateRootAttemptGet(cacheControl: cacheControl);
  }

  ///Read the configuration and progress of the current root generation attempt.
  @Get(path: '/v1/system/generate-root/attempt')
  Future<chopper.Response<SystemRootkeyStatusResponse>>
      _v1SystemGenerateRootAttemptGet(
          {@Header('Cache-Control') String? cacheControl});

  ///Initializes a new root generation attempt.
  Future<chopper.Response<SystemRootkeyStartResponse>>
      v1SystemGenerateRootAttemptPost({
    String? cacheControl,
    required SystemRootkeyStartOptions? body,
  }) {
    generatedMapping.putIfAbsent(SystemRootkeyStartResponse,
        () => SystemRootkeyStartResponse.fromJsonFactory);

    return _v1SystemGenerateRootAttemptPost(
        cacheControl: cacheControl, body: body);
  }

  ///Initializes a new root generation attempt.
  @Post(path: '/v1/system/generate-root/attempt')
  Future<chopper.Response<SystemRootkeyStartResponse>>
      _v1SystemGenerateRootAttemptPost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SystemRootkeyStartOptions? body,
  });

  ///Cancels any in-progress root generation attempt.
  Future<chopper.Response<SystemRootkeyCancelResponse>>
      v1SystemGenerateRootAttemptDelete({String? cacheControl}) {
    generatedMapping.putIfAbsent(SystemRootkeyCancelResponse,
        () => SystemRootkeyCancelResponse.fromJsonFactory);

    return _v1SystemGenerateRootAttemptDelete(cacheControl: cacheControl);
  }

  ///Cancels any in-progress root generation attempt.
  @Delete(path: '/v1/system/generate-root/attempt')
  Future<chopper.Response<SystemRootkeyCancelResponse>>
      _v1SystemGenerateRootAttemptDelete(
          {@Header('Cache-Control') String? cacheControl});

  ///decode the rootkey
  Future<chopper.Response<SystemRootkeyDecodeResponse>>
      v1SystemGenerateRootDecodePost({
    String? cacheControl,
    required SystemRootkeyDecodeOptions? body,
  }) {
    generatedMapping.putIfAbsent(SystemRootkeyDecodeResponse,
        () => SystemRootkeyDecodeResponse.fromJsonFactory);

    return _v1SystemGenerateRootDecodePost(
        cacheControl: cacheControl, body: body);
  }

  ///decode the rootkey
  @Post(path: '/v1/system/generate-root/decode')
  Future<chopper.Response<SystemRootkeyDecodeResponse>>
      _v1SystemGenerateRootDecodePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SystemRootkeyDecodeOptions? body,
  });

  ///Enter a single master key share to progress the root generation attempt.
  Future<chopper.Response<SystemRootkeySubmitResponse>>
      v1SystemGenerateRootUpdatePost({
    String? cacheControl,
    required SystemRootkeySubmitOptions? body,
  }) {
    generatedMapping.putIfAbsent(SystemRootkeySubmitResponse,
        () => SystemRootkeySubmitResponse.fromJsonFactory);

    return _v1SystemGenerateRootUpdatePost(
        cacheControl: cacheControl, body: body);
  }

  ///Enter a single master key share to progress the root generation attempt.
  @Post(path: '/v1/system/generate-root/update')
  Future<chopper.Response<SystemRootkeySubmitResponse>>
      _v1SystemGenerateRootUpdatePost({
    @Header('Cache-Control') String? cacheControl,
    @Body() required SystemRootkeySubmitOptions? body,
  });

  ///retrieve a list of available images
  Future<chopper.Response<List<String>>> v1ImagesGet({String? cacheControl}) {
    return _v1ImagesGet(cacheControl: cacheControl);
  }

  ///retrieve a list of available images
  @Get(path: '/v1/images')
  Future<chopper.Response<List<String>>> _v1ImagesGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class TokenIssueOptions {
  TokenIssueOptions({
    this.roleName,
    this.policies,
    this.meta,
    this.noParent,
    this.noDefaultPolicy,
    this.renewable,
    this.lease,
    this.ttl,
    this.type,
    this.explicitMaxTtl,
    this.displayName,
    this.numUses,
    this.period,
    this.entityAlias,
  });

  factory TokenIssueOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenIssueOptionsFromJson(json);

  @JsonKey(name: 'roleName', includeIfNull: false, defaultValue: '')
  final String? roleName;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? policies;
  @JsonKey(name: 'meta', includeIfNull: false)
  final Object? meta;
  @JsonKey(name: 'noParent', includeIfNull: false)
  final bool? noParent;
  @JsonKey(name: 'noDefaultPolicy', includeIfNull: false)
  final bool? noDefaultPolicy;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool? renewable;
  @JsonKey(name: 'lease', includeIfNull: false, defaultValue: '')
  final String? lease;
  @JsonKey(name: 'ttl', includeIfNull: false, defaultValue: '')
  final String? ttl;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'explicitMaxTtl', includeIfNull: false, defaultValue: '')
  final String? explicitMaxTtl;
  @JsonKey(name: 'displayName', includeIfNull: false, defaultValue: '')
  final String? displayName;
  @JsonKey(name: 'numUses', includeIfNull: false)
  final double? numUses;
  @JsonKey(name: 'period', includeIfNull: false, defaultValue: '')
  final String? period;
  @JsonKey(name: 'entityAlias', includeIfNull: false, defaultValue: '')
  final String? entityAlias;
  static const fromJsonFactory = _$TokenIssueOptionsFromJson;
  static const toJsonFactory = _$TokenIssueOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenIssueOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenIssueOptions &&
            (identical(other.roleName, roleName) ||
                const DeepCollectionEquality()
                    .equals(other.roleName, roleName)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)) &&
            (identical(other.noParent, noParent) ||
                const DeepCollectionEquality()
                    .equals(other.noParent, noParent)) &&
            (identical(other.noDefaultPolicy, noDefaultPolicy) ||
                const DeepCollectionEquality()
                    .equals(other.noDefaultPolicy, noDefaultPolicy)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.lease, lease) ||
                const DeepCollectionEquality().equals(other.lease, lease)) &&
            (identical(other.ttl, ttl) ||
                const DeepCollectionEquality().equals(other.ttl, ttl)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.explicitMaxTtl, explicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.explicitMaxTtl, explicitMaxTtl)) &&
            (identical(other.displayName, displayName) ||
                const DeepCollectionEquality()
                    .equals(other.displayName, displayName)) &&
            (identical(other.numUses, numUses) ||
                const DeepCollectionEquality()
                    .equals(other.numUses, numUses)) &&
            (identical(other.period, period) ||
                const DeepCollectionEquality().equals(other.period, period)) &&
            (identical(other.entityAlias, entityAlias) ||
                const DeepCollectionEquality()
                    .equals(other.entityAlias, entityAlias)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(roleName) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(meta) ^
      const DeepCollectionEquality().hash(noParent) ^
      const DeepCollectionEquality().hash(noDefaultPolicy) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(lease) ^
      const DeepCollectionEquality().hash(ttl) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(explicitMaxTtl) ^
      const DeepCollectionEquality().hash(displayName) ^
      const DeepCollectionEquality().hash(numUses) ^
      const DeepCollectionEquality().hash(period) ^
      const DeepCollectionEquality().hash(entityAlias) ^
      runtimeType.hashCode;
}

extension $TokenIssueOptionsExtension on TokenIssueOptions {
  TokenIssueOptions copyWith(
      {String? roleName,
      List<String>? policies,
      Object? meta,
      bool? noParent,
      bool? noDefaultPolicy,
      bool? renewable,
      String? lease,
      String? ttl,
      String? type,
      String? explicitMaxTtl,
      String? displayName,
      double? numUses,
      String? period,
      String? entityAlias}) {
    return TokenIssueOptions(
        roleName: roleName ?? this.roleName,
        policies: policies ?? this.policies,
        meta: meta ?? this.meta,
        noParent: noParent ?? this.noParent,
        noDefaultPolicy: noDefaultPolicy ?? this.noDefaultPolicy,
        renewable: renewable ?? this.renewable,
        lease: lease ?? this.lease,
        ttl: ttl ?? this.ttl,
        type: type ?? this.type,
        explicitMaxTtl: explicitMaxTtl ?? this.explicitMaxTtl,
        displayName: displayName ?? this.displayName,
        numUses: numUses ?? this.numUses,
        period: period ?? this.period,
        entityAlias: entityAlias ?? this.entityAlias);
  }

  TokenIssueOptions copyWithWrapped(
      {Wrapped<String?>? roleName,
      Wrapped<List<String>?>? policies,
      Wrapped<Object?>? meta,
      Wrapped<bool?>? noParent,
      Wrapped<bool?>? noDefaultPolicy,
      Wrapped<bool?>? renewable,
      Wrapped<String?>? lease,
      Wrapped<String?>? ttl,
      Wrapped<String?>? type,
      Wrapped<String?>? explicitMaxTtl,
      Wrapped<String?>? displayName,
      Wrapped<double?>? numUses,
      Wrapped<String?>? period,
      Wrapped<String?>? entityAlias}) {
    return TokenIssueOptions(
        roleName: (roleName != null ? roleName.value : this.roleName),
        policies: (policies != null ? policies.value : this.policies),
        meta: (meta != null ? meta.value : this.meta),
        noParent: (noParent != null ? noParent.value : this.noParent),
        noDefaultPolicy: (noDefaultPolicy != null
            ? noDefaultPolicy.value
            : this.noDefaultPolicy),
        renewable: (renewable != null ? renewable.value : this.renewable),
        lease: (lease != null ? lease.value : this.lease),
        ttl: (ttl != null ? ttl.value : this.ttl),
        type: (type != null ? type.value : this.type),
        explicitMaxTtl: (explicitMaxTtl != null
            ? explicitMaxTtl.value
            : this.explicitMaxTtl),
        displayName:
            (displayName != null ? displayName.value : this.displayName),
        numUses: (numUses != null ? numUses.value : this.numUses),
        period: (period != null ? period.value : this.period),
        entityAlias:
            (entityAlias != null ? entityAlias.value : this.entityAlias));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenIssueResponse {
  TokenIssueResponse({
    required this.clientToken,
    required this.accessor,
    required this.policies,
    required this.tokenPolicies,
    required this.identitytokenPolicies,
    required this.metadata,
    required this.leaseDuration,
    required this.renewable,
    required this.entityId,
    required this.tokenType,
    required this.orphan,
  });

  factory TokenIssueResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenIssueResponseFromJson(json);

  @JsonKey(name: 'clientToken', includeIfNull: false, defaultValue: '')
  final String clientToken;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String> policies;
  @JsonKey(
      name: 'tokenPolicies', includeIfNull: false, defaultValue: <String>[])
  final List<String> tokenPolicies;
  @JsonKey(
      name: 'identitytokenPolicies',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String> identitytokenPolicies;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  @JsonKey(name: 'leaseDuration', includeIfNull: false)
  final double leaseDuration;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool renewable;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String entityId;
  @JsonKey(name: 'tokenType', includeIfNull: false, defaultValue: '')
  final String tokenType;
  @JsonKey(name: 'orphan', includeIfNull: false)
  final bool orphan;
  static const fromJsonFactory = _$TokenIssueResponseFromJson;
  static const toJsonFactory = _$TokenIssueResponseToJson;
  Map<String, dynamic> toJson() => _$TokenIssueResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenIssueResponse &&
            (identical(other.clientToken, clientToken) ||
                const DeepCollectionEquality()
                    .equals(other.clientToken, clientToken)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.identitytokenPolicies, identitytokenPolicies) ||
                const DeepCollectionEquality().equals(
                    other.identitytokenPolicies, identitytokenPolicies)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.leaseDuration, leaseDuration) ||
                const DeepCollectionEquality()
                    .equals(other.leaseDuration, leaseDuration)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.tokenType, tokenType) ||
                const DeepCollectionEquality()
                    .equals(other.tokenType, tokenType)) &&
            (identical(other.orphan, orphan) ||
                const DeepCollectionEquality().equals(other.orphan, orphan)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientToken) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(identitytokenPolicies) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(leaseDuration) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(orphan) ^
      runtimeType.hashCode;
}

extension $TokenIssueResponseExtension on TokenIssueResponse {
  TokenIssueResponse copyWith(
      {String? clientToken,
      String? accessor,
      List<String>? policies,
      List<String>? tokenPolicies,
      List<String>? identitytokenPolicies,
      Object? metadata,
      double? leaseDuration,
      bool? renewable,
      String? entityId,
      String? tokenType,
      bool? orphan}) {
    return TokenIssueResponse(
        clientToken: clientToken ?? this.clientToken,
        accessor: accessor ?? this.accessor,
        policies: policies ?? this.policies,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        identitytokenPolicies:
            identitytokenPolicies ?? this.identitytokenPolicies,
        metadata: metadata ?? this.metadata,
        leaseDuration: leaseDuration ?? this.leaseDuration,
        renewable: renewable ?? this.renewable,
        entityId: entityId ?? this.entityId,
        tokenType: tokenType ?? this.tokenType,
        orphan: orphan ?? this.orphan);
  }

  TokenIssueResponse copyWithWrapped(
      {Wrapped<String>? clientToken,
      Wrapped<String>? accessor,
      Wrapped<List<String>>? policies,
      Wrapped<List<String>>? tokenPolicies,
      Wrapped<List<String>>? identitytokenPolicies,
      Wrapped<Object>? metadata,
      Wrapped<double>? leaseDuration,
      Wrapped<bool>? renewable,
      Wrapped<String>? entityId,
      Wrapped<String>? tokenType,
      Wrapped<bool>? orphan}) {
    return TokenIssueResponse(
        clientToken:
            (clientToken != null ? clientToken.value : this.clientToken),
        accessor: (accessor != null ? accessor.value : this.accessor),
        policies: (policies != null ? policies.value : this.policies),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        identitytokenPolicies: (identitytokenPolicies != null
            ? identitytokenPolicies.value
            : this.identitytokenPolicies),
        metadata: (metadata != null ? metadata.value : this.metadata),
        leaseDuration:
            (leaseDuration != null ? leaseDuration.value : this.leaseDuration),
        renewable: (renewable != null ? renewable.value : this.renewable),
        entityId: (entityId != null ? entityId.value : this.entityId),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        orphan: (orphan != null ? orphan.value : this.orphan));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenLookupSelfResponse {
  TokenLookupSelfResponse({
    this.accessor,
    this.creationTime,
    this.creationTtl,
    this.displayName,
    this.entityId,
    this.expireTime,
    this.explicitMaxTtl,
    this.externalTenantPolicies,
    this.id,
    this.identityPolicies,
    this.issueTime,
    this.lastRenewal,
    this.lastRenewalTime,
    this.meta,
    this.numUses,
    this.orphan,
    this.path,
    this.policies,
    this.renewable,
    this.ttl,
    this.type,
  });

  factory TokenLookupSelfResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenLookupSelfResponseFromJson(json);

  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String? accessor;
  @JsonKey(name: 'creationTime', includeIfNull: false, defaultValue: '')
  final String? creationTime;
  @JsonKey(name: 'creationTtl', includeIfNull: false, defaultValue: '')
  final String? creationTtl;
  @JsonKey(name: 'displayName', includeIfNull: false, defaultValue: '')
  final String? displayName;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String? entityId;
  @JsonKey(name: 'expireTime', includeIfNull: false, defaultValue: '')
  final String? expireTime;
  @JsonKey(name: 'explicitMaxTtl', includeIfNull: false)
  final double? explicitMaxTtl;
  @JsonKey(name: 'externalTenantPolicies', includeIfNull: false)
  final Object? externalTenantPolicies;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
      name: 'identityPolicies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? identityPolicies;
  @JsonKey(name: 'issueTime', includeIfNull: false, defaultValue: '')
  final String? issueTime;
  @JsonKey(name: 'lastRenewal', includeIfNull: false, defaultValue: '')
  final String? lastRenewal;
  @JsonKey(name: 'lastRenewalTime', includeIfNull: false)
  final double? lastRenewalTime;
  @JsonKey(name: 'meta', includeIfNull: false)
  final Object? meta;
  @JsonKey(name: 'numUses', includeIfNull: false)
  final double? numUses;
  @JsonKey(name: 'orphan', includeIfNull: false)
  final bool? orphan;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String? path;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? policies;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool? renewable;
  @JsonKey(name: 'ttl', includeIfNull: false)
  final double? ttl;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  static const fromJsonFactory = _$TokenLookupSelfResponseFromJson;
  static const toJsonFactory = _$TokenLookupSelfResponseToJson;
  Map<String, dynamic> toJson() => _$TokenLookupSelfResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenLookupSelfResponse &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.creationTtl, creationTtl) ||
                const DeepCollectionEquality()
                    .equals(other.creationTtl, creationTtl)) &&
            (identical(other.displayName, displayName) ||
                const DeepCollectionEquality()
                    .equals(other.displayName, displayName)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.expireTime, expireTime) ||
                const DeepCollectionEquality()
                    .equals(other.expireTime, expireTime)) &&
            (identical(other.explicitMaxTtl, explicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.explicitMaxTtl, explicitMaxTtl)) &&
            (identical(other.externalTenantPolicies, externalTenantPolicies) ||
                const DeepCollectionEquality().equals(
                    other.externalTenantPolicies, externalTenantPolicies)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.identityPolicies, identityPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.identityPolicies, identityPolicies)) &&
            (identical(other.issueTime, issueTime) ||
                const DeepCollectionEquality()
                    .equals(other.issueTime, issueTime)) &&
            (identical(other.lastRenewal, lastRenewal) ||
                const DeepCollectionEquality()
                    .equals(other.lastRenewal, lastRenewal)) &&
            (identical(other.lastRenewalTime, lastRenewalTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastRenewalTime, lastRenewalTime)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)) &&
            (identical(other.numUses, numUses) ||
                const DeepCollectionEquality()
                    .equals(other.numUses, numUses)) &&
            (identical(other.orphan, orphan) ||
                const DeepCollectionEquality().equals(other.orphan, orphan)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.ttl, ttl) ||
                const DeepCollectionEquality().equals(other.ttl, ttl)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(creationTtl) ^
      const DeepCollectionEquality().hash(displayName) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(expireTime) ^
      const DeepCollectionEquality().hash(explicitMaxTtl) ^
      const DeepCollectionEquality().hash(externalTenantPolicies) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(identityPolicies) ^
      const DeepCollectionEquality().hash(issueTime) ^
      const DeepCollectionEquality().hash(lastRenewal) ^
      const DeepCollectionEquality().hash(lastRenewalTime) ^
      const DeepCollectionEquality().hash(meta) ^
      const DeepCollectionEquality().hash(numUses) ^
      const DeepCollectionEquality().hash(orphan) ^
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(ttl) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $TokenLookupSelfResponseExtension on TokenLookupSelfResponse {
  TokenLookupSelfResponse copyWith(
      {String? accessor,
      String? creationTime,
      String? creationTtl,
      String? displayName,
      String? entityId,
      String? expireTime,
      double? explicitMaxTtl,
      Object? externalTenantPolicies,
      String? id,
      List<String>? identityPolicies,
      String? issueTime,
      String? lastRenewal,
      double? lastRenewalTime,
      Object? meta,
      double? numUses,
      bool? orphan,
      String? path,
      List<String>? policies,
      bool? renewable,
      double? ttl,
      String? type}) {
    return TokenLookupSelfResponse(
        accessor: accessor ?? this.accessor,
        creationTime: creationTime ?? this.creationTime,
        creationTtl: creationTtl ?? this.creationTtl,
        displayName: displayName ?? this.displayName,
        entityId: entityId ?? this.entityId,
        expireTime: expireTime ?? this.expireTime,
        explicitMaxTtl: explicitMaxTtl ?? this.explicitMaxTtl,
        externalTenantPolicies:
            externalTenantPolicies ?? this.externalTenantPolicies,
        id: id ?? this.id,
        identityPolicies: identityPolicies ?? this.identityPolicies,
        issueTime: issueTime ?? this.issueTime,
        lastRenewal: lastRenewal ?? this.lastRenewal,
        lastRenewalTime: lastRenewalTime ?? this.lastRenewalTime,
        meta: meta ?? this.meta,
        numUses: numUses ?? this.numUses,
        orphan: orphan ?? this.orphan,
        path: path ?? this.path,
        policies: policies ?? this.policies,
        renewable: renewable ?? this.renewable,
        ttl: ttl ?? this.ttl,
        type: type ?? this.type);
  }

  TokenLookupSelfResponse copyWithWrapped(
      {Wrapped<String?>? accessor,
      Wrapped<String?>? creationTime,
      Wrapped<String?>? creationTtl,
      Wrapped<String?>? displayName,
      Wrapped<String?>? entityId,
      Wrapped<String?>? expireTime,
      Wrapped<double?>? explicitMaxTtl,
      Wrapped<Object?>? externalTenantPolicies,
      Wrapped<String?>? id,
      Wrapped<List<String>?>? identityPolicies,
      Wrapped<String?>? issueTime,
      Wrapped<String?>? lastRenewal,
      Wrapped<double?>? lastRenewalTime,
      Wrapped<Object?>? meta,
      Wrapped<double?>? numUses,
      Wrapped<bool?>? orphan,
      Wrapped<String?>? path,
      Wrapped<List<String>?>? policies,
      Wrapped<bool?>? renewable,
      Wrapped<double?>? ttl,
      Wrapped<String?>? type}) {
    return TokenLookupSelfResponse(
        accessor: (accessor != null ? accessor.value : this.accessor),
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        creationTtl:
            (creationTtl != null ? creationTtl.value : this.creationTtl),
        displayName:
            (displayName != null ? displayName.value : this.displayName),
        entityId: (entityId != null ? entityId.value : this.entityId),
        expireTime: (expireTime != null ? expireTime.value : this.expireTime),
        explicitMaxTtl: (explicitMaxTtl != null
            ? explicitMaxTtl.value
            : this.explicitMaxTtl),
        externalTenantPolicies: (externalTenantPolicies != null
            ? externalTenantPolicies.value
            : this.externalTenantPolicies),
        id: (id != null ? id.value : this.id),
        identityPolicies: (identityPolicies != null
            ? identityPolicies.value
            : this.identityPolicies),
        issueTime: (issueTime != null ? issueTime.value : this.issueTime),
        lastRenewal:
            (lastRenewal != null ? lastRenewal.value : this.lastRenewal),
        lastRenewalTime: (lastRenewalTime != null
            ? lastRenewalTime.value
            : this.lastRenewalTime),
        meta: (meta != null ? meta.value : this.meta),
        numUses: (numUses != null ? numUses.value : this.numUses),
        orphan: (orphan != null ? orphan.value : this.orphan),
        path: (path != null ? path.value : this.path),
        policies: (policies != null ? policies.value : this.policies),
        renewable: (renewable != null ? renewable.value : this.renewable),
        ttl: (ttl != null ? ttl.value : this.ttl),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenLookupOptions {
  TokenLookupOptions({
    this.token,
  });

  factory TokenLookupOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenLookupOptionsFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenLookupOptionsFromJson;
  static const toJsonFactory = _$TokenLookupOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenLookupOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenLookupOptions &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^ runtimeType.hashCode;
}

extension $TokenLookupOptionsExtension on TokenLookupOptions {
  TokenLookupOptions copyWith({String? token}) {
    return TokenLookupOptions(token: token ?? this.token);
  }

  TokenLookupOptions copyWithWrapped({Wrapped<String?>? token}) {
    return TokenLookupOptions(
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenLookupResponse {
  TokenLookupResponse({
    this.accessor,
    this.creationTime,
    this.creationTtl,
    this.displayName,
    this.entityId,
    this.expireTime,
    this.explicitMaxTtl,
    this.externalTenantPolicies,
    this.id,
    this.identityPolicies,
    this.issueTime,
    this.lastRenewal,
    this.lastRenewalTime,
    this.meta,
    this.numUses,
    this.orphan,
    this.path,
    this.policies,
    this.renewable,
    this.ttl,
    this.type,
  });

  factory TokenLookupResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenLookupResponseFromJson(json);

  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String? accessor;
  @JsonKey(name: 'creationTime', includeIfNull: false, defaultValue: '')
  final String? creationTime;
  @JsonKey(name: 'creationTtl', includeIfNull: false, defaultValue: '')
  final String? creationTtl;
  @JsonKey(name: 'displayName', includeIfNull: false, defaultValue: '')
  final String? displayName;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String? entityId;
  @JsonKey(name: 'expireTime', includeIfNull: false, defaultValue: '')
  final String? expireTime;
  @JsonKey(name: 'explicitMaxTtl', includeIfNull: false)
  final double? explicitMaxTtl;
  @JsonKey(name: 'externalTenantPolicies', includeIfNull: false)
  final Object? externalTenantPolicies;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
      name: 'identityPolicies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? identityPolicies;
  @JsonKey(name: 'issueTime', includeIfNull: false, defaultValue: '')
  final String? issueTime;
  @JsonKey(name: 'lastRenewal', includeIfNull: false, defaultValue: '')
  final String? lastRenewal;
  @JsonKey(name: 'lastRenewalTime', includeIfNull: false)
  final double? lastRenewalTime;
  @JsonKey(name: 'meta', includeIfNull: false)
  final Object? meta;
  @JsonKey(name: 'numUses', includeIfNull: false)
  final double? numUses;
  @JsonKey(name: 'orphan', includeIfNull: false)
  final bool? orphan;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String? path;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? policies;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool? renewable;
  @JsonKey(name: 'ttl', includeIfNull: false)
  final double? ttl;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  static const fromJsonFactory = _$TokenLookupResponseFromJson;
  static const toJsonFactory = _$TokenLookupResponseToJson;
  Map<String, dynamic> toJson() => _$TokenLookupResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenLookupResponse &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.creationTtl, creationTtl) ||
                const DeepCollectionEquality()
                    .equals(other.creationTtl, creationTtl)) &&
            (identical(other.displayName, displayName) ||
                const DeepCollectionEquality()
                    .equals(other.displayName, displayName)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.expireTime, expireTime) ||
                const DeepCollectionEquality()
                    .equals(other.expireTime, expireTime)) &&
            (identical(other.explicitMaxTtl, explicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.explicitMaxTtl, explicitMaxTtl)) &&
            (identical(other.externalTenantPolicies, externalTenantPolicies) ||
                const DeepCollectionEquality().equals(
                    other.externalTenantPolicies, externalTenantPolicies)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.identityPolicies, identityPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.identityPolicies, identityPolicies)) &&
            (identical(other.issueTime, issueTime) ||
                const DeepCollectionEquality()
                    .equals(other.issueTime, issueTime)) &&
            (identical(other.lastRenewal, lastRenewal) ||
                const DeepCollectionEquality()
                    .equals(other.lastRenewal, lastRenewal)) &&
            (identical(other.lastRenewalTime, lastRenewalTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastRenewalTime, lastRenewalTime)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)) &&
            (identical(other.numUses, numUses) ||
                const DeepCollectionEquality()
                    .equals(other.numUses, numUses)) &&
            (identical(other.orphan, orphan) ||
                const DeepCollectionEquality().equals(other.orphan, orphan)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.ttl, ttl) ||
                const DeepCollectionEquality().equals(other.ttl, ttl)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(creationTtl) ^
      const DeepCollectionEquality().hash(displayName) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(expireTime) ^
      const DeepCollectionEquality().hash(explicitMaxTtl) ^
      const DeepCollectionEquality().hash(externalTenantPolicies) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(identityPolicies) ^
      const DeepCollectionEquality().hash(issueTime) ^
      const DeepCollectionEquality().hash(lastRenewal) ^
      const DeepCollectionEquality().hash(lastRenewalTime) ^
      const DeepCollectionEquality().hash(meta) ^
      const DeepCollectionEquality().hash(numUses) ^
      const DeepCollectionEquality().hash(orphan) ^
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(ttl) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $TokenLookupResponseExtension on TokenLookupResponse {
  TokenLookupResponse copyWith(
      {String? accessor,
      String? creationTime,
      String? creationTtl,
      String? displayName,
      String? entityId,
      String? expireTime,
      double? explicitMaxTtl,
      Object? externalTenantPolicies,
      String? id,
      List<String>? identityPolicies,
      String? issueTime,
      String? lastRenewal,
      double? lastRenewalTime,
      Object? meta,
      double? numUses,
      bool? orphan,
      String? path,
      List<String>? policies,
      bool? renewable,
      double? ttl,
      String? type}) {
    return TokenLookupResponse(
        accessor: accessor ?? this.accessor,
        creationTime: creationTime ?? this.creationTime,
        creationTtl: creationTtl ?? this.creationTtl,
        displayName: displayName ?? this.displayName,
        entityId: entityId ?? this.entityId,
        expireTime: expireTime ?? this.expireTime,
        explicitMaxTtl: explicitMaxTtl ?? this.explicitMaxTtl,
        externalTenantPolicies:
            externalTenantPolicies ?? this.externalTenantPolicies,
        id: id ?? this.id,
        identityPolicies: identityPolicies ?? this.identityPolicies,
        issueTime: issueTime ?? this.issueTime,
        lastRenewal: lastRenewal ?? this.lastRenewal,
        lastRenewalTime: lastRenewalTime ?? this.lastRenewalTime,
        meta: meta ?? this.meta,
        numUses: numUses ?? this.numUses,
        orphan: orphan ?? this.orphan,
        path: path ?? this.path,
        policies: policies ?? this.policies,
        renewable: renewable ?? this.renewable,
        ttl: ttl ?? this.ttl,
        type: type ?? this.type);
  }

  TokenLookupResponse copyWithWrapped(
      {Wrapped<String?>? accessor,
      Wrapped<String?>? creationTime,
      Wrapped<String?>? creationTtl,
      Wrapped<String?>? displayName,
      Wrapped<String?>? entityId,
      Wrapped<String?>? expireTime,
      Wrapped<double?>? explicitMaxTtl,
      Wrapped<Object?>? externalTenantPolicies,
      Wrapped<String?>? id,
      Wrapped<List<String>?>? identityPolicies,
      Wrapped<String?>? issueTime,
      Wrapped<String?>? lastRenewal,
      Wrapped<double?>? lastRenewalTime,
      Wrapped<Object?>? meta,
      Wrapped<double?>? numUses,
      Wrapped<bool?>? orphan,
      Wrapped<String?>? path,
      Wrapped<List<String>?>? policies,
      Wrapped<bool?>? renewable,
      Wrapped<double?>? ttl,
      Wrapped<String?>? type}) {
    return TokenLookupResponse(
        accessor: (accessor != null ? accessor.value : this.accessor),
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        creationTtl:
            (creationTtl != null ? creationTtl.value : this.creationTtl),
        displayName:
            (displayName != null ? displayName.value : this.displayName),
        entityId: (entityId != null ? entityId.value : this.entityId),
        expireTime: (expireTime != null ? expireTime.value : this.expireTime),
        explicitMaxTtl: (explicitMaxTtl != null
            ? explicitMaxTtl.value
            : this.explicitMaxTtl),
        externalTenantPolicies: (externalTenantPolicies != null
            ? externalTenantPolicies.value
            : this.externalTenantPolicies),
        id: (id != null ? id.value : this.id),
        identityPolicies: (identityPolicies != null
            ? identityPolicies.value
            : this.identityPolicies),
        issueTime: (issueTime != null ? issueTime.value : this.issueTime),
        lastRenewal:
            (lastRenewal != null ? lastRenewal.value : this.lastRenewal),
        lastRenewalTime: (lastRenewalTime != null
            ? lastRenewalTime.value
            : this.lastRenewalTime),
        meta: (meta != null ? meta.value : this.meta),
        numUses: (numUses != null ? numUses.value : this.numUses),
        orphan: (orphan != null ? orphan.value : this.orphan),
        path: (path != null ? path.value : this.path),
        policies: (policies != null ? policies.value : this.policies),
        renewable: (renewable != null ? renewable.value : this.renewable),
        ttl: (ttl != null ? ttl.value : this.ttl),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenRenewOptions {
  TokenRenewOptions({
    this.increment,
    this.token,
  });

  factory TokenRenewOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenRenewOptionsFromJson(json);

  @JsonKey(name: 'increment', includeIfNull: false)
  final double? increment;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenRenewOptionsFromJson;
  static const toJsonFactory = _$TokenRenewOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenRenewOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenRenewOptions &&
            (identical(other.increment, increment) ||
                const DeepCollectionEquality()
                    .equals(other.increment, increment)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(increment) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $TokenRenewOptionsExtension on TokenRenewOptions {
  TokenRenewOptions copyWith({double? increment, String? token}) {
    return TokenRenewOptions(
        increment: increment ?? this.increment, token: token ?? this.token);
  }

  TokenRenewOptions copyWithWrapped(
      {Wrapped<double?>? increment, Wrapped<String?>? token}) {
    return TokenRenewOptions(
        increment: (increment != null ? increment.value : this.increment),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenRenewResponse {
  TokenRenewResponse({
    required this.clientToken,
    required this.accessor,
    required this.policies,
    required this.tokenPolicies,
    required this.identitytokenPolicies,
    required this.metadata,
    required this.leaseDuration,
    required this.renewable,
    required this.entityId,
    required this.tokenType,
    required this.orphan,
  });

  factory TokenRenewResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenRenewResponseFromJson(json);

  @JsonKey(name: 'clientToken', includeIfNull: false, defaultValue: '')
  final String clientToken;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String> policies;
  @JsonKey(
      name: 'tokenPolicies', includeIfNull: false, defaultValue: <String>[])
  final List<String> tokenPolicies;
  @JsonKey(
      name: 'identitytokenPolicies',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String> identitytokenPolicies;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  @JsonKey(name: 'leaseDuration', includeIfNull: false)
  final double leaseDuration;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool renewable;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String entityId;
  @JsonKey(name: 'tokenType', includeIfNull: false, defaultValue: '')
  final String tokenType;
  @JsonKey(name: 'orphan', includeIfNull: false)
  final bool orphan;
  static const fromJsonFactory = _$TokenRenewResponseFromJson;
  static const toJsonFactory = _$TokenRenewResponseToJson;
  Map<String, dynamic> toJson() => _$TokenRenewResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenRenewResponse &&
            (identical(other.clientToken, clientToken) ||
                const DeepCollectionEquality()
                    .equals(other.clientToken, clientToken)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.identitytokenPolicies, identitytokenPolicies) ||
                const DeepCollectionEquality().equals(
                    other.identitytokenPolicies, identitytokenPolicies)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.leaseDuration, leaseDuration) ||
                const DeepCollectionEquality()
                    .equals(other.leaseDuration, leaseDuration)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.tokenType, tokenType) ||
                const DeepCollectionEquality()
                    .equals(other.tokenType, tokenType)) &&
            (identical(other.orphan, orphan) ||
                const DeepCollectionEquality().equals(other.orphan, orphan)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientToken) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(identitytokenPolicies) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(leaseDuration) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(orphan) ^
      runtimeType.hashCode;
}

extension $TokenRenewResponseExtension on TokenRenewResponse {
  TokenRenewResponse copyWith(
      {String? clientToken,
      String? accessor,
      List<String>? policies,
      List<String>? tokenPolicies,
      List<String>? identitytokenPolicies,
      Object? metadata,
      double? leaseDuration,
      bool? renewable,
      String? entityId,
      String? tokenType,
      bool? orphan}) {
    return TokenRenewResponse(
        clientToken: clientToken ?? this.clientToken,
        accessor: accessor ?? this.accessor,
        policies: policies ?? this.policies,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        identitytokenPolicies:
            identitytokenPolicies ?? this.identitytokenPolicies,
        metadata: metadata ?? this.metadata,
        leaseDuration: leaseDuration ?? this.leaseDuration,
        renewable: renewable ?? this.renewable,
        entityId: entityId ?? this.entityId,
        tokenType: tokenType ?? this.tokenType,
        orphan: orphan ?? this.orphan);
  }

  TokenRenewResponse copyWithWrapped(
      {Wrapped<String>? clientToken,
      Wrapped<String>? accessor,
      Wrapped<List<String>>? policies,
      Wrapped<List<String>>? tokenPolicies,
      Wrapped<List<String>>? identitytokenPolicies,
      Wrapped<Object>? metadata,
      Wrapped<double>? leaseDuration,
      Wrapped<bool>? renewable,
      Wrapped<String>? entityId,
      Wrapped<String>? tokenType,
      Wrapped<bool>? orphan}) {
    return TokenRenewResponse(
        clientToken:
            (clientToken != null ? clientToken.value : this.clientToken),
        accessor: (accessor != null ? accessor.value : this.accessor),
        policies: (policies != null ? policies.value : this.policies),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        identitytokenPolicies: (identitytokenPolicies != null
            ? identitytokenPolicies.value
            : this.identitytokenPolicies),
        metadata: (metadata != null ? metadata.value : this.metadata),
        leaseDuration:
            (leaseDuration != null ? leaseDuration.value : this.leaseDuration),
        renewable: (renewable != null ? renewable.value : this.renewable),
        entityId: (entityId != null ? entityId.value : this.entityId),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        orphan: (orphan != null ? orphan.value : this.orphan));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenRenewSelfOptions {
  TokenRenewSelfOptions({
    this.increment,
    this.token,
  });

  factory TokenRenewSelfOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenRenewSelfOptionsFromJson(json);

  @JsonKey(name: 'increment', includeIfNull: false)
  final double? increment;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenRenewSelfOptionsFromJson;
  static const toJsonFactory = _$TokenRenewSelfOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenRenewSelfOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenRenewSelfOptions &&
            (identical(other.increment, increment) ||
                const DeepCollectionEquality()
                    .equals(other.increment, increment)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(increment) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $TokenRenewSelfOptionsExtension on TokenRenewSelfOptions {
  TokenRenewSelfOptions copyWith({double? increment, String? token}) {
    return TokenRenewSelfOptions(
        increment: increment ?? this.increment, token: token ?? this.token);
  }

  TokenRenewSelfOptions copyWithWrapped(
      {Wrapped<double?>? increment, Wrapped<String?>? token}) {
    return TokenRenewSelfOptions(
        increment: (increment != null ? increment.value : this.increment),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenRenewSelfResponse {
  TokenRenewSelfResponse({
    required this.clientToken,
    required this.accessor,
    required this.policies,
    required this.tokenPolicies,
    required this.identitytokenPolicies,
    required this.metadata,
    required this.leaseDuration,
    required this.renewable,
    required this.entityId,
    required this.tokenType,
    required this.orphan,
  });

  factory TokenRenewSelfResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenRenewSelfResponseFromJson(json);

  @JsonKey(name: 'clientToken', includeIfNull: false, defaultValue: '')
  final String clientToken;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String> policies;
  @JsonKey(
      name: 'tokenPolicies', includeIfNull: false, defaultValue: <String>[])
  final List<String> tokenPolicies;
  @JsonKey(
      name: 'identitytokenPolicies',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String> identitytokenPolicies;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  @JsonKey(name: 'leaseDuration', includeIfNull: false)
  final double leaseDuration;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool renewable;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String entityId;
  @JsonKey(name: 'tokenType', includeIfNull: false, defaultValue: '')
  final String tokenType;
  @JsonKey(name: 'orphan', includeIfNull: false)
  final bool orphan;
  static const fromJsonFactory = _$TokenRenewSelfResponseFromJson;
  static const toJsonFactory = _$TokenRenewSelfResponseToJson;
  Map<String, dynamic> toJson() => _$TokenRenewSelfResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenRenewSelfResponse &&
            (identical(other.clientToken, clientToken) ||
                const DeepCollectionEquality()
                    .equals(other.clientToken, clientToken)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.identitytokenPolicies, identitytokenPolicies) ||
                const DeepCollectionEquality().equals(
                    other.identitytokenPolicies, identitytokenPolicies)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.leaseDuration, leaseDuration) ||
                const DeepCollectionEquality()
                    .equals(other.leaseDuration, leaseDuration)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.tokenType, tokenType) ||
                const DeepCollectionEquality()
                    .equals(other.tokenType, tokenType)) &&
            (identical(other.orphan, orphan) ||
                const DeepCollectionEquality().equals(other.orphan, orphan)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientToken) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(identitytokenPolicies) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(leaseDuration) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(orphan) ^
      runtimeType.hashCode;
}

extension $TokenRenewSelfResponseExtension on TokenRenewSelfResponse {
  TokenRenewSelfResponse copyWith(
      {String? clientToken,
      String? accessor,
      List<String>? policies,
      List<String>? tokenPolicies,
      List<String>? identitytokenPolicies,
      Object? metadata,
      double? leaseDuration,
      bool? renewable,
      String? entityId,
      String? tokenType,
      bool? orphan}) {
    return TokenRenewSelfResponse(
        clientToken: clientToken ?? this.clientToken,
        accessor: accessor ?? this.accessor,
        policies: policies ?? this.policies,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        identitytokenPolicies:
            identitytokenPolicies ?? this.identitytokenPolicies,
        metadata: metadata ?? this.metadata,
        leaseDuration: leaseDuration ?? this.leaseDuration,
        renewable: renewable ?? this.renewable,
        entityId: entityId ?? this.entityId,
        tokenType: tokenType ?? this.tokenType,
        orphan: orphan ?? this.orphan);
  }

  TokenRenewSelfResponse copyWithWrapped(
      {Wrapped<String>? clientToken,
      Wrapped<String>? accessor,
      Wrapped<List<String>>? policies,
      Wrapped<List<String>>? tokenPolicies,
      Wrapped<List<String>>? identitytokenPolicies,
      Wrapped<Object>? metadata,
      Wrapped<double>? leaseDuration,
      Wrapped<bool>? renewable,
      Wrapped<String>? entityId,
      Wrapped<String>? tokenType,
      Wrapped<bool>? orphan}) {
    return TokenRenewSelfResponse(
        clientToken:
            (clientToken != null ? clientToken.value : this.clientToken),
        accessor: (accessor != null ? accessor.value : this.accessor),
        policies: (policies != null ? policies.value : this.policies),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        identitytokenPolicies: (identitytokenPolicies != null
            ? identitytokenPolicies.value
            : this.identitytokenPolicies),
        metadata: (metadata != null ? metadata.value : this.metadata),
        leaseDuration:
            (leaseDuration != null ? leaseDuration.value : this.leaseDuration),
        renewable: (renewable != null ? renewable.value : this.renewable),
        entityId: (entityId != null ? entityId.value : this.entityId),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        orphan: (orphan != null ? orphan.value : this.orphan));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenRevokeOptions {
  TokenRevokeOptions({
    this.token,
  });

  factory TokenRevokeOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenRevokeOptionsFromJson(json);

  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenRevokeOptionsFromJson;
  static const toJsonFactory = _$TokenRevokeOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenRevokeOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenRevokeOptions &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(token) ^ runtimeType.hashCode;
}

extension $TokenRevokeOptionsExtension on TokenRevokeOptions {
  TokenRevokeOptions copyWith({String? token}) {
    return TokenRevokeOptions(token: token ?? this.token);
  }

  TokenRevokeOptions copyWithWrapped({Wrapped<String?>? token}) {
    return TokenRevokeOptions(
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenRevokeResponse {
  TokenRevokeResponse();

  factory TokenRevokeResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenRevokeResponseFromJson(json);

  static const fromJsonFactory = _$TokenRevokeResponseFromJson;
  static const toJsonFactory = _$TokenRevokeResponseToJson;
  Map<String, dynamic> toJson() => _$TokenRevokeResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class TokenRevokeSelfResponse {
  TokenRevokeSelfResponse();

  factory TokenRevokeSelfResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenRevokeSelfResponseFromJson(json);

  static const fromJsonFactory = _$TokenRevokeSelfResponseFromJson;
  static const toJsonFactory = _$TokenRevokeSelfResponseToJson;
  Map<String, dynamic> toJson() => _$TokenRevokeSelfResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class TokenCapabilitiesOptions {
  TokenCapabilitiesOptions({
    this.paths,
    this.token,
  });

  factory TokenCapabilitiesOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenCapabilitiesOptionsFromJson(json);

  @JsonKey(name: 'paths', includeIfNull: false, defaultValue: <String>[])
  final List<String>? paths;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenCapabilitiesOptionsFromJson;
  static const toJsonFactory = _$TokenCapabilitiesOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenCapabilitiesOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenCapabilitiesOptions &&
            (identical(other.paths, paths) ||
                const DeepCollectionEquality().equals(other.paths, paths)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(paths) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $TokenCapabilitiesOptionsExtension on TokenCapabilitiesOptions {
  TokenCapabilitiesOptions copyWith({List<String>? paths, String? token}) {
    return TokenCapabilitiesOptions(
        paths: paths ?? this.paths, token: token ?? this.token);
  }

  TokenCapabilitiesOptions copyWithWrapped(
      {Wrapped<List<String>?>? paths, Wrapped<String?>? token}) {
    return TokenCapabilitiesOptions(
        paths: (paths != null ? paths.value : this.paths),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenCapabilitiesResponse {
  TokenCapabilitiesResponse({
    required this.path,
    required this.capabilities,
  });

  factory TokenCapabilitiesResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenCapabilitiesResponseFromJson(json);

  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  @JsonKey(name: 'capabilities', includeIfNull: false, defaultValue: <String>[])
  final List<String> capabilities;
  static const fromJsonFactory = _$TokenCapabilitiesResponseFromJson;
  static const toJsonFactory = _$TokenCapabilitiesResponseToJson;
  Map<String, dynamic> toJson() => _$TokenCapabilitiesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenCapabilitiesResponse &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.capabilities, capabilities) ||
                const DeepCollectionEquality()
                    .equals(other.capabilities, capabilities)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(capabilities) ^
      runtimeType.hashCode;
}

extension $TokenCapabilitiesResponseExtension on TokenCapabilitiesResponse {
  TokenCapabilitiesResponse copyWith(
      {String? path, List<String>? capabilities}) {
    return TokenCapabilitiesResponse(
        path: path ?? this.path,
        capabilities: capabilities ?? this.capabilities);
  }

  TokenCapabilitiesResponse copyWithWrapped(
      {Wrapped<String>? path, Wrapped<List<String>>? capabilities}) {
    return TokenCapabilitiesResponse(
        path: (path != null ? path.value : this.path),
        capabilities:
            (capabilities != null ? capabilities.value : this.capabilities));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenCapabilitiesSelfOptions {
  TokenCapabilitiesSelfOptions({
    this.paths,
    this.token,
  });

  factory TokenCapabilitiesSelfOptions.fromJson(Map<String, dynamic> json) =>
      _$TokenCapabilitiesSelfOptionsFromJson(json);

  @JsonKey(name: 'paths', includeIfNull: false, defaultValue: <String>[])
  final List<String>? paths;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$TokenCapabilitiesSelfOptionsFromJson;
  static const toJsonFactory = _$TokenCapabilitiesSelfOptionsToJson;
  Map<String, dynamic> toJson() => _$TokenCapabilitiesSelfOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenCapabilitiesSelfOptions &&
            (identical(other.paths, paths) ||
                const DeepCollectionEquality().equals(other.paths, paths)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(paths) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $TokenCapabilitiesSelfOptionsExtension
    on TokenCapabilitiesSelfOptions {
  TokenCapabilitiesSelfOptions copyWith({List<String>? paths, String? token}) {
    return TokenCapabilitiesSelfOptions(
        paths: paths ?? this.paths, token: token ?? this.token);
  }

  TokenCapabilitiesSelfOptions copyWithWrapped(
      {Wrapped<List<String>?>? paths, Wrapped<String?>? token}) {
    return TokenCapabilitiesSelfOptions(
        paths: (paths != null ? paths.value : this.paths),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenCapabilitiesSelfResponse {
  TokenCapabilitiesSelfResponse({
    required this.path,
    required this.capabilities,
  });

  factory TokenCapabilitiesSelfResponse.fromJson(Map<String, dynamic> json) =>
      _$TokenCapabilitiesSelfResponseFromJson(json);

  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  @JsonKey(name: 'capabilities', includeIfNull: false, defaultValue: <String>[])
  final List<String> capabilities;
  static const fromJsonFactory = _$TokenCapabilitiesSelfResponseFromJson;
  static const toJsonFactory = _$TokenCapabilitiesSelfResponseToJson;
  Map<String, dynamic> toJson() => _$TokenCapabilitiesSelfResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenCapabilitiesSelfResponse &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.capabilities, capabilities) ||
                const DeepCollectionEquality()
                    .equals(other.capabilities, capabilities)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(capabilities) ^
      runtimeType.hashCode;
}

extension $TokenCapabilitiesSelfResponseExtension
    on TokenCapabilitiesSelfResponse {
  TokenCapabilitiesSelfResponse copyWith(
      {String? path, List<String>? capabilities}) {
    return TokenCapabilitiesSelfResponse(
        path: path ?? this.path,
        capabilities: capabilities ?? this.capabilities);
  }

  TokenCapabilitiesSelfResponse copyWithWrapped(
      {Wrapped<String>? path, Wrapped<List<String>>? capabilities}) {
    return TokenCapabilitiesSelfResponse(
        path: (path != null ? path.value : this.path),
        capabilities:
            (capabilities != null ? capabilities.value : this.capabilities));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsReadConfigResponse {
  SecretsReadConfigResponse({
    required this.maxVersions,
    required this.casRequired,
    required this.deleteVersionAfter,
  });

  factory SecretsReadConfigResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsReadConfigResponseFromJson(json);

  @JsonKey(name: 'maxVersions', includeIfNull: false)
  final double maxVersions;
  @JsonKey(name: 'casRequired', includeIfNull: false)
  final bool casRequired;
  @JsonKey(name: 'deleteVersionAfter', includeIfNull: false, defaultValue: '')
  final String deleteVersionAfter;
  static const fromJsonFactory = _$SecretsReadConfigResponseFromJson;
  static const toJsonFactory = _$SecretsReadConfigResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsReadConfigResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsReadConfigResponse &&
            (identical(other.maxVersions, maxVersions) ||
                const DeepCollectionEquality()
                    .equals(other.maxVersions, maxVersions)) &&
            (identical(other.casRequired, casRequired) ||
                const DeepCollectionEquality()
                    .equals(other.casRequired, casRequired)) &&
            (identical(other.deleteVersionAfter, deleteVersionAfter) ||
                const DeepCollectionEquality()
                    .equals(other.deleteVersionAfter, deleteVersionAfter)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(maxVersions) ^
      const DeepCollectionEquality().hash(casRequired) ^
      const DeepCollectionEquality().hash(deleteVersionAfter) ^
      runtimeType.hashCode;
}

extension $SecretsReadConfigResponseExtension on SecretsReadConfigResponse {
  SecretsReadConfigResponse copyWith(
      {double? maxVersions, bool? casRequired, String? deleteVersionAfter}) {
    return SecretsReadConfigResponse(
        maxVersions: maxVersions ?? this.maxVersions,
        casRequired: casRequired ?? this.casRequired,
        deleteVersionAfter: deleteVersionAfter ?? this.deleteVersionAfter);
  }

  SecretsReadConfigResponse copyWithWrapped(
      {Wrapped<double>? maxVersions,
      Wrapped<bool>? casRequired,
      Wrapped<String>? deleteVersionAfter}) {
    return SecretsReadConfigResponse(
        maxVersions:
            (maxVersions != null ? maxVersions.value : this.maxVersions),
        casRequired:
            (casRequired != null ? casRequired.value : this.casRequired),
        deleteVersionAfter: (deleteVersionAfter != null
            ? deleteVersionAfter.value
            : this.deleteVersionAfter));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsWriteConfigOptions {
  SecretsWriteConfigOptions({
    this.casRequired,
    this.deleteVersionAfter,
    this.maxVersions,
  });

  factory SecretsWriteConfigOptions.fromJson(Map<String, dynamic> json) =>
      _$SecretsWriteConfigOptionsFromJson(json);

  @JsonKey(name: 'casRequired', includeIfNull: false)
  final bool? casRequired;
  @JsonKey(name: 'deleteVersionAfter', includeIfNull: false)
  final double? deleteVersionAfter;
  @JsonKey(name: 'maxVersions', includeIfNull: false)
  final double? maxVersions;
  static const fromJsonFactory = _$SecretsWriteConfigOptionsFromJson;
  static const toJsonFactory = _$SecretsWriteConfigOptionsToJson;
  Map<String, dynamic> toJson() => _$SecretsWriteConfigOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsWriteConfigOptions &&
            (identical(other.casRequired, casRequired) ||
                const DeepCollectionEquality()
                    .equals(other.casRequired, casRequired)) &&
            (identical(other.deleteVersionAfter, deleteVersionAfter) ||
                const DeepCollectionEquality()
                    .equals(other.deleteVersionAfter, deleteVersionAfter)) &&
            (identical(other.maxVersions, maxVersions) ||
                const DeepCollectionEquality()
                    .equals(other.maxVersions, maxVersions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(casRequired) ^
      const DeepCollectionEquality().hash(deleteVersionAfter) ^
      const DeepCollectionEquality().hash(maxVersions) ^
      runtimeType.hashCode;
}

extension $SecretsWriteConfigOptionsExtension on SecretsWriteConfigOptions {
  SecretsWriteConfigOptions copyWith(
      {bool? casRequired, double? deleteVersionAfter, double? maxVersions}) {
    return SecretsWriteConfigOptions(
        casRequired: casRequired ?? this.casRequired,
        deleteVersionAfter: deleteVersionAfter ?? this.deleteVersionAfter,
        maxVersions: maxVersions ?? this.maxVersions);
  }

  SecretsWriteConfigOptions copyWithWrapped(
      {Wrapped<bool?>? casRequired,
      Wrapped<double?>? deleteVersionAfter,
      Wrapped<double?>? maxVersions}) {
    return SecretsWriteConfigOptions(
        casRequired:
            (casRequired != null ? casRequired.value : this.casRequired),
        deleteVersionAfter: (deleteVersionAfter != null
            ? deleteVersionAfter.value
            : this.deleteVersionAfter),
        maxVersions:
            (maxVersions != null ? maxVersions.value : this.maxVersions));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsWriteConfigResponse {
  SecretsWriteConfigResponse();

  factory SecretsWriteConfigResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsWriteConfigResponseFromJson(json);

  static const fromJsonFactory = _$SecretsWriteConfigResponseFromJson;
  static const toJsonFactory = _$SecretsWriteConfigResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsWriteConfigResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SecretsReadResponse {
  SecretsReadResponse({
    required this.data,
    required this.metadata,
  });

  factory SecretsReadResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsReadResponseFromJson(json);

  @JsonKey(name: 'data', includeIfNull: false)
  final Object data;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final SecretsReadResponse$Metadata metadata;
  static const fromJsonFactory = _$SecretsReadResponseFromJson;
  static const toJsonFactory = _$SecretsReadResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsReadResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsReadResponse &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $SecretsReadResponseExtension on SecretsReadResponse {
  SecretsReadResponse copyWith(
      {Object? data, SecretsReadResponse$Metadata? metadata}) {
    return SecretsReadResponse(
        data: data ?? this.data, metadata: metadata ?? this.metadata);
  }

  SecretsReadResponse copyWithWrapped(
      {Wrapped<Object>? data,
      Wrapped<SecretsReadResponse$Metadata>? metadata}) {
    return SecretsReadResponse(
        data: (data != null ? data.value : this.data),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsWriteOptions {
  SecretsWriteOptions({
    this.data,
    this.options,
    this.version,
    required this.path,
  });

  factory SecretsWriteOptions.fromJson(Map<String, dynamic> json) =>
      _$SecretsWriteOptionsFromJson(json);

  @JsonKey(name: 'data', includeIfNull: false)
  final Object? data;
  @JsonKey(name: 'options', includeIfNull: false)
  final Object? options;
  @JsonKey(name: 'version', includeIfNull: false)
  final double? version;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  static const fromJsonFactory = _$SecretsWriteOptionsFromJson;
  static const toJsonFactory = _$SecretsWriteOptionsToJson;
  Map<String, dynamic> toJson() => _$SecretsWriteOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsWriteOptions &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality()
                    .equals(other.options, options)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(options) ^
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(path) ^
      runtimeType.hashCode;
}

extension $SecretsWriteOptionsExtension on SecretsWriteOptions {
  SecretsWriteOptions copyWith(
      {Object? data, Object? options, double? version, String? path}) {
    return SecretsWriteOptions(
        data: data ?? this.data,
        options: options ?? this.options,
        version: version ?? this.version,
        path: path ?? this.path);
  }

  SecretsWriteOptions copyWithWrapped(
      {Wrapped<Object?>? data,
      Wrapped<Object?>? options,
      Wrapped<double?>? version,
      Wrapped<String>? path}) {
    return SecretsWriteOptions(
        data: (data != null ? data.value : this.data),
        options: (options != null ? options.value : this.options),
        version: (version != null ? version.value : this.version),
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsWriteResponse {
  SecretsWriteResponse({
    required this.createdTime,
    required this.deletionTime,
    required this.destroyed,
    required this.version,
  });

  factory SecretsWriteResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsWriteResponseFromJson(json);

  @JsonKey(name: 'createdTime', includeIfNull: false, defaultValue: '')
  final String createdTime;
  @JsonKey(name: 'deletionTime', includeIfNull: false, defaultValue: '')
  final String deletionTime;
  @JsonKey(name: 'destroyed', includeIfNull: false)
  final bool destroyed;
  @JsonKey(name: 'version', includeIfNull: false)
  final double version;
  static const fromJsonFactory = _$SecretsWriteResponseFromJson;
  static const toJsonFactory = _$SecretsWriteResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsWriteResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsWriteResponse &&
            (identical(other.createdTime, createdTime) ||
                const DeepCollectionEquality()
                    .equals(other.createdTime, createdTime)) &&
            (identical(other.deletionTime, deletionTime) ||
                const DeepCollectionEquality()
                    .equals(other.deletionTime, deletionTime)) &&
            (identical(other.destroyed, destroyed) ||
                const DeepCollectionEquality()
                    .equals(other.destroyed, destroyed)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality().equals(other.version, version)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(createdTime) ^
      const DeepCollectionEquality().hash(deletionTime) ^
      const DeepCollectionEquality().hash(destroyed) ^
      const DeepCollectionEquality().hash(version) ^
      runtimeType.hashCode;
}

extension $SecretsWriteResponseExtension on SecretsWriteResponse {
  SecretsWriteResponse copyWith(
      {String? createdTime,
      String? deletionTime,
      bool? destroyed,
      double? version}) {
    return SecretsWriteResponse(
        createdTime: createdTime ?? this.createdTime,
        deletionTime: deletionTime ?? this.deletionTime,
        destroyed: destroyed ?? this.destroyed,
        version: version ?? this.version);
  }

  SecretsWriteResponse copyWithWrapped(
      {Wrapped<String>? createdTime,
      Wrapped<String>? deletionTime,
      Wrapped<bool>? destroyed,
      Wrapped<double>? version}) {
    return SecretsWriteResponse(
        createdTime:
            (createdTime != null ? createdTime.value : this.createdTime),
        deletionTime:
            (deletionTime != null ? deletionTime.value : this.deletionTime),
        destroyed: (destroyed != null ? destroyed.value : this.destroyed),
        version: (version != null ? version.value : this.version));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsDeleteResponse {
  SecretsDeleteResponse();

  factory SecretsDeleteResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsDeleteResponseFromJson(json);

  static const fromJsonFactory = _$SecretsDeleteResponseFromJson;
  static const toJsonFactory = _$SecretsDeleteResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsDeleteResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SecretsDeleteVersionsOptions {
  SecretsDeleteVersionsOptions({
    this.versions,
    required this.path,
  });

  factory SecretsDeleteVersionsOptions.fromJson(Map<String, dynamic> json) =>
      _$SecretsDeleteVersionsOptionsFromJson(json);

  @JsonKey(name: 'versions', includeIfNull: false, defaultValue: <double>[])
  final List<double>? versions;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  static const fromJsonFactory = _$SecretsDeleteVersionsOptionsFromJson;
  static const toJsonFactory = _$SecretsDeleteVersionsOptionsToJson;
  Map<String, dynamic> toJson() => _$SecretsDeleteVersionsOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsDeleteVersionsOptions &&
            (identical(other.versions, versions) ||
                const DeepCollectionEquality()
                    .equals(other.versions, versions)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(versions) ^
      const DeepCollectionEquality().hash(path) ^
      runtimeType.hashCode;
}

extension $SecretsDeleteVersionsOptionsExtension
    on SecretsDeleteVersionsOptions {
  SecretsDeleteVersionsOptions copyWith(
      {List<double>? versions, String? path}) {
    return SecretsDeleteVersionsOptions(
        versions: versions ?? this.versions, path: path ?? this.path);
  }

  SecretsDeleteVersionsOptions copyWithWrapped(
      {Wrapped<List<double>?>? versions, Wrapped<String>? path}) {
    return SecretsDeleteVersionsOptions(
        versions: (versions != null ? versions.value : this.versions),
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsDeleteVersionsResponse {
  SecretsDeleteVersionsResponse();

  factory SecretsDeleteVersionsResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsDeleteVersionsResponseFromJson(json);

  static const fromJsonFactory = _$SecretsDeleteVersionsResponseFromJson;
  static const toJsonFactory = _$SecretsDeleteVersionsResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsDeleteVersionsResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SecretsDestroyVersionsOptions {
  SecretsDestroyVersionsOptions({
    this.versions,
    required this.path,
  });

  factory SecretsDestroyVersionsOptions.fromJson(Map<String, dynamic> json) =>
      _$SecretsDestroyVersionsOptionsFromJson(json);

  @JsonKey(name: 'versions', includeIfNull: false, defaultValue: <double>[])
  final List<double>? versions;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  static const fromJsonFactory = _$SecretsDestroyVersionsOptionsFromJson;
  static const toJsonFactory = _$SecretsDestroyVersionsOptionsToJson;
  Map<String, dynamic> toJson() => _$SecretsDestroyVersionsOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsDestroyVersionsOptions &&
            (identical(other.versions, versions) ||
                const DeepCollectionEquality()
                    .equals(other.versions, versions)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(versions) ^
      const DeepCollectionEquality().hash(path) ^
      runtimeType.hashCode;
}

extension $SecretsDestroyVersionsOptionsExtension
    on SecretsDestroyVersionsOptions {
  SecretsDestroyVersionsOptions copyWith(
      {List<double>? versions, String? path}) {
    return SecretsDestroyVersionsOptions(
        versions: versions ?? this.versions, path: path ?? this.path);
  }

  SecretsDestroyVersionsOptions copyWithWrapped(
      {Wrapped<List<double>?>? versions, Wrapped<String>? path}) {
    return SecretsDestroyVersionsOptions(
        versions: (versions != null ? versions.value : this.versions),
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsDestroyVersionsResponse {
  SecretsDestroyVersionsResponse();

  factory SecretsDestroyVersionsResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsDestroyVersionsResponseFromJson(json);

  static const fromJsonFactory = _$SecretsDestroyVersionsResponseFromJson;
  static const toJsonFactory = _$SecretsDestroyVersionsResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsDestroyVersionsResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SecretsGetVersionsResponse {
  SecretsGetVersionsResponse({
    required this.casRequired,
    required this.createdTime,
    required this.currentVersion,
    required this.deleteVersionAfter,
    required this.maxVersions,
    required this.oldestVersion,
    required this.updatedTime,
    required this.versions,
  });

  factory SecretsGetVersionsResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsGetVersionsResponseFromJson(json);

  @JsonKey(name: 'casRequired', includeIfNull: false)
  final bool casRequired;
  @JsonKey(name: 'createdTime', includeIfNull: false, defaultValue: '')
  final String createdTime;
  @JsonKey(name: 'currentVersion', includeIfNull: false)
  final double currentVersion;
  @JsonKey(name: 'deleteVersionAfter', includeIfNull: false, defaultValue: '')
  final String deleteVersionAfter;
  @JsonKey(name: 'maxVersions', includeIfNull: false)
  final double maxVersions;
  @JsonKey(name: 'oldestVersion', includeIfNull: false)
  final double oldestVersion;
  @JsonKey(name: 'updatedTime', includeIfNull: false, defaultValue: '')
  final String updatedTime;
  @JsonKey(name: 'versions', includeIfNull: false)
  final Object versions;
  static const fromJsonFactory = _$SecretsGetVersionsResponseFromJson;
  static const toJsonFactory = _$SecretsGetVersionsResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsGetVersionsResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsGetVersionsResponse &&
            (identical(other.casRequired, casRequired) ||
                const DeepCollectionEquality()
                    .equals(other.casRequired, casRequired)) &&
            (identical(other.createdTime, createdTime) ||
                const DeepCollectionEquality()
                    .equals(other.createdTime, createdTime)) &&
            (identical(other.currentVersion, currentVersion) ||
                const DeepCollectionEquality()
                    .equals(other.currentVersion, currentVersion)) &&
            (identical(other.deleteVersionAfter, deleteVersionAfter) ||
                const DeepCollectionEquality()
                    .equals(other.deleteVersionAfter, deleteVersionAfter)) &&
            (identical(other.maxVersions, maxVersions) ||
                const DeepCollectionEquality()
                    .equals(other.maxVersions, maxVersions)) &&
            (identical(other.oldestVersion, oldestVersion) ||
                const DeepCollectionEquality()
                    .equals(other.oldestVersion, oldestVersion)) &&
            (identical(other.updatedTime, updatedTime) ||
                const DeepCollectionEquality()
                    .equals(other.updatedTime, updatedTime)) &&
            (identical(other.versions, versions) ||
                const DeepCollectionEquality()
                    .equals(other.versions, versions)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(casRequired) ^
      const DeepCollectionEquality().hash(createdTime) ^
      const DeepCollectionEquality().hash(currentVersion) ^
      const DeepCollectionEquality().hash(deleteVersionAfter) ^
      const DeepCollectionEquality().hash(maxVersions) ^
      const DeepCollectionEquality().hash(oldestVersion) ^
      const DeepCollectionEquality().hash(updatedTime) ^
      const DeepCollectionEquality().hash(versions) ^
      runtimeType.hashCode;
}

extension $SecretsGetVersionsResponseExtension on SecretsGetVersionsResponse {
  SecretsGetVersionsResponse copyWith(
      {bool? casRequired,
      String? createdTime,
      double? currentVersion,
      String? deleteVersionAfter,
      double? maxVersions,
      double? oldestVersion,
      String? updatedTime,
      Object? versions}) {
    return SecretsGetVersionsResponse(
        casRequired: casRequired ?? this.casRequired,
        createdTime: createdTime ?? this.createdTime,
        currentVersion: currentVersion ?? this.currentVersion,
        deleteVersionAfter: deleteVersionAfter ?? this.deleteVersionAfter,
        maxVersions: maxVersions ?? this.maxVersions,
        oldestVersion: oldestVersion ?? this.oldestVersion,
        updatedTime: updatedTime ?? this.updatedTime,
        versions: versions ?? this.versions);
  }

  SecretsGetVersionsResponse copyWithWrapped(
      {Wrapped<bool>? casRequired,
      Wrapped<String>? createdTime,
      Wrapped<double>? currentVersion,
      Wrapped<String>? deleteVersionAfter,
      Wrapped<double>? maxVersions,
      Wrapped<double>? oldestVersion,
      Wrapped<String>? updatedTime,
      Wrapped<Object>? versions}) {
    return SecretsGetVersionsResponse(
        casRequired:
            (casRequired != null ? casRequired.value : this.casRequired),
        createdTime:
            (createdTime != null ? createdTime.value : this.createdTime),
        currentVersion: (currentVersion != null
            ? currentVersion.value
            : this.currentVersion),
        deleteVersionAfter: (deleteVersionAfter != null
            ? deleteVersionAfter.value
            : this.deleteVersionAfter),
        maxVersions:
            (maxVersions != null ? maxVersions.value : this.maxVersions),
        oldestVersion:
            (oldestVersion != null ? oldestVersion.value : this.oldestVersion),
        updatedTime:
            (updatedTime != null ? updatedTime.value : this.updatedTime),
        versions: (versions != null ? versions.value : this.versions));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsConfigurePathOptions {
  SecretsConfigurePathOptions({
    this.casRequired,
    this.deleteVersionAfter,
    this.maxVersions,
    required this.path,
  });

  factory SecretsConfigurePathOptions.fromJson(Map<String, dynamic> json) =>
      _$SecretsConfigurePathOptionsFromJson(json);

  @JsonKey(name: 'casRequired', includeIfNull: false)
  final bool? casRequired;
  @JsonKey(name: 'deleteVersionAfter', includeIfNull: false)
  final double? deleteVersionAfter;
  @JsonKey(name: 'maxVersions', includeIfNull: false)
  final double? maxVersions;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  static const fromJsonFactory = _$SecretsConfigurePathOptionsFromJson;
  static const toJsonFactory = _$SecretsConfigurePathOptionsToJson;
  Map<String, dynamic> toJson() => _$SecretsConfigurePathOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsConfigurePathOptions &&
            (identical(other.casRequired, casRequired) ||
                const DeepCollectionEquality()
                    .equals(other.casRequired, casRequired)) &&
            (identical(other.deleteVersionAfter, deleteVersionAfter) ||
                const DeepCollectionEquality()
                    .equals(other.deleteVersionAfter, deleteVersionAfter)) &&
            (identical(other.maxVersions, maxVersions) ||
                const DeepCollectionEquality()
                    .equals(other.maxVersions, maxVersions)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(casRequired) ^
      const DeepCollectionEquality().hash(deleteVersionAfter) ^
      const DeepCollectionEquality().hash(maxVersions) ^
      const DeepCollectionEquality().hash(path) ^
      runtimeType.hashCode;
}

extension $SecretsConfigurePathOptionsExtension on SecretsConfigurePathOptions {
  SecretsConfigurePathOptions copyWith(
      {bool? casRequired,
      double? deleteVersionAfter,
      double? maxVersions,
      String? path}) {
    return SecretsConfigurePathOptions(
        casRequired: casRequired ?? this.casRequired,
        deleteVersionAfter: deleteVersionAfter ?? this.deleteVersionAfter,
        maxVersions: maxVersions ?? this.maxVersions,
        path: path ?? this.path);
  }

  SecretsConfigurePathOptions copyWithWrapped(
      {Wrapped<bool?>? casRequired,
      Wrapped<double?>? deleteVersionAfter,
      Wrapped<double?>? maxVersions,
      Wrapped<String>? path}) {
    return SecretsConfigurePathOptions(
        casRequired:
            (casRequired != null ? casRequired.value : this.casRequired),
        deleteVersionAfter: (deleteVersionAfter != null
            ? deleteVersionAfter.value
            : this.deleteVersionAfter),
        maxVersions:
            (maxVersions != null ? maxVersions.value : this.maxVersions),
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsConfigurePathResponse {
  SecretsConfigurePathResponse();

  factory SecretsConfigurePathResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsConfigurePathResponseFromJson(json);

  static const fromJsonFactory = _$SecretsConfigurePathResponseFromJson;
  static const toJsonFactory = _$SecretsConfigurePathResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsConfigurePathResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SecretsDestroyAllVersionsResponse {
  SecretsDestroyAllVersionsResponse();

  factory SecretsDestroyAllVersionsResponse.fromJson(
          Map<String, dynamic> json) =>
      _$SecretsDestroyAllVersionsResponseFromJson(json);

  static const fromJsonFactory = _$SecretsDestroyAllVersionsResponseFromJson;
  static const toJsonFactory = _$SecretsDestroyAllVersionsResponseToJson;
  Map<String, dynamic> toJson() =>
      _$SecretsDestroyAllVersionsResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SecretsListResponse {
  SecretsListResponse({
    required this.keys,
  });

  factory SecretsListResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsListResponseFromJson(json);

  @JsonKey(name: 'keys', includeIfNull: false, defaultValue: <String>[])
  final List<String> keys;
  static const fromJsonFactory = _$SecretsListResponseFromJson;
  static const toJsonFactory = _$SecretsListResponseToJson;
  Map<String, dynamic> toJson() => _$SecretsListResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsListResponse &&
            (identical(other.keys, keys) ||
                const DeepCollectionEquality().equals(other.keys, keys)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(keys) ^ runtimeType.hashCode;
}

extension $SecretsListResponseExtension on SecretsListResponse {
  SecretsListResponse copyWith({List<String>? keys}) {
    return SecretsListResponse(keys: keys ?? this.keys);
  }

  SecretsListResponse copyWithWrapped({Wrapped<List<String>>? keys}) {
    return SecretsListResponse(keys: (keys != null ? keys.value : this.keys));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsUndeleteVersionsOptions {
  SecretsUndeleteVersionsOptions({
    this.versions,
    required this.path,
  });

  factory SecretsUndeleteVersionsOptions.fromJson(Map<String, dynamic> json) =>
      _$SecretsUndeleteVersionsOptionsFromJson(json);

  @JsonKey(name: 'versions', includeIfNull: false, defaultValue: <double>[])
  final List<double>? versions;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  static const fromJsonFactory = _$SecretsUndeleteVersionsOptionsFromJson;
  static const toJsonFactory = _$SecretsUndeleteVersionsOptionsToJson;
  Map<String, dynamic> toJson() => _$SecretsUndeleteVersionsOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsUndeleteVersionsOptions &&
            (identical(other.versions, versions) ||
                const DeepCollectionEquality()
                    .equals(other.versions, versions)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(versions) ^
      const DeepCollectionEquality().hash(path) ^
      runtimeType.hashCode;
}

extension $SecretsUndeleteVersionsOptionsExtension
    on SecretsUndeleteVersionsOptions {
  SecretsUndeleteVersionsOptions copyWith(
      {List<double>? versions, String? path}) {
    return SecretsUndeleteVersionsOptions(
        versions: versions ?? this.versions, path: path ?? this.path);
  }

  SecretsUndeleteVersionsOptions copyWithWrapped(
      {Wrapped<List<double>?>? versions, Wrapped<String>? path}) {
    return SecretsUndeleteVersionsOptions(
        versions: (versions != null ? versions.value : this.versions),
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsUndeleteVersionsResponse {
  SecretsUndeleteVersionsResponse();

  factory SecretsUndeleteVersionsResponse.fromJson(Map<String, dynamic> json) =>
      _$SecretsUndeleteVersionsResponseFromJson(json);

  static const fromJsonFactory = _$SecretsUndeleteVersionsResponseFromJson;
  static const toJsonFactory = _$SecretsUndeleteVersionsResponseToJson;
  Map<String, dynamic> toJson() =>
      _$SecretsUndeleteVersionsResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class IdentityUpdateOptions {
  IdentityUpdateOptions({
    required this.groups,
    this.color,
    this.description,
    this.disabled,
    this.metadata,
    this.name,
    this.oidcUsername,
  });

  factory IdentityUpdateOptions.fromJson(Map<String, dynamic> json) =>
      _$IdentityUpdateOptionsFromJson(json);

  @JsonKey(name: 'groups', includeIfNull: false, defaultValue: <String>[])
  final List<String> groups;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool? disabled;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'oidcUsername', includeIfNull: false, defaultValue: '')
  final String? oidcUsername;
  static const fromJsonFactory = _$IdentityUpdateOptionsFromJson;
  static const toJsonFactory = _$IdentityUpdateOptionsToJson;
  Map<String, dynamic> toJson() => _$IdentityUpdateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityUpdateOptions &&
            (identical(other.groups, groups) ||
                const DeepCollectionEquality().equals(other.groups, groups)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.oidcUsername, oidcUsername) ||
                const DeepCollectionEquality()
                    .equals(other.oidcUsername, oidcUsername)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(groups) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(oidcUsername) ^
      runtimeType.hashCode;
}

extension $IdentityUpdateOptionsExtension on IdentityUpdateOptions {
  IdentityUpdateOptions copyWith(
      {List<String>? groups,
      String? color,
      String? description,
      bool? disabled,
      Object? metadata,
      String? name,
      String? oidcUsername}) {
    return IdentityUpdateOptions(
        groups: groups ?? this.groups,
        color: color ?? this.color,
        description: description ?? this.description,
        disabled: disabled ?? this.disabled,
        metadata: metadata ?? this.metadata,
        name: name ?? this.name,
        oidcUsername: oidcUsername ?? this.oidcUsername);
  }

  IdentityUpdateOptions copyWithWrapped(
      {Wrapped<List<String>>? groups,
      Wrapped<String?>? color,
      Wrapped<String?>? description,
      Wrapped<bool?>? disabled,
      Wrapped<Object?>? metadata,
      Wrapped<String?>? name,
      Wrapped<String?>? oidcUsername}) {
    return IdentityUpdateOptions(
        groups: (groups != null ? groups.value : this.groups),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        disabled: (disabled != null ? disabled.value : this.disabled),
        metadata: (metadata != null ? metadata.value : this.metadata),
        name: (name != null ? name.value : this.name),
        oidcUsername:
            (oidcUsername != null ? oidcUsername.value : this.oidcUsername));
  }
}

@JsonSerializable(explicitToJson: true)
class Tenant {
  Tenant({
    this.id,
    required this.name,
    this.description,
    this.color,
    this.domain,
    this.metadata,
  });

  factory Tenant.fromJson(Map<String, dynamic> json) => _$TenantFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String? domain;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  static const fromJsonFactory = _$TenantFromJson;
  static const toJsonFactory = _$TenantToJson;
  Map<String, dynamic> toJson() => _$TenantToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Tenant &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $TenantExtension on Tenant {
  Tenant copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      String? domain,
      Object? metadata}) {
    return Tenant(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        domain: domain ?? this.domain,
        metadata: metadata ?? this.metadata);
  }

  Tenant copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<String?>? domain,
      Wrapped<Object?>? metadata}) {
    return Tenant(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        domain: (domain != null ? domain.value : this.domain),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class ProviderMetadata {
  ProviderMetadata({
    this.config,
  });

  factory ProviderMetadata.fromJson(Map<String, dynamic> json) =>
      _$ProviderMetadataFromJson(json);

  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  static const fromJsonFactory = _$ProviderMetadataFromJson;
  static const toJsonFactory = _$ProviderMetadataToJson;
  Map<String, dynamic> toJson() => _$ProviderMetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProviderMetadata &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(config) ^ runtimeType.hashCode;
}

extension $ProviderMetadataExtension on ProviderMetadata {
  ProviderMetadata copyWith({Object? config}) {
    return ProviderMetadata(config: config ?? this.config);
  }

  ProviderMetadata copyWithWrapped({Wrapped<Object?>? config}) {
    return ProviderMetadata(
        config: (config != null ? config.value : this.config));
  }
}

@JsonSerializable(explicitToJson: true)
class ProviderOidcRole {
  ProviderOidcRole({
    this.authenticationService,
    this.id,
    this.name,
    this.description,
    this.color,
    this.allowedRedirectUris,
    this.boundAudiences,
    this.boundClaims,
    this.boundSubject,
    this.claimMappings,
    this.clockSkewLeeway,
    this.expirationLeeway,
    this.groupsClaim,
    this.notBeforeLeeway,
    this.oidcScopes,
    this.roleType,
    this.tokenBoundCidrs,
    this.tokenExplicitMaxTtl,
    this.tokenMaxTtl,
    this.tokenNoDefaultPolicy,
    this.tokenNumUses,
    this.tokenPeriod,
    this.tokenPolicies,
    this.tokenTtl,
    this.tokenType,
    this.userClaim,
    this.verboseOidcLogging,
    this.authenticationServiceId,
  });

  factory ProviderOidcRole.fromJson(Map<String, dynamic> json) =>
      _$ProviderOidcRoleFromJson(json);

  @JsonKey(name: 'authenticationService', includeIfNull: false)
  final Provider? authenticationService;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(
      name: 'allowed_redirect_uris', includeIfNull: false, defaultValue: '')
  final String? allowedRedirectUris;
  @JsonKey(name: 'bound_audiences', includeIfNull: false, defaultValue: '')
  final String? boundAudiences;
  @JsonKey(name: 'bound_claims', includeIfNull: false, defaultValue: '')
  final String? boundClaims;
  @JsonKey(name: 'bound_subject', includeIfNull: false, defaultValue: '')
  final String? boundSubject;
  @JsonKey(name: 'claim_mappings', includeIfNull: false)
  final Object? claimMappings;
  @JsonKey(name: 'clock_skew_leeway', includeIfNull: false)
  final double? clockSkewLeeway;
  @JsonKey(name: 'expiration_leeway', includeIfNull: false)
  final double? expirationLeeway;
  @JsonKey(name: 'groups_claim', includeIfNull: false, defaultValue: '')
  final String? groupsClaim;
  @JsonKey(name: 'not_before_leeway', includeIfNull: false)
  final double? notBeforeLeeway;
  @JsonKey(name: 'oidc_scopes', includeIfNull: false, defaultValue: '')
  final String? oidcScopes;
  @JsonKey(name: 'role_type', includeIfNull: false, defaultValue: '')
  final String? roleType;
  @JsonKey(name: 'token_bound_cidrs', includeIfNull: false, defaultValue: '')
  final String? tokenBoundCidrs;
  @JsonKey(name: 'token_explicit_max_ttl', includeIfNull: false)
  final double? tokenExplicitMaxTtl;
  @JsonKey(name: 'token_max_ttl', includeIfNull: false)
  final double? tokenMaxTtl;
  @JsonKey(name: 'token_no_default_policy', includeIfNull: false)
  final bool? tokenNoDefaultPolicy;
  @JsonKey(name: 'token_num_uses', includeIfNull: false)
  final double? tokenNumUses;
  @JsonKey(name: 'token_period', includeIfNull: false)
  final double? tokenPeriod;
  @JsonKey(name: 'token_policies', includeIfNull: false, defaultValue: '')
  final String? tokenPolicies;
  @JsonKey(name: 'token_ttl', includeIfNull: false)
  final double? tokenTtl;
  @JsonKey(name: 'token_type', includeIfNull: false, defaultValue: '')
  final String? tokenType;
  @JsonKey(name: 'user_claim', includeIfNull: false, defaultValue: '')
  final String? userClaim;
  @JsonKey(name: 'verbose_oidc_logging', includeIfNull: false)
  final bool? verboseOidcLogging;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String? authenticationServiceId;
  static const fromJsonFactory = _$ProviderOidcRoleFromJson;
  static const toJsonFactory = _$ProviderOidcRoleToJson;
  Map<String, dynamic> toJson() => _$ProviderOidcRoleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProviderOidcRole &&
            (identical(other.authenticationService, authenticationService) ||
                const DeepCollectionEquality().equals(
                    other.authenticationService, authenticationService)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.allowedRedirectUris, allowedRedirectUris) ||
                const DeepCollectionEquality()
                    .equals(other.allowedRedirectUris, allowedRedirectUris)) &&
            (identical(other.boundAudiences, boundAudiences) ||
                const DeepCollectionEquality()
                    .equals(other.boundAudiences, boundAudiences)) &&
            (identical(other.boundClaims, boundClaims) ||
                const DeepCollectionEquality()
                    .equals(other.boundClaims, boundClaims)) &&
            (identical(other.boundSubject, boundSubject) ||
                const DeepCollectionEquality()
                    .equals(other.boundSubject, boundSubject)) &&
            (identical(other.claimMappings, claimMappings) ||
                const DeepCollectionEquality()
                    .equals(other.claimMappings, claimMappings)) &&
            (identical(other.clockSkewLeeway, clockSkewLeeway) ||
                const DeepCollectionEquality()
                    .equals(other.clockSkewLeeway, clockSkewLeeway)) &&
            (identical(other.expirationLeeway, expirationLeeway) ||
                const DeepCollectionEquality()
                    .equals(other.expirationLeeway, expirationLeeway)) &&
            (identical(other.groupsClaim, groupsClaim) ||
                const DeepCollectionEquality()
                    .equals(other.groupsClaim, groupsClaim)) &&
            (identical(other.notBeforeLeeway, notBeforeLeeway) ||
                const DeepCollectionEquality()
                    .equals(other.notBeforeLeeway, notBeforeLeeway)) &&
            (identical(other.oidcScopes, oidcScopes) ||
                const DeepCollectionEquality()
                    .equals(other.oidcScopes, oidcScopes)) &&
            (identical(other.roleType, roleType) ||
                const DeepCollectionEquality()
                    .equals(other.roleType, roleType)) &&
            (identical(other.tokenBoundCidrs, tokenBoundCidrs) ||
                const DeepCollectionEquality()
                    .equals(other.tokenBoundCidrs, tokenBoundCidrs)) &&
            (identical(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl)) &&
            (identical(other.tokenMaxTtl, tokenMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenMaxTtl, tokenMaxTtl)) &&
            (identical(other.tokenNoDefaultPolicy, tokenNoDefaultPolicy) ||
                const DeepCollectionEquality().equals(
                    other.tokenNoDefaultPolicy, tokenNoDefaultPolicy)) &&
            (identical(other.tokenNumUses, tokenNumUses) ||
                const DeepCollectionEquality()
                    .equals(other.tokenNumUses, tokenNumUses)) &&
            (identical(other.tokenPeriod, tokenPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPeriod, tokenPeriod)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality().equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.tokenTtl, tokenTtl) || const DeepCollectionEquality().equals(other.tokenTtl, tokenTtl)) &&
            (identical(other.tokenType, tokenType) || const DeepCollectionEquality().equals(other.tokenType, tokenType)) &&
            (identical(other.userClaim, userClaim) || const DeepCollectionEquality().equals(other.userClaim, userClaim)) &&
            (identical(other.verboseOidcLogging, verboseOidcLogging) || const DeepCollectionEquality().equals(other.verboseOidcLogging, verboseOidcLogging)) &&
            (identical(other.authenticationServiceId, authenticationServiceId) || const DeepCollectionEquality().equals(other.authenticationServiceId, authenticationServiceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authenticationService) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(allowedRedirectUris) ^
      const DeepCollectionEquality().hash(boundAudiences) ^
      const DeepCollectionEquality().hash(boundClaims) ^
      const DeepCollectionEquality().hash(boundSubject) ^
      const DeepCollectionEquality().hash(claimMappings) ^
      const DeepCollectionEquality().hash(clockSkewLeeway) ^
      const DeepCollectionEquality().hash(expirationLeeway) ^
      const DeepCollectionEquality().hash(groupsClaim) ^
      const DeepCollectionEquality().hash(notBeforeLeeway) ^
      const DeepCollectionEquality().hash(oidcScopes) ^
      const DeepCollectionEquality().hash(roleType) ^
      const DeepCollectionEquality().hash(tokenBoundCidrs) ^
      const DeepCollectionEquality().hash(tokenExplicitMaxTtl) ^
      const DeepCollectionEquality().hash(tokenMaxTtl) ^
      const DeepCollectionEquality().hash(tokenNoDefaultPolicy) ^
      const DeepCollectionEquality().hash(tokenNumUses) ^
      const DeepCollectionEquality().hash(tokenPeriod) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(tokenTtl) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(userClaim) ^
      const DeepCollectionEquality().hash(verboseOidcLogging) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      runtimeType.hashCode;
}

extension $ProviderOidcRoleExtension on ProviderOidcRole {
  ProviderOidcRole copyWith(
      {Provider? authenticationService,
      String? id,
      String? name,
      String? description,
      String? color,
      String? allowedRedirectUris,
      String? boundAudiences,
      String? boundClaims,
      String? boundSubject,
      Object? claimMappings,
      double? clockSkewLeeway,
      double? expirationLeeway,
      String? groupsClaim,
      double? notBeforeLeeway,
      String? oidcScopes,
      String? roleType,
      String? tokenBoundCidrs,
      double? tokenExplicitMaxTtl,
      double? tokenMaxTtl,
      bool? tokenNoDefaultPolicy,
      double? tokenNumUses,
      double? tokenPeriod,
      String? tokenPolicies,
      double? tokenTtl,
      String? tokenType,
      String? userClaim,
      bool? verboseOidcLogging,
      String? authenticationServiceId}) {
    return ProviderOidcRole(
        authenticationService:
            authenticationService ?? this.authenticationService,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        allowedRedirectUris: allowedRedirectUris ?? this.allowedRedirectUris,
        boundAudiences: boundAudiences ?? this.boundAudiences,
        boundClaims: boundClaims ?? this.boundClaims,
        boundSubject: boundSubject ?? this.boundSubject,
        claimMappings: claimMappings ?? this.claimMappings,
        clockSkewLeeway: clockSkewLeeway ?? this.clockSkewLeeway,
        expirationLeeway: expirationLeeway ?? this.expirationLeeway,
        groupsClaim: groupsClaim ?? this.groupsClaim,
        notBeforeLeeway: notBeforeLeeway ?? this.notBeforeLeeway,
        oidcScopes: oidcScopes ?? this.oidcScopes,
        roleType: roleType ?? this.roleType,
        tokenBoundCidrs: tokenBoundCidrs ?? this.tokenBoundCidrs,
        tokenExplicitMaxTtl: tokenExplicitMaxTtl ?? this.tokenExplicitMaxTtl,
        tokenMaxTtl: tokenMaxTtl ?? this.tokenMaxTtl,
        tokenNoDefaultPolicy: tokenNoDefaultPolicy ?? this.tokenNoDefaultPolicy,
        tokenNumUses: tokenNumUses ?? this.tokenNumUses,
        tokenPeriod: tokenPeriod ?? this.tokenPeriod,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        tokenTtl: tokenTtl ?? this.tokenTtl,
        tokenType: tokenType ?? this.tokenType,
        userClaim: userClaim ?? this.userClaim,
        verboseOidcLogging: verboseOidcLogging ?? this.verboseOidcLogging,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId);
  }

  ProviderOidcRole copyWithWrapped(
      {Wrapped<Provider?>? authenticationService,
      Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<String?>? allowedRedirectUris,
      Wrapped<String?>? boundAudiences,
      Wrapped<String?>? boundClaims,
      Wrapped<String?>? boundSubject,
      Wrapped<Object?>? claimMappings,
      Wrapped<double?>? clockSkewLeeway,
      Wrapped<double?>? expirationLeeway,
      Wrapped<String?>? groupsClaim,
      Wrapped<double?>? notBeforeLeeway,
      Wrapped<String?>? oidcScopes,
      Wrapped<String?>? roleType,
      Wrapped<String?>? tokenBoundCidrs,
      Wrapped<double?>? tokenExplicitMaxTtl,
      Wrapped<double?>? tokenMaxTtl,
      Wrapped<bool?>? tokenNoDefaultPolicy,
      Wrapped<double?>? tokenNumUses,
      Wrapped<double?>? tokenPeriod,
      Wrapped<String?>? tokenPolicies,
      Wrapped<double?>? tokenTtl,
      Wrapped<String?>? tokenType,
      Wrapped<String?>? userClaim,
      Wrapped<bool?>? verboseOidcLogging,
      Wrapped<String?>? authenticationServiceId}) {
    return ProviderOidcRole(
        authenticationService: (authenticationService != null
            ? authenticationService.value
            : this.authenticationService),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        allowedRedirectUris: (allowedRedirectUris != null
            ? allowedRedirectUris.value
            : this.allowedRedirectUris),
        boundAudiences: (boundAudiences != null
            ? boundAudiences.value
            : this.boundAudiences),
        boundClaims:
            (boundClaims != null ? boundClaims.value : this.boundClaims),
        boundSubject:
            (boundSubject != null ? boundSubject.value : this.boundSubject),
        claimMappings:
            (claimMappings != null ? claimMappings.value : this.claimMappings),
        clockSkewLeeway: (clockSkewLeeway != null
            ? clockSkewLeeway.value
            : this.clockSkewLeeway),
        expirationLeeway: (expirationLeeway != null
            ? expirationLeeway.value
            : this.expirationLeeway),
        groupsClaim:
            (groupsClaim != null ? groupsClaim.value : this.groupsClaim),
        notBeforeLeeway: (notBeforeLeeway != null
            ? notBeforeLeeway.value
            : this.notBeforeLeeway),
        oidcScopes: (oidcScopes != null ? oidcScopes.value : this.oidcScopes),
        roleType: (roleType != null ? roleType.value : this.roleType),
        tokenBoundCidrs: (tokenBoundCidrs != null
            ? tokenBoundCidrs.value
            : this.tokenBoundCidrs),
        tokenExplicitMaxTtl: (tokenExplicitMaxTtl != null
            ? tokenExplicitMaxTtl.value
            : this.tokenExplicitMaxTtl),
        tokenMaxTtl:
            (tokenMaxTtl != null ? tokenMaxTtl.value : this.tokenMaxTtl),
        tokenNoDefaultPolicy: (tokenNoDefaultPolicy != null
            ? tokenNoDefaultPolicy.value
            : this.tokenNoDefaultPolicy),
        tokenNumUses:
            (tokenNumUses != null ? tokenNumUses.value : this.tokenNumUses),
        tokenPeriod:
            (tokenPeriod != null ? tokenPeriod.value : this.tokenPeriod),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        tokenTtl: (tokenTtl != null ? tokenTtl.value : this.tokenTtl),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        userClaim: (userClaim != null ? userClaim.value : this.userClaim),
        verboseOidcLogging: (verboseOidcLogging != null
            ? verboseOidcLogging.value
            : this.verboseOidcLogging),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId));
  }
}

@JsonSerializable(explicitToJson: true)
class Provider {
  Provider({
    required this.metadata,
    this.aliases,
    this.groupAliases,
    this.authOidcRoles,
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.icon,
    required this.domain,
    required this.color,
    required this.type,
    required this.accessor,
    required this.callback,
    required this.disabled,
    required this.autoCreateEntity,
    this.enableTotp,
    this.config,
    this.tenantId,
  });

  factory Provider.fromJson(Map<String, dynamic> json) =>
      _$ProviderFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final ProviderMetadata metadata;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector>? aliases;
  @JsonKey(
      name: 'groupAliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? groupAliases;
  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'callback', includeIfNull: false, defaultValue: '')
  final String callback;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'auto_create_entity', includeIfNull: false)
  final bool autoCreateEntity;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  static const fromJsonFactory = _$ProviderFromJson;
  static const toJsonFactory = _$ProviderToJson;
  Map<String, dynamic> toJson() => _$ProviderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Provider &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.groupAliases, groupAliases) ||
                const DeepCollectionEquality()
                    .equals(other.groupAliases, groupAliases)) &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.callback, callback) ||
                const DeepCollectionEquality()
                    .equals(other.callback, callback)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.autoCreateEntity, autoCreateEntity) ||
                const DeepCollectionEquality()
                    .equals(other.autoCreateEntity, autoCreateEntity)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(groupAliases) ^
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(callback) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(autoCreateEntity) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(tenantId) ^
      runtimeType.hashCode;
}

extension $ProviderExtension on Provider {
  Provider copyWith(
      {ProviderMetadata? metadata,
      List<IdentityConnector>? aliases,
      List<IdentityGroupAlias>? groupAliases,
      List<ProviderOidcRole>? authOidcRoles,
      Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? icon,
      String? domain,
      String? color,
      String? type,
      String? accessor,
      String? callback,
      bool? disabled,
      bool? autoCreateEntity,
      bool? enableTotp,
      Object? config,
      String? tenantId}) {
    return Provider(
        metadata: metadata ?? this.metadata,
        aliases: aliases ?? this.aliases,
        groupAliases: groupAliases ?? this.groupAliases,
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        domain: domain ?? this.domain,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        callback: callback ?? this.callback,
        disabled: disabled ?? this.disabled,
        autoCreateEntity: autoCreateEntity ?? this.autoCreateEntity,
        enableTotp: enableTotp ?? this.enableTotp,
        config: config ?? this.config,
        tenantId: tenantId ?? this.tenantId);
  }

  Provider copyWithWrapped(
      {Wrapped<ProviderMetadata>? metadata,
      Wrapped<List<IdentityConnector>?>? aliases,
      Wrapped<List<IdentityGroupAlias>?>? groupAliases,
      Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<String>? domain,
      Wrapped<String>? color,
      Wrapped<String>? type,
      Wrapped<String>? accessor,
      Wrapped<String>? callback,
      Wrapped<bool>? disabled,
      Wrapped<bool>? autoCreateEntity,
      Wrapped<bool?>? enableTotp,
      Wrapped<Object?>? config,
      Wrapped<String?>? tenantId}) {
    return Provider(
        metadata: (metadata != null ? metadata.value : this.metadata),
        aliases: (aliases != null ? aliases.value : this.aliases),
        groupAliases:
            (groupAliases != null ? groupAliases.value : this.groupAliases),
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        domain: (domain != null ? domain.value : this.domain),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        callback: (callback != null ? callback.value : this.callback),
        disabled: (disabled != null ? disabled.value : this.disabled),
        autoCreateEntity: (autoCreateEntity != null
            ? autoCreateEntity.value
            : this.autoCreateEntity),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        config: (config != null ? config.value : this.config),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityGroupAlias {
  IdentityGroupAlias({
    required this.id,
    required this.name,
    required this.description,
    required this.color,
    required this.authenticationServiceId,
    required this.groupId,
    required this.group,
    required this.authenticationService,
  });

  factory IdentityGroupAlias.fromJson(Map<String, dynamic> json) =>
      _$IdentityGroupAliasFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String authenticationServiceId;
  @JsonKey(name: 'groupId', includeIfNull: false, defaultValue: '')
  final String groupId;
  @JsonKey(name: 'group', includeIfNull: false)
  final IdentityGroup group;
  @JsonKey(name: 'authenticationService', includeIfNull: false)
  final Provider authenticationService;
  static const fromJsonFactory = _$IdentityGroupAliasFromJson;
  static const toJsonFactory = _$IdentityGroupAliasToJson;
  Map<String, dynamic> toJson() => _$IdentityGroupAliasToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityGroupAlias &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(
                    other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)) &&
            (identical(other.groupId, groupId) ||
                const DeepCollectionEquality()
                    .equals(other.groupId, groupId)) &&
            (identical(other.group, group) ||
                const DeepCollectionEquality().equals(other.group, group)) &&
            (identical(other.authenticationService, authenticationService) ||
                const DeepCollectionEquality().equals(
                    other.authenticationService, authenticationService)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      const DeepCollectionEquality().hash(groupId) ^
      const DeepCollectionEquality().hash(group) ^
      const DeepCollectionEquality().hash(authenticationService) ^
      runtimeType.hashCode;
}

extension $IdentityGroupAliasExtension on IdentityGroupAlias {
  IdentityGroupAlias copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      String? authenticationServiceId,
      String? groupId,
      IdentityGroup? group,
      Provider? authenticationService}) {
    return IdentityGroupAlias(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId,
        groupId: groupId ?? this.groupId,
        group: group ?? this.group,
        authenticationService:
            authenticationService ?? this.authenticationService);
  }

  IdentityGroupAlias copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? color,
      Wrapped<String>? authenticationServiceId,
      Wrapped<String>? groupId,
      Wrapped<IdentityGroup>? group,
      Wrapped<Provider>? authenticationService}) {
    return IdentityGroupAlias(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId),
        groupId: (groupId != null ? groupId.value : this.groupId),
        group: (group != null ? group.value : this.group),
        authenticationService: (authenticationService != null
            ? authenticationService.value
            : this.authenticationService));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyMetaRule {
  PolicyMetaRule({
    required this.capabilities,
    required this.policyTemplateId,
    this.path,
    this.description,
  });

  factory PolicyMetaRule.fromJson(Map<String, dynamic> json) =>
      _$PolicyMetaRuleFromJson(json);

  @JsonKey(name: 'capabilities', includeIfNull: false, defaultValue: <String>[])
  final List<String> capabilities;
  @JsonKey(name: 'policyTemplateId', includeIfNull: false, defaultValue: '')
  final String policyTemplateId;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String? path;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$PolicyMetaRuleFromJson;
  static const toJsonFactory = _$PolicyMetaRuleToJson;
  Map<String, dynamic> toJson() => _$PolicyMetaRuleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyMetaRule &&
            (identical(other.capabilities, capabilities) ||
                const DeepCollectionEquality()
                    .equals(other.capabilities, capabilities)) &&
            (identical(other.policyTemplateId, policyTemplateId) ||
                const DeepCollectionEquality()
                    .equals(other.policyTemplateId, policyTemplateId)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(capabilities) ^
      const DeepCollectionEquality().hash(policyTemplateId) ^
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $PolicyMetaRuleExtension on PolicyMetaRule {
  PolicyMetaRule copyWith(
      {List<String>? capabilities,
      String? policyTemplateId,
      String? path,
      String? description}) {
    return PolicyMetaRule(
        capabilities: capabilities ?? this.capabilities,
        policyTemplateId: policyTemplateId ?? this.policyTemplateId,
        path: path ?? this.path,
        description: description ?? this.description);
  }

  PolicyMetaRule copyWithWrapped(
      {Wrapped<List<String>>? capabilities,
      Wrapped<String>? policyTemplateId,
      Wrapped<String?>? path,
      Wrapped<String?>? description}) {
    return PolicyMetaRule(
        capabilities:
            (capabilities != null ? capabilities.value : this.capabilities),
        policyTemplateId: (policyTemplateId != null
            ? policyTemplateId.value
            : this.policyTemplateId),
        path: (path != null ? path.value : this.path),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyMetaData {
  PolicyMetaData({
    required this.rules,
  });

  factory PolicyMetaData.fromJson(Map<String, dynamic> json) =>
      _$PolicyMetaDataFromJson(json);

  @JsonKey(
      name: 'rules', includeIfNull: false, defaultValue: <PolicyMetaRule>[])
  final List<PolicyMetaRule> rules;
  static const fromJsonFactory = _$PolicyMetaDataFromJson;
  static const toJsonFactory = _$PolicyMetaDataToJson;
  Map<String, dynamic> toJson() => _$PolicyMetaDataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyMetaData &&
            (identical(other.rules, rules) ||
                const DeepCollectionEquality().equals(other.rules, rules)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(rules) ^ runtimeType.hashCode;
}

extension $PolicyMetaDataExtension on PolicyMetaData {
  PolicyMetaData copyWith({List<PolicyMetaRule>? rules}) {
    return PolicyMetaData(rules: rules ?? this.rules);
  }

  PolicyMetaData copyWithWrapped({Wrapped<List<PolicyMetaRule>>? rules}) {
    return PolicyMetaData(rules: (rules != null ? rules.value : this.rules));
  }
}

@JsonSerializable(explicitToJson: true)
class Policy {
  Policy({
    required this.id,
    required this.name,
    this.description,
    this.color,
    this.creationTime,
    this.lastUpdateTime,
    this.disabled,
    this.metadata,
    this.groups,
    this.type,
  });

  factory Policy.fromJson(Map<String, dynamic> json) => _$PolicyFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'creation_time', includeIfNull: false)
  final DateTime? creationTime;
  @JsonKey(name: 'last_update_time', includeIfNull: false)
  final DateTime? lastUpdateTime;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool? disabled;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final PolicyMetaData? metadata;
  @JsonKey(
      name: 'groups', includeIfNull: false, defaultValue: <IdentityGroup>[])
  final List<IdentityGroup>? groups;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: policyTypeToJson,
    fromJson: policyTypeFromJson,
  )
  final enums.PolicyType? type;
  static const fromJsonFactory = _$PolicyFromJson;
  static const toJsonFactory = _$PolicyToJson;
  Map<String, dynamic> toJson() => _$PolicyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Policy &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.lastUpdateTime, lastUpdateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdateTime, lastUpdateTime)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.groups, groups) ||
                const DeepCollectionEquality().equals(other.groups, groups)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(lastUpdateTime) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(groups) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $PolicyExtension on Policy {
  Policy copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      DateTime? creationTime,
      DateTime? lastUpdateTime,
      bool? disabled,
      PolicyMetaData? metadata,
      List<IdentityGroup>? groups,
      enums.PolicyType? type}) {
    return Policy(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        creationTime: creationTime ?? this.creationTime,
        lastUpdateTime: lastUpdateTime ?? this.lastUpdateTime,
        disabled: disabled ?? this.disabled,
        metadata: metadata ?? this.metadata,
        groups: groups ?? this.groups,
        type: type ?? this.type);
  }

  Policy copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<DateTime?>? creationTime,
      Wrapped<DateTime?>? lastUpdateTime,
      Wrapped<bool?>? disabled,
      Wrapped<PolicyMetaData?>? metadata,
      Wrapped<List<IdentityGroup>?>? groups,
      Wrapped<enums.PolicyType?>? type}) {
    return Policy(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        lastUpdateTime: (lastUpdateTime != null
            ? lastUpdateTime.value
            : this.lastUpdateTime),
        disabled: (disabled != null ? disabled.value : this.disabled),
        metadata: (metadata != null ? metadata.value : this.metadata),
        groups: (groups != null ? groups.value : this.groups),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityGroup {
  IdentityGroup({
    required this.creationTime,
    required this.lastUpdateTime,
    this.aliases,
    required this.policies,
    required this.members,
    required this.id,
    required this.name,
    required this.description,
    required this.color,
    required this.$external,
    required this.modifyIndex,
    required this.metadata,
  });

  factory IdentityGroup.fromJson(Map<String, dynamic> json) =>
      _$IdentityGroupFromJson(json);

  @JsonKey(name: 'creation_time', includeIfNull: false)
  final DateTime creationTime;
  @JsonKey(name: 'last_update_time', includeIfNull: false)
  final DateTime lastUpdateTime;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? aliases;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <Policy>[])
  final List<Policy> policies;
  @JsonKey(name: 'members', includeIfNull: false, defaultValue: <Identity>[])
  final List<Identity> members;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'external', includeIfNull: false)
  final bool $external;
  @JsonKey(name: 'modify_index', includeIfNull: false)
  final double modifyIndex;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  static const fromJsonFactory = _$IdentityGroupFromJson;
  static const toJsonFactory = _$IdentityGroupToJson;
  Map<String, dynamic> toJson() => _$IdentityGroupToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityGroup &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.lastUpdateTime, lastUpdateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdateTime, lastUpdateTime)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.members, members) ||
                const DeepCollectionEquality()
                    .equals(other.members, members)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.$external, $external) ||
                const DeepCollectionEquality()
                    .equals(other.$external, $external)) &&
            (identical(other.modifyIndex, modifyIndex) ||
                const DeepCollectionEquality()
                    .equals(other.modifyIndex, modifyIndex)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(lastUpdateTime) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(members) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash($external) ^
      const DeepCollectionEquality().hash(modifyIndex) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $IdentityGroupExtension on IdentityGroup {
  IdentityGroup copyWith(
      {DateTime? creationTime,
      DateTime? lastUpdateTime,
      List<IdentityGroupAlias>? aliases,
      List<Policy>? policies,
      List<Identity>? members,
      String? id,
      String? name,
      String? description,
      String? color,
      bool? $external,
      double? modifyIndex,
      Object? metadata}) {
    return IdentityGroup(
        creationTime: creationTime ?? this.creationTime,
        lastUpdateTime: lastUpdateTime ?? this.lastUpdateTime,
        aliases: aliases ?? this.aliases,
        policies: policies ?? this.policies,
        members: members ?? this.members,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        $external: $external ?? this.$external,
        modifyIndex: modifyIndex ?? this.modifyIndex,
        metadata: metadata ?? this.metadata);
  }

  IdentityGroup copyWithWrapped(
      {Wrapped<DateTime>? creationTime,
      Wrapped<DateTime>? lastUpdateTime,
      Wrapped<List<IdentityGroupAlias>?>? aliases,
      Wrapped<List<Policy>>? policies,
      Wrapped<List<Identity>>? members,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? color,
      Wrapped<bool>? $external,
      Wrapped<double>? modifyIndex,
      Wrapped<Object>? metadata}) {
    return IdentityGroup(
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        lastUpdateTime: (lastUpdateTime != null
            ? lastUpdateTime.value
            : this.lastUpdateTime),
        aliases: (aliases != null ? aliases.value : this.aliases),
        policies: (policies != null ? policies.value : this.policies),
        members: (members != null ? members.value : this.members),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        $external: ($external != null ? $external.value : this.$external),
        modifyIndex:
            (modifyIndex != null ? modifyIndex.value : this.modifyIndex),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class Identity {
  Identity({
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.color,
    required this.creationTime,
    required this.lastUpdateTime,
    required this.aliases,
    required this.directGroupIds,
    required this.disabled,
    required this.groupIds,
    required this.inheritedGroupIds,
    required this.mergedEntityIds,
    required this.metadata,
    required this.groups,
    required this.skipWriteToVault,
    this.tenantId,
    this.oidcUsername,
  });

  factory Identity.fromJson(Map<String, dynamic> json) =>
      _$IdentityFromJson(json);

  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'creation_time', includeIfNull: false)
  final DateTime creationTime;
  @JsonKey(name: 'last_update_time', includeIfNull: false)
  final DateTime lastUpdateTime;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector> aliases;
  @JsonKey(
      name: 'direct_group_ids', includeIfNull: false, defaultValue: <String>[])
  final List<String> directGroupIds;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'group_ids', includeIfNull: false, defaultValue: <String>[])
  final List<String> groupIds;
  @JsonKey(
      name: 'inherited_group_ids',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String> inheritedGroupIds;
  @JsonKey(
      name: 'merged_entity_ids', includeIfNull: false, defaultValue: <String>[])
  final List<String> mergedEntityIds;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  @JsonKey(
      name: 'groups', includeIfNull: false, defaultValue: <IdentityGroup>[])
  final List<IdentityGroup> groups;
  @JsonKey(name: 'skipWriteToVault', includeIfNull: false)
  final bool skipWriteToVault;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  @JsonKey(name: 'oidcUsername', includeIfNull: false, defaultValue: '')
  final String? oidcUsername;
  static const fromJsonFactory = _$IdentityFromJson;
  static const toJsonFactory = _$IdentityToJson;
  Map<String, dynamic> toJson() => _$IdentityToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Identity &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.lastUpdateTime, lastUpdateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdateTime, lastUpdateTime)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.directGroupIds, directGroupIds) ||
                const DeepCollectionEquality()
                    .equals(other.directGroupIds, directGroupIds)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.groupIds, groupIds) ||
                const DeepCollectionEquality()
                    .equals(other.groupIds, groupIds)) &&
            (identical(other.inheritedGroupIds, inheritedGroupIds) ||
                const DeepCollectionEquality()
                    .equals(other.inheritedGroupIds, inheritedGroupIds)) &&
            (identical(other.mergedEntityIds, mergedEntityIds) ||
                const DeepCollectionEquality()
                    .equals(other.mergedEntityIds, mergedEntityIds)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.groups, groups) ||
                const DeepCollectionEquality().equals(other.groups, groups)) &&
            (identical(other.skipWriteToVault, skipWriteToVault) ||
                const DeepCollectionEquality()
                    .equals(other.skipWriteToVault, skipWriteToVault)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)) &&
            (identical(other.oidcUsername, oidcUsername) ||
                const DeepCollectionEquality()
                    .equals(other.oidcUsername, oidcUsername)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(lastUpdateTime) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(directGroupIds) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(groupIds) ^
      const DeepCollectionEquality().hash(inheritedGroupIds) ^
      const DeepCollectionEquality().hash(mergedEntityIds) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(groups) ^
      const DeepCollectionEquality().hash(skipWriteToVault) ^
      const DeepCollectionEquality().hash(tenantId) ^
      const DeepCollectionEquality().hash(oidcUsername) ^
      runtimeType.hashCode;
}

extension $IdentityExtension on Identity {
  Identity copyWith(
      {Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? color,
      DateTime? creationTime,
      DateTime? lastUpdateTime,
      List<IdentityConnector>? aliases,
      List<String>? directGroupIds,
      bool? disabled,
      List<String>? groupIds,
      List<String>? inheritedGroupIds,
      List<String>? mergedEntityIds,
      Object? metadata,
      List<IdentityGroup>? groups,
      bool? skipWriteToVault,
      String? tenantId,
      String? oidcUsername}) {
    return Identity(
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        creationTime: creationTime ?? this.creationTime,
        lastUpdateTime: lastUpdateTime ?? this.lastUpdateTime,
        aliases: aliases ?? this.aliases,
        directGroupIds: directGroupIds ?? this.directGroupIds,
        disabled: disabled ?? this.disabled,
        groupIds: groupIds ?? this.groupIds,
        inheritedGroupIds: inheritedGroupIds ?? this.inheritedGroupIds,
        mergedEntityIds: mergedEntityIds ?? this.mergedEntityIds,
        metadata: metadata ?? this.metadata,
        groups: groups ?? this.groups,
        skipWriteToVault: skipWriteToVault ?? this.skipWriteToVault,
        tenantId: tenantId ?? this.tenantId,
        oidcUsername: oidcUsername ?? this.oidcUsername);
  }

  Identity copyWithWrapped(
      {Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? color,
      Wrapped<DateTime>? creationTime,
      Wrapped<DateTime>? lastUpdateTime,
      Wrapped<List<IdentityConnector>>? aliases,
      Wrapped<List<String>>? directGroupIds,
      Wrapped<bool>? disabled,
      Wrapped<List<String>>? groupIds,
      Wrapped<List<String>>? inheritedGroupIds,
      Wrapped<List<String>>? mergedEntityIds,
      Wrapped<Object>? metadata,
      Wrapped<List<IdentityGroup>>? groups,
      Wrapped<bool>? skipWriteToVault,
      Wrapped<String?>? tenantId,
      Wrapped<String?>? oidcUsername}) {
    return Identity(
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        lastUpdateTime: (lastUpdateTime != null
            ? lastUpdateTime.value
            : this.lastUpdateTime),
        aliases: (aliases != null ? aliases.value : this.aliases),
        directGroupIds: (directGroupIds != null
            ? directGroupIds.value
            : this.directGroupIds),
        disabled: (disabled != null ? disabled.value : this.disabled),
        groupIds: (groupIds != null ? groupIds.value : this.groupIds),
        inheritedGroupIds: (inheritedGroupIds != null
            ? inheritedGroupIds.value
            : this.inheritedGroupIds),
        mergedEntityIds: (mergedEntityIds != null
            ? mergedEntityIds.value
            : this.mergedEntityIds),
        metadata: (metadata != null ? metadata.value : this.metadata),
        groups: (groups != null ? groups.value : this.groups),
        skipWriteToVault: (skipWriteToVault != null
            ? skipWriteToVault.value
            : this.skipWriteToVault),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId),
        oidcUsername:
            (oidcUsername != null ? oidcUsername.value : this.oidcUsername));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityConnector {
  IdentityConnector({
    required this.id,
    this.entity,
    required this.entityId,
    this.authenticationService,
    required this.authenticationServiceId,
    this.creationTime,
    this.lastUpdateTime,
    this.metadata,
    required this.name,
    required this.oidcUsername,
    this.mountPath,
    this.password,
    this.skipWriteToVault,
  });

  factory IdentityConnector.fromJson(Map<String, dynamic> json) =>
      _$IdentityConnectorFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'entity', includeIfNull: false)
  final Identity? entity;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String entityId;
  @JsonKey(name: 'authenticationService', includeIfNull: false)
  final Provider? authenticationService;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String authenticationServiceId;
  @JsonKey(name: 'creationTime', includeIfNull: false)
  final DateTime? creationTime;
  @JsonKey(name: 'lastUpdateTime', includeIfNull: false)
  final DateTime? lastUpdateTime;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'oidcUsername', includeIfNull: false, defaultValue: '')
  final String oidcUsername;
  @JsonKey(name: 'mountPath', includeIfNull: false, defaultValue: '')
  final String? mountPath;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  @JsonKey(name: 'skipWriteToVault', includeIfNull: false)
  final bool? skipWriteToVault;
  static const fromJsonFactory = _$IdentityConnectorFromJson;
  static const toJsonFactory = _$IdentityConnectorToJson;
  Map<String, dynamic> toJson() => _$IdentityConnectorToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityConnector &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.entity, entity) ||
                const DeepCollectionEquality().equals(other.entity, entity)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.authenticationService, authenticationService) ||
                const DeepCollectionEquality().equals(
                    other.authenticationService, authenticationService)) &&
            (identical(
                    other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)) &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.lastUpdateTime, lastUpdateTime) ||
                const DeepCollectionEquality()
                    .equals(other.lastUpdateTime, lastUpdateTime)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.oidcUsername, oidcUsername) ||
                const DeepCollectionEquality()
                    .equals(other.oidcUsername, oidcUsername)) &&
            (identical(other.mountPath, mountPath) ||
                const DeepCollectionEquality()
                    .equals(other.mountPath, mountPath)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.skipWriteToVault, skipWriteToVault) ||
                const DeepCollectionEquality()
                    .equals(other.skipWriteToVault, skipWriteToVault)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(entity) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(authenticationService) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(lastUpdateTime) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(oidcUsername) ^
      const DeepCollectionEquality().hash(mountPath) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(skipWriteToVault) ^
      runtimeType.hashCode;
}

extension $IdentityConnectorExtension on IdentityConnector {
  IdentityConnector copyWith(
      {String? id,
      Identity? entity,
      String? entityId,
      Provider? authenticationService,
      String? authenticationServiceId,
      DateTime? creationTime,
      DateTime? lastUpdateTime,
      Object? metadata,
      String? name,
      String? oidcUsername,
      String? mountPath,
      String? password,
      bool? skipWriteToVault}) {
    return IdentityConnector(
        id: id ?? this.id,
        entity: entity ?? this.entity,
        entityId: entityId ?? this.entityId,
        authenticationService:
            authenticationService ?? this.authenticationService,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId,
        creationTime: creationTime ?? this.creationTime,
        lastUpdateTime: lastUpdateTime ?? this.lastUpdateTime,
        metadata: metadata ?? this.metadata,
        name: name ?? this.name,
        oidcUsername: oidcUsername ?? this.oidcUsername,
        mountPath: mountPath ?? this.mountPath,
        password: password ?? this.password,
        skipWriteToVault: skipWriteToVault ?? this.skipWriteToVault);
  }

  IdentityConnector copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<Identity?>? entity,
      Wrapped<String>? entityId,
      Wrapped<Provider?>? authenticationService,
      Wrapped<String>? authenticationServiceId,
      Wrapped<DateTime?>? creationTime,
      Wrapped<DateTime?>? lastUpdateTime,
      Wrapped<Object?>? metadata,
      Wrapped<String>? name,
      Wrapped<String>? oidcUsername,
      Wrapped<String?>? mountPath,
      Wrapped<String?>? password,
      Wrapped<bool?>? skipWriteToVault}) {
    return IdentityConnector(
        id: (id != null ? id.value : this.id),
        entity: (entity != null ? entity.value : this.entity),
        entityId: (entityId != null ? entityId.value : this.entityId),
        authenticationService: (authenticationService != null
            ? authenticationService.value
            : this.authenticationService),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId),
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        lastUpdateTime: (lastUpdateTime != null
            ? lastUpdateTime.value
            : this.lastUpdateTime),
        metadata: (metadata != null ? metadata.value : this.metadata),
        name: (name != null ? name.value : this.name),
        oidcUsername:
            (oidcUsername != null ? oidcUsername.value : this.oidcUsername),
        mountPath: (mountPath != null ? mountPath.value : this.mountPath),
        password: (password != null ? password.value : this.password),
        skipWriteToVault: (skipWriteToVault != null
            ? skipWriteToVault.value
            : this.skipWriteToVault));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityCreateOptions {
  IdentityCreateOptions({
    this.color,
    this.description,
    this.name,
    this.oidcUsername,
  });

  factory IdentityCreateOptions.fromJson(Map<String, dynamic> json) =>
      _$IdentityCreateOptionsFromJson(json);

  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'oidcUsername', includeIfNull: false, defaultValue: '')
  final String? oidcUsername;
  static const fromJsonFactory = _$IdentityCreateOptionsFromJson;
  static const toJsonFactory = _$IdentityCreateOptionsToJson;
  Map<String, dynamic> toJson() => _$IdentityCreateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityCreateOptions &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.oidcUsername, oidcUsername) ||
                const DeepCollectionEquality()
                    .equals(other.oidcUsername, oidcUsername)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(oidcUsername) ^
      runtimeType.hashCode;
}

extension $IdentityCreateOptionsExtension on IdentityCreateOptions {
  IdentityCreateOptions copyWith(
      {String? color,
      String? description,
      String? name,
      String? oidcUsername}) {
    return IdentityCreateOptions(
        color: color ?? this.color,
        description: description ?? this.description,
        name: name ?? this.name,
        oidcUsername: oidcUsername ?? this.oidcUsername);
  }

  IdentityCreateOptions copyWithWrapped(
      {Wrapped<String?>? color,
      Wrapped<String?>? description,
      Wrapped<String?>? name,
      Wrapped<String?>? oidcUsername}) {
    return IdentityCreateOptions(
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        name: (name != null ? name.value : this.name),
        oidcUsername:
            (oidcUsername != null ? oidcUsername.value : this.oidcUsername));
  }
}

@JsonSerializable(explicitToJson: true)
class LoginOptions {
  LoginOptions({
    this.username,
    this.password,
    this.role,
    this.totp,
    this.authenticationServiceId,
    this.authenticationService,
    this.useKerberos,
    this.generateOIDC,
  });

  factory LoginOptions.fromJson(Map<String, dynamic> json) =>
      _$LoginOptionsFromJson(json);

  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  @JsonKey(name: 'role', includeIfNull: false, defaultValue: '')
  final String? role;
  @JsonKey(name: 'totp', includeIfNull: false, defaultValue: '')
  final String? totp;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String? authenticationServiceId;
  @JsonKey(
      name: 'authenticationService', includeIfNull: false, defaultValue: '')
  final String? authenticationService;
  @JsonKey(name: 'useKerberos', includeIfNull: false)
  final bool? useKerberos;
  @JsonKey(name: 'generateOIDC', includeIfNull: false, defaultValue: '')
  final String? generateOIDC;
  static const fromJsonFactory = _$LoginOptionsFromJson;
  static const toJsonFactory = _$LoginOptionsToJson;
  Map<String, dynamic> toJson() => _$LoginOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LoginOptions &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.role, role) ||
                const DeepCollectionEquality().equals(other.role, role)) &&
            (identical(other.totp, totp) ||
                const DeepCollectionEquality().equals(other.totp, totp)) &&
            (identical(
                    other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)) &&
            (identical(other.authenticationService, authenticationService) ||
                const DeepCollectionEquality().equals(
                    other.authenticationService, authenticationService)) &&
            (identical(other.useKerberos, useKerberos) ||
                const DeepCollectionEquality()
                    .equals(other.useKerberos, useKerberos)) &&
            (identical(other.generateOIDC, generateOIDC) ||
                const DeepCollectionEquality()
                    .equals(other.generateOIDC, generateOIDC)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(role) ^
      const DeepCollectionEquality().hash(totp) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      const DeepCollectionEquality().hash(authenticationService) ^
      const DeepCollectionEquality().hash(useKerberos) ^
      const DeepCollectionEquality().hash(generateOIDC) ^
      runtimeType.hashCode;
}

extension $LoginOptionsExtension on LoginOptions {
  LoginOptions copyWith(
      {String? username,
      String? password,
      String? role,
      String? totp,
      String? authenticationServiceId,
      String? authenticationService,
      bool? useKerberos,
      String? generateOIDC}) {
    return LoginOptions(
        username: username ?? this.username,
        password: password ?? this.password,
        role: role ?? this.role,
        totp: totp ?? this.totp,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId,
        authenticationService:
            authenticationService ?? this.authenticationService,
        useKerberos: useKerberos ?? this.useKerberos,
        generateOIDC: generateOIDC ?? this.generateOIDC);
  }

  LoginOptions copyWithWrapped(
      {Wrapped<String?>? username,
      Wrapped<String?>? password,
      Wrapped<String?>? role,
      Wrapped<String?>? totp,
      Wrapped<String?>? authenticationServiceId,
      Wrapped<String?>? authenticationService,
      Wrapped<bool?>? useKerberos,
      Wrapped<String?>? generateOIDC}) {
    return LoginOptions(
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password),
        role: (role != null ? role.value : this.role),
        totp: (totp != null ? totp.value : this.totp),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId),
        authenticationService: (authenticationService != null
            ? authenticationService.value
            : this.authenticationService),
        useKerberos:
            (useKerberos != null ? useKerberos.value : this.useKerberos),
        generateOIDC:
            (generateOIDC != null ? generateOIDC.value : this.generateOIDC));
  }
}

@JsonSerializable(explicitToJson: true)
class LoginResponse {
  LoginResponse({
    this.creationTime,
    this.creationTtl,
    this.displayName,
    this.entityId,
    this.expireTime,
    this.explicitMaxTtl,
    this.id,
    this.identityPolicies,
    this.issueTime,
    required this.meta,
    this.numUses,
    this.path,
    this.policies,
    this.renewable,
    this.ttl,
    this.entity,
    this.authUrl,
    this.authenticationServiceId,
    this.authenticationService,
    this.aliasId,
    this.oidcToken,
    this.tenantId,
    this.tenant,
    this.negotiate,
    this.isSaml,
  });

  factory LoginResponse.fromJson(Map<String, dynamic> json) =>
      _$LoginResponseFromJson(json);

  @JsonKey(name: 'creation_time', includeIfNull: false, defaultValue: '')
  final String? creationTime;
  @JsonKey(name: 'creation_ttl', includeIfNull: false, defaultValue: '')
  final String? creationTtl;
  @JsonKey(name: 'display_name', includeIfNull: false, defaultValue: '')
  final String? displayName;
  @JsonKey(name: 'entity_id', includeIfNull: false, defaultValue: '')
  final String? entityId;
  @JsonKey(name: 'expire_time', includeIfNull: false, defaultValue: '')
  final String? expireTime;
  @JsonKey(name: 'explicit_max_ttl', includeIfNull: false)
  final double? explicitMaxTtl;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(
      name: 'identity_policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? identityPolicies;
  @JsonKey(name: 'issue_time', includeIfNull: false, defaultValue: '')
  final String? issueTime;
  @JsonKey(name: 'meta', includeIfNull: false)
  final LoginResponse$Meta meta;
  @JsonKey(name: 'num_uses', includeIfNull: false)
  final double? numUses;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String? path;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? policies;
  @JsonKey(name: 'renewable', includeIfNull: false)
  final bool? renewable;
  @JsonKey(name: 'ttl', includeIfNull: false)
  final double? ttl;
  @JsonKey(name: 'entity', includeIfNull: false)
  final Identity? entity;
  @JsonKey(name: 'auth_url', includeIfNull: false, defaultValue: '')
  final String? authUrl;
  @JsonKey(
      name: 'authentication_service_id', includeIfNull: false, defaultValue: '')
  final String? authenticationServiceId;
  @JsonKey(name: 'authenticationService', includeIfNull: false)
  final Provider? authenticationService;
  @JsonKey(name: 'alias_id', includeIfNull: false, defaultValue: '')
  final String? aliasId;
  @JsonKey(name: 'oidc_token', includeIfNull: false, defaultValue: '')
  final String? oidcToken;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'negotiate', includeIfNull: false)
  final bool? negotiate;
  @JsonKey(name: 'isSaml', includeIfNull: false)
  final bool? isSaml;
  static const fromJsonFactory = _$LoginResponseFromJson;
  static const toJsonFactory = _$LoginResponseToJson;
  Map<String, dynamic> toJson() => _$LoginResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LoginResponse &&
            (identical(other.creationTime, creationTime) ||
                const DeepCollectionEquality()
                    .equals(other.creationTime, creationTime)) &&
            (identical(other.creationTtl, creationTtl) ||
                const DeepCollectionEquality()
                    .equals(other.creationTtl, creationTtl)) &&
            (identical(other.displayName, displayName) ||
                const DeepCollectionEquality()
                    .equals(other.displayName, displayName)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.expireTime, expireTime) ||
                const DeepCollectionEquality()
                    .equals(other.expireTime, expireTime)) &&
            (identical(other.explicitMaxTtl, explicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.explicitMaxTtl, explicitMaxTtl)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.identityPolicies, identityPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.identityPolicies, identityPolicies)) &&
            (identical(other.issueTime, issueTime) ||
                const DeepCollectionEquality()
                    .equals(other.issueTime, issueTime)) &&
            (identical(other.meta, meta) ||
                const DeepCollectionEquality().equals(other.meta, meta)) &&
            (identical(other.numUses, numUses) ||
                const DeepCollectionEquality()
                    .equals(other.numUses, numUses)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.renewable, renewable) ||
                const DeepCollectionEquality()
                    .equals(other.renewable, renewable)) &&
            (identical(other.ttl, ttl) ||
                const DeepCollectionEquality().equals(other.ttl, ttl)) &&
            (identical(other.entity, entity) ||
                const DeepCollectionEquality().equals(other.entity, entity)) &&
            (identical(other.authUrl, authUrl) ||
                const DeepCollectionEquality()
                    .equals(other.authUrl, authUrl)) &&
            (identical(other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)) &&
            (identical(other.authenticationService, authenticationService) ||
                const DeepCollectionEquality().equals(
                    other.authenticationService, authenticationService)) &&
            (identical(other.aliasId, aliasId) ||
                const DeepCollectionEquality()
                    .equals(other.aliasId, aliasId)) &&
            (identical(other.oidcToken, oidcToken) ||
                const DeepCollectionEquality()
                    .equals(other.oidcToken, oidcToken)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.negotiate, negotiate) ||
                const DeepCollectionEquality().equals(other.negotiate, negotiate)) &&
            (identical(other.isSaml, isSaml) || const DeepCollectionEquality().equals(other.isSaml, isSaml)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(creationTime) ^
      const DeepCollectionEquality().hash(creationTtl) ^
      const DeepCollectionEquality().hash(displayName) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(expireTime) ^
      const DeepCollectionEquality().hash(explicitMaxTtl) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(identityPolicies) ^
      const DeepCollectionEquality().hash(issueTime) ^
      const DeepCollectionEquality().hash(meta) ^
      const DeepCollectionEquality().hash(numUses) ^
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(renewable) ^
      const DeepCollectionEquality().hash(ttl) ^
      const DeepCollectionEquality().hash(entity) ^
      const DeepCollectionEquality().hash(authUrl) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      const DeepCollectionEquality().hash(authenticationService) ^
      const DeepCollectionEquality().hash(aliasId) ^
      const DeepCollectionEquality().hash(oidcToken) ^
      const DeepCollectionEquality().hash(tenantId) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(negotiate) ^
      const DeepCollectionEquality().hash(isSaml) ^
      runtimeType.hashCode;
}

extension $LoginResponseExtension on LoginResponse {
  LoginResponse copyWith(
      {String? creationTime,
      String? creationTtl,
      String? displayName,
      String? entityId,
      String? expireTime,
      double? explicitMaxTtl,
      String? id,
      List<String>? identityPolicies,
      String? issueTime,
      LoginResponse$Meta? meta,
      double? numUses,
      String? path,
      List<String>? policies,
      bool? renewable,
      double? ttl,
      Identity? entity,
      String? authUrl,
      String? authenticationServiceId,
      Provider? authenticationService,
      String? aliasId,
      String? oidcToken,
      String? tenantId,
      Tenant? tenant,
      bool? negotiate,
      bool? isSaml}) {
    return LoginResponse(
        creationTime: creationTime ?? this.creationTime,
        creationTtl: creationTtl ?? this.creationTtl,
        displayName: displayName ?? this.displayName,
        entityId: entityId ?? this.entityId,
        expireTime: expireTime ?? this.expireTime,
        explicitMaxTtl: explicitMaxTtl ?? this.explicitMaxTtl,
        id: id ?? this.id,
        identityPolicies: identityPolicies ?? this.identityPolicies,
        issueTime: issueTime ?? this.issueTime,
        meta: meta ?? this.meta,
        numUses: numUses ?? this.numUses,
        path: path ?? this.path,
        policies: policies ?? this.policies,
        renewable: renewable ?? this.renewable,
        ttl: ttl ?? this.ttl,
        entity: entity ?? this.entity,
        authUrl: authUrl ?? this.authUrl,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId,
        authenticationService:
            authenticationService ?? this.authenticationService,
        aliasId: aliasId ?? this.aliasId,
        oidcToken: oidcToken ?? this.oidcToken,
        tenantId: tenantId ?? this.tenantId,
        tenant: tenant ?? this.tenant,
        negotiate: negotiate ?? this.negotiate,
        isSaml: isSaml ?? this.isSaml);
  }

  LoginResponse copyWithWrapped(
      {Wrapped<String?>? creationTime,
      Wrapped<String?>? creationTtl,
      Wrapped<String?>? displayName,
      Wrapped<String?>? entityId,
      Wrapped<String?>? expireTime,
      Wrapped<double?>? explicitMaxTtl,
      Wrapped<String?>? id,
      Wrapped<List<String>?>? identityPolicies,
      Wrapped<String?>? issueTime,
      Wrapped<LoginResponse$Meta>? meta,
      Wrapped<double?>? numUses,
      Wrapped<String?>? path,
      Wrapped<List<String>?>? policies,
      Wrapped<bool?>? renewable,
      Wrapped<double?>? ttl,
      Wrapped<Identity?>? entity,
      Wrapped<String?>? authUrl,
      Wrapped<String?>? authenticationServiceId,
      Wrapped<Provider?>? authenticationService,
      Wrapped<String?>? aliasId,
      Wrapped<String?>? oidcToken,
      Wrapped<String?>? tenantId,
      Wrapped<Tenant?>? tenant,
      Wrapped<bool?>? negotiate,
      Wrapped<bool?>? isSaml}) {
    return LoginResponse(
        creationTime:
            (creationTime != null ? creationTime.value : this.creationTime),
        creationTtl:
            (creationTtl != null ? creationTtl.value : this.creationTtl),
        displayName:
            (displayName != null ? displayName.value : this.displayName),
        entityId: (entityId != null ? entityId.value : this.entityId),
        expireTime: (expireTime != null ? expireTime.value : this.expireTime),
        explicitMaxTtl: (explicitMaxTtl != null
            ? explicitMaxTtl.value
            : this.explicitMaxTtl),
        id: (id != null ? id.value : this.id),
        identityPolicies: (identityPolicies != null
            ? identityPolicies.value
            : this.identityPolicies),
        issueTime: (issueTime != null ? issueTime.value : this.issueTime),
        meta: (meta != null ? meta.value : this.meta),
        numUses: (numUses != null ? numUses.value : this.numUses),
        path: (path != null ? path.value : this.path),
        policies: (policies != null ? policies.value : this.policies),
        renewable: (renewable != null ? renewable.value : this.renewable),
        ttl: (ttl != null ? ttl.value : this.ttl),
        entity: (entity != null ? entity.value : this.entity),
        authUrl: (authUrl != null ? authUrl.value : this.authUrl),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId),
        authenticationService: (authenticationService != null
            ? authenticationService.value
            : this.authenticationService),
        aliasId: (aliasId != null ? aliasId.value : this.aliasId),
        oidcToken: (oidcToken != null ? oidcToken.value : this.oidcToken),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId),
        tenant: (tenant != null ? tenant.value : this.tenant),
        negotiate: (negotiate != null ? negotiate.value : this.negotiate),
        isSaml: (isSaml != null ? isSaml.value : this.isSaml));
  }
}

@JsonSerializable(explicitToJson: true)
class PostRegisterTotpResponse {
  PostRegisterTotpResponse({
    required this.barcode,
    required this.url,
  });

  factory PostRegisterTotpResponse.fromJson(Map<String, dynamic> json) =>
      _$PostRegisterTotpResponseFromJson(json);

  @JsonKey(name: 'barcode', includeIfNull: false, defaultValue: '')
  final String barcode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$PostRegisterTotpResponseFromJson;
  static const toJsonFactory = _$PostRegisterTotpResponseToJson;
  Map<String, dynamic> toJson() => _$PostRegisterTotpResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostRegisterTotpResponse &&
            (identical(other.barcode, barcode) ||
                const DeepCollectionEquality()
                    .equals(other.barcode, barcode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(barcode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $PostRegisterTotpResponseExtension on PostRegisterTotpResponse {
  PostRegisterTotpResponse copyWith({String? barcode, String? url}) {
    return PostRegisterTotpResponse(
        barcode: barcode ?? this.barcode, url: url ?? this.url);
  }

  PostRegisterTotpResponse copyWithWrapped(
      {Wrapped<String>? barcode, Wrapped<String>? url}) {
    return PostRegisterTotpResponse(
        barcode: (barcode != null ? barcode.value : this.barcode),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class TokenExchange {
  TokenExchange({
    required this.state,
    this.nonce,
    required this.code,
    this.authenticationServiceId,
  });

  factory TokenExchange.fromJson(Map<String, dynamic> json) =>
      _$TokenExchangeFromJson(json);

  @JsonKey(name: 'state', includeIfNull: false, defaultValue: '')
  final String state;
  @JsonKey(name: 'nonce', includeIfNull: false, defaultValue: '')
  final String? nonce;
  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String code;
  @JsonKey(
      name: 'authentication_service_id', includeIfNull: false, defaultValue: '')
  final String? authenticationServiceId;
  static const fromJsonFactory = _$TokenExchangeFromJson;
  static const toJsonFactory = _$TokenExchangeToJson;
  Map<String, dynamic> toJson() => _$TokenExchangeToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TokenExchange &&
            (identical(other.state, state) ||
                const DeepCollectionEquality().equals(other.state, state)) &&
            (identical(other.nonce, nonce) ||
                const DeepCollectionEquality().equals(other.nonce, nonce)) &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(
                    other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(state) ^
      const DeepCollectionEquality().hash(nonce) ^
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      runtimeType.hashCode;
}

extension $TokenExchangeExtension on TokenExchange {
  TokenExchange copyWith(
      {String? state,
      String? nonce,
      String? code,
      String? authenticationServiceId}) {
    return TokenExchange(
        state: state ?? this.state,
        nonce: nonce ?? this.nonce,
        code: code ?? this.code,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId);
  }

  TokenExchange copyWithWrapped(
      {Wrapped<String>? state,
      Wrapped<String?>? nonce,
      Wrapped<String>? code,
      Wrapped<String?>? authenticationServiceId}) {
    return TokenExchange(
        state: (state != null ? state.value : this.state),
        nonce: (nonce != null ? nonce.value : this.nonce),
        code: (code != null ? code.value : this.code),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityMergeOptions {
  IdentityMergeOptions({
    this.force,
    this.fromEntityIds,
    this.toEntityId,
  });

  factory IdentityMergeOptions.fromJson(Map<String, dynamic> json) =>
      _$IdentityMergeOptionsFromJson(json);

  @JsonKey(name: 'force', includeIfNull: false)
  final bool? force;
  @JsonKey(
      name: 'from_entity_ids', includeIfNull: false, defaultValue: <String>[])
  final List<String>? fromEntityIds;
  @JsonKey(name: 'to_entity_id', includeIfNull: false, defaultValue: '')
  final String? toEntityId;
  static const fromJsonFactory = _$IdentityMergeOptionsFromJson;
  static const toJsonFactory = _$IdentityMergeOptionsToJson;
  Map<String, dynamic> toJson() => _$IdentityMergeOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityMergeOptions &&
            (identical(other.force, force) ||
                const DeepCollectionEquality().equals(other.force, force)) &&
            (identical(other.fromEntityIds, fromEntityIds) ||
                const DeepCollectionEquality()
                    .equals(other.fromEntityIds, fromEntityIds)) &&
            (identical(other.toEntityId, toEntityId) ||
                const DeepCollectionEquality()
                    .equals(other.toEntityId, toEntityId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(force) ^
      const DeepCollectionEquality().hash(fromEntityIds) ^
      const DeepCollectionEquality().hash(toEntityId) ^
      runtimeType.hashCode;
}

extension $IdentityMergeOptionsExtension on IdentityMergeOptions {
  IdentityMergeOptions copyWith(
      {bool? force, List<String>? fromEntityIds, String? toEntityId}) {
    return IdentityMergeOptions(
        force: force ?? this.force,
        fromEntityIds: fromEntityIds ?? this.fromEntityIds,
        toEntityId: toEntityId ?? this.toEntityId);
  }

  IdentityMergeOptions copyWithWrapped(
      {Wrapped<bool?>? force,
      Wrapped<List<String>?>? fromEntityIds,
      Wrapped<String?>? toEntityId}) {
    return IdentityMergeOptions(
        force: (force != null ? force.value : this.force),
        fromEntityIds:
            (fromEntityIds != null ? fromEntityIds.value : this.fromEntityIds),
        toEntityId: (toEntityId != null ? toEntityId.value : this.toEntityId));
  }
}

@JsonSerializable(explicitToJson: true)
class TenantCreateOptions {
  TenantCreateOptions({
    this.color,
    this.description,
    this.metadata,
    required this.name,
    this.domain,
  });

  factory TenantCreateOptions.fromJson(Map<String, dynamic> json) =>
      _$TenantCreateOptionsFromJson(json);

  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String? domain;
  static const fromJsonFactory = _$TenantCreateOptionsFromJson;
  static const toJsonFactory = _$TenantCreateOptionsToJson;
  Map<String, dynamic> toJson() => _$TenantCreateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TenantCreateOptions &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(domain) ^
      runtimeType.hashCode;
}

extension $TenantCreateOptionsExtension on TenantCreateOptions {
  TenantCreateOptions copyWith(
      {String? color,
      String? description,
      Object? metadata,
      String? name,
      String? domain}) {
    return TenantCreateOptions(
        color: color ?? this.color,
        description: description ?? this.description,
        metadata: metadata ?? this.metadata,
        name: name ?? this.name,
        domain: domain ?? this.domain);
  }

  TenantCreateOptions copyWithWrapped(
      {Wrapped<String?>? color,
      Wrapped<String?>? description,
      Wrapped<Object?>? metadata,
      Wrapped<String>? name,
      Wrapped<String?>? domain}) {
    return TenantCreateOptions(
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        metadata: (metadata != null ? metadata.value : this.metadata),
        name: (name != null ? name.value : this.name),
        domain: (domain != null ? domain.value : this.domain));
  }
}

@JsonSerializable(explicitToJson: true)
class TenantUpdateResponse {
  TenantUpdateResponse({
    this.id,
    required this.name,
    this.description,
    this.color,
    this.domain,
    this.metadata,
  });

  factory TenantUpdateResponse.fromJson(Map<String, dynamic> json) =>
      _$TenantUpdateResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String? domain;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  static const fromJsonFactory = _$TenantUpdateResponseFromJson;
  static const toJsonFactory = _$TenantUpdateResponseToJson;
  Map<String, dynamic> toJson() => _$TenantUpdateResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TenantUpdateResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $TenantUpdateResponseExtension on TenantUpdateResponse {
  TenantUpdateResponse copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      String? domain,
      Object? metadata}) {
    return TenantUpdateResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        domain: domain ?? this.domain,
        metadata: metadata ?? this.metadata);
  }

  TenantUpdateResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<String?>? domain,
      Wrapped<Object?>? metadata}) {
    return TenantUpdateResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        domain: (domain != null ? domain.value : this.domain),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class TenantCreateResponse {
  TenantCreateResponse({
    this.id,
    required this.name,
    this.description,
    this.color,
    this.domain,
    this.metadata,
  });

  factory TenantCreateResponse.fromJson(Map<String, dynamic> json) =>
      _$TenantCreateResponseFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String? domain;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  static const fromJsonFactory = _$TenantCreateResponseFromJson;
  static const toJsonFactory = _$TenantCreateResponseToJson;
  Map<String, dynamic> toJson() => _$TenantCreateResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TenantCreateResponse &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $TenantCreateResponseExtension on TenantCreateResponse {
  TenantCreateResponse copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      String? domain,
      Object? metadata}) {
    return TenantCreateResponse(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        domain: domain ?? this.domain,
        metadata: metadata ?? this.metadata);
  }

  TenantCreateResponse copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<String?>? domain,
      Wrapped<Object?>? metadata}) {
    return TenantCreateResponse(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        domain: (domain != null ? domain.value : this.domain),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class AclCapabilitiesOptions {
  AclCapabilitiesOptions({
    required this.paths,
    this.token,
  });

  factory AclCapabilitiesOptions.fromJson(Map<String, dynamic> json) =>
      _$AclCapabilitiesOptionsFromJson(json);

  @JsonKey(name: 'paths', includeIfNull: false, defaultValue: <String>[])
  final List<String> paths;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$AclCapabilitiesOptionsFromJson;
  static const toJsonFactory = _$AclCapabilitiesOptionsToJson;
  Map<String, dynamic> toJson() => _$AclCapabilitiesOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AclCapabilitiesOptions &&
            (identical(other.paths, paths) ||
                const DeepCollectionEquality().equals(other.paths, paths)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(paths) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $AclCapabilitiesOptionsExtension on AclCapabilitiesOptions {
  AclCapabilitiesOptions copyWith({List<String>? paths, String? token}) {
    return AclCapabilitiesOptions(
        paths: paths ?? this.paths, token: token ?? this.token);
  }

  AclCapabilitiesOptions copyWithWrapped(
      {Wrapped<List<String>>? paths, Wrapped<String?>? token}) {
    return AclCapabilitiesOptions(
        paths: (paths != null ? paths.value : this.paths),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class AclCapabilitiesResponse {
  AclCapabilitiesResponse({
    required this.path,
    required this.capabilities,
  });

  factory AclCapabilitiesResponse.fromJson(Map<String, dynamic> json) =>
      _$AclCapabilitiesResponseFromJson(json);

  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  @JsonKey(name: 'capabilities', includeIfNull: false, defaultValue: <String>[])
  final List<String> capabilities;
  static const fromJsonFactory = _$AclCapabilitiesResponseFromJson;
  static const toJsonFactory = _$AclCapabilitiesResponseToJson;
  Map<String, dynamic> toJson() => _$AclCapabilitiesResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AclCapabilitiesResponse &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.capabilities, capabilities) ||
                const DeepCollectionEquality()
                    .equals(other.capabilities, capabilities)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(capabilities) ^
      runtimeType.hashCode;
}

extension $AclCapabilitiesResponseExtension on AclCapabilitiesResponse {
  AclCapabilitiesResponse copyWith({String? path, List<String>? capabilities}) {
    return AclCapabilitiesResponse(
        path: path ?? this.path,
        capabilities: capabilities ?? this.capabilities);
  }

  AclCapabilitiesResponse copyWithWrapped(
      {Wrapped<String>? path, Wrapped<List<String>>? capabilities}) {
    return AclCapabilitiesResponse(
        path: (path != null ? path.value : this.path),
        capabilities:
            (capabilities != null ? capabilities.value : this.capabilities));
  }
}

@JsonSerializable(explicitToJson: true)
class GetIdentityOidcConfigResponse {
  GetIdentityOidcConfigResponse();

  factory GetIdentityOidcConfigResponse.fromJson(Map<String, dynamic> json) =>
      _$GetIdentityOidcConfigResponseFromJson(json);

  static const fromJsonFactory = _$GetIdentityOidcConfigResponseFromJson;
  static const toJsonFactory = _$GetIdentityOidcConfigResponseToJson;
  Map<String, dynamic> toJson() => _$GetIdentityOidcConfigResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcKeyName {
  PostIdentityOidcKeyName({
    this.algorithm,
    this.allowedClientIds,
    this.rotationPeriod,
    this.verificationTtl,
    this.name,
  });

  factory PostIdentityOidcKeyName.fromJson(Map<String, dynamic> json) =>
      _$PostIdentityOidcKeyNameFromJson(json);

  @JsonKey(name: 'algorithm', includeIfNull: false, defaultValue: '')
  final String? algorithm;
  @JsonKey(
      name: 'allowed_client_ids',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? allowedClientIds;
  @JsonKey(name: 'rotation_period', includeIfNull: false, defaultValue: '')
  final String? rotationPeriod;
  @JsonKey(name: 'verification_ttl', includeIfNull: false, defaultValue: '')
  final String? verificationTtl;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$PostIdentityOidcKeyNameFromJson;
  static const toJsonFactory = _$PostIdentityOidcKeyNameToJson;
  Map<String, dynamic> toJson() => _$PostIdentityOidcKeyNameToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostIdentityOidcKeyName &&
            (identical(other.algorithm, algorithm) ||
                const DeepCollectionEquality()
                    .equals(other.algorithm, algorithm)) &&
            (identical(other.allowedClientIds, allowedClientIds) ||
                const DeepCollectionEquality()
                    .equals(other.allowedClientIds, allowedClientIds)) &&
            (identical(other.rotationPeriod, rotationPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.rotationPeriod, rotationPeriod)) &&
            (identical(other.verificationTtl, verificationTtl) ||
                const DeepCollectionEquality()
                    .equals(other.verificationTtl, verificationTtl)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(algorithm) ^
      const DeepCollectionEquality().hash(allowedClientIds) ^
      const DeepCollectionEquality().hash(rotationPeriod) ^
      const DeepCollectionEquality().hash(verificationTtl) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $PostIdentityOidcKeyNameExtension on PostIdentityOidcKeyName {
  PostIdentityOidcKeyName copyWith(
      {String? algorithm,
      List<String>? allowedClientIds,
      String? rotationPeriod,
      String? verificationTtl,
      String? name}) {
    return PostIdentityOidcKeyName(
        algorithm: algorithm ?? this.algorithm,
        allowedClientIds: allowedClientIds ?? this.allowedClientIds,
        rotationPeriod: rotationPeriod ?? this.rotationPeriod,
        verificationTtl: verificationTtl ?? this.verificationTtl,
        name: name ?? this.name);
  }

  PostIdentityOidcKeyName copyWithWrapped(
      {Wrapped<String?>? algorithm,
      Wrapped<List<String>?>? allowedClientIds,
      Wrapped<String?>? rotationPeriod,
      Wrapped<String?>? verificationTtl,
      Wrapped<String?>? name}) {
    return PostIdentityOidcKeyName(
        algorithm: (algorithm != null ? algorithm.value : this.algorithm),
        allowedClientIds: (allowedClientIds != null
            ? allowedClientIds.value
            : this.allowedClientIds),
        rotationPeriod: (rotationPeriod != null
            ? rotationPeriod.value
            : this.rotationPeriod),
        verificationTtl: (verificationTtl != null
            ? verificationTtl.value
            : this.verificationTtl),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcRoleMetaData {
  OidcRoleMetaData({
    this.secureableUrl,
    this.clientId,
    this.key,
    this.template,
    this.ttl,
    this.name,
  });

  factory OidcRoleMetaData.fromJson(Map<String, dynamic> json) =>
      _$OidcRoleMetaDataFromJson(json);

  @JsonKey(name: 'secureableUrl', includeIfNull: false, defaultValue: '')
  final String? secureableUrl;
  @JsonKey(name: 'client_id', includeIfNull: false, defaultValue: '')
  final String? clientId;
  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String? key;
  @JsonKey(name: 'template', includeIfNull: false, defaultValue: '')
  final String? template;
  @JsonKey(name: 'ttl', includeIfNull: false, defaultValue: '')
  final String? ttl;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$OidcRoleMetaDataFromJson;
  static const toJsonFactory = _$OidcRoleMetaDataToJson;
  Map<String, dynamic> toJson() => _$OidcRoleMetaDataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcRoleMetaData &&
            (identical(other.secureableUrl, secureableUrl) ||
                const DeepCollectionEquality()
                    .equals(other.secureableUrl, secureableUrl)) &&
            (identical(other.clientId, clientId) ||
                const DeepCollectionEquality()
                    .equals(other.clientId, clientId)) &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.template, template) ||
                const DeepCollectionEquality()
                    .equals(other.template, template)) &&
            (identical(other.ttl, ttl) ||
                const DeepCollectionEquality().equals(other.ttl, ttl)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(secureableUrl) ^
      const DeepCollectionEquality().hash(clientId) ^
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(template) ^
      const DeepCollectionEquality().hash(ttl) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $OidcRoleMetaDataExtension on OidcRoleMetaData {
  OidcRoleMetaData copyWith(
      {String? secureableUrl,
      String? clientId,
      String? key,
      String? template,
      String? ttl,
      String? name}) {
    return OidcRoleMetaData(
        secureableUrl: secureableUrl ?? this.secureableUrl,
        clientId: clientId ?? this.clientId,
        key: key ?? this.key,
        template: template ?? this.template,
        ttl: ttl ?? this.ttl,
        name: name ?? this.name);
  }

  OidcRoleMetaData copyWithWrapped(
      {Wrapped<String?>? secureableUrl,
      Wrapped<String?>? clientId,
      Wrapped<String?>? key,
      Wrapped<String?>? template,
      Wrapped<String?>? ttl,
      Wrapped<String?>? name}) {
    return OidcRoleMetaData(
        secureableUrl:
            (secureableUrl != null ? secureableUrl.value : this.secureableUrl),
        clientId: (clientId != null ? clientId.value : this.clientId),
        key: (key != null ? key.value : this.key),
        template: (template != null ? template.value : this.template),
        ttl: (ttl != null ? ttl.value : this.ttl),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcKey {
  OidcKey({
    this.id,
    required this.name,
    required this.description,
    this.color,
    required this.metadata,
    this.oidcRoles,
  });

  factory OidcKey.fromJson(Map<String, dynamic> json) =>
      _$OidcKeyFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final PostIdentityOidcKeyName metadata;
  @JsonKey(name: 'oidcRoles', includeIfNull: false, defaultValue: <OidcRole>[])
  final List<OidcRole>? oidcRoles;
  static const fromJsonFactory = _$OidcKeyFromJson;
  static const toJsonFactory = _$OidcKeyToJson;
  Map<String, dynamic> toJson() => _$OidcKeyToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcKey &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.oidcRoles, oidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.oidcRoles, oidcRoles)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(oidcRoles) ^
      runtimeType.hashCode;
}

extension $OidcKeyExtension on OidcKey {
  OidcKey copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      PostIdentityOidcKeyName? metadata,
      List<OidcRole>? oidcRoles}) {
    return OidcKey(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        metadata: metadata ?? this.metadata,
        oidcRoles: oidcRoles ?? this.oidcRoles);
  }

  OidcKey copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String?>? color,
      Wrapped<PostIdentityOidcKeyName>? metadata,
      Wrapped<List<OidcRole>?>? oidcRoles}) {
    return OidcKey(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        metadata: (metadata != null ? metadata.value : this.metadata),
        oidcRoles: (oidcRoles != null ? oidcRoles.value : this.oidcRoles));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcRoleTemplate {
  OidcRoleTemplate({
    this.id,
    required this.name,
    required this.description,
    required this.color,
    required this.content,
    this.oidcRoles,
  });

  factory OidcRoleTemplate.fromJson(Map<String, dynamic> json) =>
      _$OidcRoleTemplateFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'content', includeIfNull: false, defaultValue: '')
  final String content;
  @JsonKey(name: 'oidcRoles', includeIfNull: false, defaultValue: <OidcRole>[])
  final List<OidcRole>? oidcRoles;
  static const fromJsonFactory = _$OidcRoleTemplateFromJson;
  static const toJsonFactory = _$OidcRoleTemplateToJson;
  Map<String, dynamic> toJson() => _$OidcRoleTemplateToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcRoleTemplate &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.content, content) ||
                const DeepCollectionEquality()
                    .equals(other.content, content)) &&
            (identical(other.oidcRoles, oidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.oidcRoles, oidcRoles)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(content) ^
      const DeepCollectionEquality().hash(oidcRoles) ^
      runtimeType.hashCode;
}

extension $OidcRoleTemplateExtension on OidcRoleTemplate {
  OidcRoleTemplate copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      String? content,
      List<OidcRole>? oidcRoles}) {
    return OidcRoleTemplate(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        content: content ?? this.content,
        oidcRoles: oidcRoles ?? this.oidcRoles);
  }

  OidcRoleTemplate copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? color,
      Wrapped<String>? content,
      Wrapped<List<OidcRole>?>? oidcRoles}) {
    return OidcRoleTemplate(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        content: (content != null ? content.value : this.content),
        oidcRoles: (oidcRoles != null ? oidcRoles.value : this.oidcRoles));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcRole {
  OidcRole({
    this.id,
    required this.name,
    required this.description,
    required this.color,
    required this.metadata,
    required this.vaultData,
    this.oidcKeyId,
    this.oidcKey,
    this.templates,
  });

  factory OidcRole.fromJson(Map<String, dynamic> json) =>
      _$OidcRoleFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  @JsonKey(name: 'vaultData', includeIfNull: false)
  final OidcRoleMetaData vaultData;
  @JsonKey(name: 'oidcKeyId', includeIfNull: false, defaultValue: '')
  final String? oidcKeyId;
  @JsonKey(name: 'oidcKey', includeIfNull: false)
  final OidcKey? oidcKey;
  @JsonKey(
      name: 'templates',
      includeIfNull: false,
      defaultValue: <OidcRoleTemplate>[])
  final List<OidcRoleTemplate>? templates;
  static const fromJsonFactory = _$OidcRoleFromJson;
  static const toJsonFactory = _$OidcRoleToJson;
  Map<String, dynamic> toJson() => _$OidcRoleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcRole &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.vaultData, vaultData) ||
                const DeepCollectionEquality()
                    .equals(other.vaultData, vaultData)) &&
            (identical(other.oidcKeyId, oidcKeyId) ||
                const DeepCollectionEquality()
                    .equals(other.oidcKeyId, oidcKeyId)) &&
            (identical(other.oidcKey, oidcKey) ||
                const DeepCollectionEquality()
                    .equals(other.oidcKey, oidcKey)) &&
            (identical(other.templates, templates) ||
                const DeepCollectionEquality()
                    .equals(other.templates, templates)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(vaultData) ^
      const DeepCollectionEquality().hash(oidcKeyId) ^
      const DeepCollectionEquality().hash(oidcKey) ^
      const DeepCollectionEquality().hash(templates) ^
      runtimeType.hashCode;
}

extension $OidcRoleExtension on OidcRole {
  OidcRole copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      Object? metadata,
      OidcRoleMetaData? vaultData,
      String? oidcKeyId,
      OidcKey? oidcKey,
      List<OidcRoleTemplate>? templates}) {
    return OidcRole(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        metadata: metadata ?? this.metadata,
        vaultData: vaultData ?? this.vaultData,
        oidcKeyId: oidcKeyId ?? this.oidcKeyId,
        oidcKey: oidcKey ?? this.oidcKey,
        templates: templates ?? this.templates);
  }

  OidcRole copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? color,
      Wrapped<Object>? metadata,
      Wrapped<OidcRoleMetaData>? vaultData,
      Wrapped<String?>? oidcKeyId,
      Wrapped<OidcKey?>? oidcKey,
      Wrapped<List<OidcRoleTemplate>?>? templates}) {
    return OidcRole(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        metadata: (metadata != null ? metadata.value : this.metadata),
        vaultData: (vaultData != null ? vaultData.value : this.vaultData),
        oidcKeyId: (oidcKeyId != null ? oidcKeyId.value : this.oidcKeyId),
        oidcKey: (oidcKey != null ? oidcKey.value : this.oidcKey),
        templates: (templates != null ? templates.value : this.templates));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcTokenName {
  OidcTokenName({
    required this.clientId,
    required this.token,
    required this.ttl,
  });

  factory OidcTokenName.fromJson(Map<String, dynamic> json) =>
      _$OidcTokenNameFromJson(json);

  @JsonKey(name: 'client_id', includeIfNull: false, defaultValue: '')
  final String clientId;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String token;
  @JsonKey(name: 'ttl', includeIfNull: false)
  final double ttl;
  static const fromJsonFactory = _$OidcTokenNameFromJson;
  static const toJsonFactory = _$OidcTokenNameToJson;
  Map<String, dynamic> toJson() => _$OidcTokenNameToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcTokenName &&
            (identical(other.clientId, clientId) ||
                const DeepCollectionEquality()
                    .equals(other.clientId, clientId)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.ttl, ttl) ||
                const DeepCollectionEquality().equals(other.ttl, ttl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientId) ^
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(ttl) ^
      runtimeType.hashCode;
}

extension $OidcTokenNameExtension on OidcTokenName {
  OidcTokenName copyWith({String? clientId, String? token, double? ttl}) {
    return OidcTokenName(
        clientId: clientId ?? this.clientId,
        token: token ?? this.token,
        ttl: ttl ?? this.ttl);
  }

  OidcTokenName copyWithWrapped(
      {Wrapped<String>? clientId,
      Wrapped<String>? token,
      Wrapped<double>? ttl}) {
    return OidcTokenName(
        clientId: (clientId != null ? clientId.value : this.clientId),
        token: (token != null ? token.value : this.token),
        ttl: (ttl != null ? ttl.value : this.ttl));
  }
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcConfig {
  PostIdentityOidcConfig({
    this.issuer,
  });

  factory PostIdentityOidcConfig.fromJson(Map<String, dynamic> json) =>
      _$PostIdentityOidcConfigFromJson(json);

  @JsonKey(name: 'issuer', includeIfNull: false, defaultValue: '')
  final String? issuer;
  static const fromJsonFactory = _$PostIdentityOidcConfigFromJson;
  static const toJsonFactory = _$PostIdentityOidcConfigToJson;
  Map<String, dynamic> toJson() => _$PostIdentityOidcConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostIdentityOidcConfig &&
            (identical(other.issuer, issuer) ||
                const DeepCollectionEquality().equals(other.issuer, issuer)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(issuer) ^ runtimeType.hashCode;
}

extension $PostIdentityOidcConfigExtension on PostIdentityOidcConfig {
  PostIdentityOidcConfig copyWith({String? issuer}) {
    return PostIdentityOidcConfig(issuer: issuer ?? this.issuer);
  }

  PostIdentityOidcConfig copyWithWrapped({Wrapped<String?>? issuer}) {
    return PostIdentityOidcConfig(
        issuer: (issuer != null ? issuer.value : this.issuer));
  }
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcConfigResponse {
  PostIdentityOidcConfigResponse();

  factory PostIdentityOidcConfigResponse.fromJson(Map<String, dynamic> json) =>
      _$PostIdentityOidcConfigResponseFromJson(json);

  static const fromJsonFactory = _$PostIdentityOidcConfigResponseFromJson;
  static const toJsonFactory = _$PostIdentityOidcConfigResponseToJson;
  Map<String, dynamic> toJson() => _$PostIdentityOidcConfigResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcIntrospect {
  PostIdentityOidcIntrospect({
    this.clientId,
    this.token,
  });

  factory PostIdentityOidcIntrospect.fromJson(Map<String, dynamic> json) =>
      _$PostIdentityOidcIntrospectFromJson(json);

  @JsonKey(name: 'client_id', includeIfNull: false, defaultValue: '')
  final String? clientId;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String? token;
  static const fromJsonFactory = _$PostIdentityOidcIntrospectFromJson;
  static const toJsonFactory = _$PostIdentityOidcIntrospectToJson;
  Map<String, dynamic> toJson() => _$PostIdentityOidcIntrospectToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostIdentityOidcIntrospect &&
            (identical(other.clientId, clientId) ||
                const DeepCollectionEquality()
                    .equals(other.clientId, clientId)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientId) ^
      const DeepCollectionEquality().hash(token) ^
      runtimeType.hashCode;
}

extension $PostIdentityOidcIntrospectExtension on PostIdentityOidcIntrospect {
  PostIdentityOidcIntrospect copyWith({String? clientId, String? token}) {
    return PostIdentityOidcIntrospect(
        clientId: clientId ?? this.clientId, token: token ?? this.token);
  }

  PostIdentityOidcIntrospect copyWithWrapped(
      {Wrapped<String?>? clientId, Wrapped<String?>? token}) {
    return PostIdentityOidcIntrospect(
        clientId: (clientId != null ? clientId.value : this.clientId),
        token: (token != null ? token.value : this.token));
  }
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcIntrospectResponse {
  PostIdentityOidcIntrospectResponse();

  factory PostIdentityOidcIntrospectResponse.fromJson(
          Map<String, dynamic> json) =>
      _$PostIdentityOidcIntrospectResponseFromJson(json);

  static const fromJsonFactory = _$PostIdentityOidcIntrospectResponseFromJson;
  static const toJsonFactory = _$PostIdentityOidcIntrospectResponseToJson;
  Map<String, dynamic> toJson() =>
      _$PostIdentityOidcIntrospectResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcKeyNameRotate {
  PostIdentityOidcKeyNameRotate({
    this.verificationTtl,
    this.name,
  });

  factory PostIdentityOidcKeyNameRotate.fromJson(Map<String, dynamic> json) =>
      _$PostIdentityOidcKeyNameRotateFromJson(json);

  @JsonKey(name: 'verification_ttl', includeIfNull: false, defaultValue: '')
  final String? verificationTtl;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$PostIdentityOidcKeyNameRotateFromJson;
  static const toJsonFactory = _$PostIdentityOidcKeyNameRotateToJson;
  Map<String, dynamic> toJson() => _$PostIdentityOidcKeyNameRotateToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostIdentityOidcKeyNameRotate &&
            (identical(other.verificationTtl, verificationTtl) ||
                const DeepCollectionEquality()
                    .equals(other.verificationTtl, verificationTtl)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(verificationTtl) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $PostIdentityOidcKeyNameRotateExtension
    on PostIdentityOidcKeyNameRotate {
  PostIdentityOidcKeyNameRotate copyWith(
      {String? verificationTtl, String? name}) {
    return PostIdentityOidcKeyNameRotate(
        verificationTtl: verificationTtl ?? this.verificationTtl,
        name: name ?? this.name);
  }

  PostIdentityOidcKeyNameRotate copyWithWrapped(
      {Wrapped<String?>? verificationTtl, Wrapped<String?>? name}) {
    return PostIdentityOidcKeyNameRotate(
        verificationTtl: (verificationTtl != null
            ? verificationTtl.value
            : this.verificationTtl),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class PostIdentityOidcKeyNameRotateResponse {
  PostIdentityOidcKeyNameRotateResponse();

  factory PostIdentityOidcKeyNameRotateResponse.fromJson(
          Map<String, dynamic> json) =>
      _$PostIdentityOidcKeyNameRotateResponseFromJson(json);

  static const fromJsonFactory =
      _$PostIdentityOidcKeyNameRotateResponseFromJson;
  static const toJsonFactory = _$PostIdentityOidcKeyNameRotateResponseToJson;
  Map<String, dynamic> toJson() =>
      _$PostIdentityOidcKeyNameRotateResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class GetIdentityOidcWellKnownKeysResponse {
  GetIdentityOidcWellKnownKeysResponse();

  factory GetIdentityOidcWellKnownKeysResponse.fromJson(
          Map<String, dynamic> json) =>
      _$GetIdentityOidcWellKnownKeysResponseFromJson(json);

  static const fromJsonFactory = _$GetIdentityOidcWellKnownKeysResponseFromJson;
  static const toJsonFactory = _$GetIdentityOidcWellKnownKeysResponseToJson;
  Map<String, dynamic> toJson() =>
      _$GetIdentityOidcWellKnownKeysResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class GetIdentityOidcWellKnownOpenidConfigurationResponse {
  GetIdentityOidcWellKnownOpenidConfigurationResponse();

  factory GetIdentityOidcWellKnownOpenidConfigurationResponse.fromJson(
          Map<String, dynamic> json) =>
      _$GetIdentityOidcWellKnownOpenidConfigurationResponseFromJson(json);

  static const fromJsonFactory =
      _$GetIdentityOidcWellKnownOpenidConfigurationResponseFromJson;
  static const toJsonFactory =
      _$GetIdentityOidcWellKnownOpenidConfigurationResponseToJson;
  Map<String, dynamic> toJson() =>
      _$GetIdentityOidcWellKnownOpenidConfigurationResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class ProviderInfo {
  ProviderInfo({
    required this.id,
    required this.name,
    required this.type,
    this.enableTotp,
    required this.description,
    required this.icon,
    required this.tenant,
  });

  factory ProviderInfo.fromJson(Map<String, dynamic> json) =>
      _$ProviderInfoFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant tenant;
  static const fromJsonFactory = _$ProviderInfoFromJson;
  static const toJsonFactory = _$ProviderInfoToJson;
  Map<String, dynamic> toJson() => _$ProviderInfoToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ProviderInfo &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(tenant) ^
      runtimeType.hashCode;
}

extension $ProviderInfoExtension on ProviderInfo {
  ProviderInfo copyWith(
      {String? id,
      String? name,
      String? type,
      bool? enableTotp,
      String? description,
      String? icon,
      Tenant? tenant}) {
    return ProviderInfo(
        id: id ?? this.id,
        name: name ?? this.name,
        type: type ?? this.type,
        enableTotp: enableTotp ?? this.enableTotp,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        tenant: tenant ?? this.tenant);
  }

  ProviderInfo copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? type,
      Wrapped<bool?>? enableTotp,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<Tenant>? tenant}) {
    return ProviderInfo(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        type: (type != null ? type.value : this.type),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        tenant: (tenant != null ? tenant.value : this.tenant));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyUpdateOptions {
  PolicyUpdateOptions({
    this.name,
    this.description,
    this.color,
    this.disabled,
    this.metadata,
    required this.id,
    this.type,
  });

  factory PolicyUpdateOptions.fromJson(Map<String, dynamic> json) =>
      _$PolicyUpdateOptionsFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool? disabled;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final PolicyMetaData? metadata;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: policyUpdateOptionsTypeToJson,
    fromJson: policyUpdateOptionsTypeFromJson,
  )
  final enums.PolicyUpdateOptionsType? type;
  static const fromJsonFactory = _$PolicyUpdateOptionsFromJson;
  static const toJsonFactory = _$PolicyUpdateOptionsToJson;
  Map<String, dynamic> toJson() => _$PolicyUpdateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyUpdateOptions &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $PolicyUpdateOptionsExtension on PolicyUpdateOptions {
  PolicyUpdateOptions copyWith(
      {String? name,
      String? description,
      String? color,
      bool? disabled,
      PolicyMetaData? metadata,
      String? id,
      enums.PolicyUpdateOptionsType? type}) {
    return PolicyUpdateOptions(
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        disabled: disabled ?? this.disabled,
        metadata: metadata ?? this.metadata,
        id: id ?? this.id,
        type: type ?? this.type);
  }

  PolicyUpdateOptions copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<bool?>? disabled,
      Wrapped<PolicyMetaData?>? metadata,
      Wrapped<String>? id,
      Wrapped<enums.PolicyUpdateOptionsType?>? type}) {
    return PolicyUpdateOptions(
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        disabled: (disabled != null ? disabled.value : this.disabled),
        metadata: (metadata != null ? metadata.value : this.metadata),
        id: (id != null ? id.value : this.id),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyCreateOptions {
  PolicyCreateOptions({
    this.name,
    this.description,
    this.color,
    this.disabled,
    this.metadata,
    this.type,
  });

  factory PolicyCreateOptions.fromJson(Map<String, dynamic> json) =>
      _$PolicyCreateOptionsFromJson(json);

  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool? disabled;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final PolicyMetaData? metadata;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: policyCreateOptionsTypeToJson,
    fromJson: policyCreateOptionsTypeFromJson,
  )
  final enums.PolicyCreateOptionsType? type;
  static const fromJsonFactory = _$PolicyCreateOptionsFromJson;
  static const toJsonFactory = _$PolicyCreateOptionsToJson;
  Map<String, dynamic> toJson() => _$PolicyCreateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyCreateOptions &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $PolicyCreateOptionsExtension on PolicyCreateOptions {
  PolicyCreateOptions copyWith(
      {String? name,
      String? description,
      String? color,
      bool? disabled,
      PolicyMetaData? metadata,
      enums.PolicyCreateOptionsType? type}) {
    return PolicyCreateOptions(
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        disabled: disabled ?? this.disabled,
        metadata: metadata ?? this.metadata,
        type: type ?? this.type);
  }

  PolicyCreateOptions copyWithWrapped(
      {Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<bool?>? disabled,
      Wrapped<PolicyMetaData?>? metadata,
      Wrapped<enums.PolicyCreateOptionsType?>? type}) {
    return PolicyCreateOptions(
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        disabled: (disabled != null ? disabled.value : this.disabled),
        metadata: (metadata != null ? metadata.value : this.metadata),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyPathOption {
  PolicyPathOption({
    this.id,
    required this.label,
    required this.capability,
    this.vaultCapability,
    this.path,
    this.subPath,
    this.vaultPath,
    this.pattern,
    this.description,
  });

  factory PolicyPathOption.fromJson(Map<String, dynamic> json) =>
      _$PolicyPathOptionFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'label', includeIfNull: false, defaultValue: '')
  final String label;
  @JsonKey(name: 'capability', includeIfNull: false, defaultValue: '')
  final String capability;
  @JsonKey(name: 'vaultCapability', includeIfNull: false, defaultValue: '')
  final String? vaultCapability;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String? path;
  @JsonKey(name: 'subPath', includeIfNull: false, defaultValue: '')
  final String? subPath;
  @JsonKey(name: 'vaultPath', includeIfNull: false, defaultValue: <String>[])
  final List<String>? vaultPath;
  @JsonKey(name: 'pattern', includeIfNull: false, defaultValue: '')
  final String? pattern;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  static const fromJsonFactory = _$PolicyPathOptionFromJson;
  static const toJsonFactory = _$PolicyPathOptionToJson;
  Map<String, dynamic> toJson() => _$PolicyPathOptionToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyPathOption &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.label, label) ||
                const DeepCollectionEquality().equals(other.label, label)) &&
            (identical(other.capability, capability) ||
                const DeepCollectionEquality()
                    .equals(other.capability, capability)) &&
            (identical(other.vaultCapability, vaultCapability) ||
                const DeepCollectionEquality()
                    .equals(other.vaultCapability, vaultCapability)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.subPath, subPath) ||
                const DeepCollectionEquality()
                    .equals(other.subPath, subPath)) &&
            (identical(other.vaultPath, vaultPath) ||
                const DeepCollectionEquality()
                    .equals(other.vaultPath, vaultPath)) &&
            (identical(other.pattern, pattern) ||
                const DeepCollectionEquality()
                    .equals(other.pattern, pattern)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(label) ^
      const DeepCollectionEquality().hash(capability) ^
      const DeepCollectionEquality().hash(vaultCapability) ^
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(subPath) ^
      const DeepCollectionEquality().hash(vaultPath) ^
      const DeepCollectionEquality().hash(pattern) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $PolicyPathOptionExtension on PolicyPathOption {
  PolicyPathOption copyWith(
      {String? id,
      String? label,
      String? capability,
      String? vaultCapability,
      String? path,
      String? subPath,
      List<String>? vaultPath,
      String? pattern,
      String? description}) {
    return PolicyPathOption(
        id: id ?? this.id,
        label: label ?? this.label,
        capability: capability ?? this.capability,
        vaultCapability: vaultCapability ?? this.vaultCapability,
        path: path ?? this.path,
        subPath: subPath ?? this.subPath,
        vaultPath: vaultPath ?? this.vaultPath,
        pattern: pattern ?? this.pattern,
        description: description ?? this.description);
  }

  PolicyPathOption copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? label,
      Wrapped<String>? capability,
      Wrapped<String?>? vaultCapability,
      Wrapped<String?>? path,
      Wrapped<String?>? subPath,
      Wrapped<List<String>?>? vaultPath,
      Wrapped<String?>? pattern,
      Wrapped<String?>? description}) {
    return PolicyPathOption(
        id: (id != null ? id.value : this.id),
        label: (label != null ? label.value : this.label),
        capability: (capability != null ? capability.value : this.capability),
        vaultCapability: (vaultCapability != null
            ? vaultCapability.value
            : this.vaultCapability),
        path: (path != null ? path.value : this.path),
        subPath: (subPath != null ? subPath.value : this.subPath),
        vaultPath: (vaultPath != null ? vaultPath.value : this.vaultPath),
        pattern: (pattern != null ? pattern.value : this.pattern),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyPath {
  PolicyPath({
    required this.label,
    this.subPath,
    this.vaultPath,
    this.sudo,
    required this.showPath,
    this.isVault,
    this.description,
    required this.options,
  });

  factory PolicyPath.fromJson(Map<String, dynamic> json) =>
      _$PolicyPathFromJson(json);

  @JsonKey(name: 'label', includeIfNull: false, defaultValue: '')
  final String label;
  @JsonKey(name: 'subPath', includeIfNull: false, defaultValue: '')
  final String? subPath;
  @JsonKey(name: 'vaultPath', includeIfNull: false, defaultValue: <String>[])
  final List<String>? vaultPath;
  @JsonKey(name: 'sudo', includeIfNull: false)
  final bool? sudo;
  @JsonKey(name: 'showPath', includeIfNull: false)
  final bool showPath;
  @JsonKey(name: 'isVault', includeIfNull: false)
  final bool? isVault;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(
      name: 'options', includeIfNull: false, defaultValue: <PolicyPathOption>[])
  final List<PolicyPathOption> options;
  static const fromJsonFactory = _$PolicyPathFromJson;
  static const toJsonFactory = _$PolicyPathToJson;
  Map<String, dynamic> toJson() => _$PolicyPathToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyPath &&
            (identical(other.label, label) ||
                const DeepCollectionEquality().equals(other.label, label)) &&
            (identical(other.subPath, subPath) ||
                const DeepCollectionEquality()
                    .equals(other.subPath, subPath)) &&
            (identical(other.vaultPath, vaultPath) ||
                const DeepCollectionEquality()
                    .equals(other.vaultPath, vaultPath)) &&
            (identical(other.sudo, sudo) ||
                const DeepCollectionEquality().equals(other.sudo, sudo)) &&
            (identical(other.showPath, showPath) ||
                const DeepCollectionEquality()
                    .equals(other.showPath, showPath)) &&
            (identical(other.isVault, isVault) ||
                const DeepCollectionEquality()
                    .equals(other.isVault, isVault)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.options, options) ||
                const DeepCollectionEquality().equals(other.options, options)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(label) ^
      const DeepCollectionEquality().hash(subPath) ^
      const DeepCollectionEquality().hash(vaultPath) ^
      const DeepCollectionEquality().hash(sudo) ^
      const DeepCollectionEquality().hash(showPath) ^
      const DeepCollectionEquality().hash(isVault) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(options) ^
      runtimeType.hashCode;
}

extension $PolicyPathExtension on PolicyPath {
  PolicyPath copyWith(
      {String? label,
      String? subPath,
      List<String>? vaultPath,
      bool? sudo,
      bool? showPath,
      bool? isVault,
      String? description,
      List<PolicyPathOption>? options}) {
    return PolicyPath(
        label: label ?? this.label,
        subPath: subPath ?? this.subPath,
        vaultPath: vaultPath ?? this.vaultPath,
        sudo: sudo ?? this.sudo,
        showPath: showPath ?? this.showPath,
        isVault: isVault ?? this.isVault,
        description: description ?? this.description,
        options: options ?? this.options);
  }

  PolicyPath copyWithWrapped(
      {Wrapped<String>? label,
      Wrapped<String?>? subPath,
      Wrapped<List<String>?>? vaultPath,
      Wrapped<bool?>? sudo,
      Wrapped<bool>? showPath,
      Wrapped<bool?>? isVault,
      Wrapped<String?>? description,
      Wrapped<List<PolicyPathOption>>? options}) {
    return PolicyPath(
        label: (label != null ? label.value : this.label),
        subPath: (subPath != null ? subPath.value : this.subPath),
        vaultPath: (vaultPath != null ? vaultPath.value : this.vaultPath),
        sudo: (sudo != null ? sudo.value : this.sudo),
        showPath: (showPath != null ? showPath.value : this.showPath),
        isVault: (isVault != null ? isVault.value : this.isVault),
        description:
            (description != null ? description.value : this.description),
        options: (options != null ? options.value : this.options));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyTemplate {
  PolicyTemplate({
    this.id,
    this.isSecureable,
    required this.name,
    this.description,
    this.color,
    this.enablePath,
    required this.metadata,
    this.type,
  });

  factory PolicyTemplate.fromJson(Map<String, dynamic> json) =>
      _$PolicyTemplateFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'isSecureable', includeIfNull: false)
  final bool? isSecureable;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'enablePath', includeIfNull: false)
  final bool? enablePath;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final PolicyTemplate$Metadata metadata;
  @JsonKey(
    name: 'type',
    includeIfNull: false,
    toJson: policyTemplateTypeToJson,
    fromJson: policyTemplateTypeFromJson,
  )
  final enums.PolicyTemplateType? type;
  static const fromJsonFactory = _$PolicyTemplateFromJson;
  static const toJsonFactory = _$PolicyTemplateToJson;
  Map<String, dynamic> toJson() => _$PolicyTemplateToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyTemplate &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.isSecureable, isSecureable) ||
                const DeepCollectionEquality()
                    .equals(other.isSecureable, isSecureable)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.enablePath, enablePath) ||
                const DeepCollectionEquality()
                    .equals(other.enablePath, enablePath)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(isSecureable) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(enablePath) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(type) ^
      runtimeType.hashCode;
}

extension $PolicyTemplateExtension on PolicyTemplate {
  PolicyTemplate copyWith(
      {String? id,
      bool? isSecureable,
      String? name,
      String? description,
      String? color,
      bool? enablePath,
      PolicyTemplate$Metadata? metadata,
      enums.PolicyTemplateType? type}) {
    return PolicyTemplate(
        id: id ?? this.id,
        isSecureable: isSecureable ?? this.isSecureable,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        enablePath: enablePath ?? this.enablePath,
        metadata: metadata ?? this.metadata,
        type: type ?? this.type);
  }

  PolicyTemplate copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<bool?>? isSecureable,
      Wrapped<String>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<bool?>? enablePath,
      Wrapped<PolicyTemplate$Metadata>? metadata,
      Wrapped<enums.PolicyTemplateType?>? type}) {
    return PolicyTemplate(
        id: (id != null ? id.value : this.id),
        isSecureable:
            (isSecureable != null ? isSecureable.value : this.isSecureable),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        enablePath: (enablePath != null ? enablePath.value : this.enablePath),
        metadata: (metadata != null ? metadata.value : this.metadata),
        type: (type != null ? type.value : this.type));
  }
}

@JsonSerializable(explicitToJson: true)
class DeleteTotpKeysNameResponse {
  DeleteTotpKeysNameResponse();

  factory DeleteTotpKeysNameResponse.fromJson(Map<String, dynamic> json) =>
      _$DeleteTotpKeysNameResponseFromJson(json);

  static const fromJsonFactory = _$DeleteTotpKeysNameResponseFromJson;
  static const toJsonFactory = _$DeleteTotpKeysNameResponseToJson;
  Map<String, dynamic> toJson() => _$DeleteTotpKeysNameResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class TotpCodeNameOptions {
  TotpCodeNameOptions({
    this.code,
    this.name,
    this.id,
  });

  factory TotpCodeNameOptions.fromJson(Map<String, dynamic> json) =>
      _$TotpCodeNameOptionsFromJson(json);

  @JsonKey(name: 'code', includeIfNull: false, defaultValue: '')
  final String? code;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$TotpCodeNameOptionsFromJson;
  static const toJsonFactory = _$TotpCodeNameOptionsToJson;
  Map<String, dynamic> toJson() => _$TotpCodeNameOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TotpCodeNameOptions &&
            (identical(other.code, code) ||
                const DeepCollectionEquality().equals(other.code, code)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(code) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $TotpCodeNameOptionsExtension on TotpCodeNameOptions {
  TotpCodeNameOptions copyWith({String? code, String? name, String? id}) {
    return TotpCodeNameOptions(
        code: code ?? this.code, name: name ?? this.name, id: id ?? this.id);
  }

  TotpCodeNameOptions copyWithWrapped(
      {Wrapped<String?>? code, Wrapped<String?>? name, Wrapped<String?>? id}) {
    return TotpCodeNameOptions(
        code: (code != null ? code.value : this.code),
        name: (name != null ? name.value : this.name),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class TotpKeysNameOptions {
  TotpKeysNameOptions({
    this.accountName,
    this.algorithm,
    this.digits,
    this.exported,
    this.generate,
    this.issuer,
    this.key,
    this.keySize,
    this.period,
    this.qrSize,
    this.skew,
    this.url,
    this.name,
    this.id,
  });

  factory TotpKeysNameOptions.fromJson(Map<String, dynamic> json) =>
      _$TotpKeysNameOptionsFromJson(json);

  @JsonKey(name: 'account_name', includeIfNull: false, defaultValue: '')
  final String? accountName;
  @JsonKey(name: 'algorithm', includeIfNull: false, defaultValue: '')
  final String? algorithm;
  @JsonKey(name: 'digits', includeIfNull: false)
  final double? digits;
  @JsonKey(name: 'exported', includeIfNull: false)
  final bool? exported;
  @JsonKey(name: 'generate', includeIfNull: false)
  final bool? generate;
  @JsonKey(name: 'issuer', includeIfNull: false, defaultValue: '')
  final String? issuer;
  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String? key;
  @JsonKey(name: 'key_size', includeIfNull: false)
  final double? keySize;
  @JsonKey(name: 'period', includeIfNull: false)
  final double? period;
  @JsonKey(name: 'qr_size', includeIfNull: false)
  final double? qrSize;
  @JsonKey(name: 'skew', includeIfNull: false)
  final double? skew;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$TotpKeysNameOptionsFromJson;
  static const toJsonFactory = _$TotpKeysNameOptionsToJson;
  Map<String, dynamic> toJson() => _$TotpKeysNameOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is TotpKeysNameOptions &&
            (identical(other.accountName, accountName) ||
                const DeepCollectionEquality()
                    .equals(other.accountName, accountName)) &&
            (identical(other.algorithm, algorithm) ||
                const DeepCollectionEquality()
                    .equals(other.algorithm, algorithm)) &&
            (identical(other.digits, digits) ||
                const DeepCollectionEquality().equals(other.digits, digits)) &&
            (identical(other.exported, exported) ||
                const DeepCollectionEquality()
                    .equals(other.exported, exported)) &&
            (identical(other.generate, generate) ||
                const DeepCollectionEquality()
                    .equals(other.generate, generate)) &&
            (identical(other.issuer, issuer) ||
                const DeepCollectionEquality().equals(other.issuer, issuer)) &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.keySize, keySize) ||
                const DeepCollectionEquality()
                    .equals(other.keySize, keySize)) &&
            (identical(other.period, period) ||
                const DeepCollectionEquality().equals(other.period, period)) &&
            (identical(other.qrSize, qrSize) ||
                const DeepCollectionEquality().equals(other.qrSize, qrSize)) &&
            (identical(other.skew, skew) ||
                const DeepCollectionEquality().equals(other.skew, skew)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accountName) ^
      const DeepCollectionEquality().hash(algorithm) ^
      const DeepCollectionEquality().hash(digits) ^
      const DeepCollectionEquality().hash(exported) ^
      const DeepCollectionEquality().hash(generate) ^
      const DeepCollectionEquality().hash(issuer) ^
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(keySize) ^
      const DeepCollectionEquality().hash(period) ^
      const DeepCollectionEquality().hash(qrSize) ^
      const DeepCollectionEquality().hash(skew) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $TotpKeysNameOptionsExtension on TotpKeysNameOptions {
  TotpKeysNameOptions copyWith(
      {String? accountName,
      String? algorithm,
      double? digits,
      bool? exported,
      bool? generate,
      String? issuer,
      String? key,
      double? keySize,
      double? period,
      double? qrSize,
      double? skew,
      String? url,
      String? name,
      String? id}) {
    return TotpKeysNameOptions(
        accountName: accountName ?? this.accountName,
        algorithm: algorithm ?? this.algorithm,
        digits: digits ?? this.digits,
        exported: exported ?? this.exported,
        generate: generate ?? this.generate,
        issuer: issuer ?? this.issuer,
        key: key ?? this.key,
        keySize: keySize ?? this.keySize,
        period: period ?? this.period,
        qrSize: qrSize ?? this.qrSize,
        skew: skew ?? this.skew,
        url: url ?? this.url,
        name: name ?? this.name,
        id: id ?? this.id);
  }

  TotpKeysNameOptions copyWithWrapped(
      {Wrapped<String?>? accountName,
      Wrapped<String?>? algorithm,
      Wrapped<double?>? digits,
      Wrapped<bool?>? exported,
      Wrapped<bool?>? generate,
      Wrapped<String?>? issuer,
      Wrapped<String?>? key,
      Wrapped<double?>? keySize,
      Wrapped<double?>? period,
      Wrapped<double?>? qrSize,
      Wrapped<double?>? skew,
      Wrapped<String?>? url,
      Wrapped<String?>? name,
      Wrapped<String?>? id}) {
    return TotpKeysNameOptions(
        accountName:
            (accountName != null ? accountName.value : this.accountName),
        algorithm: (algorithm != null ? algorithm.value : this.algorithm),
        digits: (digits != null ? digits.value : this.digits),
        exported: (exported != null ? exported.value : this.exported),
        generate: (generate != null ? generate.value : this.generate),
        issuer: (issuer != null ? issuer.value : this.issuer),
        key: (key != null ? key.value : this.key),
        keySize: (keySize != null ? keySize.value : this.keySize),
        period: (period != null ? period.value : this.period),
        qrSize: (qrSize != null ? qrSize.value : this.qrSize),
        skew: (skew != null ? skew.value : this.skew),
        url: (url != null ? url.value : this.url),
        name: (name != null ? name.value : this.name),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class PostTotpKeysNameResponse {
  PostTotpKeysNameResponse({
    required this.barcode,
    required this.url,
  });

  factory PostTotpKeysNameResponse.fromJson(Map<String, dynamic> json) =>
      _$PostTotpKeysNameResponseFromJson(json);

  @JsonKey(name: 'barcode', includeIfNull: false, defaultValue: '')
  final String barcode;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String url;
  static const fromJsonFactory = _$PostTotpKeysNameResponseFromJson;
  static const toJsonFactory = _$PostTotpKeysNameResponseToJson;
  Map<String, dynamic> toJson() => _$PostTotpKeysNameResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostTotpKeysNameResponse &&
            (identical(other.barcode, barcode) ||
                const DeepCollectionEquality()
                    .equals(other.barcode, barcode)) &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(barcode) ^
      const DeepCollectionEquality().hash(url) ^
      runtimeType.hashCode;
}

extension $PostTotpKeysNameResponseExtension on PostTotpKeysNameResponse {
  PostTotpKeysNameResponse copyWith({String? barcode, String? url}) {
    return PostTotpKeysNameResponse(
        barcode: barcode ?? this.barcode, url: url ?? this.url);
  }

  PostTotpKeysNameResponse copyWithWrapped(
      {Wrapped<String>? barcode, Wrapped<String>? url}) {
    return PostTotpKeysNameResponse(
        barcode: (barcode != null ? barcode.value : this.barcode),
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class DeletedResponse {
  DeletedResponse();

  factory DeletedResponse.fromJson(Map<String, dynamic> json) =>
      _$DeletedResponseFromJson(json);

  static const fromJsonFactory = _$DeletedResponseFromJson;
  static const toJsonFactory = _$DeletedResponseToJson;
  Map<String, dynamic> toJson() => _$DeletedResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class OidcProviderConfig {
  OidcProviderConfig({
    this.boundIssuer,
    this.defaultRole,
    this.jwksCaPem,
    this.jwksUrl,
    this.jwtSupportedAlgs,
    this.jwtValidationPubkeys,
    this.oidcClientId,
    this.oidcClientSecret,
    this.oidcDiscoveryCaPem,
    this.oidcDiscoveryUrl,
    this.oidcResponseMode,
    this.oidcResponseTypes,
    this.authenticationServiceId,
  });

  factory OidcProviderConfig.fromJson(Map<String, dynamic> json) =>
      _$OidcProviderConfigFromJson(json);

  @JsonKey(name: 'bound_issuer', includeIfNull: false, defaultValue: '')
  final String? boundIssuer;
  @JsonKey(name: 'default_role', includeIfNull: false, defaultValue: '')
  final String? defaultRole;
  @JsonKey(name: 'jwks_ca_pem', includeIfNull: false, defaultValue: '')
  final String? jwksCaPem;
  @JsonKey(name: 'jwks_url', includeIfNull: false, defaultValue: '')
  final String? jwksUrl;
  @JsonKey(
      name: 'jwt_supported_algs',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? jwtSupportedAlgs;
  @JsonKey(
      name: 'jwt_validation_pubkeys',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? jwtValidationPubkeys;
  @JsonKey(name: 'oidc_client_id', includeIfNull: false, defaultValue: '')
  final String? oidcClientId;
  @JsonKey(name: 'oidc_client_secret', includeIfNull: false, defaultValue: '')
  final String? oidcClientSecret;
  @JsonKey(
      name: 'oidc_discovery_ca_pem', includeIfNull: false, defaultValue: '')
  final String? oidcDiscoveryCaPem;
  @JsonKey(name: 'oidc_discovery_url', includeIfNull: false, defaultValue: '')
  final String? oidcDiscoveryUrl;
  @JsonKey(name: 'oidc_response_mode', includeIfNull: false, defaultValue: '')
  final String? oidcResponseMode;
  @JsonKey(
      name: 'oidc_response_types',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? oidcResponseTypes;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String? authenticationServiceId;
  static const fromJsonFactory = _$OidcProviderConfigFromJson;
  static const toJsonFactory = _$OidcProviderConfigToJson;
  Map<String, dynamic> toJson() => _$OidcProviderConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcProviderConfig &&
            (identical(other.boundIssuer, boundIssuer) ||
                const DeepCollectionEquality()
                    .equals(other.boundIssuer, boundIssuer)) &&
            (identical(other.defaultRole, defaultRole) ||
                const DeepCollectionEquality()
                    .equals(other.defaultRole, defaultRole)) &&
            (identical(other.jwksCaPem, jwksCaPem) ||
                const DeepCollectionEquality()
                    .equals(other.jwksCaPem, jwksCaPem)) &&
            (identical(other.jwksUrl, jwksUrl) ||
                const DeepCollectionEquality()
                    .equals(other.jwksUrl, jwksUrl)) &&
            (identical(other.jwtSupportedAlgs, jwtSupportedAlgs) ||
                const DeepCollectionEquality()
                    .equals(other.jwtSupportedAlgs, jwtSupportedAlgs)) &&
            (identical(other.jwtValidationPubkeys, jwtValidationPubkeys) ||
                const DeepCollectionEquality().equals(
                    other.jwtValidationPubkeys, jwtValidationPubkeys)) &&
            (identical(other.oidcClientId, oidcClientId) ||
                const DeepCollectionEquality()
                    .equals(other.oidcClientId, oidcClientId)) &&
            (identical(other.oidcClientSecret, oidcClientSecret) ||
                const DeepCollectionEquality()
                    .equals(other.oidcClientSecret, oidcClientSecret)) &&
            (identical(other.oidcDiscoveryCaPem, oidcDiscoveryCaPem) ||
                const DeepCollectionEquality()
                    .equals(other.oidcDiscoveryCaPem, oidcDiscoveryCaPem)) &&
            (identical(other.oidcDiscoveryUrl, oidcDiscoveryUrl) ||
                const DeepCollectionEquality()
                    .equals(other.oidcDiscoveryUrl, oidcDiscoveryUrl)) &&
            (identical(other.oidcResponseMode, oidcResponseMode) ||
                const DeepCollectionEquality()
                    .equals(other.oidcResponseMode, oidcResponseMode)) &&
            (identical(other.oidcResponseTypes, oidcResponseTypes) ||
                const DeepCollectionEquality()
                    .equals(other.oidcResponseTypes, oidcResponseTypes)) &&
            (identical(
                    other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(boundIssuer) ^
      const DeepCollectionEquality().hash(defaultRole) ^
      const DeepCollectionEquality().hash(jwksCaPem) ^
      const DeepCollectionEquality().hash(jwksUrl) ^
      const DeepCollectionEquality().hash(jwtSupportedAlgs) ^
      const DeepCollectionEquality().hash(jwtValidationPubkeys) ^
      const DeepCollectionEquality().hash(oidcClientId) ^
      const DeepCollectionEquality().hash(oidcClientSecret) ^
      const DeepCollectionEquality().hash(oidcDiscoveryCaPem) ^
      const DeepCollectionEquality().hash(oidcDiscoveryUrl) ^
      const DeepCollectionEquality().hash(oidcResponseMode) ^
      const DeepCollectionEquality().hash(oidcResponseTypes) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      runtimeType.hashCode;
}

extension $OidcProviderConfigExtension on OidcProviderConfig {
  OidcProviderConfig copyWith(
      {String? boundIssuer,
      String? defaultRole,
      String? jwksCaPem,
      String? jwksUrl,
      List<String>? jwtSupportedAlgs,
      List<String>? jwtValidationPubkeys,
      String? oidcClientId,
      String? oidcClientSecret,
      String? oidcDiscoveryCaPem,
      String? oidcDiscoveryUrl,
      String? oidcResponseMode,
      List<String>? oidcResponseTypes,
      String? authenticationServiceId}) {
    return OidcProviderConfig(
        boundIssuer: boundIssuer ?? this.boundIssuer,
        defaultRole: defaultRole ?? this.defaultRole,
        jwksCaPem: jwksCaPem ?? this.jwksCaPem,
        jwksUrl: jwksUrl ?? this.jwksUrl,
        jwtSupportedAlgs: jwtSupportedAlgs ?? this.jwtSupportedAlgs,
        jwtValidationPubkeys: jwtValidationPubkeys ?? this.jwtValidationPubkeys,
        oidcClientId: oidcClientId ?? this.oidcClientId,
        oidcClientSecret: oidcClientSecret ?? this.oidcClientSecret,
        oidcDiscoveryCaPem: oidcDiscoveryCaPem ?? this.oidcDiscoveryCaPem,
        oidcDiscoveryUrl: oidcDiscoveryUrl ?? this.oidcDiscoveryUrl,
        oidcResponseMode: oidcResponseMode ?? this.oidcResponseMode,
        oidcResponseTypes: oidcResponseTypes ?? this.oidcResponseTypes,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId);
  }

  OidcProviderConfig copyWithWrapped(
      {Wrapped<String?>? boundIssuer,
      Wrapped<String?>? defaultRole,
      Wrapped<String?>? jwksCaPem,
      Wrapped<String?>? jwksUrl,
      Wrapped<List<String>?>? jwtSupportedAlgs,
      Wrapped<List<String>?>? jwtValidationPubkeys,
      Wrapped<String?>? oidcClientId,
      Wrapped<String?>? oidcClientSecret,
      Wrapped<String?>? oidcDiscoveryCaPem,
      Wrapped<String?>? oidcDiscoveryUrl,
      Wrapped<String?>? oidcResponseMode,
      Wrapped<List<String>?>? oidcResponseTypes,
      Wrapped<String?>? authenticationServiceId}) {
    return OidcProviderConfig(
        boundIssuer:
            (boundIssuer != null ? boundIssuer.value : this.boundIssuer),
        defaultRole:
            (defaultRole != null ? defaultRole.value : this.defaultRole),
        jwksCaPem: (jwksCaPem != null ? jwksCaPem.value : this.jwksCaPem),
        jwksUrl: (jwksUrl != null ? jwksUrl.value : this.jwksUrl),
        jwtSupportedAlgs: (jwtSupportedAlgs != null
            ? jwtSupportedAlgs.value
            : this.jwtSupportedAlgs),
        jwtValidationPubkeys: (jwtValidationPubkeys != null
            ? jwtValidationPubkeys.value
            : this.jwtValidationPubkeys),
        oidcClientId:
            (oidcClientId != null ? oidcClientId.value : this.oidcClientId),
        oidcClientSecret: (oidcClientSecret != null
            ? oidcClientSecret.value
            : this.oidcClientSecret),
        oidcDiscoveryCaPem: (oidcDiscoveryCaPem != null
            ? oidcDiscoveryCaPem.value
            : this.oidcDiscoveryCaPem),
        oidcDiscoveryUrl: (oidcDiscoveryUrl != null
            ? oidcDiscoveryUrl.value
            : this.oidcDiscoveryUrl),
        oidcResponseMode: (oidcResponseMode != null
            ? oidcResponseMode.value
            : this.oidcResponseMode),
        oidcResponseTypes: (oidcResponseTypes != null
            ? oidcResponseTypes.value
            : this.oidcResponseTypes),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcProviderOptions {
  OidcProviderOptions({
    this.authOidcRoles,
    required this.metadata,
    required this.color,
    required this.description,
    required this.domain,
    this.enableTotp,
    required this.name,
  });

  factory OidcProviderOptions.fromJson(Map<String, dynamic> json) =>
      _$OidcProviderOptionsFromJson(json);

  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final OidcProviderOptions$Metadata metadata;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$OidcProviderOptionsFromJson;
  static const toJsonFactory = _$OidcProviderOptionsToJson;
  Map<String, dynamic> toJson() => _$OidcProviderOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcProviderOptions &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $OidcProviderOptionsExtension on OidcProviderOptions {
  OidcProviderOptions copyWith(
      {List<ProviderOidcRole>? authOidcRoles,
      OidcProviderOptions$Metadata? metadata,
      String? color,
      String? description,
      String? domain,
      bool? enableTotp,
      String? name}) {
    return OidcProviderOptions(
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        metadata: metadata ?? this.metadata,
        color: color ?? this.color,
        description: description ?? this.description,
        domain: domain ?? this.domain,
        enableTotp: enableTotp ?? this.enableTotp,
        name: name ?? this.name);
  }

  OidcProviderOptions copyWithWrapped(
      {Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<OidcProviderOptions$Metadata>? metadata,
      Wrapped<String>? color,
      Wrapped<String>? description,
      Wrapped<String>? domain,
      Wrapped<bool?>? enableTotp,
      Wrapped<String>? name}) {
    return OidcProviderOptions(
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        metadata: (metadata != null ? metadata.value : this.metadata),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        domain: (domain != null ? domain.value : this.domain),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcProvider {
  OidcProvider({
    required this.metadata,
    this.aliases,
    this.groupAliases,
    this.authOidcRoles,
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.icon,
    required this.domain,
    required this.color,
    required this.type,
    required this.accessor,
    required this.callback,
    required this.disabled,
    required this.autoCreateEntity,
    this.enableTotp,
    this.config,
    this.tenantId,
  });

  factory OidcProvider.fromJson(Map<String, dynamic> json) =>
      _$OidcProviderFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final ProviderMetadata metadata;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector>? aliases;
  @JsonKey(
      name: 'groupAliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? groupAliases;
  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'callback', includeIfNull: false, defaultValue: '')
  final String callback;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'auto_create_entity', includeIfNull: false)
  final bool autoCreateEntity;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  static const fromJsonFactory = _$OidcProviderFromJson;
  static const toJsonFactory = _$OidcProviderToJson;
  Map<String, dynamic> toJson() => _$OidcProviderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcProvider &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.groupAliases, groupAliases) ||
                const DeepCollectionEquality()
                    .equals(other.groupAliases, groupAliases)) &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.callback, callback) ||
                const DeepCollectionEquality()
                    .equals(other.callback, callback)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.autoCreateEntity, autoCreateEntity) ||
                const DeepCollectionEquality()
                    .equals(other.autoCreateEntity, autoCreateEntity)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(groupAliases) ^
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(callback) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(autoCreateEntity) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(tenantId) ^
      runtimeType.hashCode;
}

extension $OidcProviderExtension on OidcProvider {
  OidcProvider copyWith(
      {ProviderMetadata? metadata,
      List<IdentityConnector>? aliases,
      List<IdentityGroupAlias>? groupAliases,
      List<ProviderOidcRole>? authOidcRoles,
      Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? icon,
      String? domain,
      String? color,
      String? type,
      String? accessor,
      String? callback,
      bool? disabled,
      bool? autoCreateEntity,
      bool? enableTotp,
      Object? config,
      String? tenantId}) {
    return OidcProvider(
        metadata: metadata ?? this.metadata,
        aliases: aliases ?? this.aliases,
        groupAliases: groupAliases ?? this.groupAliases,
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        domain: domain ?? this.domain,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        callback: callback ?? this.callback,
        disabled: disabled ?? this.disabled,
        autoCreateEntity: autoCreateEntity ?? this.autoCreateEntity,
        enableTotp: enableTotp ?? this.enableTotp,
        config: config ?? this.config,
        tenantId: tenantId ?? this.tenantId);
  }

  OidcProvider copyWithWrapped(
      {Wrapped<ProviderMetadata>? metadata,
      Wrapped<List<IdentityConnector>?>? aliases,
      Wrapped<List<IdentityGroupAlias>?>? groupAliases,
      Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<String>? domain,
      Wrapped<String>? color,
      Wrapped<String>? type,
      Wrapped<String>? accessor,
      Wrapped<String>? callback,
      Wrapped<bool>? disabled,
      Wrapped<bool>? autoCreateEntity,
      Wrapped<bool?>? enableTotp,
      Wrapped<Object?>? config,
      Wrapped<String?>? tenantId}) {
    return OidcProvider(
        metadata: (metadata != null ? metadata.value : this.metadata),
        aliases: (aliases != null ? aliases.value : this.aliases),
        groupAliases:
            (groupAliases != null ? groupAliases.value : this.groupAliases),
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        domain: (domain != null ? domain.value : this.domain),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        callback: (callback != null ? callback.value : this.callback),
        disabled: (disabled != null ? disabled.value : this.disabled),
        autoCreateEntity: (autoCreateEntity != null
            ? autoCreateEntity.value
            : this.autoCreateEntity),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        config: (config != null ? config.value : this.config),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcProviderRoleNameOptions {
  OidcProviderRoleNameOptions({
    this.authenticationService,
    this.id,
    this.name,
    this.description,
    this.color,
    this.allowedRedirectUris,
    this.boundAudiences,
    this.boundClaims,
    this.boundSubject,
    this.claimMappings,
    this.clockSkewLeeway,
    this.expirationLeeway,
    this.groupsClaim,
    this.notBeforeLeeway,
    this.oidcScopes,
    this.roleType,
    this.tokenBoundCidrs,
    this.tokenExplicitMaxTtl,
    this.tokenMaxTtl,
    this.tokenNoDefaultPolicy,
    this.tokenNumUses,
    this.tokenPeriod,
    this.tokenPolicies,
    this.tokenTtl,
    this.tokenType,
    this.userClaim,
    this.verboseOidcLogging,
    this.authenticationServiceId,
    this.boundCidrs,
    this.boundClaimsType,
    this.maxTtl,
    this.numUses,
    this.period,
    this.policies,
    this.ttl,
  });

  factory OidcProviderRoleNameOptions.fromJson(Map<String, dynamic> json) =>
      _$OidcProviderRoleNameOptionsFromJson(json);

  @JsonKey(name: 'authenticationService', includeIfNull: false)
  final Provider? authenticationService;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(
      name: 'allowed_redirect_uris', includeIfNull: false, defaultValue: '')
  final String? allowedRedirectUris;
  @JsonKey(name: 'bound_audiences', includeIfNull: false, defaultValue: '')
  final String? boundAudiences;
  @JsonKey(name: 'bound_claims', includeIfNull: false, defaultValue: '')
  final String? boundClaims;
  @JsonKey(name: 'bound_subject', includeIfNull: false, defaultValue: '')
  final String? boundSubject;
  @JsonKey(name: 'claim_mappings', includeIfNull: false)
  final Object? claimMappings;
  @JsonKey(name: 'clock_skew_leeway', includeIfNull: false)
  final double? clockSkewLeeway;
  @JsonKey(name: 'expiration_leeway', includeIfNull: false)
  final double? expirationLeeway;
  @JsonKey(name: 'groups_claim', includeIfNull: false, defaultValue: '')
  final String? groupsClaim;
  @JsonKey(name: 'not_before_leeway', includeIfNull: false)
  final double? notBeforeLeeway;
  @JsonKey(name: 'oidc_scopes', includeIfNull: false, defaultValue: '')
  final String? oidcScopes;
  @JsonKey(name: 'role_type', includeIfNull: false, defaultValue: '')
  final String? roleType;
  @JsonKey(name: 'token_bound_cidrs', includeIfNull: false, defaultValue: '')
  final String? tokenBoundCidrs;
  @JsonKey(name: 'token_explicit_max_ttl', includeIfNull: false)
  final double? tokenExplicitMaxTtl;
  @JsonKey(name: 'token_max_ttl', includeIfNull: false)
  final double? tokenMaxTtl;
  @JsonKey(name: 'token_no_default_policy', includeIfNull: false)
  final bool? tokenNoDefaultPolicy;
  @JsonKey(name: 'token_num_uses', includeIfNull: false)
  final double? tokenNumUses;
  @JsonKey(name: 'token_period', includeIfNull: false)
  final double? tokenPeriod;
  @JsonKey(name: 'token_policies', includeIfNull: false, defaultValue: '')
  final String? tokenPolicies;
  @JsonKey(name: 'token_ttl', includeIfNull: false)
  final double? tokenTtl;
  @JsonKey(name: 'token_type', includeIfNull: false, defaultValue: '')
  final String? tokenType;
  @JsonKey(name: 'user_claim', includeIfNull: false, defaultValue: '')
  final String? userClaim;
  @JsonKey(name: 'verbose_oidc_logging', includeIfNull: false)
  final bool? verboseOidcLogging;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String? authenticationServiceId;
  @JsonKey(name: 'bound_cidrs', includeIfNull: false, defaultValue: '')
  final String? boundCidrs;
  @JsonKey(name: 'bound_claims_type', includeIfNull: false, defaultValue: '')
  final String? boundClaimsType;
  @JsonKey(name: 'max_ttl', includeIfNull: false)
  final double? maxTtl;
  @JsonKey(name: 'num_uses', includeIfNull: false)
  final double? numUses;
  @JsonKey(name: 'period', includeIfNull: false)
  final double? period;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? policies;
  @JsonKey(name: 'ttl', includeIfNull: false)
  final double? ttl;
  static const fromJsonFactory = _$OidcProviderRoleNameOptionsFromJson;
  static const toJsonFactory = _$OidcProviderRoleNameOptionsToJson;
  Map<String, dynamic> toJson() => _$OidcProviderRoleNameOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcProviderRoleNameOptions &&
            (identical(other.authenticationService, authenticationService) ||
                const DeepCollectionEquality().equals(
                    other.authenticationService, authenticationService)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.allowedRedirectUris, allowedRedirectUris) ||
                const DeepCollectionEquality()
                    .equals(other.allowedRedirectUris, allowedRedirectUris)) &&
            (identical(other.boundAudiences, boundAudiences) ||
                const DeepCollectionEquality()
                    .equals(other.boundAudiences, boundAudiences)) &&
            (identical(other.boundClaims, boundClaims) ||
                const DeepCollectionEquality()
                    .equals(other.boundClaims, boundClaims)) &&
            (identical(other.boundSubject, boundSubject) ||
                const DeepCollectionEquality()
                    .equals(other.boundSubject, boundSubject)) &&
            (identical(other.claimMappings, claimMappings) ||
                const DeepCollectionEquality()
                    .equals(other.claimMappings, claimMappings)) &&
            (identical(other.clockSkewLeeway, clockSkewLeeway) ||
                const DeepCollectionEquality()
                    .equals(other.clockSkewLeeway, clockSkewLeeway)) &&
            (identical(other.expirationLeeway, expirationLeeway) ||
                const DeepCollectionEquality()
                    .equals(other.expirationLeeway, expirationLeeway)) &&
            (identical(other.groupsClaim, groupsClaim) ||
                const DeepCollectionEquality()
                    .equals(other.groupsClaim, groupsClaim)) &&
            (identical(other.notBeforeLeeway, notBeforeLeeway) ||
                const DeepCollectionEquality()
                    .equals(other.notBeforeLeeway, notBeforeLeeway)) &&
            (identical(other.oidcScopes, oidcScopes) ||
                const DeepCollectionEquality()
                    .equals(other.oidcScopes, oidcScopes)) &&
            (identical(other.roleType, roleType) ||
                const DeepCollectionEquality()
                    .equals(other.roleType, roleType)) &&
            (identical(other.tokenBoundCidrs, tokenBoundCidrs) ||
                const DeepCollectionEquality()
                    .equals(other.tokenBoundCidrs, tokenBoundCidrs)) &&
            (identical(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl)) &&
            (identical(other.tokenMaxTtl, tokenMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenMaxTtl, tokenMaxTtl)) &&
            (identical(other.tokenNoDefaultPolicy, tokenNoDefaultPolicy) ||
                const DeepCollectionEquality().equals(
                    other.tokenNoDefaultPolicy, tokenNoDefaultPolicy)) &&
            (identical(other.tokenNumUses, tokenNumUses) ||
                const DeepCollectionEquality()
                    .equals(other.tokenNumUses, tokenNumUses)) &&
            (identical(other.tokenPeriod, tokenPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPeriod, tokenPeriod)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality().equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.tokenTtl, tokenTtl) || const DeepCollectionEquality().equals(other.tokenTtl, tokenTtl)) &&
            (identical(other.tokenType, tokenType) || const DeepCollectionEquality().equals(other.tokenType, tokenType)) &&
            (identical(other.userClaim, userClaim) || const DeepCollectionEquality().equals(other.userClaim, userClaim)) &&
            (identical(other.verboseOidcLogging, verboseOidcLogging) || const DeepCollectionEquality().equals(other.verboseOidcLogging, verboseOidcLogging)) &&
            (identical(other.authenticationServiceId, authenticationServiceId) || const DeepCollectionEquality().equals(other.authenticationServiceId, authenticationServiceId)) &&
            (identical(other.boundCidrs, boundCidrs) || const DeepCollectionEquality().equals(other.boundCidrs, boundCidrs)) &&
            (identical(other.boundClaimsType, boundClaimsType) || const DeepCollectionEquality().equals(other.boundClaimsType, boundClaimsType)) &&
            (identical(other.maxTtl, maxTtl) || const DeepCollectionEquality().equals(other.maxTtl, maxTtl)) &&
            (identical(other.numUses, numUses) || const DeepCollectionEquality().equals(other.numUses, numUses)) &&
            (identical(other.period, period) || const DeepCollectionEquality().equals(other.period, period)) &&
            (identical(other.policies, policies) || const DeepCollectionEquality().equals(other.policies, policies)) &&
            (identical(other.ttl, ttl) || const DeepCollectionEquality().equals(other.ttl, ttl)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authenticationService) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(allowedRedirectUris) ^
      const DeepCollectionEquality().hash(boundAudiences) ^
      const DeepCollectionEquality().hash(boundClaims) ^
      const DeepCollectionEquality().hash(boundSubject) ^
      const DeepCollectionEquality().hash(claimMappings) ^
      const DeepCollectionEquality().hash(clockSkewLeeway) ^
      const DeepCollectionEquality().hash(expirationLeeway) ^
      const DeepCollectionEquality().hash(groupsClaim) ^
      const DeepCollectionEquality().hash(notBeforeLeeway) ^
      const DeepCollectionEquality().hash(oidcScopes) ^
      const DeepCollectionEquality().hash(roleType) ^
      const DeepCollectionEquality().hash(tokenBoundCidrs) ^
      const DeepCollectionEquality().hash(tokenExplicitMaxTtl) ^
      const DeepCollectionEquality().hash(tokenMaxTtl) ^
      const DeepCollectionEquality().hash(tokenNoDefaultPolicy) ^
      const DeepCollectionEquality().hash(tokenNumUses) ^
      const DeepCollectionEquality().hash(tokenPeriod) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(tokenTtl) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(userClaim) ^
      const DeepCollectionEquality().hash(verboseOidcLogging) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      const DeepCollectionEquality().hash(boundCidrs) ^
      const DeepCollectionEquality().hash(boundClaimsType) ^
      const DeepCollectionEquality().hash(maxTtl) ^
      const DeepCollectionEquality().hash(numUses) ^
      const DeepCollectionEquality().hash(period) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(ttl) ^
      runtimeType.hashCode;
}

extension $OidcProviderRoleNameOptionsExtension on OidcProviderRoleNameOptions {
  OidcProviderRoleNameOptions copyWith(
      {Provider? authenticationService,
      String? id,
      String? name,
      String? description,
      String? color,
      String? allowedRedirectUris,
      String? boundAudiences,
      String? boundClaims,
      String? boundSubject,
      Object? claimMappings,
      double? clockSkewLeeway,
      double? expirationLeeway,
      String? groupsClaim,
      double? notBeforeLeeway,
      String? oidcScopes,
      String? roleType,
      String? tokenBoundCidrs,
      double? tokenExplicitMaxTtl,
      double? tokenMaxTtl,
      bool? tokenNoDefaultPolicy,
      double? tokenNumUses,
      double? tokenPeriod,
      String? tokenPolicies,
      double? tokenTtl,
      String? tokenType,
      String? userClaim,
      bool? verboseOidcLogging,
      String? authenticationServiceId,
      String? boundCidrs,
      String? boundClaimsType,
      double? maxTtl,
      double? numUses,
      double? period,
      List<String>? policies,
      double? ttl}) {
    return OidcProviderRoleNameOptions(
        authenticationService:
            authenticationService ?? this.authenticationService,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        allowedRedirectUris: allowedRedirectUris ?? this.allowedRedirectUris,
        boundAudiences: boundAudiences ?? this.boundAudiences,
        boundClaims: boundClaims ?? this.boundClaims,
        boundSubject: boundSubject ?? this.boundSubject,
        claimMappings: claimMappings ?? this.claimMappings,
        clockSkewLeeway: clockSkewLeeway ?? this.clockSkewLeeway,
        expirationLeeway: expirationLeeway ?? this.expirationLeeway,
        groupsClaim: groupsClaim ?? this.groupsClaim,
        notBeforeLeeway: notBeforeLeeway ?? this.notBeforeLeeway,
        oidcScopes: oidcScopes ?? this.oidcScopes,
        roleType: roleType ?? this.roleType,
        tokenBoundCidrs: tokenBoundCidrs ?? this.tokenBoundCidrs,
        tokenExplicitMaxTtl: tokenExplicitMaxTtl ?? this.tokenExplicitMaxTtl,
        tokenMaxTtl: tokenMaxTtl ?? this.tokenMaxTtl,
        tokenNoDefaultPolicy: tokenNoDefaultPolicy ?? this.tokenNoDefaultPolicy,
        tokenNumUses: tokenNumUses ?? this.tokenNumUses,
        tokenPeriod: tokenPeriod ?? this.tokenPeriod,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        tokenTtl: tokenTtl ?? this.tokenTtl,
        tokenType: tokenType ?? this.tokenType,
        userClaim: userClaim ?? this.userClaim,
        verboseOidcLogging: verboseOidcLogging ?? this.verboseOidcLogging,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId,
        boundCidrs: boundCidrs ?? this.boundCidrs,
        boundClaimsType: boundClaimsType ?? this.boundClaimsType,
        maxTtl: maxTtl ?? this.maxTtl,
        numUses: numUses ?? this.numUses,
        period: period ?? this.period,
        policies: policies ?? this.policies,
        ttl: ttl ?? this.ttl);
  }

  OidcProviderRoleNameOptions copyWithWrapped(
      {Wrapped<Provider?>? authenticationService,
      Wrapped<String?>? id,
      Wrapped<String?>? name,
      Wrapped<String?>? description,
      Wrapped<String?>? color,
      Wrapped<String?>? allowedRedirectUris,
      Wrapped<String?>? boundAudiences,
      Wrapped<String?>? boundClaims,
      Wrapped<String?>? boundSubject,
      Wrapped<Object?>? claimMappings,
      Wrapped<double?>? clockSkewLeeway,
      Wrapped<double?>? expirationLeeway,
      Wrapped<String?>? groupsClaim,
      Wrapped<double?>? notBeforeLeeway,
      Wrapped<String?>? oidcScopes,
      Wrapped<String?>? roleType,
      Wrapped<String?>? tokenBoundCidrs,
      Wrapped<double?>? tokenExplicitMaxTtl,
      Wrapped<double?>? tokenMaxTtl,
      Wrapped<bool?>? tokenNoDefaultPolicy,
      Wrapped<double?>? tokenNumUses,
      Wrapped<double?>? tokenPeriod,
      Wrapped<String?>? tokenPolicies,
      Wrapped<double?>? tokenTtl,
      Wrapped<String?>? tokenType,
      Wrapped<String?>? userClaim,
      Wrapped<bool?>? verboseOidcLogging,
      Wrapped<String?>? authenticationServiceId,
      Wrapped<String?>? boundCidrs,
      Wrapped<String?>? boundClaimsType,
      Wrapped<double?>? maxTtl,
      Wrapped<double?>? numUses,
      Wrapped<double?>? period,
      Wrapped<List<String>?>? policies,
      Wrapped<double?>? ttl}) {
    return OidcProviderRoleNameOptions(
        authenticationService: (authenticationService != null
            ? authenticationService.value
            : this.authenticationService),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        allowedRedirectUris: (allowedRedirectUris != null
            ? allowedRedirectUris.value
            : this.allowedRedirectUris),
        boundAudiences: (boundAudiences != null
            ? boundAudiences.value
            : this.boundAudiences),
        boundClaims:
            (boundClaims != null ? boundClaims.value : this.boundClaims),
        boundSubject:
            (boundSubject != null ? boundSubject.value : this.boundSubject),
        claimMappings:
            (claimMappings != null ? claimMappings.value : this.claimMappings),
        clockSkewLeeway: (clockSkewLeeway != null
            ? clockSkewLeeway.value
            : this.clockSkewLeeway),
        expirationLeeway: (expirationLeeway != null
            ? expirationLeeway.value
            : this.expirationLeeway),
        groupsClaim:
            (groupsClaim != null ? groupsClaim.value : this.groupsClaim),
        notBeforeLeeway: (notBeforeLeeway != null
            ? notBeforeLeeway.value
            : this.notBeforeLeeway),
        oidcScopes: (oidcScopes != null ? oidcScopes.value : this.oidcScopes),
        roleType: (roleType != null ? roleType.value : this.roleType),
        tokenBoundCidrs: (tokenBoundCidrs != null
            ? tokenBoundCidrs.value
            : this.tokenBoundCidrs),
        tokenExplicitMaxTtl: (tokenExplicitMaxTtl != null
            ? tokenExplicitMaxTtl.value
            : this.tokenExplicitMaxTtl),
        tokenMaxTtl:
            (tokenMaxTtl != null ? tokenMaxTtl.value : this.tokenMaxTtl),
        tokenNoDefaultPolicy: (tokenNoDefaultPolicy != null
            ? tokenNoDefaultPolicy.value
            : this.tokenNoDefaultPolicy),
        tokenNumUses:
            (tokenNumUses != null ? tokenNumUses.value : this.tokenNumUses),
        tokenPeriod:
            (tokenPeriod != null ? tokenPeriod.value : this.tokenPeriod),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        tokenTtl: (tokenTtl != null ? tokenTtl.value : this.tokenTtl),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        userClaim: (userClaim != null ? userClaim.value : this.userClaim),
        verboseOidcLogging: (verboseOidcLogging != null
            ? verboseOidcLogging.value
            : this.verboseOidcLogging),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId),
        boundCidrs: (boundCidrs != null ? boundCidrs.value : this.boundCidrs),
        boundClaimsType: (boundClaimsType != null
            ? boundClaimsType.value
            : this.boundClaimsType),
        maxTtl: (maxTtl != null ? maxTtl.value : this.maxTtl),
        numUses: (numUses != null ? numUses.value : this.numUses),
        period: (period != null ? period.value : this.period),
        policies: (policies != null ? policies.value : this.policies),
        ttl: (ttl != null ? ttl.value : this.ttl));
  }
}

@JsonSerializable(explicitToJson: true)
class PutGroup {
  PutGroup({
    required this.id,
    required this.members,
    required this.policies,
    this.color,
    this.description,
    this.metadata,
    this.$external,
    this.name,
  });

  factory PutGroup.fromJson(Map<String, dynamic> json) =>
      _$PutGroupFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'members', includeIfNull: false, defaultValue: <String>[])
  final List<String> members;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String> policies;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'external', includeIfNull: false)
  final bool? $external;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$PutGroupFromJson;
  static const toJsonFactory = _$PutGroupToJson;
  Map<String, dynamic> toJson() => _$PutGroupToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PutGroup &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.members, members) ||
                const DeepCollectionEquality()
                    .equals(other.members, members)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.$external, $external) ||
                const DeepCollectionEquality()
                    .equals(other.$external, $external)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(members) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash($external) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $PutGroupExtension on PutGroup {
  PutGroup copyWith(
      {String? id,
      List<String>? members,
      List<String>? policies,
      String? color,
      String? description,
      Object? metadata,
      bool? $external,
      String? name}) {
    return PutGroup(
        id: id ?? this.id,
        members: members ?? this.members,
        policies: policies ?? this.policies,
        color: color ?? this.color,
        description: description ?? this.description,
        metadata: metadata ?? this.metadata,
        $external: $external ?? this.$external,
        name: name ?? this.name);
  }

  PutGroup copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<List<String>>? members,
      Wrapped<List<String>>? policies,
      Wrapped<String?>? color,
      Wrapped<String?>? description,
      Wrapped<Object?>? metadata,
      Wrapped<bool?>? $external,
      Wrapped<String?>? name}) {
    return PutGroup(
        id: (id != null ? id.value : this.id),
        members: (members != null ? members.value : this.members),
        policies: (policies != null ? policies.value : this.policies),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        metadata: (metadata != null ? metadata.value : this.metadata),
        $external: ($external != null ? $external.value : this.$external),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class PostGroup {
  PostGroup({
    required this.members,
    required this.policies,
    this.color,
    this.description,
    this.metadata,
    this.$external,
    this.name,
  });

  factory PostGroup.fromJson(Map<String, dynamic> json) =>
      _$PostGroupFromJson(json);

  @JsonKey(name: 'members', includeIfNull: false, defaultValue: <String>[])
  final List<String> members;
  @JsonKey(name: 'policies', includeIfNull: false, defaultValue: <String>[])
  final List<String> policies;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String? description;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'external', includeIfNull: false)
  final bool? $external;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  static const fromJsonFactory = _$PostGroupFromJson;
  static const toJsonFactory = _$PostGroupToJson;
  Map<String, dynamic> toJson() => _$PostGroupToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PostGroup &&
            (identical(other.members, members) ||
                const DeepCollectionEquality()
                    .equals(other.members, members)) &&
            (identical(other.policies, policies) ||
                const DeepCollectionEquality()
                    .equals(other.policies, policies)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.$external, $external) ||
                const DeepCollectionEquality()
                    .equals(other.$external, $external)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(members) ^
      const DeepCollectionEquality().hash(policies) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash($external) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $PostGroupExtension on PostGroup {
  PostGroup copyWith(
      {List<String>? members,
      List<String>? policies,
      String? color,
      String? description,
      Object? metadata,
      bool? $external,
      String? name}) {
    return PostGroup(
        members: members ?? this.members,
        policies: policies ?? this.policies,
        color: color ?? this.color,
        description: description ?? this.description,
        metadata: metadata ?? this.metadata,
        $external: $external ?? this.$external,
        name: name ?? this.name);
  }

  PostGroup copyWithWrapped(
      {Wrapped<List<String>>? members,
      Wrapped<List<String>>? policies,
      Wrapped<String?>? color,
      Wrapped<String?>? description,
      Wrapped<Object?>? metadata,
      Wrapped<bool?>? $external,
      Wrapped<String?>? name}) {
    return PostGroup(
        members: (members != null ? members.value : this.members),
        policies: (policies != null ? policies.value : this.policies),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        metadata: (metadata != null ? metadata.value : this.metadata),
        $external: ($external != null ? $external.value : this.$external),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityConnectorUpdateOptions {
  IdentityConnectorUpdateOptions({
    this.metadata,
    required this.oidcUsername,
    this.password,
  });

  factory IdentityConnectorUpdateOptions.fromJson(Map<String, dynamic> json) =>
      _$IdentityConnectorUpdateOptionsFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'oidcUsername', includeIfNull: false, defaultValue: '')
  final String oidcUsername;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  static const fromJsonFactory = _$IdentityConnectorUpdateOptionsFromJson;
  static const toJsonFactory = _$IdentityConnectorUpdateOptionsToJson;
  Map<String, dynamic> toJson() => _$IdentityConnectorUpdateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityConnectorUpdateOptions &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.oidcUsername, oidcUsername) ||
                const DeepCollectionEquality()
                    .equals(other.oidcUsername, oidcUsername)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(oidcUsername) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $IdentityConnectorUpdateOptionsExtension
    on IdentityConnectorUpdateOptions {
  IdentityConnectorUpdateOptions copyWith(
      {Object? metadata, String? oidcUsername, String? password}) {
    return IdentityConnectorUpdateOptions(
        metadata: metadata ?? this.metadata,
        oidcUsername: oidcUsername ?? this.oidcUsername,
        password: password ?? this.password);
  }

  IdentityConnectorUpdateOptions copyWithWrapped(
      {Wrapped<Object?>? metadata,
      Wrapped<String>? oidcUsername,
      Wrapped<String?>? password}) {
    return IdentityConnectorUpdateOptions(
        metadata: (metadata != null ? metadata.value : this.metadata),
        oidcUsername:
            (oidcUsername != null ? oidcUsername.value : this.oidcUsername),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class IdentityConnectorCreateOptions {
  IdentityConnectorCreateOptions({
    required this.entityId,
    required this.authenticationServiceId,
    this.metadata,
    required this.name,
    required this.oidcUsername,
    this.password,
  });

  factory IdentityConnectorCreateOptions.fromJson(Map<String, dynamic> json) =>
      _$IdentityConnectorCreateOptionsFromJson(json);

  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String entityId;
  @JsonKey(
      name: 'authenticationServiceId', includeIfNull: false, defaultValue: '')
  final String authenticationServiceId;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object? metadata;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'oidcUsername', includeIfNull: false, defaultValue: '')
  final String oidcUsername;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  static const fromJsonFactory = _$IdentityConnectorCreateOptionsFromJson;
  static const toJsonFactory = _$IdentityConnectorCreateOptionsToJson;
  Map<String, dynamic> toJson() => _$IdentityConnectorCreateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is IdentityConnectorCreateOptions &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(
                    other.authenticationServiceId, authenticationServiceId) ||
                const DeepCollectionEquality().equals(
                    other.authenticationServiceId, authenticationServiceId)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.oidcUsername, oidcUsername) ||
                const DeepCollectionEquality()
                    .equals(other.oidcUsername, oidcUsername)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(authenticationServiceId) ^
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(oidcUsername) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $IdentityConnectorCreateOptionsExtension
    on IdentityConnectorCreateOptions {
  IdentityConnectorCreateOptions copyWith(
      {String? entityId,
      String? authenticationServiceId,
      Object? metadata,
      String? name,
      String? oidcUsername,
      String? password}) {
    return IdentityConnectorCreateOptions(
        entityId: entityId ?? this.entityId,
        authenticationServiceId:
            authenticationServiceId ?? this.authenticationServiceId,
        metadata: metadata ?? this.metadata,
        name: name ?? this.name,
        oidcUsername: oidcUsername ?? this.oidcUsername,
        password: password ?? this.password);
  }

  IdentityConnectorCreateOptions copyWithWrapped(
      {Wrapped<String>? entityId,
      Wrapped<String>? authenticationServiceId,
      Wrapped<Object?>? metadata,
      Wrapped<String>? name,
      Wrapped<String>? oidcUsername,
      Wrapped<String?>? password}) {
    return IdentityConnectorCreateOptions(
        entityId: (entityId != null ? entityId.value : this.entityId),
        authenticationServiceId: (authenticationServiceId != null
            ? authenticationServiceId.value
            : this.authenticationServiceId),
        metadata: (metadata != null ? metadata.value : this.metadata),
        name: (name != null ? name.value : this.name),
        oidcUsername:
            (oidcUsername != null ? oidcUsername.value : this.oidcUsername),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class SamlProvider {
  SamlProvider({
    required this.metadata,
    this.aliases,
    this.groupAliases,
    this.authOidcRoles,
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.icon,
    required this.domain,
    required this.color,
    required this.type,
    required this.accessor,
    required this.callback,
    required this.disabled,
    required this.autoCreateEntity,
    this.enableTotp,
    this.config,
    this.tenantId,
  });

  factory SamlProvider.fromJson(Map<String, dynamic> json) =>
      _$SamlProviderFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final ProviderMetadata metadata;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector>? aliases;
  @JsonKey(
      name: 'groupAliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? groupAliases;
  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'callback', includeIfNull: false, defaultValue: '')
  final String callback;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'auto_create_entity', includeIfNull: false)
  final bool autoCreateEntity;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  static const fromJsonFactory = _$SamlProviderFromJson;
  static const toJsonFactory = _$SamlProviderToJson;
  Map<String, dynamic> toJson() => _$SamlProviderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SamlProvider &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.groupAliases, groupAliases) ||
                const DeepCollectionEquality()
                    .equals(other.groupAliases, groupAliases)) &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.callback, callback) ||
                const DeepCollectionEquality()
                    .equals(other.callback, callback)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.autoCreateEntity, autoCreateEntity) ||
                const DeepCollectionEquality()
                    .equals(other.autoCreateEntity, autoCreateEntity)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(groupAliases) ^
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(callback) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(autoCreateEntity) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(tenantId) ^
      runtimeType.hashCode;
}

extension $SamlProviderExtension on SamlProvider {
  SamlProvider copyWith(
      {ProviderMetadata? metadata,
      List<IdentityConnector>? aliases,
      List<IdentityGroupAlias>? groupAliases,
      List<ProviderOidcRole>? authOidcRoles,
      Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? icon,
      String? domain,
      String? color,
      String? type,
      String? accessor,
      String? callback,
      bool? disabled,
      bool? autoCreateEntity,
      bool? enableTotp,
      Object? config,
      String? tenantId}) {
    return SamlProvider(
        metadata: metadata ?? this.metadata,
        aliases: aliases ?? this.aliases,
        groupAliases: groupAliases ?? this.groupAliases,
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        domain: domain ?? this.domain,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        callback: callback ?? this.callback,
        disabled: disabled ?? this.disabled,
        autoCreateEntity: autoCreateEntity ?? this.autoCreateEntity,
        enableTotp: enableTotp ?? this.enableTotp,
        config: config ?? this.config,
        tenantId: tenantId ?? this.tenantId);
  }

  SamlProvider copyWithWrapped(
      {Wrapped<ProviderMetadata>? metadata,
      Wrapped<List<IdentityConnector>?>? aliases,
      Wrapped<List<IdentityGroupAlias>?>? groupAliases,
      Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<String>? domain,
      Wrapped<String>? color,
      Wrapped<String>? type,
      Wrapped<String>? accessor,
      Wrapped<String>? callback,
      Wrapped<bool>? disabled,
      Wrapped<bool>? autoCreateEntity,
      Wrapped<bool?>? enableTotp,
      Wrapped<Object?>? config,
      Wrapped<String?>? tenantId}) {
    return SamlProvider(
        metadata: (metadata != null ? metadata.value : this.metadata),
        aliases: (aliases != null ? aliases.value : this.aliases),
        groupAliases:
            (groupAliases != null ? groupAliases.value : this.groupAliases),
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        domain: (domain != null ? domain.value : this.domain),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        callback: (callback != null ? callback.value : this.callback),
        disabled: (disabled != null ? disabled.value : this.disabled),
        autoCreateEntity: (autoCreateEntity != null
            ? autoCreateEntity.value
            : this.autoCreateEntity),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        config: (config != null ? config.value : this.config),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId));
  }
}

@JsonSerializable(explicitToJson: true)
class SamlProviderMetadata {
  SamlProviderMetadata({
    required this.config,
    required this.entityId,
    required this.login,
    required this.signGetRequest,
    required this.logout,
    required this.allowUnencryptedAssertion,
    required this.nameIdFormat,
    required this.redirect,
    required this.certificates,
  });

  factory SamlProviderMetadata.fromJson(Map<String, dynamic> json) =>
      _$SamlProviderMetadataFromJson(json);

  @JsonKey(name: 'config', includeIfNull: false)
  final SamlProviderMetadata$Config config;
  @JsonKey(name: 'entityId', includeIfNull: false, defaultValue: '')
  final String entityId;
  @JsonKey(name: 'login', includeIfNull: false, defaultValue: '')
  final String login;
  @JsonKey(name: 'signGetRequest', includeIfNull: false)
  final bool signGetRequest;
  @JsonKey(name: 'logout', includeIfNull: false, defaultValue: '')
  final String logout;
  @JsonKey(name: 'allowUnencryptedAssertion', includeIfNull: false)
  final bool allowUnencryptedAssertion;
  @JsonKey(name: 'nameIdFormat', includeIfNull: false, defaultValue: '')
  final String nameIdFormat;
  @JsonKey(name: 'redirect', includeIfNull: false, defaultValue: '')
  final String redirect;
  @JsonKey(name: 'certificates', includeIfNull: false, defaultValue: <String>[])
  final List<String> certificates;
  static const fromJsonFactory = _$SamlProviderMetadataFromJson;
  static const toJsonFactory = _$SamlProviderMetadataToJson;
  Map<String, dynamic> toJson() => _$SamlProviderMetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SamlProviderMetadata &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.entityId, entityId) ||
                const DeepCollectionEquality()
                    .equals(other.entityId, entityId)) &&
            (identical(other.login, login) ||
                const DeepCollectionEquality().equals(other.login, login)) &&
            (identical(other.signGetRequest, signGetRequest) ||
                const DeepCollectionEquality()
                    .equals(other.signGetRequest, signGetRequest)) &&
            (identical(other.logout, logout) ||
                const DeepCollectionEquality().equals(other.logout, logout)) &&
            (identical(other.allowUnencryptedAssertion,
                    allowUnencryptedAssertion) ||
                const DeepCollectionEquality().equals(
                    other.allowUnencryptedAssertion,
                    allowUnencryptedAssertion)) &&
            (identical(other.nameIdFormat, nameIdFormat) ||
                const DeepCollectionEquality()
                    .equals(other.nameIdFormat, nameIdFormat)) &&
            (identical(other.redirect, redirect) ||
                const DeepCollectionEquality()
                    .equals(other.redirect, redirect)) &&
            (identical(other.certificates, certificates) ||
                const DeepCollectionEquality()
                    .equals(other.certificates, certificates)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(entityId) ^
      const DeepCollectionEquality().hash(login) ^
      const DeepCollectionEquality().hash(signGetRequest) ^
      const DeepCollectionEquality().hash(logout) ^
      const DeepCollectionEquality().hash(allowUnencryptedAssertion) ^
      const DeepCollectionEquality().hash(nameIdFormat) ^
      const DeepCollectionEquality().hash(redirect) ^
      const DeepCollectionEquality().hash(certificates) ^
      runtimeType.hashCode;
}

extension $SamlProviderMetadataExtension on SamlProviderMetadata {
  SamlProviderMetadata copyWith(
      {SamlProviderMetadata$Config? config,
      String? entityId,
      String? login,
      bool? signGetRequest,
      String? logout,
      bool? allowUnencryptedAssertion,
      String? nameIdFormat,
      String? redirect,
      List<String>? certificates}) {
    return SamlProviderMetadata(
        config: config ?? this.config,
        entityId: entityId ?? this.entityId,
        login: login ?? this.login,
        signGetRequest: signGetRequest ?? this.signGetRequest,
        logout: logout ?? this.logout,
        allowUnencryptedAssertion:
            allowUnencryptedAssertion ?? this.allowUnencryptedAssertion,
        nameIdFormat: nameIdFormat ?? this.nameIdFormat,
        redirect: redirect ?? this.redirect,
        certificates: certificates ?? this.certificates);
  }

  SamlProviderMetadata copyWithWrapped(
      {Wrapped<SamlProviderMetadata$Config>? config,
      Wrapped<String>? entityId,
      Wrapped<String>? login,
      Wrapped<bool>? signGetRequest,
      Wrapped<String>? logout,
      Wrapped<bool>? allowUnencryptedAssertion,
      Wrapped<String>? nameIdFormat,
      Wrapped<String>? redirect,
      Wrapped<List<String>>? certificates}) {
    return SamlProviderMetadata(
        config: (config != null ? config.value : this.config),
        entityId: (entityId != null ? entityId.value : this.entityId),
        login: (login != null ? login.value : this.login),
        signGetRequest: (signGetRequest != null
            ? signGetRequest.value
            : this.signGetRequest),
        logout: (logout != null ? logout.value : this.logout),
        allowUnencryptedAssertion: (allowUnencryptedAssertion != null
            ? allowUnencryptedAssertion.value
            : this.allowUnencryptedAssertion),
        nameIdFormat:
            (nameIdFormat != null ? nameIdFormat.value : this.nameIdFormat),
        redirect: (redirect != null ? redirect.value : this.redirect),
        certificates:
            (certificates != null ? certificates.value : this.certificates));
  }
}

@JsonSerializable(explicitToJson: true)
class SamlProviderOptions {
  SamlProviderOptions({
    required this.metadata,
    this.id,
    required this.color,
    required this.description,
    required this.domain,
    required this.name,
  });

  factory SamlProviderOptions.fromJson(Map<String, dynamic> json) =>
      _$SamlProviderOptionsFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final SamlProviderMetadata metadata;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$SamlProviderOptionsFromJson;
  static const toJsonFactory = _$SamlProviderOptionsToJson;
  Map<String, dynamic> toJson() => _$SamlProviderOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SamlProviderOptions &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $SamlProviderOptionsExtension on SamlProviderOptions {
  SamlProviderOptions copyWith(
      {SamlProviderMetadata? metadata,
      String? id,
      String? color,
      String? description,
      String? domain,
      String? name}) {
    return SamlProviderOptions(
        metadata: metadata ?? this.metadata,
        id: id ?? this.id,
        color: color ?? this.color,
        description: description ?? this.description,
        domain: domain ?? this.domain,
        name: name ?? this.name);
  }

  SamlProviderOptions copyWithWrapped(
      {Wrapped<SamlProviderMetadata>? metadata,
      Wrapped<String?>? id,
      Wrapped<String>? color,
      Wrapped<String>? description,
      Wrapped<String>? domain,
      Wrapped<String>? name}) {
    return SamlProviderOptions(
        metadata: (metadata != null ? metadata.value : this.metadata),
        id: (id != null ? id.value : this.id),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        domain: (domain != null ? domain.value : this.domain),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class KerberosProvider {
  KerberosProvider({
    required this.metadata,
    this.aliases,
    this.groupAliases,
    this.authOidcRoles,
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.icon,
    required this.domain,
    required this.color,
    required this.type,
    required this.accessor,
    required this.callback,
    required this.disabled,
    required this.autoCreateEntity,
    this.enableTotp,
    this.config,
    this.tenantId,
  });

  factory KerberosProvider.fromJson(Map<String, dynamic> json) =>
      _$KerberosProviderFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final ProviderMetadata metadata;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector>? aliases;
  @JsonKey(
      name: 'groupAliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? groupAliases;
  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'callback', includeIfNull: false, defaultValue: '')
  final String callback;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'auto_create_entity', includeIfNull: false)
  final bool autoCreateEntity;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  static const fromJsonFactory = _$KerberosProviderFromJson;
  static const toJsonFactory = _$KerberosProviderToJson;
  Map<String, dynamic> toJson() => _$KerberosProviderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KerberosProvider &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.groupAliases, groupAliases) ||
                const DeepCollectionEquality()
                    .equals(other.groupAliases, groupAliases)) &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.callback, callback) ||
                const DeepCollectionEquality()
                    .equals(other.callback, callback)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.autoCreateEntity, autoCreateEntity) ||
                const DeepCollectionEquality()
                    .equals(other.autoCreateEntity, autoCreateEntity)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(groupAliases) ^
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(callback) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(autoCreateEntity) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(tenantId) ^
      runtimeType.hashCode;
}

extension $KerberosProviderExtension on KerberosProvider {
  KerberosProvider copyWith(
      {ProviderMetadata? metadata,
      List<IdentityConnector>? aliases,
      List<IdentityGroupAlias>? groupAliases,
      List<ProviderOidcRole>? authOidcRoles,
      Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? icon,
      String? domain,
      String? color,
      String? type,
      String? accessor,
      String? callback,
      bool? disabled,
      bool? autoCreateEntity,
      bool? enableTotp,
      Object? config,
      String? tenantId}) {
    return KerberosProvider(
        metadata: metadata ?? this.metadata,
        aliases: aliases ?? this.aliases,
        groupAliases: groupAliases ?? this.groupAliases,
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        domain: domain ?? this.domain,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        callback: callback ?? this.callback,
        disabled: disabled ?? this.disabled,
        autoCreateEntity: autoCreateEntity ?? this.autoCreateEntity,
        enableTotp: enableTotp ?? this.enableTotp,
        config: config ?? this.config,
        tenantId: tenantId ?? this.tenantId);
  }

  KerberosProvider copyWithWrapped(
      {Wrapped<ProviderMetadata>? metadata,
      Wrapped<List<IdentityConnector>?>? aliases,
      Wrapped<List<IdentityGroupAlias>?>? groupAliases,
      Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<String>? domain,
      Wrapped<String>? color,
      Wrapped<String>? type,
      Wrapped<String>? accessor,
      Wrapped<String>? callback,
      Wrapped<bool>? disabled,
      Wrapped<bool>? autoCreateEntity,
      Wrapped<bool?>? enableTotp,
      Wrapped<Object?>? config,
      Wrapped<String?>? tenantId}) {
    return KerberosProvider(
        metadata: (metadata != null ? metadata.value : this.metadata),
        aliases: (aliases != null ? aliases.value : this.aliases),
        groupAliases:
            (groupAliases != null ? groupAliases.value : this.groupAliases),
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        domain: (domain != null ? domain.value : this.domain),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        callback: (callback != null ? callback.value : this.callback),
        disabled: (disabled != null ? disabled.value : this.disabled),
        autoCreateEntity: (autoCreateEntity != null
            ? autoCreateEntity.value
            : this.autoCreateEntity),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        config: (config != null ? config.value : this.config),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId));
  }
}

@JsonSerializable(explicitToJson: true)
class KerberosProviderConfigLdap {
  KerberosProviderConfigLdap({
    this.binddn,
    this.bindpass,
    this.caseSensitiveNames,
    this.certificate,
    this.denyNullBind,
    this.discoverdn,
    this.groupattr,
    this.groupdn,
    this.groupfilter,
    this.insecureTls,
    this.requestTimeout,
    this.starttls,
    this.tlsMaxVersion,
    this.tlsMinVersion,
    this.tokenBoundCidrs,
    this.tokenExplicitMaxTtl,
    this.tokenMaxTtl,
    this.tokenNoDefaultPolicy,
    this.tokenNumUses,
    this.tokenPeriod,
    this.tokenPolicies,
    this.tokenTtl,
    this.tokenType,
    this.upndomain,
    this.url,
    this.usePre111GroupCnBehavior,
    this.useTokenGroups,
    this.userattr,
    this.userdn,
    this.id,
    this.anonymousGroupSearch,
    this.clientTlsCert,
    this.clientTlsKey,
  });

  factory KerberosProviderConfigLdap.fromJson(Map<String, dynamic> json) =>
      _$KerberosProviderConfigLdapFromJson(json);

  @JsonKey(name: 'binddn', includeIfNull: false, defaultValue: '')
  final String? binddn;
  @JsonKey(name: 'bindpass', includeIfNull: false, defaultValue: '')
  final String? bindpass;
  @JsonKey(name: 'case_sensitive_names', includeIfNull: false)
  final bool? caseSensitiveNames;
  @JsonKey(name: 'certificate', includeIfNull: false, defaultValue: '')
  final String? certificate;
  @JsonKey(name: 'deny_null_bind', includeIfNull: false)
  final bool? denyNullBind;
  @JsonKey(name: 'discoverdn', includeIfNull: false)
  final bool? discoverdn;
  @JsonKey(name: 'groupattr', includeIfNull: false, defaultValue: '')
  final String? groupattr;
  @JsonKey(name: 'groupdn', includeIfNull: false, defaultValue: '')
  final String? groupdn;
  @JsonKey(name: 'groupfilter', includeIfNull: false, defaultValue: '')
  final String? groupfilter;
  @JsonKey(name: 'insecure_tls', includeIfNull: false)
  final bool? insecureTls;
  @JsonKey(name: 'request_timeout', includeIfNull: false)
  final double? requestTimeout;
  @JsonKey(name: 'starttls', includeIfNull: false)
  final bool? starttls;
  @JsonKey(name: 'tls_max_version', includeIfNull: false, defaultValue: '')
  final String? tlsMaxVersion;
  @JsonKey(name: 'tls_min_version', includeIfNull: false, defaultValue: '')
  final String? tlsMinVersion;
  @JsonKey(
      name: 'token_bound_cidrs', includeIfNull: false, defaultValue: <String>[])
  final List<String>? tokenBoundCidrs;
  @JsonKey(name: 'token_explicit_max_ttl', includeIfNull: false)
  final double? tokenExplicitMaxTtl;
  @JsonKey(name: 'token_max_ttl', includeIfNull: false)
  final double? tokenMaxTtl;
  @JsonKey(name: 'token_no_default_policy', includeIfNull: false)
  final bool? tokenNoDefaultPolicy;
  @JsonKey(name: 'token_num_uses', includeIfNull: false)
  final double? tokenNumUses;
  @JsonKey(name: 'token_period', includeIfNull: false)
  final double? tokenPeriod;
  @JsonKey(
      name: 'token_policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? tokenPolicies;
  @JsonKey(name: 'token_ttl', includeIfNull: false)
  final double? tokenTtl;
  @JsonKey(name: 'token_type', includeIfNull: false, defaultValue: '')
  final String? tokenType;
  @JsonKey(name: 'upndomain', includeIfNull: false, defaultValue: '')
  final String? upndomain;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'use_pre111_group_cn_behavior', includeIfNull: false)
  final bool? usePre111GroupCnBehavior;
  @JsonKey(name: 'use_token_groups', includeIfNull: false)
  final bool? useTokenGroups;
  @JsonKey(name: 'userattr', includeIfNull: false, defaultValue: '')
  final String? userattr;
  @JsonKey(name: 'userdn', includeIfNull: false, defaultValue: '')
  final String? userdn;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'anonymous_group_search', includeIfNull: false)
  final bool? anonymousGroupSearch;
  @JsonKey(name: 'client_tls_cert', includeIfNull: false, defaultValue: '')
  final String? clientTlsCert;
  @JsonKey(name: 'client_tls_key', includeIfNull: false, defaultValue: '')
  final String? clientTlsKey;
  static const fromJsonFactory = _$KerberosProviderConfigLdapFromJson;
  static const toJsonFactory = _$KerberosProviderConfigLdapToJson;
  Map<String, dynamic> toJson() => _$KerberosProviderConfigLdapToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KerberosProviderConfigLdap &&
            (identical(other.binddn, binddn) ||
                const DeepCollectionEquality().equals(other.binddn, binddn)) &&
            (identical(other.bindpass, bindpass) ||
                const DeepCollectionEquality()
                    .equals(other.bindpass, bindpass)) &&
            (identical(other.caseSensitiveNames, caseSensitiveNames) ||
                const DeepCollectionEquality()
                    .equals(other.caseSensitiveNames, caseSensitiveNames)) &&
            (identical(other.certificate, certificate) ||
                const DeepCollectionEquality()
                    .equals(other.certificate, certificate)) &&
            (identical(other.denyNullBind, denyNullBind) ||
                const DeepCollectionEquality()
                    .equals(other.denyNullBind, denyNullBind)) &&
            (identical(other.discoverdn, discoverdn) ||
                const DeepCollectionEquality()
                    .equals(other.discoverdn, discoverdn)) &&
            (identical(other.groupattr, groupattr) ||
                const DeepCollectionEquality()
                    .equals(other.groupattr, groupattr)) &&
            (identical(other.groupdn, groupdn) ||
                const DeepCollectionEquality()
                    .equals(other.groupdn, groupdn)) &&
            (identical(other.groupfilter, groupfilter) ||
                const DeepCollectionEquality()
                    .equals(other.groupfilter, groupfilter)) &&
            (identical(other.insecureTls, insecureTls) ||
                const DeepCollectionEquality()
                    .equals(other.insecureTls, insecureTls)) &&
            (identical(other.requestTimeout, requestTimeout) ||
                const DeepCollectionEquality()
                    .equals(other.requestTimeout, requestTimeout)) &&
            (identical(other.starttls, starttls) ||
                const DeepCollectionEquality()
                    .equals(other.starttls, starttls)) &&
            (identical(other.tlsMaxVersion, tlsMaxVersion) ||
                const DeepCollectionEquality()
                    .equals(other.tlsMaxVersion, tlsMaxVersion)) &&
            (identical(other.tlsMinVersion, tlsMinVersion) ||
                const DeepCollectionEquality()
                    .equals(other.tlsMinVersion, tlsMinVersion)) &&
            (identical(other.tokenBoundCidrs, tokenBoundCidrs) ||
                const DeepCollectionEquality()
                    .equals(other.tokenBoundCidrs, tokenBoundCidrs)) &&
            (identical(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl)) &&
            (identical(other.tokenMaxTtl, tokenMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenMaxTtl, tokenMaxTtl)) &&
            (identical(other.tokenNoDefaultPolicy, tokenNoDefaultPolicy) ||
                const DeepCollectionEquality().equals(
                    other.tokenNoDefaultPolicy, tokenNoDefaultPolicy)) &&
            (identical(other.tokenNumUses, tokenNumUses) ||
                const DeepCollectionEquality()
                    .equals(other.tokenNumUses, tokenNumUses)) &&
            (identical(other.tokenPeriod, tokenPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPeriod, tokenPeriod)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.tokenTtl, tokenTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenTtl, tokenTtl)) &&
            (identical(other.tokenType, tokenType) || const DeepCollectionEquality().equals(other.tokenType, tokenType)) &&
            (identical(other.upndomain, upndomain) || const DeepCollectionEquality().equals(other.upndomain, upndomain)) &&
            (identical(other.url, url) || const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.usePre111GroupCnBehavior, usePre111GroupCnBehavior) || const DeepCollectionEquality().equals(other.usePre111GroupCnBehavior, usePre111GroupCnBehavior)) &&
            (identical(other.useTokenGroups, useTokenGroups) || const DeepCollectionEquality().equals(other.useTokenGroups, useTokenGroups)) &&
            (identical(other.userattr, userattr) || const DeepCollectionEquality().equals(other.userattr, userattr)) &&
            (identical(other.userdn, userdn) || const DeepCollectionEquality().equals(other.userdn, userdn)) &&
            (identical(other.id, id) || const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.anonymousGroupSearch, anonymousGroupSearch) || const DeepCollectionEquality().equals(other.anonymousGroupSearch, anonymousGroupSearch)) &&
            (identical(other.clientTlsCert, clientTlsCert) || const DeepCollectionEquality().equals(other.clientTlsCert, clientTlsCert)) &&
            (identical(other.clientTlsKey, clientTlsKey) || const DeepCollectionEquality().equals(other.clientTlsKey, clientTlsKey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(binddn) ^
      const DeepCollectionEquality().hash(bindpass) ^
      const DeepCollectionEquality().hash(caseSensitiveNames) ^
      const DeepCollectionEquality().hash(certificate) ^
      const DeepCollectionEquality().hash(denyNullBind) ^
      const DeepCollectionEquality().hash(discoverdn) ^
      const DeepCollectionEquality().hash(groupattr) ^
      const DeepCollectionEquality().hash(groupdn) ^
      const DeepCollectionEquality().hash(groupfilter) ^
      const DeepCollectionEquality().hash(insecureTls) ^
      const DeepCollectionEquality().hash(requestTimeout) ^
      const DeepCollectionEquality().hash(starttls) ^
      const DeepCollectionEquality().hash(tlsMaxVersion) ^
      const DeepCollectionEquality().hash(tlsMinVersion) ^
      const DeepCollectionEquality().hash(tokenBoundCidrs) ^
      const DeepCollectionEquality().hash(tokenExplicitMaxTtl) ^
      const DeepCollectionEquality().hash(tokenMaxTtl) ^
      const DeepCollectionEquality().hash(tokenNoDefaultPolicy) ^
      const DeepCollectionEquality().hash(tokenNumUses) ^
      const DeepCollectionEquality().hash(tokenPeriod) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(tokenTtl) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(upndomain) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(usePre111GroupCnBehavior) ^
      const DeepCollectionEquality().hash(useTokenGroups) ^
      const DeepCollectionEquality().hash(userattr) ^
      const DeepCollectionEquality().hash(userdn) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(anonymousGroupSearch) ^
      const DeepCollectionEquality().hash(clientTlsCert) ^
      const DeepCollectionEquality().hash(clientTlsKey) ^
      runtimeType.hashCode;
}

extension $KerberosProviderConfigLdapExtension on KerberosProviderConfigLdap {
  KerberosProviderConfigLdap copyWith(
      {String? binddn,
      String? bindpass,
      bool? caseSensitiveNames,
      String? certificate,
      bool? denyNullBind,
      bool? discoverdn,
      String? groupattr,
      String? groupdn,
      String? groupfilter,
      bool? insecureTls,
      double? requestTimeout,
      bool? starttls,
      String? tlsMaxVersion,
      String? tlsMinVersion,
      List<String>? tokenBoundCidrs,
      double? tokenExplicitMaxTtl,
      double? tokenMaxTtl,
      bool? tokenNoDefaultPolicy,
      double? tokenNumUses,
      double? tokenPeriod,
      List<String>? tokenPolicies,
      double? tokenTtl,
      String? tokenType,
      String? upndomain,
      String? url,
      bool? usePre111GroupCnBehavior,
      bool? useTokenGroups,
      String? userattr,
      String? userdn,
      String? id,
      bool? anonymousGroupSearch,
      String? clientTlsCert,
      String? clientTlsKey}) {
    return KerberosProviderConfigLdap(
        binddn: binddn ?? this.binddn,
        bindpass: bindpass ?? this.bindpass,
        caseSensitiveNames: caseSensitiveNames ?? this.caseSensitiveNames,
        certificate: certificate ?? this.certificate,
        denyNullBind: denyNullBind ?? this.denyNullBind,
        discoverdn: discoverdn ?? this.discoverdn,
        groupattr: groupattr ?? this.groupattr,
        groupdn: groupdn ?? this.groupdn,
        groupfilter: groupfilter ?? this.groupfilter,
        insecureTls: insecureTls ?? this.insecureTls,
        requestTimeout: requestTimeout ?? this.requestTimeout,
        starttls: starttls ?? this.starttls,
        tlsMaxVersion: tlsMaxVersion ?? this.tlsMaxVersion,
        tlsMinVersion: tlsMinVersion ?? this.tlsMinVersion,
        tokenBoundCidrs: tokenBoundCidrs ?? this.tokenBoundCidrs,
        tokenExplicitMaxTtl: tokenExplicitMaxTtl ?? this.tokenExplicitMaxTtl,
        tokenMaxTtl: tokenMaxTtl ?? this.tokenMaxTtl,
        tokenNoDefaultPolicy: tokenNoDefaultPolicy ?? this.tokenNoDefaultPolicy,
        tokenNumUses: tokenNumUses ?? this.tokenNumUses,
        tokenPeriod: tokenPeriod ?? this.tokenPeriod,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        tokenTtl: tokenTtl ?? this.tokenTtl,
        tokenType: tokenType ?? this.tokenType,
        upndomain: upndomain ?? this.upndomain,
        url: url ?? this.url,
        usePre111GroupCnBehavior:
            usePre111GroupCnBehavior ?? this.usePre111GroupCnBehavior,
        useTokenGroups: useTokenGroups ?? this.useTokenGroups,
        userattr: userattr ?? this.userattr,
        userdn: userdn ?? this.userdn,
        id: id ?? this.id,
        anonymousGroupSearch: anonymousGroupSearch ?? this.anonymousGroupSearch,
        clientTlsCert: clientTlsCert ?? this.clientTlsCert,
        clientTlsKey: clientTlsKey ?? this.clientTlsKey);
  }

  KerberosProviderConfigLdap copyWithWrapped(
      {Wrapped<String?>? binddn,
      Wrapped<String?>? bindpass,
      Wrapped<bool?>? caseSensitiveNames,
      Wrapped<String?>? certificate,
      Wrapped<bool?>? denyNullBind,
      Wrapped<bool?>? discoverdn,
      Wrapped<String?>? groupattr,
      Wrapped<String?>? groupdn,
      Wrapped<String?>? groupfilter,
      Wrapped<bool?>? insecureTls,
      Wrapped<double?>? requestTimeout,
      Wrapped<bool?>? starttls,
      Wrapped<String?>? tlsMaxVersion,
      Wrapped<String?>? tlsMinVersion,
      Wrapped<List<String>?>? tokenBoundCidrs,
      Wrapped<double?>? tokenExplicitMaxTtl,
      Wrapped<double?>? tokenMaxTtl,
      Wrapped<bool?>? tokenNoDefaultPolicy,
      Wrapped<double?>? tokenNumUses,
      Wrapped<double?>? tokenPeriod,
      Wrapped<List<String>?>? tokenPolicies,
      Wrapped<double?>? tokenTtl,
      Wrapped<String?>? tokenType,
      Wrapped<String?>? upndomain,
      Wrapped<String?>? url,
      Wrapped<bool?>? usePre111GroupCnBehavior,
      Wrapped<bool?>? useTokenGroups,
      Wrapped<String?>? userattr,
      Wrapped<String?>? userdn,
      Wrapped<String?>? id,
      Wrapped<bool?>? anonymousGroupSearch,
      Wrapped<String?>? clientTlsCert,
      Wrapped<String?>? clientTlsKey}) {
    return KerberosProviderConfigLdap(
        binddn: (binddn != null ? binddn.value : this.binddn),
        bindpass: (bindpass != null ? bindpass.value : this.bindpass),
        caseSensitiveNames: (caseSensitiveNames != null
            ? caseSensitiveNames.value
            : this.caseSensitiveNames),
        certificate:
            (certificate != null ? certificate.value : this.certificate),
        denyNullBind:
            (denyNullBind != null ? denyNullBind.value : this.denyNullBind),
        discoverdn: (discoverdn != null ? discoverdn.value : this.discoverdn),
        groupattr: (groupattr != null ? groupattr.value : this.groupattr),
        groupdn: (groupdn != null ? groupdn.value : this.groupdn),
        groupfilter:
            (groupfilter != null ? groupfilter.value : this.groupfilter),
        insecureTls:
            (insecureTls != null ? insecureTls.value : this.insecureTls),
        requestTimeout: (requestTimeout != null
            ? requestTimeout.value
            : this.requestTimeout),
        starttls: (starttls != null ? starttls.value : this.starttls),
        tlsMaxVersion:
            (tlsMaxVersion != null ? tlsMaxVersion.value : this.tlsMaxVersion),
        tlsMinVersion:
            (tlsMinVersion != null ? tlsMinVersion.value : this.tlsMinVersion),
        tokenBoundCidrs: (tokenBoundCidrs != null
            ? tokenBoundCidrs.value
            : this.tokenBoundCidrs),
        tokenExplicitMaxTtl: (tokenExplicitMaxTtl != null
            ? tokenExplicitMaxTtl.value
            : this.tokenExplicitMaxTtl),
        tokenMaxTtl:
            (tokenMaxTtl != null ? tokenMaxTtl.value : this.tokenMaxTtl),
        tokenNoDefaultPolicy: (tokenNoDefaultPolicy != null
            ? tokenNoDefaultPolicy.value
            : this.tokenNoDefaultPolicy),
        tokenNumUses:
            (tokenNumUses != null ? tokenNumUses.value : this.tokenNumUses),
        tokenPeriod:
            (tokenPeriod != null ? tokenPeriod.value : this.tokenPeriod),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        tokenTtl: (tokenTtl != null ? tokenTtl.value : this.tokenTtl),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        upndomain: (upndomain != null ? upndomain.value : this.upndomain),
        url: (url != null ? url.value : this.url),
        usePre111GroupCnBehavior: (usePre111GroupCnBehavior != null
            ? usePre111GroupCnBehavior.value
            : this.usePre111GroupCnBehavior),
        useTokenGroups: (useTokenGroups != null
            ? useTokenGroups.value
            : this.useTokenGroups),
        userattr: (userattr != null ? userattr.value : this.userattr),
        userdn: (userdn != null ? userdn.value : this.userdn),
        id: (id != null ? id.value : this.id),
        anonymousGroupSearch: (anonymousGroupSearch != null
            ? anonymousGroupSearch.value
            : this.anonymousGroupSearch),
        clientTlsCert:
            (clientTlsCert != null ? clientTlsCert.value : this.clientTlsCert),
        clientTlsKey:
            (clientTlsKey != null ? clientTlsKey.value : this.clientTlsKey));
  }
}

@JsonSerializable(explicitToJson: true)
class KerberosProviderConfig {
  KerberosProviderConfig({
    this.keytab,
    this.serviceAccount,
    this.id,
  });

  factory KerberosProviderConfig.fromJson(Map<String, dynamic> json) =>
      _$KerberosProviderConfigFromJson(json);

  @JsonKey(name: 'keytab', includeIfNull: false, defaultValue: '')
  final String? keytab;
  @JsonKey(name: 'service_account', includeIfNull: false, defaultValue: '')
  final String? serviceAccount;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$KerberosProviderConfigFromJson;
  static const toJsonFactory = _$KerberosProviderConfigToJson;
  Map<String, dynamic> toJson() => _$KerberosProviderConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KerberosProviderConfig &&
            (identical(other.keytab, keytab) ||
                const DeepCollectionEquality().equals(other.keytab, keytab)) &&
            (identical(other.serviceAccount, serviceAccount) ||
                const DeepCollectionEquality()
                    .equals(other.serviceAccount, serviceAccount)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(keytab) ^
      const DeepCollectionEquality().hash(serviceAccount) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $KerberosProviderConfigExtension on KerberosProviderConfig {
  KerberosProviderConfig copyWith(
      {String? keytab, String? serviceAccount, String? id}) {
    return KerberosProviderConfig(
        keytab: keytab ?? this.keytab,
        serviceAccount: serviceAccount ?? this.serviceAccount,
        id: id ?? this.id);
  }

  KerberosProviderConfig copyWithWrapped(
      {Wrapped<String?>? keytab,
      Wrapped<String?>? serviceAccount,
      Wrapped<String?>? id}) {
    return KerberosProviderConfig(
        keytab: (keytab != null ? keytab.value : this.keytab),
        serviceAccount: (serviceAccount != null
            ? serviceAccount.value
            : this.serviceAccount),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class KerberosProviderOptions {
  KerberosProviderOptions({
    required this.metadata,
    required this.color,
    required this.description,
    required this.domain,
    required this.name,
  });

  factory KerberosProviderOptions.fromJson(Map<String, dynamic> json) =>
      _$KerberosProviderOptionsFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final KerberosProviderOptions$Metadata metadata;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$KerberosProviderOptionsFromJson;
  static const toJsonFactory = _$KerberosProviderOptionsToJson;
  Map<String, dynamic> toJson() => _$KerberosProviderOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KerberosProviderOptions &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $KerberosProviderOptionsExtension on KerberosProviderOptions {
  KerberosProviderOptions copyWith(
      {KerberosProviderOptions$Metadata? metadata,
      String? color,
      String? description,
      String? domain,
      String? name}) {
    return KerberosProviderOptions(
        metadata: metadata ?? this.metadata,
        color: color ?? this.color,
        description: description ?? this.description,
        domain: domain ?? this.domain,
        name: name ?? this.name);
  }

  KerberosProviderOptions copyWithWrapped(
      {Wrapped<KerberosProviderOptions$Metadata>? metadata,
      Wrapped<String>? color,
      Wrapped<String>? description,
      Wrapped<String>? domain,
      Wrapped<String>? name}) {
    return KerberosProviderOptions(
        metadata: (metadata != null ? metadata.value : this.metadata),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        domain: (domain != null ? domain.value : this.domain),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class KerberosProviderLoginOptions {
  KerberosProviderLoginOptions({
    this.authorization,
    this.id,
  });

  factory KerberosProviderLoginOptions.fromJson(Map<String, dynamic> json) =>
      _$KerberosProviderLoginOptionsFromJson(json);

  @JsonKey(name: 'authorization', includeIfNull: false, defaultValue: '')
  final String? authorization;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$KerberosProviderLoginOptionsFromJson;
  static const toJsonFactory = _$KerberosProviderLoginOptionsToJson;
  Map<String, dynamic> toJson() => _$KerberosProviderLoginOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KerberosProviderLoginOptions &&
            (identical(other.authorization, authorization) ||
                const DeepCollectionEquality()
                    .equals(other.authorization, authorization)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(authorization) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $KerberosProviderLoginOptionsExtension
    on KerberosProviderLoginOptions {
  KerberosProviderLoginOptions copyWith({String? authorization, String? id}) {
    return KerberosProviderLoginOptions(
        authorization: authorization ?? this.authorization, id: id ?? this.id);
  }

  KerberosProviderLoginOptions copyWithWrapped(
      {Wrapped<String?>? authorization, Wrapped<String?>? id}) {
    return KerberosProviderLoginOptions(
        authorization:
            (authorization != null ? authorization.value : this.authorization),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class LdapProvider {
  LdapProvider({
    required this.metadata,
    this.aliases,
    this.groupAliases,
    this.authOidcRoles,
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.icon,
    required this.domain,
    required this.color,
    required this.type,
    required this.accessor,
    required this.callback,
    required this.disabled,
    required this.autoCreateEntity,
    this.enableTotp,
    this.config,
    this.tenantId,
  });

  factory LdapProvider.fromJson(Map<String, dynamic> json) =>
      _$LdapProviderFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final ProviderMetadata metadata;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector>? aliases;
  @JsonKey(
      name: 'groupAliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? groupAliases;
  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'callback', includeIfNull: false, defaultValue: '')
  final String callback;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'auto_create_entity', includeIfNull: false)
  final bool autoCreateEntity;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  static const fromJsonFactory = _$LdapProviderFromJson;
  static const toJsonFactory = _$LdapProviderToJson;
  Map<String, dynamic> toJson() => _$LdapProviderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LdapProvider &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.groupAliases, groupAliases) ||
                const DeepCollectionEquality()
                    .equals(other.groupAliases, groupAliases)) &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.callback, callback) ||
                const DeepCollectionEquality()
                    .equals(other.callback, callback)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.autoCreateEntity, autoCreateEntity) ||
                const DeepCollectionEquality()
                    .equals(other.autoCreateEntity, autoCreateEntity)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(groupAliases) ^
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(callback) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(autoCreateEntity) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(tenantId) ^
      runtimeType.hashCode;
}

extension $LdapProviderExtension on LdapProvider {
  LdapProvider copyWith(
      {ProviderMetadata? metadata,
      List<IdentityConnector>? aliases,
      List<IdentityGroupAlias>? groupAliases,
      List<ProviderOidcRole>? authOidcRoles,
      Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? icon,
      String? domain,
      String? color,
      String? type,
      String? accessor,
      String? callback,
      bool? disabled,
      bool? autoCreateEntity,
      bool? enableTotp,
      Object? config,
      String? tenantId}) {
    return LdapProvider(
        metadata: metadata ?? this.metadata,
        aliases: aliases ?? this.aliases,
        groupAliases: groupAliases ?? this.groupAliases,
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        domain: domain ?? this.domain,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        callback: callback ?? this.callback,
        disabled: disabled ?? this.disabled,
        autoCreateEntity: autoCreateEntity ?? this.autoCreateEntity,
        enableTotp: enableTotp ?? this.enableTotp,
        config: config ?? this.config,
        tenantId: tenantId ?? this.tenantId);
  }

  LdapProvider copyWithWrapped(
      {Wrapped<ProviderMetadata>? metadata,
      Wrapped<List<IdentityConnector>?>? aliases,
      Wrapped<List<IdentityGroupAlias>?>? groupAliases,
      Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<String>? domain,
      Wrapped<String>? color,
      Wrapped<String>? type,
      Wrapped<String>? accessor,
      Wrapped<String>? callback,
      Wrapped<bool>? disabled,
      Wrapped<bool>? autoCreateEntity,
      Wrapped<bool?>? enableTotp,
      Wrapped<Object?>? config,
      Wrapped<String?>? tenantId}) {
    return LdapProvider(
        metadata: (metadata != null ? metadata.value : this.metadata),
        aliases: (aliases != null ? aliases.value : this.aliases),
        groupAliases:
            (groupAliases != null ? groupAliases.value : this.groupAliases),
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        domain: (domain != null ? domain.value : this.domain),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        callback: (callback != null ? callback.value : this.callback),
        disabled: (disabled != null ? disabled.value : this.disabled),
        autoCreateEntity: (autoCreateEntity != null
            ? autoCreateEntity.value
            : this.autoCreateEntity),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        config: (config != null ? config.value : this.config),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId));
  }
}

@JsonSerializable(explicitToJson: true)
class LdapProviderConfig {
  LdapProviderConfig({
    this.binddn,
    this.bindpass,
    this.caseSensitiveNames,
    this.certificate,
    this.denyNullBind,
    this.discoverdn,
    this.groupattr,
    this.groupdn,
    this.groupfilter,
    this.insecureTls,
    this.requestTimeout,
    this.starttls,
    this.tlsMaxVersion,
    this.tlsMinVersion,
    this.tokenBoundCidrs,
    this.tokenExplicitMaxTtl,
    this.tokenMaxTtl,
    this.tokenNoDefaultPolicy,
    this.tokenNumUses,
    this.tokenPeriod,
    this.tokenPolicies,
    this.tokenTtl,
    this.tokenType,
    this.upndomain,
    this.url,
    this.usePre111GroupCnBehavior,
    this.useTokenGroups,
    this.userattr,
    this.userdn,
    this.id,
    this.anonymousGroupSearch,
    this.clientTlsCert,
    this.clientTlsKey,
  });

  factory LdapProviderConfig.fromJson(Map<String, dynamic> json) =>
      _$LdapProviderConfigFromJson(json);

  @JsonKey(name: 'binddn', includeIfNull: false, defaultValue: '')
  final String? binddn;
  @JsonKey(name: 'bindpass', includeIfNull: false, defaultValue: '')
  final String? bindpass;
  @JsonKey(name: 'case_sensitive_names', includeIfNull: false)
  final bool? caseSensitiveNames;
  @JsonKey(name: 'certificate', includeIfNull: false, defaultValue: '')
  final String? certificate;
  @JsonKey(name: 'deny_null_bind', includeIfNull: false)
  final bool? denyNullBind;
  @JsonKey(name: 'discoverdn', includeIfNull: false)
  final bool? discoverdn;
  @JsonKey(name: 'groupattr', includeIfNull: false, defaultValue: '')
  final String? groupattr;
  @JsonKey(name: 'groupdn', includeIfNull: false, defaultValue: '')
  final String? groupdn;
  @JsonKey(name: 'groupfilter', includeIfNull: false, defaultValue: '')
  final String? groupfilter;
  @JsonKey(name: 'insecure_tls', includeIfNull: false)
  final bool? insecureTls;
  @JsonKey(name: 'request_timeout', includeIfNull: false)
  final double? requestTimeout;
  @JsonKey(name: 'starttls', includeIfNull: false)
  final bool? starttls;
  @JsonKey(name: 'tls_max_version', includeIfNull: false, defaultValue: '')
  final String? tlsMaxVersion;
  @JsonKey(name: 'tls_min_version', includeIfNull: false, defaultValue: '')
  final String? tlsMinVersion;
  @JsonKey(
      name: 'token_bound_cidrs', includeIfNull: false, defaultValue: <String>[])
  final List<String>? tokenBoundCidrs;
  @JsonKey(name: 'token_explicit_max_ttl', includeIfNull: false)
  final double? tokenExplicitMaxTtl;
  @JsonKey(name: 'token_max_ttl', includeIfNull: false)
  final double? tokenMaxTtl;
  @JsonKey(name: 'token_no_default_policy', includeIfNull: false)
  final bool? tokenNoDefaultPolicy;
  @JsonKey(name: 'token_num_uses', includeIfNull: false)
  final double? tokenNumUses;
  @JsonKey(name: 'token_period', includeIfNull: false)
  final double? tokenPeriod;
  @JsonKey(
      name: 'token_policies', includeIfNull: false, defaultValue: <String>[])
  final List<String>? tokenPolicies;
  @JsonKey(name: 'token_ttl', includeIfNull: false)
  final double? tokenTtl;
  @JsonKey(name: 'token_type', includeIfNull: false, defaultValue: '')
  final String? tokenType;
  @JsonKey(name: 'upndomain', includeIfNull: false, defaultValue: '')
  final String? upndomain;
  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  @JsonKey(name: 'use_pre111_group_cn_behavior', includeIfNull: false)
  final bool? usePre111GroupCnBehavior;
  @JsonKey(name: 'use_token_groups', includeIfNull: false)
  final bool? useTokenGroups;
  @JsonKey(name: 'userattr', includeIfNull: false, defaultValue: '')
  final String? userattr;
  @JsonKey(name: 'userdn', includeIfNull: false, defaultValue: '')
  final String? userdn;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'anonymous_group_search', includeIfNull: false)
  final bool? anonymousGroupSearch;
  @JsonKey(name: 'client_tls_cert', includeIfNull: false, defaultValue: '')
  final String? clientTlsCert;
  @JsonKey(name: 'client_tls_key', includeIfNull: false, defaultValue: '')
  final String? clientTlsKey;
  static const fromJsonFactory = _$LdapProviderConfigFromJson;
  static const toJsonFactory = _$LdapProviderConfigToJson;
  Map<String, dynamic> toJson() => _$LdapProviderConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LdapProviderConfig &&
            (identical(other.binddn, binddn) ||
                const DeepCollectionEquality().equals(other.binddn, binddn)) &&
            (identical(other.bindpass, bindpass) ||
                const DeepCollectionEquality()
                    .equals(other.bindpass, bindpass)) &&
            (identical(other.caseSensitiveNames, caseSensitiveNames) ||
                const DeepCollectionEquality()
                    .equals(other.caseSensitiveNames, caseSensitiveNames)) &&
            (identical(other.certificate, certificate) ||
                const DeepCollectionEquality()
                    .equals(other.certificate, certificate)) &&
            (identical(other.denyNullBind, denyNullBind) ||
                const DeepCollectionEquality()
                    .equals(other.denyNullBind, denyNullBind)) &&
            (identical(other.discoverdn, discoverdn) ||
                const DeepCollectionEquality()
                    .equals(other.discoverdn, discoverdn)) &&
            (identical(other.groupattr, groupattr) ||
                const DeepCollectionEquality()
                    .equals(other.groupattr, groupattr)) &&
            (identical(other.groupdn, groupdn) ||
                const DeepCollectionEquality()
                    .equals(other.groupdn, groupdn)) &&
            (identical(other.groupfilter, groupfilter) ||
                const DeepCollectionEquality()
                    .equals(other.groupfilter, groupfilter)) &&
            (identical(other.insecureTls, insecureTls) ||
                const DeepCollectionEquality()
                    .equals(other.insecureTls, insecureTls)) &&
            (identical(other.requestTimeout, requestTimeout) ||
                const DeepCollectionEquality()
                    .equals(other.requestTimeout, requestTimeout)) &&
            (identical(other.starttls, starttls) ||
                const DeepCollectionEquality()
                    .equals(other.starttls, starttls)) &&
            (identical(other.tlsMaxVersion, tlsMaxVersion) ||
                const DeepCollectionEquality()
                    .equals(other.tlsMaxVersion, tlsMaxVersion)) &&
            (identical(other.tlsMinVersion, tlsMinVersion) ||
                const DeepCollectionEquality()
                    .equals(other.tlsMinVersion, tlsMinVersion)) &&
            (identical(other.tokenBoundCidrs, tokenBoundCidrs) ||
                const DeepCollectionEquality()
                    .equals(other.tokenBoundCidrs, tokenBoundCidrs)) &&
            (identical(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenExplicitMaxTtl, tokenExplicitMaxTtl)) &&
            (identical(other.tokenMaxTtl, tokenMaxTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenMaxTtl, tokenMaxTtl)) &&
            (identical(other.tokenNoDefaultPolicy, tokenNoDefaultPolicy) ||
                const DeepCollectionEquality().equals(
                    other.tokenNoDefaultPolicy, tokenNoDefaultPolicy)) &&
            (identical(other.tokenNumUses, tokenNumUses) ||
                const DeepCollectionEquality()
                    .equals(other.tokenNumUses, tokenNumUses)) &&
            (identical(other.tokenPeriod, tokenPeriod) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPeriod, tokenPeriod)) &&
            (identical(other.tokenPolicies, tokenPolicies) ||
                const DeepCollectionEquality()
                    .equals(other.tokenPolicies, tokenPolicies)) &&
            (identical(other.tokenTtl, tokenTtl) ||
                const DeepCollectionEquality()
                    .equals(other.tokenTtl, tokenTtl)) &&
            (identical(other.tokenType, tokenType) || const DeepCollectionEquality().equals(other.tokenType, tokenType)) &&
            (identical(other.upndomain, upndomain) || const DeepCollectionEquality().equals(other.upndomain, upndomain)) &&
            (identical(other.url, url) || const DeepCollectionEquality().equals(other.url, url)) &&
            (identical(other.usePre111GroupCnBehavior, usePre111GroupCnBehavior) || const DeepCollectionEquality().equals(other.usePre111GroupCnBehavior, usePre111GroupCnBehavior)) &&
            (identical(other.useTokenGroups, useTokenGroups) || const DeepCollectionEquality().equals(other.useTokenGroups, useTokenGroups)) &&
            (identical(other.userattr, userattr) || const DeepCollectionEquality().equals(other.userattr, userattr)) &&
            (identical(other.userdn, userdn) || const DeepCollectionEquality().equals(other.userdn, userdn)) &&
            (identical(other.id, id) || const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.anonymousGroupSearch, anonymousGroupSearch) || const DeepCollectionEquality().equals(other.anonymousGroupSearch, anonymousGroupSearch)) &&
            (identical(other.clientTlsCert, clientTlsCert) || const DeepCollectionEquality().equals(other.clientTlsCert, clientTlsCert)) &&
            (identical(other.clientTlsKey, clientTlsKey) || const DeepCollectionEquality().equals(other.clientTlsKey, clientTlsKey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(binddn) ^
      const DeepCollectionEquality().hash(bindpass) ^
      const DeepCollectionEquality().hash(caseSensitiveNames) ^
      const DeepCollectionEquality().hash(certificate) ^
      const DeepCollectionEquality().hash(denyNullBind) ^
      const DeepCollectionEquality().hash(discoverdn) ^
      const DeepCollectionEquality().hash(groupattr) ^
      const DeepCollectionEquality().hash(groupdn) ^
      const DeepCollectionEquality().hash(groupfilter) ^
      const DeepCollectionEquality().hash(insecureTls) ^
      const DeepCollectionEquality().hash(requestTimeout) ^
      const DeepCollectionEquality().hash(starttls) ^
      const DeepCollectionEquality().hash(tlsMaxVersion) ^
      const DeepCollectionEquality().hash(tlsMinVersion) ^
      const DeepCollectionEquality().hash(tokenBoundCidrs) ^
      const DeepCollectionEquality().hash(tokenExplicitMaxTtl) ^
      const DeepCollectionEquality().hash(tokenMaxTtl) ^
      const DeepCollectionEquality().hash(tokenNoDefaultPolicy) ^
      const DeepCollectionEquality().hash(tokenNumUses) ^
      const DeepCollectionEquality().hash(tokenPeriod) ^
      const DeepCollectionEquality().hash(tokenPolicies) ^
      const DeepCollectionEquality().hash(tokenTtl) ^
      const DeepCollectionEquality().hash(tokenType) ^
      const DeepCollectionEquality().hash(upndomain) ^
      const DeepCollectionEquality().hash(url) ^
      const DeepCollectionEquality().hash(usePre111GroupCnBehavior) ^
      const DeepCollectionEquality().hash(useTokenGroups) ^
      const DeepCollectionEquality().hash(userattr) ^
      const DeepCollectionEquality().hash(userdn) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(anonymousGroupSearch) ^
      const DeepCollectionEquality().hash(clientTlsCert) ^
      const DeepCollectionEquality().hash(clientTlsKey) ^
      runtimeType.hashCode;
}

extension $LdapProviderConfigExtension on LdapProviderConfig {
  LdapProviderConfig copyWith(
      {String? binddn,
      String? bindpass,
      bool? caseSensitiveNames,
      String? certificate,
      bool? denyNullBind,
      bool? discoverdn,
      String? groupattr,
      String? groupdn,
      String? groupfilter,
      bool? insecureTls,
      double? requestTimeout,
      bool? starttls,
      String? tlsMaxVersion,
      String? tlsMinVersion,
      List<String>? tokenBoundCidrs,
      double? tokenExplicitMaxTtl,
      double? tokenMaxTtl,
      bool? tokenNoDefaultPolicy,
      double? tokenNumUses,
      double? tokenPeriod,
      List<String>? tokenPolicies,
      double? tokenTtl,
      String? tokenType,
      String? upndomain,
      String? url,
      bool? usePre111GroupCnBehavior,
      bool? useTokenGroups,
      String? userattr,
      String? userdn,
      String? id,
      bool? anonymousGroupSearch,
      String? clientTlsCert,
      String? clientTlsKey}) {
    return LdapProviderConfig(
        binddn: binddn ?? this.binddn,
        bindpass: bindpass ?? this.bindpass,
        caseSensitiveNames: caseSensitiveNames ?? this.caseSensitiveNames,
        certificate: certificate ?? this.certificate,
        denyNullBind: denyNullBind ?? this.denyNullBind,
        discoverdn: discoverdn ?? this.discoverdn,
        groupattr: groupattr ?? this.groupattr,
        groupdn: groupdn ?? this.groupdn,
        groupfilter: groupfilter ?? this.groupfilter,
        insecureTls: insecureTls ?? this.insecureTls,
        requestTimeout: requestTimeout ?? this.requestTimeout,
        starttls: starttls ?? this.starttls,
        tlsMaxVersion: tlsMaxVersion ?? this.tlsMaxVersion,
        tlsMinVersion: tlsMinVersion ?? this.tlsMinVersion,
        tokenBoundCidrs: tokenBoundCidrs ?? this.tokenBoundCidrs,
        tokenExplicitMaxTtl: tokenExplicitMaxTtl ?? this.tokenExplicitMaxTtl,
        tokenMaxTtl: tokenMaxTtl ?? this.tokenMaxTtl,
        tokenNoDefaultPolicy: tokenNoDefaultPolicy ?? this.tokenNoDefaultPolicy,
        tokenNumUses: tokenNumUses ?? this.tokenNumUses,
        tokenPeriod: tokenPeriod ?? this.tokenPeriod,
        tokenPolicies: tokenPolicies ?? this.tokenPolicies,
        tokenTtl: tokenTtl ?? this.tokenTtl,
        tokenType: tokenType ?? this.tokenType,
        upndomain: upndomain ?? this.upndomain,
        url: url ?? this.url,
        usePre111GroupCnBehavior:
            usePre111GroupCnBehavior ?? this.usePre111GroupCnBehavior,
        useTokenGroups: useTokenGroups ?? this.useTokenGroups,
        userattr: userattr ?? this.userattr,
        userdn: userdn ?? this.userdn,
        id: id ?? this.id,
        anonymousGroupSearch: anonymousGroupSearch ?? this.anonymousGroupSearch,
        clientTlsCert: clientTlsCert ?? this.clientTlsCert,
        clientTlsKey: clientTlsKey ?? this.clientTlsKey);
  }

  LdapProviderConfig copyWithWrapped(
      {Wrapped<String?>? binddn,
      Wrapped<String?>? bindpass,
      Wrapped<bool?>? caseSensitiveNames,
      Wrapped<String?>? certificate,
      Wrapped<bool?>? denyNullBind,
      Wrapped<bool?>? discoverdn,
      Wrapped<String?>? groupattr,
      Wrapped<String?>? groupdn,
      Wrapped<String?>? groupfilter,
      Wrapped<bool?>? insecureTls,
      Wrapped<double?>? requestTimeout,
      Wrapped<bool?>? starttls,
      Wrapped<String?>? tlsMaxVersion,
      Wrapped<String?>? tlsMinVersion,
      Wrapped<List<String>?>? tokenBoundCidrs,
      Wrapped<double?>? tokenExplicitMaxTtl,
      Wrapped<double?>? tokenMaxTtl,
      Wrapped<bool?>? tokenNoDefaultPolicy,
      Wrapped<double?>? tokenNumUses,
      Wrapped<double?>? tokenPeriod,
      Wrapped<List<String>?>? tokenPolicies,
      Wrapped<double?>? tokenTtl,
      Wrapped<String?>? tokenType,
      Wrapped<String?>? upndomain,
      Wrapped<String?>? url,
      Wrapped<bool?>? usePre111GroupCnBehavior,
      Wrapped<bool?>? useTokenGroups,
      Wrapped<String?>? userattr,
      Wrapped<String?>? userdn,
      Wrapped<String?>? id,
      Wrapped<bool?>? anonymousGroupSearch,
      Wrapped<String?>? clientTlsCert,
      Wrapped<String?>? clientTlsKey}) {
    return LdapProviderConfig(
        binddn: (binddn != null ? binddn.value : this.binddn),
        bindpass: (bindpass != null ? bindpass.value : this.bindpass),
        caseSensitiveNames: (caseSensitiveNames != null
            ? caseSensitiveNames.value
            : this.caseSensitiveNames),
        certificate:
            (certificate != null ? certificate.value : this.certificate),
        denyNullBind:
            (denyNullBind != null ? denyNullBind.value : this.denyNullBind),
        discoverdn: (discoverdn != null ? discoverdn.value : this.discoverdn),
        groupattr: (groupattr != null ? groupattr.value : this.groupattr),
        groupdn: (groupdn != null ? groupdn.value : this.groupdn),
        groupfilter:
            (groupfilter != null ? groupfilter.value : this.groupfilter),
        insecureTls:
            (insecureTls != null ? insecureTls.value : this.insecureTls),
        requestTimeout: (requestTimeout != null
            ? requestTimeout.value
            : this.requestTimeout),
        starttls: (starttls != null ? starttls.value : this.starttls),
        tlsMaxVersion:
            (tlsMaxVersion != null ? tlsMaxVersion.value : this.tlsMaxVersion),
        tlsMinVersion:
            (tlsMinVersion != null ? tlsMinVersion.value : this.tlsMinVersion),
        tokenBoundCidrs: (tokenBoundCidrs != null
            ? tokenBoundCidrs.value
            : this.tokenBoundCidrs),
        tokenExplicitMaxTtl: (tokenExplicitMaxTtl != null
            ? tokenExplicitMaxTtl.value
            : this.tokenExplicitMaxTtl),
        tokenMaxTtl:
            (tokenMaxTtl != null ? tokenMaxTtl.value : this.tokenMaxTtl),
        tokenNoDefaultPolicy: (tokenNoDefaultPolicy != null
            ? tokenNoDefaultPolicy.value
            : this.tokenNoDefaultPolicy),
        tokenNumUses:
            (tokenNumUses != null ? tokenNumUses.value : this.tokenNumUses),
        tokenPeriod:
            (tokenPeriod != null ? tokenPeriod.value : this.tokenPeriod),
        tokenPolicies:
            (tokenPolicies != null ? tokenPolicies.value : this.tokenPolicies),
        tokenTtl: (tokenTtl != null ? tokenTtl.value : this.tokenTtl),
        tokenType: (tokenType != null ? tokenType.value : this.tokenType),
        upndomain: (upndomain != null ? upndomain.value : this.upndomain),
        url: (url != null ? url.value : this.url),
        usePre111GroupCnBehavior: (usePre111GroupCnBehavior != null
            ? usePre111GroupCnBehavior.value
            : this.usePre111GroupCnBehavior),
        useTokenGroups: (useTokenGroups != null
            ? useTokenGroups.value
            : this.useTokenGroups),
        userattr: (userattr != null ? userattr.value : this.userattr),
        userdn: (userdn != null ? userdn.value : this.userdn),
        id: (id != null ? id.value : this.id),
        anonymousGroupSearch: (anonymousGroupSearch != null
            ? anonymousGroupSearch.value
            : this.anonymousGroupSearch),
        clientTlsCert:
            (clientTlsCert != null ? clientTlsCert.value : this.clientTlsCert),
        clientTlsKey:
            (clientTlsKey != null ? clientTlsKey.value : this.clientTlsKey));
  }
}

@JsonSerializable(explicitToJson: true)
class LdapProviderOptions {
  LdapProviderOptions({
    required this.metadata,
    required this.color,
    required this.description,
    required this.domain,
    this.enableTotp,
    required this.name,
  });

  factory LdapProviderOptions.fromJson(Map<String, dynamic> json) =>
      _$LdapProviderOptionsFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final LdapProviderOptions$Metadata metadata;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$LdapProviderOptionsFromJson;
  static const toJsonFactory = _$LdapProviderOptionsToJson;
  Map<String, dynamic> toJson() => _$LdapProviderOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LdapProviderOptions &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $LdapProviderOptionsExtension on LdapProviderOptions {
  LdapProviderOptions copyWith(
      {LdapProviderOptions$Metadata? metadata,
      String? color,
      String? description,
      String? domain,
      bool? enableTotp,
      String? name}) {
    return LdapProviderOptions(
        metadata: metadata ?? this.metadata,
        color: color ?? this.color,
        description: description ?? this.description,
        domain: domain ?? this.domain,
        enableTotp: enableTotp ?? this.enableTotp,
        name: name ?? this.name);
  }

  LdapProviderOptions copyWithWrapped(
      {Wrapped<LdapProviderOptions$Metadata>? metadata,
      Wrapped<String>? color,
      Wrapped<String>? description,
      Wrapped<String>? domain,
      Wrapped<bool?>? enableTotp,
      Wrapped<String>? name}) {
    return LdapProviderOptions(
        metadata: (metadata != null ? metadata.value : this.metadata),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        domain: (domain != null ? domain.value : this.domain),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class UserPassProvider {
  UserPassProvider({
    required this.metadata,
    this.aliases,
    this.groupAliases,
    this.authOidcRoles,
    this.tenant,
    required this.id,
    required this.name,
    required this.description,
    required this.icon,
    required this.domain,
    required this.color,
    required this.type,
    required this.accessor,
    required this.callback,
    required this.disabled,
    required this.autoCreateEntity,
    this.enableTotp,
    this.config,
    this.tenantId,
  });

  factory UserPassProvider.fromJson(Map<String, dynamic> json) =>
      _$UserPassProviderFromJson(json);

  @JsonKey(name: 'metadata', includeIfNull: false)
  final ProviderMetadata metadata;
  @JsonKey(
      name: 'aliases',
      includeIfNull: false,
      defaultValue: <IdentityConnector>[])
  final List<IdentityConnector>? aliases;
  @JsonKey(
      name: 'groupAliases',
      includeIfNull: false,
      defaultValue: <IdentityGroupAlias>[])
  final List<IdentityGroupAlias>? groupAliases;
  @JsonKey(
      name: 'authOidcRoles',
      includeIfNull: false,
      defaultValue: <ProviderOidcRole>[])
  final List<ProviderOidcRole>? authOidcRoles;
  @JsonKey(name: 'tenant', includeIfNull: false)
  final Tenant? tenant;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'icon', includeIfNull: false, defaultValue: '')
  final String icon;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String accessor;
  @JsonKey(name: 'callback', includeIfNull: false, defaultValue: '')
  final String callback;
  @JsonKey(name: 'disabled', includeIfNull: false)
  final bool disabled;
  @JsonKey(name: 'auto_create_entity', includeIfNull: false)
  final bool autoCreateEntity;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String? tenantId;
  static const fromJsonFactory = _$UserPassProviderFromJson;
  static const toJsonFactory = _$UserPassProviderToJson;
  Map<String, dynamic> toJson() => _$UserPassProviderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserPassProvider &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)) &&
            (identical(other.aliases, aliases) ||
                const DeepCollectionEquality()
                    .equals(other.aliases, aliases)) &&
            (identical(other.groupAliases, groupAliases) ||
                const DeepCollectionEquality()
                    .equals(other.groupAliases, groupAliases)) &&
            (identical(other.authOidcRoles, authOidcRoles) ||
                const DeepCollectionEquality()
                    .equals(other.authOidcRoles, authOidcRoles)) &&
            (identical(other.tenant, tenant) ||
                const DeepCollectionEquality().equals(other.tenant, tenant)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.icon, icon) ||
                const DeepCollectionEquality().equals(other.icon, icon)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.callback, callback) ||
                const DeepCollectionEquality()
                    .equals(other.callback, callback)) &&
            (identical(other.disabled, disabled) ||
                const DeepCollectionEquality()
                    .equals(other.disabled, disabled)) &&
            (identical(other.autoCreateEntity, autoCreateEntity) ||
                const DeepCollectionEquality()
                    .equals(other.autoCreateEntity, autoCreateEntity)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(metadata) ^
      const DeepCollectionEquality().hash(aliases) ^
      const DeepCollectionEquality().hash(groupAliases) ^
      const DeepCollectionEquality().hash(authOidcRoles) ^
      const DeepCollectionEquality().hash(tenant) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(icon) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(callback) ^
      const DeepCollectionEquality().hash(disabled) ^
      const DeepCollectionEquality().hash(autoCreateEntity) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(tenantId) ^
      runtimeType.hashCode;
}

extension $UserPassProviderExtension on UserPassProvider {
  UserPassProvider copyWith(
      {ProviderMetadata? metadata,
      List<IdentityConnector>? aliases,
      List<IdentityGroupAlias>? groupAliases,
      List<ProviderOidcRole>? authOidcRoles,
      Tenant? tenant,
      String? id,
      String? name,
      String? description,
      String? icon,
      String? domain,
      String? color,
      String? type,
      String? accessor,
      String? callback,
      bool? disabled,
      bool? autoCreateEntity,
      bool? enableTotp,
      Object? config,
      String? tenantId}) {
    return UserPassProvider(
        metadata: metadata ?? this.metadata,
        aliases: aliases ?? this.aliases,
        groupAliases: groupAliases ?? this.groupAliases,
        authOidcRoles: authOidcRoles ?? this.authOidcRoles,
        tenant: tenant ?? this.tenant,
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        icon: icon ?? this.icon,
        domain: domain ?? this.domain,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        callback: callback ?? this.callback,
        disabled: disabled ?? this.disabled,
        autoCreateEntity: autoCreateEntity ?? this.autoCreateEntity,
        enableTotp: enableTotp ?? this.enableTotp,
        config: config ?? this.config,
        tenantId: tenantId ?? this.tenantId);
  }

  UserPassProvider copyWithWrapped(
      {Wrapped<ProviderMetadata>? metadata,
      Wrapped<List<IdentityConnector>?>? aliases,
      Wrapped<List<IdentityGroupAlias>?>? groupAliases,
      Wrapped<List<ProviderOidcRole>?>? authOidcRoles,
      Wrapped<Tenant?>? tenant,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? icon,
      Wrapped<String>? domain,
      Wrapped<String>? color,
      Wrapped<String>? type,
      Wrapped<String>? accessor,
      Wrapped<String>? callback,
      Wrapped<bool>? disabled,
      Wrapped<bool>? autoCreateEntity,
      Wrapped<bool?>? enableTotp,
      Wrapped<Object?>? config,
      Wrapped<String?>? tenantId}) {
    return UserPassProvider(
        metadata: (metadata != null ? metadata.value : this.metadata),
        aliases: (aliases != null ? aliases.value : this.aliases),
        groupAliases:
            (groupAliases != null ? groupAliases.value : this.groupAliases),
        authOidcRoles:
            (authOidcRoles != null ? authOidcRoles.value : this.authOidcRoles),
        tenant: (tenant != null ? tenant.value : this.tenant),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        icon: (icon != null ? icon.value : this.icon),
        domain: (domain != null ? domain.value : this.domain),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        callback: (callback != null ? callback.value : this.callback),
        disabled: (disabled != null ? disabled.value : this.disabled),
        autoCreateEntity: (autoCreateEntity != null
            ? autoCreateEntity.value
            : this.autoCreateEntity),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        config: (config != null ? config.value : this.config),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId));
  }
}

@JsonSerializable(explicitToJson: true)
class UserpassProviderOptions {
  UserpassProviderOptions({
    required this.color,
    required this.description,
    required this.domain,
    this.enableTotp,
    required this.name,
  });

  factory UserpassProviderOptions.fromJson(Map<String, dynamic> json) =>
      _$UserpassProviderOptionsFromJson(json);

  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'domain', includeIfNull: false, defaultValue: '')
  final String domain;
  @JsonKey(name: 'enable_totp', includeIfNull: false)
  final bool? enableTotp;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  static const fromJsonFactory = _$UserpassProviderOptionsFromJson;
  static const toJsonFactory = _$UserpassProviderOptionsToJson;
  Map<String, dynamic> toJson() => _$UserpassProviderOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is UserpassProviderOptions &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.domain, domain) ||
                const DeepCollectionEquality().equals(other.domain, domain)) &&
            (identical(other.enableTotp, enableTotp) ||
                const DeepCollectionEquality()
                    .equals(other.enableTotp, enableTotp)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(domain) ^
      const DeepCollectionEquality().hash(enableTotp) ^
      const DeepCollectionEquality().hash(name) ^
      runtimeType.hashCode;
}

extension $UserpassProviderOptionsExtension on UserpassProviderOptions {
  UserpassProviderOptions copyWith(
      {String? color,
      String? description,
      String? domain,
      bool? enableTotp,
      String? name}) {
    return UserpassProviderOptions(
        color: color ?? this.color,
        description: description ?? this.description,
        domain: domain ?? this.domain,
        enableTotp: enableTotp ?? this.enableTotp,
        name: name ?? this.name);
  }

  UserpassProviderOptions copyWithWrapped(
      {Wrapped<String>? color,
      Wrapped<String>? description,
      Wrapped<String>? domain,
      Wrapped<bool?>? enableTotp,
      Wrapped<String>? name}) {
    return UserpassProviderOptions(
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        domain: (domain != null ? domain.value : this.domain),
        enableTotp: (enableTotp != null ? enableTotp.value : this.enableTotp),
        name: (name != null ? name.value : this.name));
  }
}

@JsonSerializable(explicitToJson: true)
class CubbyholeDeleteResponse {
  CubbyholeDeleteResponse();

  factory CubbyholeDeleteResponse.fromJson(Map<String, dynamic> json) =>
      _$CubbyholeDeleteResponseFromJson(json);

  static const fromJsonFactory = _$CubbyholeDeleteResponseFromJson;
  static const toJsonFactory = _$CubbyholeDeleteResponseToJson;
  Map<String, dynamic> toJson() => _$CubbyholeDeleteResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class KeyPair {
  KeyPair();

  factory KeyPair.fromJson(Map<String, dynamic> json) =>
      _$KeyPairFromJson(json);

  static const fromJsonFactory = _$KeyPairFromJson;
  static const toJsonFactory = _$KeyPairToJson;
  Map<String, dynamic> toJson() => _$KeyPairToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class CubbyholeReadResponse {
  CubbyholeReadResponse({
    required this.path,
    required this.folders,
    required this.data,
  });

  factory CubbyholeReadResponse.fromJson(Map<String, dynamic> json) =>
      _$CubbyholeReadResponseFromJson(json);

  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String path;
  @JsonKey(name: 'folders', includeIfNull: false, defaultValue: <String>[])
  final List<String> folders;
  @JsonKey(name: 'data', includeIfNull: false)
  final KeyPair data;
  static const fromJsonFactory = _$CubbyholeReadResponseFromJson;
  static const toJsonFactory = _$CubbyholeReadResponseToJson;
  Map<String, dynamic> toJson() => _$CubbyholeReadResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CubbyholeReadResponse &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)) &&
            (identical(other.folders, folders) ||
                const DeepCollectionEquality()
                    .equals(other.folders, folders)) &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(path) ^
      const DeepCollectionEquality().hash(folders) ^
      const DeepCollectionEquality().hash(data) ^
      runtimeType.hashCode;
}

extension $CubbyholeReadResponseExtension on CubbyholeReadResponse {
  CubbyholeReadResponse copyWith(
      {String? path, List<String>? folders, KeyPair? data}) {
    return CubbyholeReadResponse(
        path: path ?? this.path,
        folders: folders ?? this.folders,
        data: data ?? this.data);
  }

  CubbyholeReadResponse copyWithWrapped(
      {Wrapped<String>? path,
      Wrapped<List<String>>? folders,
      Wrapped<KeyPair>? data}) {
    return CubbyholeReadResponse(
        path: (path != null ? path.value : this.path),
        folders: (folders != null ? folders.value : this.folders),
        data: (data != null ? data.value : this.data));
  }
}

@JsonSerializable(explicitToJson: true)
class CubbyholeWriteOptions {
  CubbyholeWriteOptions({
    this.data,
    this.path,
  });

  factory CubbyholeWriteOptions.fromJson(Map<String, dynamic> json) =>
      _$CubbyholeWriteOptionsFromJson(json);

  @JsonKey(name: 'data', includeIfNull: false)
  final Object? data;
  @JsonKey(name: 'path', includeIfNull: false, defaultValue: '')
  final String? path;
  static const fromJsonFactory = _$CubbyholeWriteOptionsFromJson;
  static const toJsonFactory = _$CubbyholeWriteOptionsToJson;
  Map<String, dynamic> toJson() => _$CubbyholeWriteOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CubbyholeWriteOptions &&
            (identical(other.data, data) ||
                const DeepCollectionEquality().equals(other.data, data)) &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(data) ^
      const DeepCollectionEquality().hash(path) ^
      runtimeType.hashCode;
}

extension $CubbyholeWriteOptionsExtension on CubbyholeWriteOptions {
  CubbyholeWriteOptions copyWith({Object? data, String? path}) {
    return CubbyholeWriteOptions(
        data: data ?? this.data, path: path ?? this.path);
  }

  CubbyholeWriteOptions copyWithWrapped(
      {Wrapped<Object?>? data, Wrapped<String?>? path}) {
    return CubbyholeWriteOptions(
        data: (data != null ? data.value : this.data),
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class CubbyholeWriteResponse {
  CubbyholeWriteResponse();

  factory CubbyholeWriteResponse.fromJson(Map<String, dynamic> json) =>
      _$CubbyholeWriteResponseFromJson(json);

  static const fromJsonFactory = _$CubbyholeWriteResponseFromJson;
  static const toJsonFactory = _$CubbyholeWriteResponseToJson;
  Map<String, dynamic> toJson() => _$CubbyholeWriteResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class EventLog {
  EventLog({
    this.id,
    required this.event,
    this.date,
    required this.tableName,
    required this.metadata,
  });

  factory EventLog.fromJson(Map<String, dynamic> json) =>
      _$EventLogFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'event', includeIfNull: false, defaultValue: '')
  final String event;
  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'tableName', includeIfNull: false, defaultValue: '')
  final String tableName;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  static const fromJsonFactory = _$EventLogFromJson;
  static const toJsonFactory = _$EventLogToJson;
  Map<String, dynamic> toJson() => _$EventLogToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventLog &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.event, event) ||
                const DeepCollectionEquality().equals(other.event, event)) &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.tableName, tableName) ||
                const DeepCollectionEquality()
                    .equals(other.tableName, tableName)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(event) ^
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(tableName) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $EventLogExtension on EventLog {
  EventLog copyWith(
      {String? id,
      String? event,
      DateTime? date,
      String? tableName,
      Object? metadata}) {
    return EventLog(
        id: id ?? this.id,
        event: event ?? this.event,
        date: date ?? this.date,
        tableName: tableName ?? this.tableName,
        metadata: metadata ?? this.metadata);
  }

  EventLog copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? event,
      Wrapped<DateTime?>? date,
      Wrapped<String>? tableName,
      Wrapped<Object>? metadata}) {
    return EventLog(
        id: (id != null ? id.value : this.id),
        event: (event != null ? event.value : this.event),
        date: (date != null ? date.value : this.date),
        tableName: (tableName != null ? tableName.value : this.tableName),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class QueryBuilder {
  QueryBuilder({
    required this.id,
    required this.name,
    required this.description,
    required this.color,
    required this.metadata,
  });

  factory QueryBuilder.fromJson(Map<String, dynamic> json) =>
      _$QueryBuilderFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String color;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  static const fromJsonFactory = _$QueryBuilderFromJson;
  static const toJsonFactory = _$QueryBuilderToJson;
  Map<String, dynamic> toJson() => _$QueryBuilderToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is QueryBuilder &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $QueryBuilderExtension on QueryBuilder {
  QueryBuilder copyWith(
      {String? id,
      String? name,
      String? description,
      String? color,
      Object? metadata}) {
    return QueryBuilder(
        id: id ?? this.id,
        name: name ?? this.name,
        description: description ?? this.description,
        color: color ?? this.color,
        metadata: metadata ?? this.metadata);
  }

  QueryBuilder copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String>? description,
      Wrapped<String>? color,
      Wrapped<Object>? metadata}) {
    return QueryBuilder(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        description:
            (description != null ? description.value : this.description),
        color: (color != null ? color.value : this.color),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class FilterFind {
  FilterFind({
    this.relations,
    this.select,
    this.where,
    this.order,
    this.loadEagerRelations,
    required this.filter,
    required this.sortBy,
    required this.ascending,
    this.skip,
    this.take,
  });

  factory FilterFind.fromJson(Map<String, dynamic> json) =>
      _$FilterFindFromJson(json);

  @JsonKey(name: 'relations', includeIfNull: false, defaultValue: <String>[])
  final List<String>? relations;
  @JsonKey(name: 'select', includeIfNull: false)
  final Object? select;
  @JsonKey(name: 'where', includeIfNull: false)
  final Object? where;
  @JsonKey(name: 'order', includeIfNull: false)
  final Object? order;
  @JsonKey(name: 'loadEagerRelations', includeIfNull: false)
  final bool? loadEagerRelations;
  @JsonKey(name: 'filter', includeIfNull: false)
  final QueryBuilder filter;
  @JsonKey(name: 'sortBy', includeIfNull: false, defaultValue: '')
  final String sortBy;
  @JsonKey(name: 'ascending', includeIfNull: false)
  final bool ascending;
  @JsonKey(name: 'skip', includeIfNull: false)
  final double? skip;
  @JsonKey(name: 'take', includeIfNull: false)
  final double? take;
  static const fromJsonFactory = _$FilterFindFromJson;
  static const toJsonFactory = _$FilterFindToJson;
  Map<String, dynamic> toJson() => _$FilterFindToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is FilterFind &&
            (identical(other.relations, relations) ||
                const DeepCollectionEquality()
                    .equals(other.relations, relations)) &&
            (identical(other.select, select) ||
                const DeepCollectionEquality().equals(other.select, select)) &&
            (identical(other.where, where) ||
                const DeepCollectionEquality().equals(other.where, where)) &&
            (identical(other.order, order) ||
                const DeepCollectionEquality().equals(other.order, order)) &&
            (identical(other.loadEagerRelations, loadEagerRelations) ||
                const DeepCollectionEquality()
                    .equals(other.loadEagerRelations, loadEagerRelations)) &&
            (identical(other.filter, filter) ||
                const DeepCollectionEquality().equals(other.filter, filter)) &&
            (identical(other.sortBy, sortBy) ||
                const DeepCollectionEquality().equals(other.sortBy, sortBy)) &&
            (identical(other.ascending, ascending) ||
                const DeepCollectionEquality()
                    .equals(other.ascending, ascending)) &&
            (identical(other.skip, skip) ||
                const DeepCollectionEquality().equals(other.skip, skip)) &&
            (identical(other.take, take) ||
                const DeepCollectionEquality().equals(other.take, take)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(relations) ^
      const DeepCollectionEquality().hash(select) ^
      const DeepCollectionEquality().hash(where) ^
      const DeepCollectionEquality().hash(order) ^
      const DeepCollectionEquality().hash(loadEagerRelations) ^
      const DeepCollectionEquality().hash(filter) ^
      const DeepCollectionEquality().hash(sortBy) ^
      const DeepCollectionEquality().hash(ascending) ^
      const DeepCollectionEquality().hash(skip) ^
      const DeepCollectionEquality().hash(take) ^
      runtimeType.hashCode;
}

extension $FilterFindExtension on FilterFind {
  FilterFind copyWith(
      {List<String>? relations,
      Object? select,
      Object? where,
      Object? order,
      bool? loadEagerRelations,
      QueryBuilder? filter,
      String? sortBy,
      bool? ascending,
      double? skip,
      double? take}) {
    return FilterFind(
        relations: relations ?? this.relations,
        select: select ?? this.select,
        where: where ?? this.where,
        order: order ?? this.order,
        loadEagerRelations: loadEagerRelations ?? this.loadEagerRelations,
        filter: filter ?? this.filter,
        sortBy: sortBy ?? this.sortBy,
        ascending: ascending ?? this.ascending,
        skip: skip ?? this.skip,
        take: take ?? this.take);
  }

  FilterFind copyWithWrapped(
      {Wrapped<List<String>?>? relations,
      Wrapped<Object?>? select,
      Wrapped<Object?>? where,
      Wrapped<Object?>? order,
      Wrapped<bool?>? loadEagerRelations,
      Wrapped<QueryBuilder>? filter,
      Wrapped<String>? sortBy,
      Wrapped<bool>? ascending,
      Wrapped<double?>? skip,
      Wrapped<double?>? take}) {
    return FilterFind(
        relations: (relations != null ? relations.value : this.relations),
        select: (select != null ? select.value : this.select),
        where: (where != null ? where.value : this.where),
        order: (order != null ? order.value : this.order),
        loadEagerRelations: (loadEagerRelations != null
            ? loadEagerRelations.value
            : this.loadEagerRelations),
        filter: (filter != null ? filter.value : this.filter),
        sortBy: (sortBy != null ? sortBy.value : this.sortBy),
        ascending: (ascending != null ? ascending.value : this.ascending),
        skip: (skip != null ? skip.value : this.skip),
        take: (take != null ? take.value : this.take));
  }
}

@JsonSerializable(explicitToJson: true)
class EventLogCreateOptions {
  EventLogCreateOptions({
    this.id,
    required this.event,
    this.date,
    required this.tableName,
    required this.metadata,
  });

  factory EventLogCreateOptions.fromJson(Map<String, dynamic> json) =>
      _$EventLogCreateOptionsFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  @JsonKey(name: 'event', includeIfNull: false, defaultValue: '')
  final String event;
  @JsonKey(name: 'date', includeIfNull: false)
  final DateTime? date;
  @JsonKey(name: 'tableName', includeIfNull: false, defaultValue: '')
  final String tableName;
  @JsonKey(name: 'metadata', includeIfNull: false)
  final Object metadata;
  static const fromJsonFactory = _$EventLogCreateOptionsFromJson;
  static const toJsonFactory = _$EventLogCreateOptionsToJson;
  Map<String, dynamic> toJson() => _$EventLogCreateOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is EventLogCreateOptions &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.event, event) ||
                const DeepCollectionEquality().equals(other.event, event)) &&
            (identical(other.date, date) ||
                const DeepCollectionEquality().equals(other.date, date)) &&
            (identical(other.tableName, tableName) ||
                const DeepCollectionEquality()
                    .equals(other.tableName, tableName)) &&
            (identical(other.metadata, metadata) ||
                const DeepCollectionEquality()
                    .equals(other.metadata, metadata)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(event) ^
      const DeepCollectionEquality().hash(date) ^
      const DeepCollectionEquality().hash(tableName) ^
      const DeepCollectionEquality().hash(metadata) ^
      runtimeType.hashCode;
}

extension $EventLogCreateOptionsExtension on EventLogCreateOptions {
  EventLogCreateOptions copyWith(
      {String? id,
      String? event,
      DateTime? date,
      String? tableName,
      Object? metadata}) {
    return EventLogCreateOptions(
        id: id ?? this.id,
        event: event ?? this.event,
        date: date ?? this.date,
        tableName: tableName ?? this.tableName,
        metadata: metadata ?? this.metadata);
  }

  EventLogCreateOptions copyWithWrapped(
      {Wrapped<String?>? id,
      Wrapped<String>? event,
      Wrapped<DateTime?>? date,
      Wrapped<String>? tableName,
      Wrapped<Object>? metadata}) {
    return EventLogCreateOptions(
        id: (id != null ? id.value : this.id),
        event: (event != null ? event.value : this.event),
        date: (date != null ? date.value : this.date),
        tableName: (tableName != null ? tableName.value : this.tableName),
        metadata: (metadata != null ? metadata.value : this.metadata));
  }
}

@JsonSerializable(explicitToJson: true)
class AwsCredentialsRolesConfig {
  AwsCredentialsRolesConfig({
    this.arn,
    this.credentialType,
    this.defaultStsTtl,
    this.maxStsTtl,
    this.permissionsBoundaryArn,
    this.policy,
    this.policyArns,
    this.policyDocument,
    this.roleArns,
    this.userPath,
    this.name,
    this.id,
  });

  factory AwsCredentialsRolesConfig.fromJson(Map<String, dynamic> json) =>
      _$AwsCredentialsRolesConfigFromJson(json);

  @JsonKey(name: 'arn', includeIfNull: false, defaultValue: '')
  final String? arn;
  @JsonKey(name: 'credential_type', includeIfNull: false, defaultValue: '')
  final String? credentialType;
  @JsonKey(name: 'default_sts_ttl', includeIfNull: false)
  final double? defaultStsTtl;
  @JsonKey(name: 'max_sts_ttl', includeIfNull: false)
  final double? maxStsTtl;
  @JsonKey(
      name: 'permissions_boundary_arn', includeIfNull: false, defaultValue: '')
  final String? permissionsBoundaryArn;
  @JsonKey(name: 'policy', includeIfNull: false, defaultValue: '')
  final String? policy;
  @JsonKey(name: 'policy_arns', includeIfNull: false, defaultValue: <String>[])
  final List<String>? policyArns;
  @JsonKey(name: 'policy_document', includeIfNull: false, defaultValue: '')
  final String? policyDocument;
  @JsonKey(name: 'role_arns', includeIfNull: false, defaultValue: <String>[])
  final List<String>? roleArns;
  @JsonKey(name: 'user_path', includeIfNull: false, defaultValue: '')
  final String? userPath;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String? name;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$AwsCredentialsRolesConfigFromJson;
  static const toJsonFactory = _$AwsCredentialsRolesConfigToJson;
  Map<String, dynamic> toJson() => _$AwsCredentialsRolesConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AwsCredentialsRolesConfig &&
            (identical(other.arn, arn) ||
                const DeepCollectionEquality().equals(other.arn, arn)) &&
            (identical(other.credentialType, credentialType) ||
                const DeepCollectionEquality()
                    .equals(other.credentialType, credentialType)) &&
            (identical(other.defaultStsTtl, defaultStsTtl) ||
                const DeepCollectionEquality()
                    .equals(other.defaultStsTtl, defaultStsTtl)) &&
            (identical(other.maxStsTtl, maxStsTtl) ||
                const DeepCollectionEquality()
                    .equals(other.maxStsTtl, maxStsTtl)) &&
            (identical(other.permissionsBoundaryArn, permissionsBoundaryArn) ||
                const DeepCollectionEquality().equals(
                    other.permissionsBoundaryArn, permissionsBoundaryArn)) &&
            (identical(other.policy, policy) ||
                const DeepCollectionEquality().equals(other.policy, policy)) &&
            (identical(other.policyArns, policyArns) ||
                const DeepCollectionEquality()
                    .equals(other.policyArns, policyArns)) &&
            (identical(other.policyDocument, policyDocument) ||
                const DeepCollectionEquality()
                    .equals(other.policyDocument, policyDocument)) &&
            (identical(other.roleArns, roleArns) ||
                const DeepCollectionEquality()
                    .equals(other.roleArns, roleArns)) &&
            (identical(other.userPath, userPath) ||
                const DeepCollectionEquality()
                    .equals(other.userPath, userPath)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(arn) ^
      const DeepCollectionEquality().hash(credentialType) ^
      const DeepCollectionEquality().hash(defaultStsTtl) ^
      const DeepCollectionEquality().hash(maxStsTtl) ^
      const DeepCollectionEquality().hash(permissionsBoundaryArn) ^
      const DeepCollectionEquality().hash(policy) ^
      const DeepCollectionEquality().hash(policyArns) ^
      const DeepCollectionEquality().hash(policyDocument) ^
      const DeepCollectionEquality().hash(roleArns) ^
      const DeepCollectionEquality().hash(userPath) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $AwsCredentialsRolesConfigExtension on AwsCredentialsRolesConfig {
  AwsCredentialsRolesConfig copyWith(
      {String? arn,
      String? credentialType,
      double? defaultStsTtl,
      double? maxStsTtl,
      String? permissionsBoundaryArn,
      String? policy,
      List<String>? policyArns,
      String? policyDocument,
      List<String>? roleArns,
      String? userPath,
      String? name,
      String? id}) {
    return AwsCredentialsRolesConfig(
        arn: arn ?? this.arn,
        credentialType: credentialType ?? this.credentialType,
        defaultStsTtl: defaultStsTtl ?? this.defaultStsTtl,
        maxStsTtl: maxStsTtl ?? this.maxStsTtl,
        permissionsBoundaryArn:
            permissionsBoundaryArn ?? this.permissionsBoundaryArn,
        policy: policy ?? this.policy,
        policyArns: policyArns ?? this.policyArns,
        policyDocument: policyDocument ?? this.policyDocument,
        roleArns: roleArns ?? this.roleArns,
        userPath: userPath ?? this.userPath,
        name: name ?? this.name,
        id: id ?? this.id);
  }

  AwsCredentialsRolesConfig copyWithWrapped(
      {Wrapped<String?>? arn,
      Wrapped<String?>? credentialType,
      Wrapped<double?>? defaultStsTtl,
      Wrapped<double?>? maxStsTtl,
      Wrapped<String?>? permissionsBoundaryArn,
      Wrapped<String?>? policy,
      Wrapped<List<String>?>? policyArns,
      Wrapped<String?>? policyDocument,
      Wrapped<List<String>?>? roleArns,
      Wrapped<String?>? userPath,
      Wrapped<String?>? name,
      Wrapped<String?>? id}) {
    return AwsCredentialsRolesConfig(
        arn: (arn != null ? arn.value : this.arn),
        credentialType: (credentialType != null
            ? credentialType.value
            : this.credentialType),
        defaultStsTtl:
            (defaultStsTtl != null ? defaultStsTtl.value : this.defaultStsTtl),
        maxStsTtl: (maxStsTtl != null ? maxStsTtl.value : this.maxStsTtl),
        permissionsBoundaryArn: (permissionsBoundaryArn != null
            ? permissionsBoundaryArn.value
            : this.permissionsBoundaryArn),
        policy: (policy != null ? policy.value : this.policy),
        policyArns: (policyArns != null ? policyArns.value : this.policyArns),
        policyDocument: (policyDocument != null
            ? policyDocument.value
            : this.policyDocument),
        roleArns: (roleArns != null ? roleArns.value : this.roleArns),
        userPath: (userPath != null ? userPath.value : this.userPath),
        name: (name != null ? name.value : this.name),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class CredentialsRole {
  CredentialsRole({
    required this.id,
    required this.name,
    this.color,
    required this.description,
    this.config,
    this.credentials,
    this.credentialsId,
  });

  factory CredentialsRole.fromJson(Map<String, dynamic> json) =>
      _$CredentialsRoleFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'credentials', includeIfNull: false)
  final Credentials? credentials;
  @JsonKey(name: 'credentialsId', includeIfNull: false, defaultValue: '')
  final String? credentialsId;
  static const fromJsonFactory = _$CredentialsRoleFromJson;
  static const toJsonFactory = _$CredentialsRoleToJson;
  Map<String, dynamic> toJson() => _$CredentialsRoleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is CredentialsRole &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.credentials, credentials) ||
                const DeepCollectionEquality()
                    .equals(other.credentials, credentials)) &&
            (identical(other.credentialsId, credentialsId) ||
                const DeepCollectionEquality()
                    .equals(other.credentialsId, credentialsId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(credentials) ^
      const DeepCollectionEquality().hash(credentialsId) ^
      runtimeType.hashCode;
}

extension $CredentialsRoleExtension on CredentialsRole {
  CredentialsRole copyWith(
      {String? id,
      String? name,
      String? color,
      String? description,
      Object? config,
      Credentials? credentials,
      String? credentialsId}) {
    return CredentialsRole(
        id: id ?? this.id,
        name: name ?? this.name,
        color: color ?? this.color,
        description: description ?? this.description,
        config: config ?? this.config,
        credentials: credentials ?? this.credentials,
        credentialsId: credentialsId ?? this.credentialsId);
  }

  CredentialsRole copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String?>? color,
      Wrapped<String>? description,
      Wrapped<Object?>? config,
      Wrapped<Credentials?>? credentials,
      Wrapped<String?>? credentialsId}) {
    return CredentialsRole(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        config: (config != null ? config.value : this.config),
        credentials:
            (credentials != null ? credentials.value : this.credentials),
        credentialsId:
            (credentialsId != null ? credentialsId.value : this.credentialsId));
  }
}

@JsonSerializable(explicitToJson: true)
class Credentials {
  Credentials({
    required this.id,
    required this.name,
    required this.config,
    this.color,
    this.type,
    this.accessor,
    this.defaultLeaseTTL,
    this.maxLeaseTTL,
    required this.description,
    this.roles,
  });

  factory Credentials.fromJson(Map<String, dynamic> json) =>
      _$CredentialsFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object config;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String? accessor;
  @JsonKey(name: 'defaultLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? defaultLeaseTTL;
  @JsonKey(name: 'maxLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? maxLeaseTTL;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(
      name: 'roles', includeIfNull: false, defaultValue: <CredentialsRole>[])
  final List<CredentialsRole>? roles;
  static const fromJsonFactory = _$CredentialsFromJson;
  static const toJsonFactory = _$CredentialsToJson;
  Map<String, dynamic> toJson() => _$CredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is Credentials &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.defaultLeaseTTL, defaultLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.defaultLeaseTTL, defaultLeaseTTL)) &&
            (identical(other.maxLeaseTTL, maxLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.maxLeaseTTL, maxLeaseTTL)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.roles, roles) ||
                const DeepCollectionEquality().equals(other.roles, roles)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(defaultLeaseTTL) ^
      const DeepCollectionEquality().hash(maxLeaseTTL) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(roles) ^
      runtimeType.hashCode;
}

extension $CredentialsExtension on Credentials {
  Credentials copyWith(
      {String? id,
      String? name,
      Object? config,
      String? color,
      String? type,
      String? accessor,
      String? defaultLeaseTTL,
      String? maxLeaseTTL,
      String? description,
      List<CredentialsRole>? roles}) {
    return Credentials(
        id: id ?? this.id,
        name: name ?? this.name,
        config: config ?? this.config,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        defaultLeaseTTL: defaultLeaseTTL ?? this.defaultLeaseTTL,
        maxLeaseTTL: maxLeaseTTL ?? this.maxLeaseTTL,
        description: description ?? this.description,
        roles: roles ?? this.roles);
  }

  Credentials copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<Object>? config,
      Wrapped<String?>? color,
      Wrapped<String?>? type,
      Wrapped<String?>? accessor,
      Wrapped<String?>? defaultLeaseTTL,
      Wrapped<String?>? maxLeaseTTL,
      Wrapped<String>? description,
      Wrapped<List<CredentialsRole>?>? roles}) {
    return Credentials(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        config: (config != null ? config.value : this.config),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        defaultLeaseTTL: (defaultLeaseTTL != null
            ? defaultLeaseTTL.value
            : this.defaultLeaseTTL),
        maxLeaseTTL:
            (maxLeaseTTL != null ? maxLeaseTTL.value : this.maxLeaseTTL),
        description:
            (description != null ? description.value : this.description),
        roles: (roles != null ? roles.value : this.roles));
  }
}

@JsonSerializable(explicitToJson: true)
class AwsCredentialsRole {
  AwsCredentialsRole({
    required this.config,
    required this.id,
    required this.name,
    this.color,
    required this.description,
    this.credentials,
    this.credentialsId,
  });

  factory AwsCredentialsRole.fromJson(Map<String, dynamic> json) =>
      _$AwsCredentialsRoleFromJson(json);

  @JsonKey(name: 'config', includeIfNull: false)
  final AwsCredentialsRolesConfig config;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'credentials', includeIfNull: false)
  final Credentials? credentials;
  @JsonKey(name: 'credentialsId', includeIfNull: false, defaultValue: '')
  final String? credentialsId;
  static const fromJsonFactory = _$AwsCredentialsRoleFromJson;
  static const toJsonFactory = _$AwsCredentialsRoleToJson;
  Map<String, dynamic> toJson() => _$AwsCredentialsRoleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AwsCredentialsRole &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.credentials, credentials) ||
                const DeepCollectionEquality()
                    .equals(other.credentials, credentials)) &&
            (identical(other.credentialsId, credentialsId) ||
                const DeepCollectionEquality()
                    .equals(other.credentialsId, credentialsId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(credentials) ^
      const DeepCollectionEquality().hash(credentialsId) ^
      runtimeType.hashCode;
}

extension $AwsCredentialsRoleExtension on AwsCredentialsRole {
  AwsCredentialsRole copyWith(
      {AwsCredentialsRolesConfig? config,
      String? id,
      String? name,
      String? color,
      String? description,
      Credentials? credentials,
      String? credentialsId}) {
    return AwsCredentialsRole(
        config: config ?? this.config,
        id: id ?? this.id,
        name: name ?? this.name,
        color: color ?? this.color,
        description: description ?? this.description,
        credentials: credentials ?? this.credentials,
        credentialsId: credentialsId ?? this.credentialsId);
  }

  AwsCredentialsRole copyWithWrapped(
      {Wrapped<AwsCredentialsRolesConfig>? config,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String?>? color,
      Wrapped<String>? description,
      Wrapped<Credentials?>? credentials,
      Wrapped<String?>? credentialsId}) {
    return AwsCredentialsRole(
        config: (config != null ? config.value : this.config),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        credentials:
            (credentials != null ? credentials.value : this.credentials),
        credentialsId:
            (credentialsId != null ? credentialsId.value : this.credentialsId));
  }
}

@JsonSerializable(explicitToJson: true)
class AwsCredentialsConfig {
  AwsCredentialsConfig({
    this.accessKey,
    this.iamEndpoint,
    this.maxRetries,
    this.region,
    this.secretKey,
    this.stsEndpoint,
    this.id,
  });

  factory AwsCredentialsConfig.fromJson(Map<String, dynamic> json) =>
      _$AwsCredentialsConfigFromJson(json);

  @JsonKey(name: 'access_key', includeIfNull: false, defaultValue: '')
  final String? accessKey;
  @JsonKey(name: 'iam_endpoint', includeIfNull: false, defaultValue: '')
  final String? iamEndpoint;
  @JsonKey(name: 'max_retries', includeIfNull: false)
  final double? maxRetries;
  @JsonKey(name: 'region', includeIfNull: false, defaultValue: '')
  final String? region;
  @JsonKey(name: 'secret_key', includeIfNull: false, defaultValue: '')
  final String? secretKey;
  @JsonKey(name: 'sts_endpoint', includeIfNull: false, defaultValue: '')
  final String? stsEndpoint;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String? id;
  static const fromJsonFactory = _$AwsCredentialsConfigFromJson;
  static const toJsonFactory = _$AwsCredentialsConfigToJson;
  Map<String, dynamic> toJson() => _$AwsCredentialsConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AwsCredentialsConfig &&
            (identical(other.accessKey, accessKey) ||
                const DeepCollectionEquality()
                    .equals(other.accessKey, accessKey)) &&
            (identical(other.iamEndpoint, iamEndpoint) ||
                const DeepCollectionEquality()
                    .equals(other.iamEndpoint, iamEndpoint)) &&
            (identical(other.maxRetries, maxRetries) ||
                const DeepCollectionEquality()
                    .equals(other.maxRetries, maxRetries)) &&
            (identical(other.region, region) ||
                const DeepCollectionEquality().equals(other.region, region)) &&
            (identical(other.secretKey, secretKey) ||
                const DeepCollectionEquality()
                    .equals(other.secretKey, secretKey)) &&
            (identical(other.stsEndpoint, stsEndpoint) ||
                const DeepCollectionEquality()
                    .equals(other.stsEndpoint, stsEndpoint)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accessKey) ^
      const DeepCollectionEquality().hash(iamEndpoint) ^
      const DeepCollectionEquality().hash(maxRetries) ^
      const DeepCollectionEquality().hash(region) ^
      const DeepCollectionEquality().hash(secretKey) ^
      const DeepCollectionEquality().hash(stsEndpoint) ^
      const DeepCollectionEquality().hash(id) ^
      runtimeType.hashCode;
}

extension $AwsCredentialsConfigExtension on AwsCredentialsConfig {
  AwsCredentialsConfig copyWith(
      {String? accessKey,
      String? iamEndpoint,
      double? maxRetries,
      String? region,
      String? secretKey,
      String? stsEndpoint,
      String? id}) {
    return AwsCredentialsConfig(
        accessKey: accessKey ?? this.accessKey,
        iamEndpoint: iamEndpoint ?? this.iamEndpoint,
        maxRetries: maxRetries ?? this.maxRetries,
        region: region ?? this.region,
        secretKey: secretKey ?? this.secretKey,
        stsEndpoint: stsEndpoint ?? this.stsEndpoint,
        id: id ?? this.id);
  }

  AwsCredentialsConfig copyWithWrapped(
      {Wrapped<String?>? accessKey,
      Wrapped<String?>? iamEndpoint,
      Wrapped<double?>? maxRetries,
      Wrapped<String?>? region,
      Wrapped<String?>? secretKey,
      Wrapped<String?>? stsEndpoint,
      Wrapped<String?>? id}) {
    return AwsCredentialsConfig(
        accessKey: (accessKey != null ? accessKey.value : this.accessKey),
        iamEndpoint:
            (iamEndpoint != null ? iamEndpoint.value : this.iamEndpoint),
        maxRetries: (maxRetries != null ? maxRetries.value : this.maxRetries),
        region: (region != null ? region.value : this.region),
        secretKey: (secretKey != null ? secretKey.value : this.secretKey),
        stsEndpoint:
            (stsEndpoint != null ? stsEndpoint.value : this.stsEndpoint),
        id: (id != null ? id.value : this.id));
  }
}

@JsonSerializable(explicitToJson: true)
class AwsCredentials {
  AwsCredentials({
    this.roles,
    required this.config,
    required this.id,
    required this.name,
    this.color,
    this.type,
    this.accessor,
    this.defaultLeaseTTL,
    this.maxLeaseTTL,
    required this.description,
  });

  factory AwsCredentials.fromJson(Map<String, dynamic> json) =>
      _$AwsCredentialsFromJson(json);

  @JsonKey(
      name: 'roles', includeIfNull: false, defaultValue: <AwsCredentialsRole>[])
  final List<AwsCredentialsRole>? roles;
  @JsonKey(name: 'config', includeIfNull: false)
  final AwsCredentialsConfig config;
  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String? accessor;
  @JsonKey(name: 'defaultLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? defaultLeaseTTL;
  @JsonKey(name: 'maxLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? maxLeaseTTL;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  static const fromJsonFactory = _$AwsCredentialsFromJson;
  static const toJsonFactory = _$AwsCredentialsToJson;
  Map<String, dynamic> toJson() => _$AwsCredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AwsCredentials &&
            (identical(other.roles, roles) ||
                const DeepCollectionEquality().equals(other.roles, roles)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.defaultLeaseTTL, defaultLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.defaultLeaseTTL, defaultLeaseTTL)) &&
            (identical(other.maxLeaseTTL, maxLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.maxLeaseTTL, maxLeaseTTL)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(roles) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(defaultLeaseTTL) ^
      const DeepCollectionEquality().hash(maxLeaseTTL) ^
      const DeepCollectionEquality().hash(description) ^
      runtimeType.hashCode;
}

extension $AwsCredentialsExtension on AwsCredentials {
  AwsCredentials copyWith(
      {List<AwsCredentialsRole>? roles,
      AwsCredentialsConfig? config,
      String? id,
      String? name,
      String? color,
      String? type,
      String? accessor,
      String? defaultLeaseTTL,
      String? maxLeaseTTL,
      String? description}) {
    return AwsCredentials(
        roles: roles ?? this.roles,
        config: config ?? this.config,
        id: id ?? this.id,
        name: name ?? this.name,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        defaultLeaseTTL: defaultLeaseTTL ?? this.defaultLeaseTTL,
        maxLeaseTTL: maxLeaseTTL ?? this.maxLeaseTTL,
        description: description ?? this.description);
  }

  AwsCredentials copyWithWrapped(
      {Wrapped<List<AwsCredentialsRole>?>? roles,
      Wrapped<AwsCredentialsConfig>? config,
      Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String?>? color,
      Wrapped<String?>? type,
      Wrapped<String?>? accessor,
      Wrapped<String?>? defaultLeaseTTL,
      Wrapped<String?>? maxLeaseTTL,
      Wrapped<String>? description}) {
    return AwsCredentials(
        roles: (roles != null ? roles.value : this.roles),
        config: (config != null ? config.value : this.config),
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        defaultLeaseTTL: (defaultLeaseTTL != null
            ? defaultLeaseTTL.value
            : this.defaultLeaseTTL),
        maxLeaseTTL:
            (maxLeaseTTL != null ? maxLeaseTTL.value : this.maxLeaseTTL),
        description:
            (description != null ? description.value : this.description));
  }
}

@JsonSerializable(explicitToJson: true)
class AwsCreds {
  AwsCreds({
    this.accessKey,
    required this.secretKey,
    required this.securityToken,
  });

  factory AwsCreds.fromJson(Map<String, dynamic> json) =>
      _$AwsCredsFromJson(json);

  @JsonKey(name: 'access_key', includeIfNull: false, defaultValue: '')
  final String? accessKey;
  @JsonKey(name: 'secret_key', includeIfNull: false, defaultValue: '')
  final String secretKey;
  @JsonKey(name: 'security_token', includeIfNull: false, defaultValue: '')
  final String securityToken;
  static const fromJsonFactory = _$AwsCredsFromJson;
  static const toJsonFactory = _$AwsCredsToJson;
  Map<String, dynamic> toJson() => _$AwsCredsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AwsCreds &&
            (identical(other.accessKey, accessKey) ||
                const DeepCollectionEquality()
                    .equals(other.accessKey, accessKey)) &&
            (identical(other.secretKey, secretKey) ||
                const DeepCollectionEquality()
                    .equals(other.secretKey, secretKey)) &&
            (identical(other.securityToken, securityToken) ||
                const DeepCollectionEquality()
                    .equals(other.securityToken, securityToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(accessKey) ^
      const DeepCollectionEquality().hash(secretKey) ^
      const DeepCollectionEquality().hash(securityToken) ^
      runtimeType.hashCode;
}

extension $AwsCredsExtension on AwsCreds {
  AwsCreds copyWith(
      {String? accessKey, String? secretKey, String? securityToken}) {
    return AwsCreds(
        accessKey: accessKey ?? this.accessKey,
        secretKey: secretKey ?? this.secretKey,
        securityToken: securityToken ?? this.securityToken);
  }

  AwsCreds copyWithWrapped(
      {Wrapped<String?>? accessKey,
      Wrapped<String>? secretKey,
      Wrapped<String>? securityToken}) {
    return AwsCreds(
        accessKey: (accessKey != null ? accessKey.value : this.accessKey),
        secretKey: (secretKey != null ? secretKey.value : this.secretKey),
        securityToken:
            (securityToken != null ? securityToken.value : this.securityToken));
  }
}

@JsonSerializable(explicitToJson: true)
class AzureCredentials {
  AzureCredentials({
    required this.id,
    required this.name,
    required this.config,
    this.color,
    this.type,
    this.accessor,
    this.defaultLeaseTTL,
    this.maxLeaseTTL,
    required this.description,
    this.roles,
  });

  factory AzureCredentials.fromJson(Map<String, dynamic> json) =>
      _$AzureCredentialsFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object config;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String? accessor;
  @JsonKey(name: 'defaultLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? defaultLeaseTTL;
  @JsonKey(name: 'maxLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? maxLeaseTTL;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(
      name: 'roles', includeIfNull: false, defaultValue: <CredentialsRole>[])
  final List<CredentialsRole>? roles;
  static const fromJsonFactory = _$AzureCredentialsFromJson;
  static const toJsonFactory = _$AzureCredentialsToJson;
  Map<String, dynamic> toJson() => _$AzureCredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AzureCredentials &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.defaultLeaseTTL, defaultLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.defaultLeaseTTL, defaultLeaseTTL)) &&
            (identical(other.maxLeaseTTL, maxLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.maxLeaseTTL, maxLeaseTTL)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.roles, roles) ||
                const DeepCollectionEquality().equals(other.roles, roles)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(defaultLeaseTTL) ^
      const DeepCollectionEquality().hash(maxLeaseTTL) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(roles) ^
      runtimeType.hashCode;
}

extension $AzureCredentialsExtension on AzureCredentials {
  AzureCredentials copyWith(
      {String? id,
      String? name,
      Object? config,
      String? color,
      String? type,
      String? accessor,
      String? defaultLeaseTTL,
      String? maxLeaseTTL,
      String? description,
      List<CredentialsRole>? roles}) {
    return AzureCredentials(
        id: id ?? this.id,
        name: name ?? this.name,
        config: config ?? this.config,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        defaultLeaseTTL: defaultLeaseTTL ?? this.defaultLeaseTTL,
        maxLeaseTTL: maxLeaseTTL ?? this.maxLeaseTTL,
        description: description ?? this.description,
        roles: roles ?? this.roles);
  }

  AzureCredentials copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<Object>? config,
      Wrapped<String?>? color,
      Wrapped<String?>? type,
      Wrapped<String?>? accessor,
      Wrapped<String?>? defaultLeaseTTL,
      Wrapped<String?>? maxLeaseTTL,
      Wrapped<String>? description,
      Wrapped<List<CredentialsRole>?>? roles}) {
    return AzureCredentials(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        config: (config != null ? config.value : this.config),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        defaultLeaseTTL: (defaultLeaseTTL != null
            ? defaultLeaseTTL.value
            : this.defaultLeaseTTL),
        maxLeaseTTL:
            (maxLeaseTTL != null ? maxLeaseTTL.value : this.maxLeaseTTL),
        description:
            (description != null ? description.value : this.description),
        roles: (roles != null ? roles.value : this.roles));
  }
}

@JsonSerializable(explicitToJson: true)
class GetAzureCredsRoleResponse {
  GetAzureCredsRoleResponse({
    required this.clientId,
    required this.clientSecret,
  });

  factory GetAzureCredsRoleResponse.fromJson(Map<String, dynamic> json) =>
      _$GetAzureCredsRoleResponseFromJson(json);

  @JsonKey(name: 'client_id', includeIfNull: false, defaultValue: '')
  final String clientId;
  @JsonKey(name: 'client_secret', includeIfNull: false, defaultValue: '')
  final String clientSecret;
  static const fromJsonFactory = _$GetAzureCredsRoleResponseFromJson;
  static const toJsonFactory = _$GetAzureCredsRoleResponseToJson;
  Map<String, dynamic> toJson() => _$GetAzureCredsRoleResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetAzureCredsRoleResponse &&
            (identical(other.clientId, clientId) ||
                const DeepCollectionEquality()
                    .equals(other.clientId, clientId)) &&
            (identical(other.clientSecret, clientSecret) ||
                const DeepCollectionEquality()
                    .equals(other.clientSecret, clientSecret)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(clientId) ^
      const DeepCollectionEquality().hash(clientSecret) ^
      runtimeType.hashCode;
}

extension $GetAzureCredsRoleResponseExtension on GetAzureCredsRoleResponse {
  GetAzureCredsRoleResponse copyWith({String? clientId, String? clientSecret}) {
    return GetAzureCredsRoleResponse(
        clientId: clientId ?? this.clientId,
        clientSecret: clientSecret ?? this.clientSecret);
  }

  GetAzureCredsRoleResponse copyWithWrapped(
      {Wrapped<String>? clientId, Wrapped<String>? clientSecret}) {
    return GetAzureCredsRoleResponse(
        clientId: (clientId != null ? clientId.value : this.clientId),
        clientSecret:
            (clientSecret != null ? clientSecret.value : this.clientSecret));
  }
}

@JsonSerializable(explicitToJson: true)
class AzureCredentialsRole {
  AzureCredentialsRole({
    required this.id,
    required this.name,
    this.color,
    required this.description,
    this.config,
    this.credentials,
    this.credentialsId,
  });

  factory AzureCredentialsRole.fromJson(Map<String, dynamic> json) =>
      _$AzureCredentialsRoleFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'credentials', includeIfNull: false)
  final Credentials? credentials;
  @JsonKey(name: 'credentialsId', includeIfNull: false, defaultValue: '')
  final String? credentialsId;
  static const fromJsonFactory = _$AzureCredentialsRoleFromJson;
  static const toJsonFactory = _$AzureCredentialsRoleToJson;
  Map<String, dynamic> toJson() => _$AzureCredentialsRoleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is AzureCredentialsRole &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.credentials, credentials) ||
                const DeepCollectionEquality()
                    .equals(other.credentials, credentials)) &&
            (identical(other.credentialsId, credentialsId) ||
                const DeepCollectionEquality()
                    .equals(other.credentialsId, credentialsId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(credentials) ^
      const DeepCollectionEquality().hash(credentialsId) ^
      runtimeType.hashCode;
}

extension $AzureCredentialsRoleExtension on AzureCredentialsRole {
  AzureCredentialsRole copyWith(
      {String? id,
      String? name,
      String? color,
      String? description,
      Object? config,
      Credentials? credentials,
      String? credentialsId}) {
    return AzureCredentialsRole(
        id: id ?? this.id,
        name: name ?? this.name,
        color: color ?? this.color,
        description: description ?? this.description,
        config: config ?? this.config,
        credentials: credentials ?? this.credentials,
        credentialsId: credentialsId ?? this.credentialsId);
  }

  AzureCredentialsRole copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String?>? color,
      Wrapped<String>? description,
      Wrapped<Object?>? config,
      Wrapped<Credentials?>? credentials,
      Wrapped<String?>? credentialsId}) {
    return AzureCredentialsRole(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        config: (config != null ? config.value : this.config),
        credentials:
            (credentials != null ? credentials.value : this.credentials),
        credentialsId:
            (credentialsId != null ? credentialsId.value : this.credentialsId));
  }
}

@JsonSerializable(explicitToJson: true)
class RabbitMqCredentials {
  RabbitMqCredentials({
    required this.id,
    required this.name,
    required this.config,
    this.color,
    this.type,
    this.accessor,
    this.defaultLeaseTTL,
    this.maxLeaseTTL,
    required this.description,
    this.roles,
  });

  factory RabbitMqCredentials.fromJson(Map<String, dynamic> json) =>
      _$RabbitMqCredentialsFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object config;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'accessor', includeIfNull: false, defaultValue: '')
  final String? accessor;
  @JsonKey(name: 'defaultLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? defaultLeaseTTL;
  @JsonKey(name: 'maxLeaseTTL', includeIfNull: false, defaultValue: '')
  final String? maxLeaseTTL;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(
      name: 'roles', includeIfNull: false, defaultValue: <CredentialsRole>[])
  final List<CredentialsRole>? roles;
  static const fromJsonFactory = _$RabbitMqCredentialsFromJson;
  static const toJsonFactory = _$RabbitMqCredentialsToJson;
  Map<String, dynamic> toJson() => _$RabbitMqCredentialsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RabbitMqCredentials &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.accessor, accessor) ||
                const DeepCollectionEquality()
                    .equals(other.accessor, accessor)) &&
            (identical(other.defaultLeaseTTL, defaultLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.defaultLeaseTTL, defaultLeaseTTL)) &&
            (identical(other.maxLeaseTTL, maxLeaseTTL) ||
                const DeepCollectionEquality()
                    .equals(other.maxLeaseTTL, maxLeaseTTL)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.roles, roles) ||
                const DeepCollectionEquality().equals(other.roles, roles)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(accessor) ^
      const DeepCollectionEquality().hash(defaultLeaseTTL) ^
      const DeepCollectionEquality().hash(maxLeaseTTL) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(roles) ^
      runtimeType.hashCode;
}

extension $RabbitMqCredentialsExtension on RabbitMqCredentials {
  RabbitMqCredentials copyWith(
      {String? id,
      String? name,
      Object? config,
      String? color,
      String? type,
      String? accessor,
      String? defaultLeaseTTL,
      String? maxLeaseTTL,
      String? description,
      List<CredentialsRole>? roles}) {
    return RabbitMqCredentials(
        id: id ?? this.id,
        name: name ?? this.name,
        config: config ?? this.config,
        color: color ?? this.color,
        type: type ?? this.type,
        accessor: accessor ?? this.accessor,
        defaultLeaseTTL: defaultLeaseTTL ?? this.defaultLeaseTTL,
        maxLeaseTTL: maxLeaseTTL ?? this.maxLeaseTTL,
        description: description ?? this.description,
        roles: roles ?? this.roles);
  }

  RabbitMqCredentials copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<Object>? config,
      Wrapped<String?>? color,
      Wrapped<String?>? type,
      Wrapped<String?>? accessor,
      Wrapped<String?>? defaultLeaseTTL,
      Wrapped<String?>? maxLeaseTTL,
      Wrapped<String>? description,
      Wrapped<List<CredentialsRole>?>? roles}) {
    return RabbitMqCredentials(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        config: (config != null ? config.value : this.config),
        color: (color != null ? color.value : this.color),
        type: (type != null ? type.value : this.type),
        accessor: (accessor != null ? accessor.value : this.accessor),
        defaultLeaseTTL: (defaultLeaseTTL != null
            ? defaultLeaseTTL.value
            : this.defaultLeaseTTL),
        maxLeaseTTL:
            (maxLeaseTTL != null ? maxLeaseTTL.value : this.maxLeaseTTL),
        description:
            (description != null ? description.value : this.description),
        roles: (roles != null ? roles.value : this.roles));
  }
}

@JsonSerializable(explicitToJson: true)
class GetRabbitmqCredsNameResponse {
  GetRabbitmqCredsNameResponse({
    required this.password,
    required this.username,
  });

  factory GetRabbitmqCredsNameResponse.fromJson(Map<String, dynamic> json) =>
      _$GetRabbitmqCredsNameResponseFromJson(json);

  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String username;
  static const fromJsonFactory = _$GetRabbitmqCredsNameResponseFromJson;
  static const toJsonFactory = _$GetRabbitmqCredsNameResponseToJson;
  Map<String, dynamic> toJson() => _$GetRabbitmqCredsNameResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GetRabbitmqCredsNameResponse &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(username) ^
      runtimeType.hashCode;
}

extension $GetRabbitmqCredsNameResponseExtension
    on GetRabbitmqCredsNameResponse {
  GetRabbitmqCredsNameResponse copyWith({String? password, String? username}) {
    return GetRabbitmqCredsNameResponse(
        password: password ?? this.password,
        username: username ?? this.username);
  }

  GetRabbitmqCredsNameResponse copyWithWrapped(
      {Wrapped<String>? password, Wrapped<String>? username}) {
    return GetRabbitmqCredsNameResponse(
        password: (password != null ? password.value : this.password),
        username: (username != null ? username.value : this.username));
  }
}

@JsonSerializable(explicitToJson: true)
class RabbitMqCredentialsRole {
  RabbitMqCredentialsRole({
    required this.id,
    required this.name,
    this.color,
    required this.description,
    this.config,
    this.credentials,
    this.credentialsId,
  });

  factory RabbitMqCredentialsRole.fromJson(Map<String, dynamic> json) =>
      _$RabbitMqCredentialsRoleFromJson(json);

  @JsonKey(name: 'id', includeIfNull: false, defaultValue: '')
  final String id;
  @JsonKey(name: 'name', includeIfNull: false, defaultValue: '')
  final String name;
  @JsonKey(name: 'color', includeIfNull: false, defaultValue: '')
  final String? color;
  @JsonKey(name: 'description', includeIfNull: false, defaultValue: '')
  final String description;
  @JsonKey(name: 'config', includeIfNull: false)
  final Object? config;
  @JsonKey(name: 'credentials', includeIfNull: false)
  final Credentials? credentials;
  @JsonKey(name: 'credentialsId', includeIfNull: false, defaultValue: '')
  final String? credentialsId;
  static const fromJsonFactory = _$RabbitMqCredentialsRoleFromJson;
  static const toJsonFactory = _$RabbitMqCredentialsRoleToJson;
  Map<String, dynamic> toJson() => _$RabbitMqCredentialsRoleToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RabbitMqCredentialsRole &&
            (identical(other.id, id) ||
                const DeepCollectionEquality().equals(other.id, id)) &&
            (identical(other.name, name) ||
                const DeepCollectionEquality().equals(other.name, name)) &&
            (identical(other.color, color) ||
                const DeepCollectionEquality().equals(other.color, color)) &&
            (identical(other.description, description) ||
                const DeepCollectionEquality()
                    .equals(other.description, description)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)) &&
            (identical(other.credentials, credentials) ||
                const DeepCollectionEquality()
                    .equals(other.credentials, credentials)) &&
            (identical(other.credentialsId, credentialsId) ||
                const DeepCollectionEquality()
                    .equals(other.credentialsId, credentialsId)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(id) ^
      const DeepCollectionEquality().hash(name) ^
      const DeepCollectionEquality().hash(color) ^
      const DeepCollectionEquality().hash(description) ^
      const DeepCollectionEquality().hash(config) ^
      const DeepCollectionEquality().hash(credentials) ^
      const DeepCollectionEquality().hash(credentialsId) ^
      runtimeType.hashCode;
}

extension $RabbitMqCredentialsRoleExtension on RabbitMqCredentialsRole {
  RabbitMqCredentialsRole copyWith(
      {String? id,
      String? name,
      String? color,
      String? description,
      Object? config,
      Credentials? credentials,
      String? credentialsId}) {
    return RabbitMqCredentialsRole(
        id: id ?? this.id,
        name: name ?? this.name,
        color: color ?? this.color,
        description: description ?? this.description,
        config: config ?? this.config,
        credentials: credentials ?? this.credentials,
        credentialsId: credentialsId ?? this.credentialsId);
  }

  RabbitMqCredentialsRole copyWithWrapped(
      {Wrapped<String>? id,
      Wrapped<String>? name,
      Wrapped<String?>? color,
      Wrapped<String>? description,
      Wrapped<Object?>? config,
      Wrapped<Credentials?>? credentials,
      Wrapped<String?>? credentialsId}) {
    return RabbitMqCredentialsRole(
        id: (id != null ? id.value : this.id),
        name: (name != null ? name.value : this.name),
        color: (color != null ? color.value : this.color),
        description:
            (description != null ? description.value : this.description),
        config: (config != null ? config.value : this.config),
        credentials:
            (credentials != null ? credentials.value : this.credentials),
        credentialsId:
            (credentialsId != null ? credentialsId.value : this.credentialsId));
  }
}

@JsonSerializable(explicitToJson: true)
class GeneratePassphraseOptions {
  GeneratePassphraseOptions({
    this.separator,
    this.words,
  });

  factory GeneratePassphraseOptions.fromJson(Map<String, dynamic> json) =>
      _$GeneratePassphraseOptionsFromJson(json);

  @JsonKey(name: 'separator', includeIfNull: false, defaultValue: '')
  final String? separator;
  @JsonKey(name: 'words', includeIfNull: false)
  final double? words;
  static const fromJsonFactory = _$GeneratePassphraseOptionsFromJson;
  static const toJsonFactory = _$GeneratePassphraseOptionsToJson;
  Map<String, dynamic> toJson() => _$GeneratePassphraseOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GeneratePassphraseOptions &&
            (identical(other.separator, separator) ||
                const DeepCollectionEquality()
                    .equals(other.separator, separator)) &&
            (identical(other.words, words) ||
                const DeepCollectionEquality().equals(other.words, words)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(separator) ^
      const DeepCollectionEquality().hash(words) ^
      runtimeType.hashCode;
}

extension $GeneratePassphraseOptionsExtension on GeneratePassphraseOptions {
  GeneratePassphraseOptions copyWith({String? separator, double? words}) {
    return GeneratePassphraseOptions(
        separator: separator ?? this.separator, words: words ?? this.words);
  }

  GeneratePassphraseOptions copyWithWrapped(
      {Wrapped<String?>? separator, Wrapped<double?>? words}) {
    return GeneratePassphraseOptions(
        separator: (separator != null ? separator.value : this.separator),
        words: (words != null ? words.value : this.words));
  }
}

@JsonSerializable(explicitToJson: true)
class GeneratePassphraseResponse {
  GeneratePassphraseResponse({
    required this.value,
  });

  factory GeneratePassphraseResponse.fromJson(Map<String, dynamic> json) =>
      _$GeneratePassphraseResponseFromJson(json);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String value;
  static const fromJsonFactory = _$GeneratePassphraseResponseFromJson;
  static const toJsonFactory = _$GeneratePassphraseResponseToJson;
  Map<String, dynamic> toJson() => _$GeneratePassphraseResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GeneratePassphraseResponse &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^ runtimeType.hashCode;
}

extension $GeneratePassphraseResponseExtension on GeneratePassphraseResponse {
  GeneratePassphraseResponse copyWith({String? value}) {
    return GeneratePassphraseResponse(value: value ?? this.value);
  }

  GeneratePassphraseResponse copyWithWrapped({Wrapped<String>? value}) {
    return GeneratePassphraseResponse(
        value: (value != null ? value.value : this.value));
  }
}

@JsonSerializable(explicitToJson: true)
class GeneratePasswordOptions {
  GeneratePasswordOptions({
    this.allowRepeat,
    this.allowUppercase,
    this.digits,
    this.length,
    this.symbols,
  });

  factory GeneratePasswordOptions.fromJson(Map<String, dynamic> json) =>
      _$GeneratePasswordOptionsFromJson(json);

  @JsonKey(name: 'allowRepeat', includeIfNull: false)
  final bool? allowRepeat;
  @JsonKey(name: 'allowUppercase', includeIfNull: false)
  final bool? allowUppercase;
  @JsonKey(name: 'digits', includeIfNull: false)
  final double? digits;
  @JsonKey(name: 'length', includeIfNull: false)
  final double? length;
  @JsonKey(name: 'symbols', includeIfNull: false)
  final double? symbols;
  static const fromJsonFactory = _$GeneratePasswordOptionsFromJson;
  static const toJsonFactory = _$GeneratePasswordOptionsToJson;
  Map<String, dynamic> toJson() => _$GeneratePasswordOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GeneratePasswordOptions &&
            (identical(other.allowRepeat, allowRepeat) ||
                const DeepCollectionEquality()
                    .equals(other.allowRepeat, allowRepeat)) &&
            (identical(other.allowUppercase, allowUppercase) ||
                const DeepCollectionEquality()
                    .equals(other.allowUppercase, allowUppercase)) &&
            (identical(other.digits, digits) ||
                const DeepCollectionEquality().equals(other.digits, digits)) &&
            (identical(other.length, length) ||
                const DeepCollectionEquality().equals(other.length, length)) &&
            (identical(other.symbols, symbols) ||
                const DeepCollectionEquality().equals(other.symbols, symbols)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(allowRepeat) ^
      const DeepCollectionEquality().hash(allowUppercase) ^
      const DeepCollectionEquality().hash(digits) ^
      const DeepCollectionEquality().hash(length) ^
      const DeepCollectionEquality().hash(symbols) ^
      runtimeType.hashCode;
}

extension $GeneratePasswordOptionsExtension on GeneratePasswordOptions {
  GeneratePasswordOptions copyWith(
      {bool? allowRepeat,
      bool? allowUppercase,
      double? digits,
      double? length,
      double? symbols}) {
    return GeneratePasswordOptions(
        allowRepeat: allowRepeat ?? this.allowRepeat,
        allowUppercase: allowUppercase ?? this.allowUppercase,
        digits: digits ?? this.digits,
        length: length ?? this.length,
        symbols: symbols ?? this.symbols);
  }

  GeneratePasswordOptions copyWithWrapped(
      {Wrapped<bool?>? allowRepeat,
      Wrapped<bool?>? allowUppercase,
      Wrapped<double?>? digits,
      Wrapped<double?>? length,
      Wrapped<double?>? symbols}) {
    return GeneratePasswordOptions(
        allowRepeat:
            (allowRepeat != null ? allowRepeat.value : this.allowRepeat),
        allowUppercase: (allowUppercase != null
            ? allowUppercase.value
            : this.allowUppercase),
        digits: (digits != null ? digits.value : this.digits),
        length: (length != null ? length.value : this.length),
        symbols: (symbols != null ? symbols.value : this.symbols));
  }
}

@JsonSerializable(explicitToJson: true)
class GeneratePasswordResponse {
  GeneratePasswordResponse({
    required this.value,
  });

  factory GeneratePasswordResponse.fromJson(Map<String, dynamic> json) =>
      _$GeneratePasswordResponseFromJson(json);

  @JsonKey(name: 'value', includeIfNull: false, defaultValue: '')
  final String value;
  static const fromJsonFactory = _$GeneratePasswordResponseFromJson;
  static const toJsonFactory = _$GeneratePasswordResponseToJson;
  Map<String, dynamic> toJson() => _$GeneratePasswordResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is GeneratePasswordResponse &&
            (identical(other.value, value) ||
                const DeepCollectionEquality().equals(other.value, value)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(value) ^ runtimeType.hashCode;
}

extension $GeneratePasswordResponseExtension on GeneratePasswordResponse {
  GeneratePasswordResponse copyWith({String? value}) {
    return GeneratePasswordResponse(value: value ?? this.value);
  }

  GeneratePasswordResponse copyWithWrapped({Wrapped<String>? value}) {
    return GeneratePasswordResponse(
        value: (value != null ? value.value : this.value));
  }
}

@JsonSerializable(explicitToJson: true)
class ApiResponse {
  ApiResponse();

  factory ApiResponse.fromJson(Map<String, dynamic> json) =>
      _$ApiResponseFromJson(json);

  static const fromJsonFactory = _$ApiResponseFromJson;
  static const toJsonFactory = _$ApiResponseToJson;
  Map<String, dynamic> toJson() => _$ApiResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SystemSealStatusResponse {
  SystemSealStatusResponse({
    this.initialized,
    this.type,
    this.nonce,
    this.threshold,
    this.shares,
    this.sealed,
    this.progress,
    this.version,
    this.clusterName,
    this.clusterId,
    this.storageType,
    this.transform,
  });

  factory SystemSealStatusResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemSealStatusResponseFromJson(json);

  @JsonKey(name: 'initialized', includeIfNull: false)
  final bool? initialized;
  @JsonKey(name: 'type', includeIfNull: false, defaultValue: '')
  final String? type;
  @JsonKey(name: 'nonce', includeIfNull: false, defaultValue: '')
  final String? nonce;
  @JsonKey(name: 'threshold', includeIfNull: false)
  final double? threshold;
  @JsonKey(name: 'shares', includeIfNull: false)
  final double? shares;
  @JsonKey(name: 'sealed', includeIfNull: false)
  final bool? sealed;
  @JsonKey(name: 'progress', includeIfNull: false)
  final double? progress;
  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String? version;
  @JsonKey(name: 'clusterName', includeIfNull: false, defaultValue: '')
  final String? clusterName;
  @JsonKey(name: 'clusterId', includeIfNull: false, defaultValue: '')
  final String? clusterId;
  @JsonKey(name: 'storageType', includeIfNull: false, defaultValue: '')
  final String? storageType;
  @JsonKey(name: '__transform', includeIfNull: false)
  final Object? transform;
  static const fromJsonFactory = _$SystemSealStatusResponseFromJson;
  static const toJsonFactory = _$SystemSealStatusResponseToJson;
  Map<String, dynamic> toJson() => _$SystemSealStatusResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemSealStatusResponse &&
            (identical(other.initialized, initialized) ||
                const DeepCollectionEquality()
                    .equals(other.initialized, initialized)) &&
            (identical(other.type, type) ||
                const DeepCollectionEquality().equals(other.type, type)) &&
            (identical(other.nonce, nonce) ||
                const DeepCollectionEquality().equals(other.nonce, nonce)) &&
            (identical(other.threshold, threshold) ||
                const DeepCollectionEquality()
                    .equals(other.threshold, threshold)) &&
            (identical(other.shares, shares) ||
                const DeepCollectionEquality().equals(other.shares, shares)) &&
            (identical(other.sealed, sealed) ||
                const DeepCollectionEquality().equals(other.sealed, sealed)) &&
            (identical(other.progress, progress) ||
                const DeepCollectionEquality()
                    .equals(other.progress, progress)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.clusterName, clusterName) ||
                const DeepCollectionEquality()
                    .equals(other.clusterName, clusterName)) &&
            (identical(other.clusterId, clusterId) ||
                const DeepCollectionEquality()
                    .equals(other.clusterId, clusterId)) &&
            (identical(other.storageType, storageType) ||
                const DeepCollectionEquality()
                    .equals(other.storageType, storageType)) &&
            (identical(other.transform, transform) ||
                const DeepCollectionEquality()
                    .equals(other.transform, transform)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(initialized) ^
      const DeepCollectionEquality().hash(type) ^
      const DeepCollectionEquality().hash(nonce) ^
      const DeepCollectionEquality().hash(threshold) ^
      const DeepCollectionEquality().hash(shares) ^
      const DeepCollectionEquality().hash(sealed) ^
      const DeepCollectionEquality().hash(progress) ^
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(clusterName) ^
      const DeepCollectionEquality().hash(clusterId) ^
      const DeepCollectionEquality().hash(storageType) ^
      const DeepCollectionEquality().hash(transform) ^
      runtimeType.hashCode;
}

extension $SystemSealStatusResponseExtension on SystemSealStatusResponse {
  SystemSealStatusResponse copyWith(
      {bool? initialized,
      String? type,
      String? nonce,
      double? threshold,
      double? shares,
      bool? sealed,
      double? progress,
      String? version,
      String? clusterName,
      String? clusterId,
      String? storageType,
      Object? transform}) {
    return SystemSealStatusResponse(
        initialized: initialized ?? this.initialized,
        type: type ?? this.type,
        nonce: nonce ?? this.nonce,
        threshold: threshold ?? this.threshold,
        shares: shares ?? this.shares,
        sealed: sealed ?? this.sealed,
        progress: progress ?? this.progress,
        version: version ?? this.version,
        clusterName: clusterName ?? this.clusterName,
        clusterId: clusterId ?? this.clusterId,
        storageType: storageType ?? this.storageType,
        transform: transform ?? this.transform);
  }

  SystemSealStatusResponse copyWithWrapped(
      {Wrapped<bool?>? initialized,
      Wrapped<String?>? type,
      Wrapped<String?>? nonce,
      Wrapped<double?>? threshold,
      Wrapped<double?>? shares,
      Wrapped<bool?>? sealed,
      Wrapped<double?>? progress,
      Wrapped<String?>? version,
      Wrapped<String?>? clusterName,
      Wrapped<String?>? clusterId,
      Wrapped<String?>? storageType,
      Wrapped<Object?>? transform}) {
    return SystemSealStatusResponse(
        initialized:
            (initialized != null ? initialized.value : this.initialized),
        type: (type != null ? type.value : this.type),
        nonce: (nonce != null ? nonce.value : this.nonce),
        threshold: (threshold != null ? threshold.value : this.threshold),
        shares: (shares != null ? shares.value : this.shares),
        sealed: (sealed != null ? sealed.value : this.sealed),
        progress: (progress != null ? progress.value : this.progress),
        version: (version != null ? version.value : this.version),
        clusterName:
            (clusterName != null ? clusterName.value : this.clusterName),
        clusterId: (clusterId != null ? clusterId.value : this.clusterId),
        storageType:
            (storageType != null ? storageType.value : this.storageType),
        transform: (transform != null ? transform.value : this.transform));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemSealUnlockOptions {
  SystemSealUnlockOptions({
    this.timeout,
    this.notifyStatus,
    this.key,
    this.reset,
  });

  factory SystemSealUnlockOptions.fromJson(Map<String, dynamic> json) =>
      _$SystemSealUnlockOptionsFromJson(json);

  @JsonKey(name: 'timeout', includeIfNull: false)
  final double? timeout;
  @JsonKey(name: 'notifyStatus', includeIfNull: false, defaultValue: true)
  final bool? notifyStatus;
  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String? key;
  @JsonKey(name: 'reset', includeIfNull: false)
  final bool? reset;
  static const fromJsonFactory = _$SystemSealUnlockOptionsFromJson;
  static const toJsonFactory = _$SystemSealUnlockOptionsToJson;
  Map<String, dynamic> toJson() => _$SystemSealUnlockOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemSealUnlockOptions &&
            (identical(other.timeout, timeout) ||
                const DeepCollectionEquality()
                    .equals(other.timeout, timeout)) &&
            (identical(other.notifyStatus, notifyStatus) ||
                const DeepCollectionEquality()
                    .equals(other.notifyStatus, notifyStatus)) &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.reset, reset) ||
                const DeepCollectionEquality().equals(other.reset, reset)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(timeout) ^
      const DeepCollectionEquality().hash(notifyStatus) ^
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(reset) ^
      runtimeType.hashCode;
}

extension $SystemSealUnlockOptionsExtension on SystemSealUnlockOptions {
  SystemSealUnlockOptions copyWith(
      {double? timeout, bool? notifyStatus, String? key, bool? reset}) {
    return SystemSealUnlockOptions(
        timeout: timeout ?? this.timeout,
        notifyStatus: notifyStatus ?? this.notifyStatus,
        key: key ?? this.key,
        reset: reset ?? this.reset);
  }

  SystemSealUnlockOptions copyWithWrapped(
      {Wrapped<double?>? timeout,
      Wrapped<bool?>? notifyStatus,
      Wrapped<String?>? key,
      Wrapped<bool?>? reset}) {
    return SystemSealUnlockOptions(
        timeout: (timeout != null ? timeout.value : this.timeout),
        notifyStatus:
            (notifyStatus != null ? notifyStatus.value : this.notifyStatus),
        key: (key != null ? key.value : this.key),
        reset: (reset != null ? reset.value : this.reset));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemSealUnlockResponse {
  SystemSealUnlockResponse({
    this.threshold,
    this.shares,
    this.sealed,
    this.progress,
    this.version,
    this.clusterName,
    this.clusterId,
    this.storageType,
    this.transform,
  });

  factory SystemSealUnlockResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemSealUnlockResponseFromJson(json);

  @JsonKey(name: 'threshold', includeIfNull: false)
  final double? threshold;
  @JsonKey(name: 'shares', includeIfNull: false)
  final double? shares;
  @JsonKey(name: 'sealed', includeIfNull: false)
  final bool? sealed;
  @JsonKey(name: 'progress', includeIfNull: false)
  final double? progress;
  @JsonKey(name: 'version', includeIfNull: false, defaultValue: '')
  final String? version;
  @JsonKey(name: 'clusterName', includeIfNull: false, defaultValue: '')
  final String? clusterName;
  @JsonKey(name: 'clusterId', includeIfNull: false, defaultValue: '')
  final String? clusterId;
  @JsonKey(name: 'storageType', includeIfNull: false, defaultValue: '')
  final String? storageType;
  @JsonKey(name: '__transform', includeIfNull: false)
  final Object? transform;
  static const fromJsonFactory = _$SystemSealUnlockResponseFromJson;
  static const toJsonFactory = _$SystemSealUnlockResponseToJson;
  Map<String, dynamic> toJson() => _$SystemSealUnlockResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemSealUnlockResponse &&
            (identical(other.threshold, threshold) ||
                const DeepCollectionEquality()
                    .equals(other.threshold, threshold)) &&
            (identical(other.shares, shares) ||
                const DeepCollectionEquality().equals(other.shares, shares)) &&
            (identical(other.sealed, sealed) ||
                const DeepCollectionEquality().equals(other.sealed, sealed)) &&
            (identical(other.progress, progress) ||
                const DeepCollectionEquality()
                    .equals(other.progress, progress)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality()
                    .equals(other.version, version)) &&
            (identical(other.clusterName, clusterName) ||
                const DeepCollectionEquality()
                    .equals(other.clusterName, clusterName)) &&
            (identical(other.clusterId, clusterId) ||
                const DeepCollectionEquality()
                    .equals(other.clusterId, clusterId)) &&
            (identical(other.storageType, storageType) ||
                const DeepCollectionEquality()
                    .equals(other.storageType, storageType)) &&
            (identical(other.transform, transform) ||
                const DeepCollectionEquality()
                    .equals(other.transform, transform)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(threshold) ^
      const DeepCollectionEquality().hash(shares) ^
      const DeepCollectionEquality().hash(sealed) ^
      const DeepCollectionEquality().hash(progress) ^
      const DeepCollectionEquality().hash(version) ^
      const DeepCollectionEquality().hash(clusterName) ^
      const DeepCollectionEquality().hash(clusterId) ^
      const DeepCollectionEquality().hash(storageType) ^
      const DeepCollectionEquality().hash(transform) ^
      runtimeType.hashCode;
}

extension $SystemSealUnlockResponseExtension on SystemSealUnlockResponse {
  SystemSealUnlockResponse copyWith(
      {double? threshold,
      double? shares,
      bool? sealed,
      double? progress,
      String? version,
      String? clusterName,
      String? clusterId,
      String? storageType,
      Object? transform}) {
    return SystemSealUnlockResponse(
        threshold: threshold ?? this.threshold,
        shares: shares ?? this.shares,
        sealed: sealed ?? this.sealed,
        progress: progress ?? this.progress,
        version: version ?? this.version,
        clusterName: clusterName ?? this.clusterName,
        clusterId: clusterId ?? this.clusterId,
        storageType: storageType ?? this.storageType,
        transform: transform ?? this.transform);
  }

  SystemSealUnlockResponse copyWithWrapped(
      {Wrapped<double?>? threshold,
      Wrapped<double?>? shares,
      Wrapped<bool?>? sealed,
      Wrapped<double?>? progress,
      Wrapped<String?>? version,
      Wrapped<String?>? clusterName,
      Wrapped<String?>? clusterId,
      Wrapped<String?>? storageType,
      Wrapped<Object?>? transform}) {
    return SystemSealUnlockResponse(
        threshold: (threshold != null ? threshold.value : this.threshold),
        shares: (shares != null ? shares.value : this.shares),
        sealed: (sealed != null ? sealed.value : this.sealed),
        progress: (progress != null ? progress.value : this.progress),
        version: (version != null ? version.value : this.version),
        clusterName:
            (clusterName != null ? clusterName.value : this.clusterName),
        clusterId: (clusterId != null ? clusterId.value : this.clusterId),
        storageType:
            (storageType != null ? storageType.value : this.storageType),
        transform: (transform != null ? transform.value : this.transform));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemStatusResponse {
  SystemStatusResponse({
    required this.status,
    this.initialized,
    this.sealed,
    this.standby,
    this.performanceStandby,
    this.replicationPerfMode,
    this.replicationDrMode,
    this.serverTimeUtc,
    this.clusterName,
    this.clusterId,
    this.multiTenant,
    required this.build,
  });

  factory SystemStatusResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemStatusResponseFromJson(json);

  @JsonKey(name: 'status', includeIfNull: false)
  final double status;
  @JsonKey(name: 'initialized', includeIfNull: false)
  final bool? initialized;
  @JsonKey(name: 'sealed', includeIfNull: false)
  final bool? sealed;
  @JsonKey(name: 'standby', includeIfNull: false)
  final bool? standby;
  @JsonKey(name: 'performanceStandby', includeIfNull: false)
  final bool? performanceStandby;
  @JsonKey(name: 'replicationPerfMode', includeIfNull: false, defaultValue: '')
  final String? replicationPerfMode;
  @JsonKey(name: 'replicationDrMode', includeIfNull: false, defaultValue: '')
  final String? replicationDrMode;
  @JsonKey(name: 'serverTimeUtc', includeIfNull: false)
  final double? serverTimeUtc;
  @JsonKey(name: 'clusterName', includeIfNull: false, defaultValue: '')
  final String? clusterName;
  @JsonKey(name: 'clusterId', includeIfNull: false, defaultValue: '')
  final String? clusterId;
  @JsonKey(name: 'multiTenant', includeIfNull: false)
  final bool? multiTenant;
  @JsonKey(name: 'build', includeIfNull: false)
  final SystemStatusResponse$Build build;
  static const fromJsonFactory = _$SystemStatusResponseFromJson;
  static const toJsonFactory = _$SystemStatusResponseToJson;
  Map<String, dynamic> toJson() => _$SystemStatusResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemStatusResponse &&
            (identical(other.status, status) ||
                const DeepCollectionEquality().equals(other.status, status)) &&
            (identical(other.initialized, initialized) ||
                const DeepCollectionEquality()
                    .equals(other.initialized, initialized)) &&
            (identical(other.sealed, sealed) ||
                const DeepCollectionEquality().equals(other.sealed, sealed)) &&
            (identical(other.standby, standby) ||
                const DeepCollectionEquality()
                    .equals(other.standby, standby)) &&
            (identical(other.performanceStandby, performanceStandby) ||
                const DeepCollectionEquality()
                    .equals(other.performanceStandby, performanceStandby)) &&
            (identical(other.replicationPerfMode, replicationPerfMode) ||
                const DeepCollectionEquality()
                    .equals(other.replicationPerfMode, replicationPerfMode)) &&
            (identical(other.replicationDrMode, replicationDrMode) ||
                const DeepCollectionEquality()
                    .equals(other.replicationDrMode, replicationDrMode)) &&
            (identical(other.serverTimeUtc, serverTimeUtc) ||
                const DeepCollectionEquality()
                    .equals(other.serverTimeUtc, serverTimeUtc)) &&
            (identical(other.clusterName, clusterName) ||
                const DeepCollectionEquality()
                    .equals(other.clusterName, clusterName)) &&
            (identical(other.clusterId, clusterId) ||
                const DeepCollectionEquality()
                    .equals(other.clusterId, clusterId)) &&
            (identical(other.multiTenant, multiTenant) ||
                const DeepCollectionEquality()
                    .equals(other.multiTenant, multiTenant)) &&
            (identical(other.build, build) ||
                const DeepCollectionEquality().equals(other.build, build)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(status) ^
      const DeepCollectionEquality().hash(initialized) ^
      const DeepCollectionEquality().hash(sealed) ^
      const DeepCollectionEquality().hash(standby) ^
      const DeepCollectionEquality().hash(performanceStandby) ^
      const DeepCollectionEquality().hash(replicationPerfMode) ^
      const DeepCollectionEquality().hash(replicationDrMode) ^
      const DeepCollectionEquality().hash(serverTimeUtc) ^
      const DeepCollectionEquality().hash(clusterName) ^
      const DeepCollectionEquality().hash(clusterId) ^
      const DeepCollectionEquality().hash(multiTenant) ^
      const DeepCollectionEquality().hash(build) ^
      runtimeType.hashCode;
}

extension $SystemStatusResponseExtension on SystemStatusResponse {
  SystemStatusResponse copyWith(
      {double? status,
      bool? initialized,
      bool? sealed,
      bool? standby,
      bool? performanceStandby,
      String? replicationPerfMode,
      String? replicationDrMode,
      double? serverTimeUtc,
      String? clusterName,
      String? clusterId,
      bool? multiTenant,
      SystemStatusResponse$Build? build}) {
    return SystemStatusResponse(
        status: status ?? this.status,
        initialized: initialized ?? this.initialized,
        sealed: sealed ?? this.sealed,
        standby: standby ?? this.standby,
        performanceStandby: performanceStandby ?? this.performanceStandby,
        replicationPerfMode: replicationPerfMode ?? this.replicationPerfMode,
        replicationDrMode: replicationDrMode ?? this.replicationDrMode,
        serverTimeUtc: serverTimeUtc ?? this.serverTimeUtc,
        clusterName: clusterName ?? this.clusterName,
        clusterId: clusterId ?? this.clusterId,
        multiTenant: multiTenant ?? this.multiTenant,
        build: build ?? this.build);
  }

  SystemStatusResponse copyWithWrapped(
      {Wrapped<double>? status,
      Wrapped<bool?>? initialized,
      Wrapped<bool?>? sealed,
      Wrapped<bool?>? standby,
      Wrapped<bool?>? performanceStandby,
      Wrapped<String?>? replicationPerfMode,
      Wrapped<String?>? replicationDrMode,
      Wrapped<double?>? serverTimeUtc,
      Wrapped<String?>? clusterName,
      Wrapped<String?>? clusterId,
      Wrapped<bool?>? multiTenant,
      Wrapped<SystemStatusResponse$Build>? build}) {
    return SystemStatusResponse(
        status: (status != null ? status.value : this.status),
        initialized:
            (initialized != null ? initialized.value : this.initialized),
        sealed: (sealed != null ? sealed.value : this.sealed),
        standby: (standby != null ? standby.value : this.standby),
        performanceStandby: (performanceStandby != null
            ? performanceStandby.value
            : this.performanceStandby),
        replicationPerfMode: (replicationPerfMode != null
            ? replicationPerfMode.value
            : this.replicationPerfMode),
        replicationDrMode: (replicationDrMode != null
            ? replicationDrMode.value
            : this.replicationDrMode),
        serverTimeUtc:
            (serverTimeUtc != null ? serverTimeUtc.value : this.serverTimeUtc),
        clusterName:
            (clusterName != null ? clusterName.value : this.clusterName),
        clusterId: (clusterId != null ? clusterId.value : this.clusterId),
        multiTenant:
            (multiTenant != null ? multiTenant.value : this.multiTenant),
        build: (build != null ? build.value : this.build));
  }
}

@JsonSerializable(explicitToJson: true)
class ResetResponse {
  ResetResponse({
    required this.tenantId,
    required this.token,
    required this.password,
  });

  factory ResetResponse.fromJson(Map<String, dynamic> json) =>
      _$ResetResponseFromJson(json);

  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String tenantId;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String token;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  static const fromJsonFactory = _$ResetResponseFromJson;
  static const toJsonFactory = _$ResetResponseToJson;
  Map<String, dynamic> toJson() => _$ResetResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ResetResponse &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(tenantId) ^
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $ResetResponseExtension on ResetResponse {
  ResetResponse copyWith({String? tenantId, String? token, String? password}) {
    return ResetResponse(
        tenantId: tenantId ?? this.tenantId,
        token: token ?? this.token,
        password: password ?? this.password);
  }

  ResetResponse copyWithWrapped(
      {Wrapped<String>? tenantId,
      Wrapped<String>? token,
      Wrapped<String>? password}) {
    return ResetResponse(
        tenantId: (tenantId != null ? tenantId.value : this.tenantId),
        token: (token != null ? token.value : this.token),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class InitOptions {
  InitOptions({
    this.pgpKeys,
    this.recoveryPgpKeys,
    this.recoveryShares,
    this.recoveryThreshold,
    this.rootTokenPgpKey,
    this.secretShares,
    this.secretThreshold,
    this.storedShares,
  });

  factory InitOptions.fromJson(Map<String, dynamic> json) =>
      _$InitOptionsFromJson(json);

  @JsonKey(name: 'pgpKeys', includeIfNull: false, defaultValue: <String>[])
  final List<String>? pgpKeys;
  @JsonKey(
      name: 'recoveryPgpKeys', includeIfNull: false, defaultValue: <String>[])
  final List<String>? recoveryPgpKeys;
  @JsonKey(name: 'recoveryShares', includeIfNull: false)
  final double? recoveryShares;
  @JsonKey(name: 'recoveryThreshold', includeIfNull: false)
  final double? recoveryThreshold;
  @JsonKey(name: 'rootTokenPgpKey', includeIfNull: false, defaultValue: '')
  final String? rootTokenPgpKey;
  @JsonKey(name: 'secretShares', includeIfNull: false)
  final double? secretShares;
  @JsonKey(name: 'secretThreshold', includeIfNull: false)
  final double? secretThreshold;
  @JsonKey(name: 'storedShares', includeIfNull: false)
  final double? storedShares;
  static const fromJsonFactory = _$InitOptionsFromJson;
  static const toJsonFactory = _$InitOptionsToJson;
  Map<String, dynamic> toJson() => _$InitOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InitOptions &&
            (identical(other.pgpKeys, pgpKeys) ||
                const DeepCollectionEquality()
                    .equals(other.pgpKeys, pgpKeys)) &&
            (identical(other.recoveryPgpKeys, recoveryPgpKeys) ||
                const DeepCollectionEquality()
                    .equals(other.recoveryPgpKeys, recoveryPgpKeys)) &&
            (identical(other.recoveryShares, recoveryShares) ||
                const DeepCollectionEquality()
                    .equals(other.recoveryShares, recoveryShares)) &&
            (identical(other.recoveryThreshold, recoveryThreshold) ||
                const DeepCollectionEquality()
                    .equals(other.recoveryThreshold, recoveryThreshold)) &&
            (identical(other.rootTokenPgpKey, rootTokenPgpKey) ||
                const DeepCollectionEquality()
                    .equals(other.rootTokenPgpKey, rootTokenPgpKey)) &&
            (identical(other.secretShares, secretShares) ||
                const DeepCollectionEquality()
                    .equals(other.secretShares, secretShares)) &&
            (identical(other.secretThreshold, secretThreshold) ||
                const DeepCollectionEquality()
                    .equals(other.secretThreshold, secretThreshold)) &&
            (identical(other.storedShares, storedShares) ||
                const DeepCollectionEquality()
                    .equals(other.storedShares, storedShares)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pgpKeys) ^
      const DeepCollectionEquality().hash(recoveryPgpKeys) ^
      const DeepCollectionEquality().hash(recoveryShares) ^
      const DeepCollectionEquality().hash(recoveryThreshold) ^
      const DeepCollectionEquality().hash(rootTokenPgpKey) ^
      const DeepCollectionEquality().hash(secretShares) ^
      const DeepCollectionEquality().hash(secretThreshold) ^
      const DeepCollectionEquality().hash(storedShares) ^
      runtimeType.hashCode;
}

extension $InitOptionsExtension on InitOptions {
  InitOptions copyWith(
      {List<String>? pgpKeys,
      List<String>? recoveryPgpKeys,
      double? recoveryShares,
      double? recoveryThreshold,
      String? rootTokenPgpKey,
      double? secretShares,
      double? secretThreshold,
      double? storedShares}) {
    return InitOptions(
        pgpKeys: pgpKeys ?? this.pgpKeys,
        recoveryPgpKeys: recoveryPgpKeys ?? this.recoveryPgpKeys,
        recoveryShares: recoveryShares ?? this.recoveryShares,
        recoveryThreshold: recoveryThreshold ?? this.recoveryThreshold,
        rootTokenPgpKey: rootTokenPgpKey ?? this.rootTokenPgpKey,
        secretShares: secretShares ?? this.secretShares,
        secretThreshold: secretThreshold ?? this.secretThreshold,
        storedShares: storedShares ?? this.storedShares);
  }

  InitOptions copyWithWrapped(
      {Wrapped<List<String>?>? pgpKeys,
      Wrapped<List<String>?>? recoveryPgpKeys,
      Wrapped<double?>? recoveryShares,
      Wrapped<double?>? recoveryThreshold,
      Wrapped<String?>? rootTokenPgpKey,
      Wrapped<double?>? secretShares,
      Wrapped<double?>? secretThreshold,
      Wrapped<double?>? storedShares}) {
    return InitOptions(
        pgpKeys: (pgpKeys != null ? pgpKeys.value : this.pgpKeys),
        recoveryPgpKeys: (recoveryPgpKeys != null
            ? recoveryPgpKeys.value
            : this.recoveryPgpKeys),
        recoveryShares: (recoveryShares != null
            ? recoveryShares.value
            : this.recoveryShares),
        recoveryThreshold: (recoveryThreshold != null
            ? recoveryThreshold.value
            : this.recoveryThreshold),
        rootTokenPgpKey: (rootTokenPgpKey != null
            ? rootTokenPgpKey.value
            : this.rootTokenPgpKey),
        secretShares:
            (secretShares != null ? secretShares.value : this.secretShares),
        secretThreshold: (secretThreshold != null
            ? secretThreshold.value
            : this.secretThreshold),
        storedShares:
            (storedShares != null ? storedShares.value : this.storedShares));
  }
}

@JsonSerializable(explicitToJson: true)
class InitResponse {
  InitResponse({
    required this.password,
    required this.token,
    required this.tenantId,
    required this.keys,
    this.keysBase64,
    this.rootToken,
  });

  factory InitResponse.fromJson(Map<String, dynamic> json) =>
      _$InitResponseFromJson(json);

  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String password;
  @JsonKey(name: 'token', includeIfNull: false, defaultValue: '')
  final String token;
  @JsonKey(name: 'tenantId', includeIfNull: false, defaultValue: '')
  final String tenantId;
  @JsonKey(name: 'keys', includeIfNull: false, defaultValue: <String>[])
  final List<String> keys;
  @JsonKey(name: 'keysBase64', includeIfNull: false, defaultValue: <String>[])
  final List<String>? keysBase64;
  @JsonKey(name: 'rootToken', includeIfNull: false, defaultValue: '')
  final String? rootToken;
  static const fromJsonFactory = _$InitResponseFromJson;
  static const toJsonFactory = _$InitResponseToJson;
  Map<String, dynamic> toJson() => _$InitResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is InitResponse &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)) &&
            (identical(other.token, token) ||
                const DeepCollectionEquality().equals(other.token, token)) &&
            (identical(other.tenantId, tenantId) ||
                const DeepCollectionEquality()
                    .equals(other.tenantId, tenantId)) &&
            (identical(other.keys, keys) ||
                const DeepCollectionEquality().equals(other.keys, keys)) &&
            (identical(other.keysBase64, keysBase64) ||
                const DeepCollectionEquality()
                    .equals(other.keysBase64, keysBase64)) &&
            (identical(other.rootToken, rootToken) ||
                const DeepCollectionEquality()
                    .equals(other.rootToken, rootToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(password) ^
      const DeepCollectionEquality().hash(token) ^
      const DeepCollectionEquality().hash(tenantId) ^
      const DeepCollectionEquality().hash(keys) ^
      const DeepCollectionEquality().hash(keysBase64) ^
      const DeepCollectionEquality().hash(rootToken) ^
      runtimeType.hashCode;
}

extension $InitResponseExtension on InitResponse {
  InitResponse copyWith(
      {String? password,
      String? token,
      String? tenantId,
      List<String>? keys,
      List<String>? keysBase64,
      String? rootToken}) {
    return InitResponse(
        password: password ?? this.password,
        token: token ?? this.token,
        tenantId: tenantId ?? this.tenantId,
        keys: keys ?? this.keys,
        keysBase64: keysBase64 ?? this.keysBase64,
        rootToken: rootToken ?? this.rootToken);
  }

  InitResponse copyWithWrapped(
      {Wrapped<String>? password,
      Wrapped<String>? token,
      Wrapped<String>? tenantId,
      Wrapped<List<String>>? keys,
      Wrapped<List<String>?>? keysBase64,
      Wrapped<String?>? rootToken}) {
    return InitResponse(
        password: (password != null ? password.value : this.password),
        token: (token != null ? token.value : this.token),
        tenantId: (tenantId != null ? tenantId.value : this.tenantId),
        keys: (keys != null ? keys.value : this.keys),
        keysBase64: (keysBase64 != null ? keysBase64.value : this.keysBase64),
        rootToken: (rootToken != null ? rootToken.value : this.rootToken));
  }
}

@JsonSerializable(explicitToJson: true)
class BackupDownloadOptions {
  BackupDownloadOptions({
    required this.backupFile,
    this.db,
    this.host,
    this.username,
    this.password,
  });

  factory BackupDownloadOptions.fromJson(Map<String, dynamic> json) =>
      _$BackupDownloadOptionsFromJson(json);

  @JsonKey(name: 'backupFile', includeIfNull: false, defaultValue: '')
  final String backupFile;
  @JsonKey(name: 'db', includeIfNull: false, defaultValue: '')
  final String? db;
  @JsonKey(name: 'host', includeIfNull: false, defaultValue: '')
  final String? host;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  static const fromJsonFactory = _$BackupDownloadOptionsFromJson;
  static const toJsonFactory = _$BackupDownloadOptionsToJson;
  Map<String, dynamic> toJson() => _$BackupDownloadOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BackupDownloadOptions &&
            (identical(other.backupFile, backupFile) ||
                const DeepCollectionEquality()
                    .equals(other.backupFile, backupFile)) &&
            (identical(other.db, db) ||
                const DeepCollectionEquality().equals(other.db, db)) &&
            (identical(other.host, host) ||
                const DeepCollectionEquality().equals(other.host, host)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(backupFile) ^
      const DeepCollectionEquality().hash(db) ^
      const DeepCollectionEquality().hash(host) ^
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $BackupDownloadOptionsExtension on BackupDownloadOptions {
  BackupDownloadOptions copyWith(
      {String? backupFile,
      String? db,
      String? host,
      String? username,
      String? password}) {
    return BackupDownloadOptions(
        backupFile: backupFile ?? this.backupFile,
        db: db ?? this.db,
        host: host ?? this.host,
        username: username ?? this.username,
        password: password ?? this.password);
  }

  BackupDownloadOptions copyWithWrapped(
      {Wrapped<String>? backupFile,
      Wrapped<String?>? db,
      Wrapped<String?>? host,
      Wrapped<String?>? username,
      Wrapped<String?>? password}) {
    return BackupDownloadOptions(
        backupFile: (backupFile != null ? backupFile.value : this.backupFile),
        db: (db != null ? db.value : this.db),
        host: (host != null ? host.value : this.host),
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class BackupResponse {
  BackupResponse({
    required this.backupFile,
  });

  factory BackupResponse.fromJson(Map<String, dynamic> json) =>
      _$BackupResponseFromJson(json);

  @JsonKey(name: 'backupFile', includeIfNull: false, defaultValue: '')
  final String backupFile;
  static const fromJsonFactory = _$BackupResponseFromJson;
  static const toJsonFactory = _$BackupResponseToJson;
  Map<String, dynamic> toJson() => _$BackupResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BackupResponse &&
            (identical(other.backupFile, backupFile) ||
                const DeepCollectionEquality()
                    .equals(other.backupFile, backupFile)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(backupFile) ^ runtimeType.hashCode;
}

extension $BackupResponseExtension on BackupResponse {
  BackupResponse copyWith({String? backupFile}) {
    return BackupResponse(backupFile: backupFile ?? this.backupFile);
  }

  BackupResponse copyWithWrapped({Wrapped<String>? backupFile}) {
    return BackupResponse(
        backupFile: (backupFile != null ? backupFile.value : this.backupFile));
  }
}

@JsonSerializable(explicitToJson: true)
class RestoreOptions {
  RestoreOptions({
    required this.backupFile,
    this.db,
    this.host,
    this.username,
    this.password,
  });

  factory RestoreOptions.fromJson(Map<String, dynamic> json) =>
      _$RestoreOptionsFromJson(json);

  @JsonKey(name: 'backupFile', includeIfNull: false, defaultValue: '')
  final String backupFile;
  @JsonKey(name: 'db', includeIfNull: false, defaultValue: '')
  final String? db;
  @JsonKey(name: 'host', includeIfNull: false, defaultValue: '')
  final String? host;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  static const fromJsonFactory = _$RestoreOptionsFromJson;
  static const toJsonFactory = _$RestoreOptionsToJson;
  Map<String, dynamic> toJson() => _$RestoreOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RestoreOptions &&
            (identical(other.backupFile, backupFile) ||
                const DeepCollectionEquality()
                    .equals(other.backupFile, backupFile)) &&
            (identical(other.db, db) ||
                const DeepCollectionEquality().equals(other.db, db)) &&
            (identical(other.host, host) ||
                const DeepCollectionEquality().equals(other.host, host)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(backupFile) ^
      const DeepCollectionEquality().hash(db) ^
      const DeepCollectionEquality().hash(host) ^
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $RestoreOptionsExtension on RestoreOptions {
  RestoreOptions copyWith(
      {String? backupFile,
      String? db,
      String? host,
      String? username,
      String? password}) {
    return RestoreOptions(
        backupFile: backupFile ?? this.backupFile,
        db: db ?? this.db,
        host: host ?? this.host,
        username: username ?? this.username,
        password: password ?? this.password);
  }

  RestoreOptions copyWithWrapped(
      {Wrapped<String>? backupFile,
      Wrapped<String?>? db,
      Wrapped<String?>? host,
      Wrapped<String?>? username,
      Wrapped<String?>? password}) {
    return RestoreOptions(
        backupFile: (backupFile != null ? backupFile.value : this.backupFile),
        db: (db != null ? db.value : this.db),
        host: (host != null ? host.value : this.host),
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class RestoreResponse {
  RestoreResponse({
    required this.restored,
  });

  factory RestoreResponse.fromJson(Map<String, dynamic> json) =>
      _$RestoreResponseFromJson(json);

  @JsonKey(name: 'restored', includeIfNull: false, defaultValue: '')
  final String restored;
  static const fromJsonFactory = _$RestoreResponseFromJson;
  static const toJsonFactory = _$RestoreResponseToJson;
  Map<String, dynamic> toJson() => _$RestoreResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is RestoreResponse &&
            (identical(other.restored, restored) ||
                const DeepCollectionEquality()
                    .equals(other.restored, restored)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(restored) ^ runtimeType.hashCode;
}

extension $RestoreResponseExtension on RestoreResponse {
  RestoreResponse copyWith({String? restored}) {
    return RestoreResponse(restored: restored ?? this.restored);
  }

  RestoreResponse copyWithWrapped({Wrapped<String>? restored}) {
    return RestoreResponse(
        restored: (restored != null ? restored.value : this.restored));
  }
}

@JsonSerializable(explicitToJson: true)
class BackupDeleteOptions {
  BackupDeleteOptions({
    required this.backupFile,
    this.db,
    this.host,
    this.username,
    this.password,
  });

  factory BackupDeleteOptions.fromJson(Map<String, dynamic> json) =>
      _$BackupDeleteOptionsFromJson(json);

  @JsonKey(name: 'backupFile', includeIfNull: false, defaultValue: '')
  final String backupFile;
  @JsonKey(name: 'db', includeIfNull: false, defaultValue: '')
  final String? db;
  @JsonKey(name: 'host', includeIfNull: false, defaultValue: '')
  final String? host;
  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  @JsonKey(name: 'password', includeIfNull: false, defaultValue: '')
  final String? password;
  static const fromJsonFactory = _$BackupDeleteOptionsFromJson;
  static const toJsonFactory = _$BackupDeleteOptionsToJson;
  Map<String, dynamic> toJson() => _$BackupDeleteOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BackupDeleteOptions &&
            (identical(other.backupFile, backupFile) ||
                const DeepCollectionEquality()
                    .equals(other.backupFile, backupFile)) &&
            (identical(other.db, db) ||
                const DeepCollectionEquality().equals(other.db, db)) &&
            (identical(other.host, host) ||
                const DeepCollectionEquality().equals(other.host, host)) &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)) &&
            (identical(other.password, password) ||
                const DeepCollectionEquality()
                    .equals(other.password, password)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(backupFile) ^
      const DeepCollectionEquality().hash(db) ^
      const DeepCollectionEquality().hash(host) ^
      const DeepCollectionEquality().hash(username) ^
      const DeepCollectionEquality().hash(password) ^
      runtimeType.hashCode;
}

extension $BackupDeleteOptionsExtension on BackupDeleteOptions {
  BackupDeleteOptions copyWith(
      {String? backupFile,
      String? db,
      String? host,
      String? username,
      String? password}) {
    return BackupDeleteOptions(
        backupFile: backupFile ?? this.backupFile,
        db: db ?? this.db,
        host: host ?? this.host,
        username: username ?? this.username,
        password: password ?? this.password);
  }

  BackupDeleteOptions copyWithWrapped(
      {Wrapped<String>? backupFile,
      Wrapped<String?>? db,
      Wrapped<String?>? host,
      Wrapped<String?>? username,
      Wrapped<String?>? password}) {
    return BackupDeleteOptions(
        backupFile: (backupFile != null ? backupFile.value : this.backupFile),
        db: (db != null ? db.value : this.db),
        host: (host != null ? host.value : this.host),
        username: (username != null ? username.value : this.username),
        password: (password != null ? password.value : this.password));
  }
}

@JsonSerializable(explicitToJson: true)
class BackupDeleteResponse {
  BackupDeleteResponse({
    required this.deleted,
  });

  factory BackupDeleteResponse.fromJson(Map<String, dynamic> json) =>
      _$BackupDeleteResponseFromJson(json);

  @JsonKey(name: 'deleted', includeIfNull: false)
  final bool deleted;
  static const fromJsonFactory = _$BackupDeleteResponseFromJson;
  static const toJsonFactory = _$BackupDeleteResponseToJson;
  Map<String, dynamic> toJson() => _$BackupDeleteResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is BackupDeleteResponse &&
            (identical(other.deleted, deleted) ||
                const DeepCollectionEquality().equals(other.deleted, deleted)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(deleted) ^ runtimeType.hashCode;
}

extension $BackupDeleteResponseExtension on BackupDeleteResponse {
  BackupDeleteResponse copyWith({bool? deleted}) {
    return BackupDeleteResponse(deleted: deleted ?? this.deleted);
  }

  BackupDeleteResponse copyWithWrapped({Wrapped<bool>? deleted}) {
    return BackupDeleteResponse(
        deleted: (deleted != null ? deleted.value : this.deleted));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeyStatusResponse {
  SystemRootkeyStatusResponse({
    required this.started,
    required this.nonce,
    required this.progress,
    required this.required,
    required this.pgpFingerprint,
    required this.complete,
    required this.encodedToken,
  });

  factory SystemRootkeyStatusResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeyStatusResponseFromJson(json);

  @JsonKey(name: 'started', includeIfNull: false)
  final bool started;
  @JsonKey(name: 'nonce', includeIfNull: false, defaultValue: '')
  final String nonce;
  @JsonKey(name: 'progress', includeIfNull: false)
  final double progress;
  @JsonKey(name: 'required', includeIfNull: false)
  final double required;
  @JsonKey(name: 'pgpFingerprint', includeIfNull: false, defaultValue: '')
  final String pgpFingerprint;
  @JsonKey(name: 'complete', includeIfNull: false)
  final bool complete;
  @JsonKey(name: 'encodedToken', includeIfNull: false, defaultValue: '')
  final String encodedToken;
  static const fromJsonFactory = _$SystemRootkeyStatusResponseFromJson;
  static const toJsonFactory = _$SystemRootkeyStatusResponseToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeyStatusResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeyStatusResponse &&
            (identical(other.started, started) ||
                const DeepCollectionEquality()
                    .equals(other.started, started)) &&
            (identical(other.nonce, nonce) ||
                const DeepCollectionEquality().equals(other.nonce, nonce)) &&
            (identical(other.progress, progress) ||
                const DeepCollectionEquality()
                    .equals(other.progress, progress)) &&
            (identical(other.required, required) ||
                const DeepCollectionEquality()
                    .equals(other.required, required)) &&
            (identical(other.pgpFingerprint, pgpFingerprint) ||
                const DeepCollectionEquality()
                    .equals(other.pgpFingerprint, pgpFingerprint)) &&
            (identical(other.complete, complete) ||
                const DeepCollectionEquality()
                    .equals(other.complete, complete)) &&
            (identical(other.encodedToken, encodedToken) ||
                const DeepCollectionEquality()
                    .equals(other.encodedToken, encodedToken)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(started) ^
      const DeepCollectionEquality().hash(nonce) ^
      const DeepCollectionEquality().hash(progress) ^
      const DeepCollectionEquality().hash(required) ^
      const DeepCollectionEquality().hash(pgpFingerprint) ^
      const DeepCollectionEquality().hash(complete) ^
      const DeepCollectionEquality().hash(encodedToken) ^
      runtimeType.hashCode;
}

extension $SystemRootkeyStatusResponseExtension on SystemRootkeyStatusResponse {
  SystemRootkeyStatusResponse copyWith(
      {bool? started,
      String? nonce,
      double? progress,
      double? required,
      String? pgpFingerprint,
      bool? complete,
      String? encodedToken}) {
    return SystemRootkeyStatusResponse(
        started: started ?? this.started,
        nonce: nonce ?? this.nonce,
        progress: progress ?? this.progress,
        required: required ?? this.required,
        pgpFingerprint: pgpFingerprint ?? this.pgpFingerprint,
        complete: complete ?? this.complete,
        encodedToken: encodedToken ?? this.encodedToken);
  }

  SystemRootkeyStatusResponse copyWithWrapped(
      {Wrapped<bool>? started,
      Wrapped<String>? nonce,
      Wrapped<double>? progress,
      Wrapped<double>? required,
      Wrapped<String>? pgpFingerprint,
      Wrapped<bool>? complete,
      Wrapped<String>? encodedToken}) {
    return SystemRootkeyStatusResponse(
        started: (started != null ? started.value : this.started),
        nonce: (nonce != null ? nonce.value : this.nonce),
        progress: (progress != null ? progress.value : this.progress),
        required: (required != null ? required.value : this.required),
        pgpFingerprint: (pgpFingerprint != null
            ? pgpFingerprint.value
            : this.pgpFingerprint),
        complete: (complete != null ? complete.value : this.complete),
        encodedToken:
            (encodedToken != null ? encodedToken.value : this.encodedToken));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeyStartOptions {
  SystemRootkeyStartOptions({
    this.pgpKey,
  });

  factory SystemRootkeyStartOptions.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeyStartOptionsFromJson(json);

  @JsonKey(name: 'pgpKey', includeIfNull: false, defaultValue: '')
  final String? pgpKey;
  static const fromJsonFactory = _$SystemRootkeyStartOptionsFromJson;
  static const toJsonFactory = _$SystemRootkeyStartOptionsToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeyStartOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeyStartOptions &&
            (identical(other.pgpKey, pgpKey) ||
                const DeepCollectionEquality().equals(other.pgpKey, pgpKey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(pgpKey) ^ runtimeType.hashCode;
}

extension $SystemRootkeyStartOptionsExtension on SystemRootkeyStartOptions {
  SystemRootkeyStartOptions copyWith({String? pgpKey}) {
    return SystemRootkeyStartOptions(pgpKey: pgpKey ?? this.pgpKey);
  }

  SystemRootkeyStartOptions copyWithWrapped({Wrapped<String?>? pgpKey}) {
    return SystemRootkeyStartOptions(
        pgpKey: (pgpKey != null ? pgpKey.value : this.pgpKey));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeyStartResponse {
  SystemRootkeyStartResponse({
    required this.started,
    required this.nonce,
    required this.progress,
    required this.required,
    required this.pgpFingerprint,
    required this.complete,
    required this.encodedToken,
    required this.otp,
  });

  factory SystemRootkeyStartResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeyStartResponseFromJson(json);

  @JsonKey(name: 'started', includeIfNull: false)
  final bool started;
  @JsonKey(name: 'nonce', includeIfNull: false, defaultValue: '')
  final String nonce;
  @JsonKey(name: 'progress', includeIfNull: false)
  final double progress;
  @JsonKey(name: 'required', includeIfNull: false)
  final double required;
  @JsonKey(name: 'pgpFingerprint', includeIfNull: false, defaultValue: '')
  final String pgpFingerprint;
  @JsonKey(name: 'complete', includeIfNull: false)
  final bool complete;
  @JsonKey(name: 'encodedToken', includeIfNull: false, defaultValue: '')
  final String encodedToken;
  @JsonKey(name: 'otp', includeIfNull: false, defaultValue: '')
  final String otp;
  static const fromJsonFactory = _$SystemRootkeyStartResponseFromJson;
  static const toJsonFactory = _$SystemRootkeyStartResponseToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeyStartResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeyStartResponse &&
            (identical(other.started, started) ||
                const DeepCollectionEquality()
                    .equals(other.started, started)) &&
            (identical(other.nonce, nonce) ||
                const DeepCollectionEquality().equals(other.nonce, nonce)) &&
            (identical(other.progress, progress) ||
                const DeepCollectionEquality()
                    .equals(other.progress, progress)) &&
            (identical(other.required, required) ||
                const DeepCollectionEquality()
                    .equals(other.required, required)) &&
            (identical(other.pgpFingerprint, pgpFingerprint) ||
                const DeepCollectionEquality()
                    .equals(other.pgpFingerprint, pgpFingerprint)) &&
            (identical(other.complete, complete) ||
                const DeepCollectionEquality()
                    .equals(other.complete, complete)) &&
            (identical(other.encodedToken, encodedToken) ||
                const DeepCollectionEquality()
                    .equals(other.encodedToken, encodedToken)) &&
            (identical(other.otp, otp) ||
                const DeepCollectionEquality().equals(other.otp, otp)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(started) ^
      const DeepCollectionEquality().hash(nonce) ^
      const DeepCollectionEquality().hash(progress) ^
      const DeepCollectionEquality().hash(required) ^
      const DeepCollectionEquality().hash(pgpFingerprint) ^
      const DeepCollectionEquality().hash(complete) ^
      const DeepCollectionEquality().hash(encodedToken) ^
      const DeepCollectionEquality().hash(otp) ^
      runtimeType.hashCode;
}

extension $SystemRootkeyStartResponseExtension on SystemRootkeyStartResponse {
  SystemRootkeyStartResponse copyWith(
      {bool? started,
      String? nonce,
      double? progress,
      double? required,
      String? pgpFingerprint,
      bool? complete,
      String? encodedToken,
      String? otp}) {
    return SystemRootkeyStartResponse(
        started: started ?? this.started,
        nonce: nonce ?? this.nonce,
        progress: progress ?? this.progress,
        required: required ?? this.required,
        pgpFingerprint: pgpFingerprint ?? this.pgpFingerprint,
        complete: complete ?? this.complete,
        encodedToken: encodedToken ?? this.encodedToken,
        otp: otp ?? this.otp);
  }

  SystemRootkeyStartResponse copyWithWrapped(
      {Wrapped<bool>? started,
      Wrapped<String>? nonce,
      Wrapped<double>? progress,
      Wrapped<double>? required,
      Wrapped<String>? pgpFingerprint,
      Wrapped<bool>? complete,
      Wrapped<String>? encodedToken,
      Wrapped<String>? otp}) {
    return SystemRootkeyStartResponse(
        started: (started != null ? started.value : this.started),
        nonce: (nonce != null ? nonce.value : this.nonce),
        progress: (progress != null ? progress.value : this.progress),
        required: (required != null ? required.value : this.required),
        pgpFingerprint: (pgpFingerprint != null
            ? pgpFingerprint.value
            : this.pgpFingerprint),
        complete: (complete != null ? complete.value : this.complete),
        encodedToken:
            (encodedToken != null ? encodedToken.value : this.encodedToken),
        otp: (otp != null ? otp.value : this.otp));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeyCancelResponse {
  SystemRootkeyCancelResponse();

  factory SystemRootkeyCancelResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeyCancelResponseFromJson(json);

  static const fromJsonFactory = _$SystemRootkeyCancelResponseFromJson;
  static const toJsonFactory = _$SystemRootkeyCancelResponseToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeyCancelResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeyDecodeOptions {
  SystemRootkeyDecodeOptions({
    required this.otp,
    required this.encodedKey,
  });

  factory SystemRootkeyDecodeOptions.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeyDecodeOptionsFromJson(json);

  @JsonKey(name: 'otp', includeIfNull: false, defaultValue: '')
  final String otp;
  @JsonKey(name: 'encodedKey', includeIfNull: false, defaultValue: '')
  final String encodedKey;
  static const fromJsonFactory = _$SystemRootkeyDecodeOptionsFromJson;
  static const toJsonFactory = _$SystemRootkeyDecodeOptionsToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeyDecodeOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeyDecodeOptions &&
            (identical(other.otp, otp) ||
                const DeepCollectionEquality().equals(other.otp, otp)) &&
            (identical(other.encodedKey, encodedKey) ||
                const DeepCollectionEquality()
                    .equals(other.encodedKey, encodedKey)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(otp) ^
      const DeepCollectionEquality().hash(encodedKey) ^
      runtimeType.hashCode;
}

extension $SystemRootkeyDecodeOptionsExtension on SystemRootkeyDecodeOptions {
  SystemRootkeyDecodeOptions copyWith({String? otp, String? encodedKey}) {
    return SystemRootkeyDecodeOptions(
        otp: otp ?? this.otp, encodedKey: encodedKey ?? this.encodedKey);
  }

  SystemRootkeyDecodeOptions copyWithWrapped(
      {Wrapped<String>? otp, Wrapped<String>? encodedKey}) {
    return SystemRootkeyDecodeOptions(
        otp: (otp != null ? otp.value : this.otp),
        encodedKey: (encodedKey != null ? encodedKey.value : this.encodedKey));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeyDecodeResponse {
  SystemRootkeyDecodeResponse({
    required this.root,
  });

  factory SystemRootkeyDecodeResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeyDecodeResponseFromJson(json);

  @JsonKey(name: 'root', includeIfNull: false, defaultValue: '')
  final String root;
  static const fromJsonFactory = _$SystemRootkeyDecodeResponseFromJson;
  static const toJsonFactory = _$SystemRootkeyDecodeResponseToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeyDecodeResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeyDecodeResponse &&
            (identical(other.root, root) ||
                const DeepCollectionEquality().equals(other.root, root)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(root) ^ runtimeType.hashCode;
}

extension $SystemRootkeyDecodeResponseExtension on SystemRootkeyDecodeResponse {
  SystemRootkeyDecodeResponse copyWith({String? root}) {
    return SystemRootkeyDecodeResponse(root: root ?? this.root);
  }

  SystemRootkeyDecodeResponse copyWithWrapped({Wrapped<String>? root}) {
    return SystemRootkeyDecodeResponse(
        root: (root != null ? root.value : this.root));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeySubmitOptions {
  SystemRootkeySubmitOptions({
    this.key,
    this.nonce,
  });

  factory SystemRootkeySubmitOptions.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeySubmitOptionsFromJson(json);

  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String? key;
  @JsonKey(name: 'nonce', includeIfNull: false, defaultValue: '')
  final String? nonce;
  static const fromJsonFactory = _$SystemRootkeySubmitOptionsFromJson;
  static const toJsonFactory = _$SystemRootkeySubmitOptionsToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeySubmitOptionsToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeySubmitOptions &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.nonce, nonce) ||
                const DeepCollectionEquality().equals(other.nonce, nonce)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(nonce) ^
      runtimeType.hashCode;
}

extension $SystemRootkeySubmitOptionsExtension on SystemRootkeySubmitOptions {
  SystemRootkeySubmitOptions copyWith({String? key, String? nonce}) {
    return SystemRootkeySubmitOptions(
        key: key ?? this.key, nonce: nonce ?? this.nonce);
  }

  SystemRootkeySubmitOptions copyWithWrapped(
      {Wrapped<String?>? key, Wrapped<String?>? nonce}) {
    return SystemRootkeySubmitOptions(
        key: (key != null ? key.value : this.key),
        nonce: (nonce != null ? nonce.value : this.nonce));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemRootkeySubmitResponse {
  SystemRootkeySubmitResponse({
    required this.started,
    required this.nonce,
    required this.progress,
    required this.required,
    required this.pgpFingerprint,
    required this.complete,
    required this.encodedToken,
    required this.encodedRootToken,
    required this.otp,
    required this.otpLength,
  });

  factory SystemRootkeySubmitResponse.fromJson(Map<String, dynamic> json) =>
      _$SystemRootkeySubmitResponseFromJson(json);

  @JsonKey(name: 'started', includeIfNull: false)
  final bool started;
  @JsonKey(name: 'nonce', includeIfNull: false, defaultValue: '')
  final String nonce;
  @JsonKey(name: 'progress', includeIfNull: false)
  final double progress;
  @JsonKey(name: 'required', includeIfNull: false)
  final double required;
  @JsonKey(name: 'pgpFingerprint', includeIfNull: false, defaultValue: '')
  final String pgpFingerprint;
  @JsonKey(name: 'complete', includeIfNull: false)
  final bool complete;
  @JsonKey(name: 'encodedToken', includeIfNull: false, defaultValue: '')
  final String encodedToken;
  @JsonKey(name: 'encodedRootToken', includeIfNull: false, defaultValue: '')
  final String encodedRootToken;
  @JsonKey(name: 'otp', includeIfNull: false, defaultValue: '')
  final String otp;
  @JsonKey(name: 'otpLength', includeIfNull: false)
  final double otpLength;
  static const fromJsonFactory = _$SystemRootkeySubmitResponseFromJson;
  static const toJsonFactory = _$SystemRootkeySubmitResponseToJson;
  Map<String, dynamic> toJson() => _$SystemRootkeySubmitResponseToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemRootkeySubmitResponse &&
            (identical(other.started, started) ||
                const DeepCollectionEquality()
                    .equals(other.started, started)) &&
            (identical(other.nonce, nonce) ||
                const DeepCollectionEquality().equals(other.nonce, nonce)) &&
            (identical(other.progress, progress) ||
                const DeepCollectionEquality()
                    .equals(other.progress, progress)) &&
            (identical(other.required, required) ||
                const DeepCollectionEquality()
                    .equals(other.required, required)) &&
            (identical(other.pgpFingerprint, pgpFingerprint) ||
                const DeepCollectionEquality()
                    .equals(other.pgpFingerprint, pgpFingerprint)) &&
            (identical(other.complete, complete) ||
                const DeepCollectionEquality()
                    .equals(other.complete, complete)) &&
            (identical(other.encodedToken, encodedToken) ||
                const DeepCollectionEquality()
                    .equals(other.encodedToken, encodedToken)) &&
            (identical(other.encodedRootToken, encodedRootToken) ||
                const DeepCollectionEquality()
                    .equals(other.encodedRootToken, encodedRootToken)) &&
            (identical(other.otp, otp) ||
                const DeepCollectionEquality().equals(other.otp, otp)) &&
            (identical(other.otpLength, otpLength) ||
                const DeepCollectionEquality()
                    .equals(other.otpLength, otpLength)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(started) ^
      const DeepCollectionEquality().hash(nonce) ^
      const DeepCollectionEquality().hash(progress) ^
      const DeepCollectionEquality().hash(required) ^
      const DeepCollectionEquality().hash(pgpFingerprint) ^
      const DeepCollectionEquality().hash(complete) ^
      const DeepCollectionEquality().hash(encodedToken) ^
      const DeepCollectionEquality().hash(encodedRootToken) ^
      const DeepCollectionEquality().hash(otp) ^
      const DeepCollectionEquality().hash(otpLength) ^
      runtimeType.hashCode;
}

extension $SystemRootkeySubmitResponseExtension on SystemRootkeySubmitResponse {
  SystemRootkeySubmitResponse copyWith(
      {bool? started,
      String? nonce,
      double? progress,
      double? required,
      String? pgpFingerprint,
      bool? complete,
      String? encodedToken,
      String? encodedRootToken,
      String? otp,
      double? otpLength}) {
    return SystemRootkeySubmitResponse(
        started: started ?? this.started,
        nonce: nonce ?? this.nonce,
        progress: progress ?? this.progress,
        required: required ?? this.required,
        pgpFingerprint: pgpFingerprint ?? this.pgpFingerprint,
        complete: complete ?? this.complete,
        encodedToken: encodedToken ?? this.encodedToken,
        encodedRootToken: encodedRootToken ?? this.encodedRootToken,
        otp: otp ?? this.otp,
        otpLength: otpLength ?? this.otpLength);
  }

  SystemRootkeySubmitResponse copyWithWrapped(
      {Wrapped<bool>? started,
      Wrapped<String>? nonce,
      Wrapped<double>? progress,
      Wrapped<double>? required,
      Wrapped<String>? pgpFingerprint,
      Wrapped<bool>? complete,
      Wrapped<String>? encodedToken,
      Wrapped<String>? encodedRootToken,
      Wrapped<String>? otp,
      Wrapped<double>? otpLength}) {
    return SystemRootkeySubmitResponse(
        started: (started != null ? started.value : this.started),
        nonce: (nonce != null ? nonce.value : this.nonce),
        progress: (progress != null ? progress.value : this.progress),
        required: (required != null ? required.value : this.required),
        pgpFingerprint: (pgpFingerprint != null
            ? pgpFingerprint.value
            : this.pgpFingerprint),
        complete: (complete != null ? complete.value : this.complete),
        encodedToken:
            (encodedToken != null ? encodedToken.value : this.encodedToken),
        encodedRootToken: (encodedRootToken != null
            ? encodedRootToken.value
            : this.encodedRootToken),
        otp: (otp != null ? otp.value : this.otp),
        otpLength: (otpLength != null ? otpLength.value : this.otpLength));
  }
}

@JsonSerializable(explicitToJson: true)
class SecretsReadResponse$Metadata {
  SecretsReadResponse$Metadata({
    this.createdTime,
    this.deletionTime,
    this.destroyed,
    this.version,
  });

  factory SecretsReadResponse$Metadata.fromJson(Map<String, dynamic> json) =>
      _$SecretsReadResponse$MetadataFromJson(json);

  @JsonKey(name: 'createdTime', includeIfNull: false, defaultValue: '')
  final String? createdTime;
  @JsonKey(name: 'deletionTime', includeIfNull: false, defaultValue: '')
  final String? deletionTime;
  @JsonKey(name: 'destroyed', includeIfNull: false)
  final bool? destroyed;
  @JsonKey(name: 'version', includeIfNull: false)
  final double? version;
  static const fromJsonFactory = _$SecretsReadResponse$MetadataFromJson;
  static const toJsonFactory = _$SecretsReadResponse$MetadataToJson;
  Map<String, dynamic> toJson() => _$SecretsReadResponse$MetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SecretsReadResponse$Metadata &&
            (identical(other.createdTime, createdTime) ||
                const DeepCollectionEquality()
                    .equals(other.createdTime, createdTime)) &&
            (identical(other.deletionTime, deletionTime) ||
                const DeepCollectionEquality()
                    .equals(other.deletionTime, deletionTime)) &&
            (identical(other.destroyed, destroyed) ||
                const DeepCollectionEquality()
                    .equals(other.destroyed, destroyed)) &&
            (identical(other.version, version) ||
                const DeepCollectionEquality().equals(other.version, version)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(createdTime) ^
      const DeepCollectionEquality().hash(deletionTime) ^
      const DeepCollectionEquality().hash(destroyed) ^
      const DeepCollectionEquality().hash(version) ^
      runtimeType.hashCode;
}

extension $SecretsReadResponse$MetadataExtension
    on SecretsReadResponse$Metadata {
  SecretsReadResponse$Metadata copyWith(
      {String? createdTime,
      String? deletionTime,
      bool? destroyed,
      double? version}) {
    return SecretsReadResponse$Metadata(
        createdTime: createdTime ?? this.createdTime,
        deletionTime: deletionTime ?? this.deletionTime,
        destroyed: destroyed ?? this.destroyed,
        version: version ?? this.version);
  }

  SecretsReadResponse$Metadata copyWithWrapped(
      {Wrapped<String?>? createdTime,
      Wrapped<String?>? deletionTime,
      Wrapped<bool?>? destroyed,
      Wrapped<double?>? version}) {
    return SecretsReadResponse$Metadata(
        createdTime:
            (createdTime != null ? createdTime.value : this.createdTime),
        deletionTime:
            (deletionTime != null ? deletionTime.value : this.deletionTime),
        destroyed: (destroyed != null ? destroyed.value : this.destroyed),
        version: (version != null ? version.value : this.version));
  }
}

@JsonSerializable(explicitToJson: true)
class LoginResponse$Meta {
  LoginResponse$Meta({
    this.username,
  });

  factory LoginResponse$Meta.fromJson(Map<String, dynamic> json) =>
      _$LoginResponse$MetaFromJson(json);

  @JsonKey(name: 'username', includeIfNull: false, defaultValue: '')
  final String? username;
  static const fromJsonFactory = _$LoginResponse$MetaFromJson;
  static const toJsonFactory = _$LoginResponse$MetaToJson;
  Map<String, dynamic> toJson() => _$LoginResponse$MetaToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LoginResponse$Meta &&
            (identical(other.username, username) ||
                const DeepCollectionEquality()
                    .equals(other.username, username)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(username) ^ runtimeType.hashCode;
}

extension $LoginResponse$MetaExtension on LoginResponse$Meta {
  LoginResponse$Meta copyWith({String? username}) {
    return LoginResponse$Meta(username: username ?? this.username);
  }

  LoginResponse$Meta copyWithWrapped({Wrapped<String?>? username}) {
    return LoginResponse$Meta(
        username: (username != null ? username.value : this.username));
  }
}

@JsonSerializable(explicitToJson: true)
class PolicyTemplate$Metadata {
  PolicyTemplate$Metadata({
    this.path,
  });

  factory PolicyTemplate$Metadata.fromJson(Map<String, dynamic> json) =>
      _$PolicyTemplate$MetadataFromJson(json);

  @JsonKey(name: 'path', includeIfNull: false)
  final PolicyPath? path;
  static const fromJsonFactory = _$PolicyTemplate$MetadataFromJson;
  static const toJsonFactory = _$PolicyTemplate$MetadataToJson;
  Map<String, dynamic> toJson() => _$PolicyTemplate$MetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is PolicyTemplate$Metadata &&
            (identical(other.path, path) ||
                const DeepCollectionEquality().equals(other.path, path)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(path) ^ runtimeType.hashCode;
}

extension $PolicyTemplate$MetadataExtension on PolicyTemplate$Metadata {
  PolicyTemplate$Metadata copyWith({PolicyPath? path}) {
    return PolicyTemplate$Metadata(path: path ?? this.path);
  }

  PolicyTemplate$Metadata copyWithWrapped({Wrapped<PolicyPath?>? path}) {
    return PolicyTemplate$Metadata(
        path: (path != null ? path.value : this.path));
  }
}

@JsonSerializable(explicitToJson: true)
class OidcProviderOptions$Metadata {
  OidcProviderOptions$Metadata({
    this.config,
  });

  factory OidcProviderOptions$Metadata.fromJson(Map<String, dynamic> json) =>
      _$OidcProviderOptions$MetadataFromJson(json);

  @JsonKey(name: 'config', includeIfNull: false)
  final OidcProviderConfig? config;
  static const fromJsonFactory = _$OidcProviderOptions$MetadataFromJson;
  static const toJsonFactory = _$OidcProviderOptions$MetadataToJson;
  Map<String, dynamic> toJson() => _$OidcProviderOptions$MetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OidcProviderOptions$Metadata &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(config) ^ runtimeType.hashCode;
}

extension $OidcProviderOptions$MetadataExtension
    on OidcProviderOptions$Metadata {
  OidcProviderOptions$Metadata copyWith({OidcProviderConfig? config}) {
    return OidcProviderOptions$Metadata(config: config ?? this.config);
  }

  OidcProviderOptions$Metadata copyWithWrapped(
      {Wrapped<OidcProviderConfig?>? config}) {
    return OidcProviderOptions$Metadata(
        config: (config != null ? config.value : this.config));
  }
}

@JsonSerializable(explicitToJson: true)
class SamlProviderMetadata$Config {
  SamlProviderMetadata$Config({
    this.url,
  });

  factory SamlProviderMetadata$Config.fromJson(Map<String, dynamic> json) =>
      _$SamlProviderMetadata$ConfigFromJson(json);

  @JsonKey(name: 'url', includeIfNull: false, defaultValue: '')
  final String? url;
  static const fromJsonFactory = _$SamlProviderMetadata$ConfigFromJson;
  static const toJsonFactory = _$SamlProviderMetadata$ConfigToJson;
  Map<String, dynamic> toJson() => _$SamlProviderMetadata$ConfigToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SamlProviderMetadata$Config &&
            (identical(other.url, url) ||
                const DeepCollectionEquality().equals(other.url, url)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(url) ^ runtimeType.hashCode;
}

extension $SamlProviderMetadata$ConfigExtension on SamlProviderMetadata$Config {
  SamlProviderMetadata$Config copyWith({String? url}) {
    return SamlProviderMetadata$Config(url: url ?? this.url);
  }

  SamlProviderMetadata$Config copyWithWrapped({Wrapped<String?>? url}) {
    return SamlProviderMetadata$Config(
        url: (url != null ? url.value : this.url));
  }
}

@JsonSerializable(explicitToJson: true)
class KerberosProviderOptions$Metadata {
  KerberosProviderOptions$Metadata({
    this.ldapConfig,
    this.config,
  });

  factory KerberosProviderOptions$Metadata.fromJson(
          Map<String, dynamic> json) =>
      _$KerberosProviderOptions$MetadataFromJson(json);

  @JsonKey(name: 'ldapConfig', includeIfNull: false)
  final KerberosProviderConfigLdap? ldapConfig;
  @JsonKey(name: 'config', includeIfNull: false)
  final KerberosProviderConfig? config;
  static const fromJsonFactory = _$KerberosProviderOptions$MetadataFromJson;
  static const toJsonFactory = _$KerberosProviderOptions$MetadataToJson;
  Map<String, dynamic> toJson() =>
      _$KerberosProviderOptions$MetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is KerberosProviderOptions$Metadata &&
            (identical(other.ldapConfig, ldapConfig) ||
                const DeepCollectionEquality()
                    .equals(other.ldapConfig, ldapConfig)) &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ldapConfig) ^
      const DeepCollectionEquality().hash(config) ^
      runtimeType.hashCode;
}

extension $KerberosProviderOptions$MetadataExtension
    on KerberosProviderOptions$Metadata {
  KerberosProviderOptions$Metadata copyWith(
      {KerberosProviderConfigLdap? ldapConfig,
      KerberosProviderConfig? config}) {
    return KerberosProviderOptions$Metadata(
        ldapConfig: ldapConfig ?? this.ldapConfig,
        config: config ?? this.config);
  }

  KerberosProviderOptions$Metadata copyWithWrapped(
      {Wrapped<KerberosProviderConfigLdap?>? ldapConfig,
      Wrapped<KerberosProviderConfig?>? config}) {
    return KerberosProviderOptions$Metadata(
        ldapConfig: (ldapConfig != null ? ldapConfig.value : this.ldapConfig),
        config: (config != null ? config.value : this.config));
  }
}

@JsonSerializable(explicitToJson: true)
class LdapProviderOptions$Metadata {
  LdapProviderOptions$Metadata({
    this.config,
  });

  factory LdapProviderOptions$Metadata.fromJson(Map<String, dynamic> json) =>
      _$LdapProviderOptions$MetadataFromJson(json);

  @JsonKey(name: 'config', includeIfNull: false)
  final LdapProviderConfig? config;
  static const fromJsonFactory = _$LdapProviderOptions$MetadataFromJson;
  static const toJsonFactory = _$LdapProviderOptions$MetadataToJson;
  Map<String, dynamic> toJson() => _$LdapProviderOptions$MetadataToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is LdapProviderOptions$Metadata &&
            (identical(other.config, config) ||
                const DeepCollectionEquality().equals(other.config, config)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(config) ^ runtimeType.hashCode;
}

extension $LdapProviderOptions$MetadataExtension
    on LdapProviderOptions$Metadata {
  LdapProviderOptions$Metadata copyWith({LdapProviderConfig? config}) {
    return LdapProviderOptions$Metadata(config: config ?? this.config);
  }

  LdapProviderOptions$Metadata copyWithWrapped(
      {Wrapped<LdapProviderConfig?>? config}) {
    return LdapProviderOptions$Metadata(
        config: (config != null ? config.value : this.config));
  }
}

@JsonSerializable(explicitToJson: true)
class SystemStatusResponse$Build {
  SystemStatusResponse$Build({
    this.hash,
    this.buildDate,
    this.branch,
  });

  factory SystemStatusResponse$Build.fromJson(Map<String, dynamic> json) =>
      _$SystemStatusResponse$BuildFromJson(json);

  @JsonKey(name: 'hash', includeIfNull: false, defaultValue: '')
  final String? hash;
  @JsonKey(name: 'buildDate', includeIfNull: false, defaultValue: '')
  final String? buildDate;
  @JsonKey(name: 'branch', includeIfNull: false, defaultValue: '')
  final String? branch;
  static const fromJsonFactory = _$SystemStatusResponse$BuildFromJson;
  static const toJsonFactory = _$SystemStatusResponse$BuildToJson;
  Map<String, dynamic> toJson() => _$SystemStatusResponse$BuildToJson(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SystemStatusResponse$Build &&
            (identical(other.hash, hash) ||
                const DeepCollectionEquality().equals(other.hash, hash)) &&
            (identical(other.buildDate, buildDate) ||
                const DeepCollectionEquality()
                    .equals(other.buildDate, buildDate)) &&
            (identical(other.branch, branch) ||
                const DeepCollectionEquality().equals(other.branch, branch)));
  }

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(hash) ^
      const DeepCollectionEquality().hash(buildDate) ^
      const DeepCollectionEquality().hash(branch) ^
      runtimeType.hashCode;
}

extension $SystemStatusResponse$BuildExtension on SystemStatusResponse$Build {
  SystemStatusResponse$Build copyWith(
      {String? hash, String? buildDate, String? branch}) {
    return SystemStatusResponse$Build(
        hash: hash ?? this.hash,
        buildDate: buildDate ?? this.buildDate,
        branch: branch ?? this.branch);
  }

  SystemStatusResponse$Build copyWithWrapped(
      {Wrapped<String?>? hash,
      Wrapped<String?>? buildDate,
      Wrapped<String?>? branch}) {
    return SystemStatusResponse$Build(
        hash: (hash != null ? hash.value : this.hash),
        buildDate: (buildDate != null ? buildDate.value : this.buildDate),
        branch: (branch != null ? branch.value : this.branch));
  }
}

String? policyTypeToJson(enums.PolicyType? policyType) {
  return enums.$PolicyTypeMap[policyType];
}

enums.PolicyType policyTypeFromJson(
  Object? policyType, [
  enums.PolicyType? defaultValue,
]) {
  if (policyType is String) {
    return enums.$PolicyTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == policyType.toLowerCase(),
            orElse: () =>
                const MapEntry(enums.PolicyType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PolicyTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PolicyType.swaggerGeneratedUnknown;
}

List<String> policyTypeListToJson(List<enums.PolicyType>? policyType) {
  if (policyType == null) {
    return [];
  }

  return policyType.map((e) => enums.$PolicyTypeMap[e]!).toList();
}

List<enums.PolicyType> policyTypeListFromJson(
  List? policyType, [
  List<enums.PolicyType>? defaultValue,
]) {
  if (policyType == null) {
    return defaultValue ?? [];
  }

  return policyType.map((e) => policyTypeFromJson(e.toString())).toList();
}

List<enums.PolicyType>? policyTypeNullableListFromJson(
  List? policyType, [
  List<enums.PolicyType>? defaultValue,
]) {
  if (policyType == null) {
    return defaultValue;
  }

  return policyType.map((e) => policyTypeFromJson(e.toString())).toList();
}

String? policyUpdateOptionsTypeToJson(
    enums.PolicyUpdateOptionsType? policyUpdateOptionsType) {
  return enums.$PolicyUpdateOptionsTypeMap[policyUpdateOptionsType];
}

enums.PolicyUpdateOptionsType policyUpdateOptionsTypeFromJson(
  Object? policyUpdateOptionsType, [
  enums.PolicyUpdateOptionsType? defaultValue,
]) {
  if (policyUpdateOptionsType is String) {
    return enums.$PolicyUpdateOptionsTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                policyUpdateOptionsType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PolicyUpdateOptionsType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PolicyUpdateOptionsTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PolicyUpdateOptionsType.swaggerGeneratedUnknown;
}

List<String> policyUpdateOptionsTypeListToJson(
    List<enums.PolicyUpdateOptionsType>? policyUpdateOptionsType) {
  if (policyUpdateOptionsType == null) {
    return [];
  }

  return policyUpdateOptionsType
      .map((e) => enums.$PolicyUpdateOptionsTypeMap[e]!)
      .toList();
}

List<enums.PolicyUpdateOptionsType> policyUpdateOptionsTypeListFromJson(
  List? policyUpdateOptionsType, [
  List<enums.PolicyUpdateOptionsType>? defaultValue,
]) {
  if (policyUpdateOptionsType == null) {
    return defaultValue ?? [];
  }

  return policyUpdateOptionsType
      .map((e) => policyUpdateOptionsTypeFromJson(e.toString()))
      .toList();
}

List<enums.PolicyUpdateOptionsType>?
    policyUpdateOptionsTypeNullableListFromJson(
  List? policyUpdateOptionsType, [
  List<enums.PolicyUpdateOptionsType>? defaultValue,
]) {
  if (policyUpdateOptionsType == null) {
    return defaultValue;
  }

  return policyUpdateOptionsType
      .map((e) => policyUpdateOptionsTypeFromJson(e.toString()))
      .toList();
}

String? policyCreateOptionsTypeToJson(
    enums.PolicyCreateOptionsType? policyCreateOptionsType) {
  return enums.$PolicyCreateOptionsTypeMap[policyCreateOptionsType];
}

enums.PolicyCreateOptionsType policyCreateOptionsTypeFromJson(
  Object? policyCreateOptionsType, [
  enums.PolicyCreateOptionsType? defaultValue,
]) {
  if (policyCreateOptionsType is String) {
    return enums.$PolicyCreateOptionsTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                policyCreateOptionsType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PolicyCreateOptionsType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PolicyCreateOptionsTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PolicyCreateOptionsType.swaggerGeneratedUnknown;
}

List<String> policyCreateOptionsTypeListToJson(
    List<enums.PolicyCreateOptionsType>? policyCreateOptionsType) {
  if (policyCreateOptionsType == null) {
    return [];
  }

  return policyCreateOptionsType
      .map((e) => enums.$PolicyCreateOptionsTypeMap[e]!)
      .toList();
}

List<enums.PolicyCreateOptionsType> policyCreateOptionsTypeListFromJson(
  List? policyCreateOptionsType, [
  List<enums.PolicyCreateOptionsType>? defaultValue,
]) {
  if (policyCreateOptionsType == null) {
    return defaultValue ?? [];
  }

  return policyCreateOptionsType
      .map((e) => policyCreateOptionsTypeFromJson(e.toString()))
      .toList();
}

List<enums.PolicyCreateOptionsType>?
    policyCreateOptionsTypeNullableListFromJson(
  List? policyCreateOptionsType, [
  List<enums.PolicyCreateOptionsType>? defaultValue,
]) {
  if (policyCreateOptionsType == null) {
    return defaultValue;
  }

  return policyCreateOptionsType
      .map((e) => policyCreateOptionsTypeFromJson(e.toString()))
      .toList();
}

String? policyTemplateTypeToJson(enums.PolicyTemplateType? policyTemplateType) {
  return enums.$PolicyTemplateTypeMap[policyTemplateType];
}

enums.PolicyTemplateType policyTemplateTypeFromJson(
  Object? policyTemplateType, [
  enums.PolicyTemplateType? defaultValue,
]) {
  if (policyTemplateType is String) {
    return enums.$PolicyTemplateTypeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() == policyTemplateType.toLowerCase(),
            orElse: () => const MapEntry(
                enums.PolicyTemplateType.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$PolicyTemplateTypeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.PolicyTemplateType.swaggerGeneratedUnknown;
}

List<String> policyTemplateTypeListToJson(
    List<enums.PolicyTemplateType>? policyTemplateType) {
  if (policyTemplateType == null) {
    return [];
  }

  return policyTemplateType
      .map((e) => enums.$PolicyTemplateTypeMap[e]!)
      .toList();
}

List<enums.PolicyTemplateType> policyTemplateTypeListFromJson(
  List? policyTemplateType, [
  List<enums.PolicyTemplateType>? defaultValue,
]) {
  if (policyTemplateType == null) {
    return defaultValue ?? [];
  }

  return policyTemplateType
      .map((e) => policyTemplateTypeFromJson(e.toString()))
      .toList();
}

List<enums.PolicyTemplateType>? policyTemplateTypeNullableListFromJson(
  List? policyTemplateType, [
  List<enums.PolicyTemplateType>? defaultValue,
]) {
  if (policyTemplateType == null) {
    return defaultValue;
  }

  return policyTemplateType
      .map((e) => policyTemplateTypeFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  FutureOr<chopper.Response<ResultType>> convertResponse<ResultType, Item>(
      chopper.Response response) async {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = await super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}

class Wrapped<T> {
  final T value;
  const Wrapped.value(this.value);
}
